(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     66361,       2327]*)
(*NotebookOutlinePosition[     92322,       3121]*)
(*  CellTagsIndexPosition[     91214,       3073]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Appendix B", "ChapterLine",
  CellTags->"B.0"],

Cell["List and Matrix Essentials", "Title",
  CellTags->"B.0"],

Cell[TextData[{
  "In this appendix, we discuss some ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions that are useful for manipulating and analyzing lists and their \
contents. The techniques used here focus on examples from this book."
}], "Text",
  CellTags->"B.0"],

Cell[CellGroupData[{

Cell["B.1  List Manipulation", "Section",
  CellTags->"B.1"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function List is used to gather expressions together, similar to the way \
an egg carton can be used to gather eggs together, but can also be used to \
hold paper clips or rubber bands. We've already seen simple examples of \
Lists, which are just sequences of expressions wrapped in \"curly brackets\" \
(\"{\" and \"}\")",
  ". ",
  "The FullForm of one of those examples shows that it is an expression with \
the head List."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:1", "IndexEntries" -> {{
    "list manipulation", "", ""}}},
  CellTags->{"i:1", "B.1"}],

Cell[CellGroupData[{

Cell["FullForm[{Head[Plus], Head[\"Simulating Society\"], Head[51]}]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    TagBox[
      StyleBox[\(List[Symbol, String, Integer]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True],
      FullForm]], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
Any expression can be an argument to List, including another List. \
Thus, List can be used to store linear one-dimensional lists, two-dimensional \
matrices of expressions, matrices of arbitrary dimensions, or a mixture of \
lists and other expressions. This allows flexible grouping and storing of \
data, as well as myriad ways of rearranging and analyzing those data. \
Manipulating matrices is discussed in the next section, but here we focus on \
one-dimensional lists. Throughout this section, we use the following example.\
\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["person = {3, 1, 1, {2, 3, 4}, 4}", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({3, 1, 1, {2, 3, 4}, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
This list is taken from Chapter 1, where it represents a typical \
individual in our simulations. Each element of the list can be interpreted as \
storing a piece of information about the individual. We interpret the \
preceding individual in the following way.\
\>", "Text",
  CellTags->"B.1"],

Cell["\<\
The first element in the list (3) represents the direction in which \
the individual is facing, which is used to determine his movement at a given \
moment.\
\>", "BulletListItem",
  CellTags->"B.1"],

Cell["\<\
The second element (1) represents the name of the individual, \
allowing us to distinguish him from other individuals during the simulation, \
or keep track of him over time.\
\>", "BulletListItem",
  CellTags->"B.1"],

Cell["\<\
The third element (1) determines how the individual interacts with \
others at a given moment. For instance, a value of zero may mean that the \
individual's behavior is bad, whereas a value of one may mean that his \
behavior is good.\
\>", "BulletListItem",
  CellTags->"B.1"],

Cell[TextData[{
  "The fourth element of the list is itself a list, representing either fixed \
or changeable values or attitudes of the individual. This list is referred to \
in the book as the individual's ",
  StyleBox["meme",
    FontSlant->"Italic"],
  " list. Each position in the meme list holds the numerical value of a \
particular attribute. For instance, the first element of the list might refer \
to race, with different numbers corresponding to different races. Other \
possible interpretations include religion, IQ, height, or political loyalty."
}], "BulletListItem",
  CellTags->"B.1"],

Cell["\<\
The last element in the list (4) represents the accumulated \
resources of the individual. These resources can be material in nature (such \
as an accumulation of money or property) or nonmaterial (such as \
psychological or social distinctions).\
\>", "BulletListItem",
  CellTags->"B.1"],

Cell["\<\
In the matrix manipulation section later, we discuss how to \
generate a random individual with this given format, and also how to generate \
a society with a given population density of such individuals.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["B.1.1  Table", "Subsection",
  CellTags->"B.1"],

Cell[TextData[{
  "One of the most basic list creation commands available in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is the Table command. There are many ways to call the Table command, but \
the most basic one creates a list of ",
  StyleBox["n", "IT"],
  " identical elements. We use ",
  StyleBox["n", "IT"],
  " = 5 for a concrete example."
}], "Text",
  CellTags->{"i:2", "B.1"}],

Cell[CellGroupData[{

Cell["n = 5; Table[0, {n}]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({0, 0, 0, 0, 0}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell[TextData[{
  "The {",
  StyleBox["n", "IT"],
  "} is called an ",
  StyleBox["iterator",
    FontSlant->"Italic"],
  " for the Table. Table can generate a list of lists \[LongDash] that is, a \
list whose elements are themselves lists \[LongDash] by specifying more than \
one iterator. Here is an example of a list that has ",
  StyleBox["n", "IT"],
  " elements, each of which is a list of ",
  StyleBox["n", "IT"],
  " zeros. (This is an \"",
  StyleBox["n", "IT"],
  " by ",
  StyleBox["n", "IT"],
  "\" square matrix.)"
}], "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["n = 5; Table[0, {n}, {n}]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {
        0, 0, 0, 0, 0}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
The primary use of Table in our simulations is to create a society \
(a two-dimensional matrix containing individuals and empty sites) with \
certain characteristics. We discuss this more fully in the following matrix \
manipulation section.\
\>", "Text",
  CellTags->"B.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.1.2  Extracting Information from a List", "Subsection",
  CellTags->"B.1"],

Cell["\<\
There are a number of functions that allow us to examine a list. \
For example, we can find out the number of elements in a list using the \
built-in Length function. Recall our previously defined person.\
\>", "Text",
  CellTags->{"i:3", "B.1"}],

Cell[CellGroupData[{

Cell["person", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({3, 1, 1, {2, 3, 4}, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
This list has five elements, and so Length[person] returns 5.\
\>", 
  "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["Length[person]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \(5\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
There are also ways to extract a particular element or elements of \
a list. The functions First and Last extract the first or last element of a \
list, respectively, and Rest returns a list with the first element dropped. \
For instance, we can extract the resource level of our individual and the \
direction that the individual is facing with the following bit of code.\
\>", 
  "Text",
  CellTags->{"i:4", "B.1"}],

Cell[CellGroupData[{

Cell["{Last[person], First[person]}", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({4, 3}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell[TextData[{
  "To extract the individual's meme list, which is neither the first nor last \
element of the list, we need to use the built-in Part function. To extract \
the ",
  StyleBox["i", "IT"],
  "th element of a list ",
  StyleBox["lis", "IT"],
  " (or of any expression), we ask for Part[",
  StyleBox["lis", "IT"],
  ", ",
  StyleBox["i", "IT"],
  "]. This can also be written ",
  StyleBox["lis", "IT"],
  "[[",
  StyleBox["i", "IT"],
  "]]. In particular, the meme list is the fourth element of the individual's \
list."
}], "Text",
  CellTags->{"i:5", "B.1"}],

Cell[CellGroupData[{

Cell["person[[4]]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({2, 3, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
If you give a negative number as the second argument to Part, the \
positions are counted starting at the end of the list. In the case of our \
individual, the fourth element in the list is the same as the minus-second \
element.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["person[[-2]]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({2, 3, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
We can take this same notation one step further to extract the \
second element of the meme list. Extracting expressions from arbitrary \
matrices is discussed in the matrix manipulation section.\
\>", "Text",
  CellTags->"B.1"],

Cell["\<\
In cases where you know which element of the list you want to \
extract, Part works well. However, there are times when you need to figure \
out which elements satisfy some condition that you specify, or match a \
pattern that you give. For example, the Position function takes an expression \
and a pattern, and returns all positions within the list where the pattern \
finds a matching expression. For example, we can search our sample individual \
for all occurrences of the number 1.\
\>", "Text",
  CellTags->{"i:6", "B.1"}],

Cell[CellGroupData[{

Cell["person", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({3, 1, 1, {2, 3, 4}, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Position[person, 1]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{2}, {3}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
So the number 1 appears as the second element of person, and again \
as the third element. We show why there is an extra set of list braces around \
each position in the matrix manipulation section. We also show how to \
interpret the result of Position when it locates an expression that is nested \
within an element of the list, as in this example.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["Position[person, 3]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{1}, {4, 2}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
Here, we use Position to begin understanding the contents of the \
individual's meme list, obtaining a list of positions that hold values less \
than four.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["Position[person[[4]], _?(# < 4&)]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{1}, {2}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.1.3  Select, Cases, and Count", "Subsection",
  CellTags->"B.1"],

Cell["\<\
Three other functions for extracting information out of lists are \
Select, Cases, and Count. Select uses the list as its first argument, and a \
(predicate) function as the second argument (usually an anonymous function). \
The output is a list that contains only those elements that cause the \
function to return True. Note that this is different from Position, which \
only returned a list of positions and not a list of elements. For instance, \
recall the example individual.\
\>", "Text",
  CellTags->{"i:7", "B.1"}],

Cell[CellGroupData[{

Cell["person", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({3, 1, 1, {2, 3, 4}, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
Even without knowing where the meme list is in the individual's \
list, we can use Select to obtain a list of all the elements that have head \
List.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["Select[person, (Head[#] === List &)]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{2, 3, 4}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
If we are looking only for individuals whose meme list satisfies \
some condition, such as those whose first element is a 5, it's possible that \
Select will find no elements. In this case, it returns an empty list.\
\>", 
  "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["Select[person, (MatchQ[#, {5, ___}]&)]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
The function Cases is also used to extract elements from a list, \
but it does so using pattern-matching. Any element of the list that matches \
the specified pattern is returned.\
\>", "Text",
  CellTags->{"i:8", "B.1"}],

Cell[CellGroupData[{

Cell["Cases[person, _List]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{2, 3, 4}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
The second argument to Cases can also be a replacement rule that \
will transform expressions that are picked out of the list in whatever way \
you specify. For instance, you could extract every sublist from a given list, \
computing each sublist's average as you do so. The calculation that computes \
the average uses the Apply function, which is discussed later in this \
appendix.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell[TextData[
"Cases[person, x_List \[RuleDelayed] Apply[Plus, x]/Length[x]]"], "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({3}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
The function Count works much like Cases in that it uses \
pattern-matching to obtain a result. However, instead of returning a list of \
elements, it simply returns the number of elements found to match the given \
pattern.\
\>", "Text",
  CellTags->{"i:9", "B.1"}],

Cell[CellGroupData[{

Cell["Count[person, _List]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \(1\)], "Output",
  CellTags->"B.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.1.4  Rearranging Lists", "Subsection",
  CellTags->"B.1"],

Cell[TextData[{
  "Rearranging lists is something that can be done easily and elegantly in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". For instance, a common way to reorganize a list is to sort it",
  ". ",
  "The built-in Sort function does this."
}], "Text",
  CellTags->{"i:10", "B.1"}],

Cell[CellGroupData[{

Cell["lis = {1, -2, 3, -4, 5, -6, 0}; Sort[lis]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({\(-6\), \(-4\), \(-2\), 0, 1, 3, 5}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
By default, Sort orders elements using the built-in Less (<) \
operator. However, we can provide any function of two arguments to be used as \
a sorting function by specifying it as the second argument to Sort. That \
sorting function is applied to pairs of elements from the list to rearrange \
them into the new order. For instance, this sorting function puts numbers \
with a larger absolute value first.\
\>", "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{

Cell["Sort[lis, (Abs[#1] > Abs[#2] &)]", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({\(-6\), 5, \(-4\), 3, \(-2\), 1, 0}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell["\<\
In the next section we show how Sort can be used to obtain from a \
simulation a list of individuals who have cultural values or other attributes \
in common.\
\>", "Text",
  CellTags->"B.1"],

Cell["\<\
Also useful is the ability to rotate a list, effectively moving \
either the first or the last element to the other end of the list. The \
functions that do this are RotateLeft and RotateRight, respectively. These \
functions also take a second argument that dictates how many elements should \
be rotated in this way. A negative second argument is interpreted as a \
rotation in the opposite direction.\
\>", "Text",
  CellTags->{"i:11", "B.1"}],

Cell[CellGroupData[{

Cell["person", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({3, 1, 1, {2, 3, 4}, 4}\)], "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["{RotateLeft[person], RotateRight[person, 3]}", "Input",
  CellTags->"B.1"],

Cell[BoxData[
    \({{1, 1, {2, 3, 4}, 4, 3}, {1, {2, 3, 4}, 4, 3, 1}}\)], "Output",
  CellTags->"B.1"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.2  Matrix Manipulation", "Section",
  CellTags->"B.2"],

Cell["\<\
We've used the basic list manipulation functions in conjunction \
with one-dimensional lists. We now use them for more complicated nested \
lists. There are additional features of most of these functions to allow one \
to handle such nested lists easily and efficiently.\
\>", "Text",
  CellTags->{"i:12", "B.2"}],

Cell["\<\
For the remainder of this section, we use the following nested list \
to demonstrate the majority of the functions.\
\>", "Text",
  CellTags->"B.2"],

Cell["\<\
society = {{0, 0, 0, {3, 1, 1, {2, 3, 4}, 4}}, {0, {3, 2, 1, {4, 3, \
3}, 3}, {2, 3, 1, {4, 3, 4}, 1}, {2, 4, 1, {5, 3, 1}, 3}}, {0, {1, 5, 1, {5, \
3, 5}, 2}, 0, {1, 6, 0, {2, 1, 5}, 4}}, {0, 0, 0, {4, 7, 1, {4, 5, 5}, \
3}}};\
\>", "Input",
  CellTags->"B.2"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can display this formatted as a two-dimensional matrix (instead of as a \
list of lists) if we ask for the TraditionalForm of the matrix."
}], "Text",
  CellTags->{"i:13", "B.2"}],

Cell[CellGroupData[{

Cell["TraditionalForm[society]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "This ",
  StyleBox["society", "IT"],
  " matrix is taken from Chapter 1, and is exactly the kind of matrix or ",
  StyleBox["lattice",
    FontSlant->"Italic"],
  " that appears throughout this book. In particular, it is a matrix that has \
the same number of rows (4) as columns (4), where the elements of the rows or \
",
  StyleBox["sites",
    FontSlant->"Italic"],
  " are either empty or occupied by an individual. Empty sites are \
represented by a zero, and occupied sites contain a list in which is stored \
all the information we have about the individual. Analysis of a particular \
individual's list was the basis for the previous section. Notice that the \
example individual from the previous section is in the first row of this \
society example."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["B.2.1  Building Society", "Subsection",
  CellTags->"B.2"],

Cell[TextData[{
  "The example matrix defined previously was actually created by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " using a set of instructions in Chapter 1. In this section, we describe \
those instructions and show exactly how that matrix was created."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["Random and SeedRandom", "Subsubsection",
  CellTags->"B.2"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has a built-in function Random that can generate various sorts of random \
numbers. Random[] returns a random real number between 0 and 1. Random[",
  StyleBox["type", "IT"],
  ", {",
  StyleBox["min", "IT"],
  ", ",
  StyleBox["max", "IT"],
  "}] generates a random number of the specified ",
  StyleBox["type", "IT"],
  " between ",
  StyleBox["min", "IT"],
  " and ",
  StyleBox["max", "IT"],
  ". For example, here's an important function that is used throughout the \
book."
}], "Text",
  CellTags->{"i:14", "B.2"}],

Cell[CellGroupData[{

Cell["\<\
RND := Random[Integer, {1, 4}]
Table[RND, {10}]\
\>", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({3, 2, 1, 4, 2, 2, 2, 1, 2, 4}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
This RND function returns a random integer between one and four \
inclusive, which is used in deciding the direction an individual faces and \
moves.\
\>", "Text",
  CellTags->"B.2"],

Cell[TextData[{
  "As with any computer language, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not generate truly random numbers; rather, it uses some algorithm to \
generate a sequence of numbers that seem random. (For implementation details \
regarding ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s random number generator, see the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book.)",
  " ",
  "It is sometimes useful to be able to generate the same sequence of random \
numbers over and over. For instance, this would make it possible to begin a \
simulation with the same random initial lattice configuration each time it \
was run."
}], "Text",
  CellTags->"B.2"],

Cell["\<\
One way to do this is by using SeedRandom, which supplies the \
pseudorandom number generation algorithm with a seed or starting value. At \
any point in any kernel session, you can then put the random number generator \
into the same state by providing the same value to SeedRandom. For example, \
notice that the outputs for the next two inputs are identical.\
\>", "Text",
  CellTags->{"i:15", "B.2"}],

Cell[CellGroupData[{

Cell["SeedRandom[0]; Table[RND, {10}]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({4, 2, 4, 1, 3, 3, 1, 2, 3, 4}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SeedRandom[0]; Table[RND, {10}]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({4, 2, 4, 1, 3, 3, 1, 2, 3, 4}\)], "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Floor", "Subsubsection",
  CellTags->"B.2"],

Cell["\<\
One of the requirements for every simulation in this book is to be \
able to specify the initial population density as a real number between zero \
and one. This can be done through the use of Random and Floor. Floor is a \
numerical function that returns the largest integer less than its argument. \
So, for example, Floor of a random real number between zero and one will \
always return zero.\
\>", "Text",
  CellTags->{"i:16", "B.2"}],

Cell[CellGroupData[{

Cell["Floor[Random[]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \(0\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "Important for creating populations with a given density ",
  StyleBox["p", "IT"],
  " between 0 and 1 is the fact that Floor of a random real number between ",
  StyleBox["p", "IT"],
  " and 1 + ",
  StyleBox["p", "IT"],
  " will yield 1 about ",
  StyleBox["p", "IT"],
  " percent of the time, and 0 in the remaining cases. We can generate a \
random real between ",
  StyleBox["p", "IT"],
  " and 1 + ",
  StyleBox["p", "IT"],
  " either by using Random[Real, {",
  StyleBox["p", "IT"],
  ", 1 + ",
  StyleBox["p", "IT"],
  "}], or by adding ",
  StyleBox["p", "IT"],
  " to a random real number between 0 and 1, as in ",
  StyleBox["p", "IT"],
  " + Random[]. The latter is more efficient and easier to read."
}], "Text",
  CellTags->"B.2"],

Cell["\<\
Thus, we can create a list that contains approximately 80% ones and \
20% zeros with the following code.\
\>", "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["\<\
p = 0.8;
SeedRandom[1]
Table[Floor[p + Random[]], {15}]\
\>", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({1, 1, 1, 0, 1, 1, 1, 1, 0, 1, 1, 1, 1, 0, 1}\)], "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["PreIncrement", "Subsubsection",
  CellTags->"B.2"],

Cell[TextData[{
  "Many of the models in this book require us to name the individuals in the \
system. The simplest way to do this is to name them consecutively, starting \
at 1 and ending at the number of individuals there are in the population. In \
general, though, we do not know the number of individuals beforehand; we only \
know the target population density. In order to keep track of the number of \
individuals, we use a ",
  StyleBox["counter", "IT"],
  " variable along with the PreIncrement function. PreIncrement[",
  StyleBox["counter", "IT"],
  "], or ++",
  StyleBox["counter", "IT"],
  ", sets the new value of ",
  StyleBox["counter", "IT"],
  " to be the current value of ",
  StyleBox["counter", "IT"],
  " plus 1."
}], "Text",
  CellTags->{"i:17", "B.2"}],

Cell[TextData[{
  "For instance, since each value of 1 in the previous example corresponds to \
a site occupied by a person, we can replace it with a name. This can be done \
with the replacement rule 1 \[RuleDelayed] ++",
  StyleBox["counter", "IT"],
  "."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell[TextData[
"p = 0.8;\nk = 0;\nSeedRandom[1]\nTable[Floor[p + Random[]], {15}] /. 1 \
\[RuleDelayed] ++k"], "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({1, 2, 3, 0, 4, 5, 6, 7, 0, 8, 9, 10, 11, 0, 12}\)], "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Building Society", "Subsubsection",
  CellTags->"B.2"],

Cell["\<\
Recall that the Table function can take more than one iterator, \
thereby specifying a table in more than one dimension. With this information, \
and the techniques just developed, we can generate a lattice that has the \
following properties.\
\>", "Text",
  CellTags->"B.2"],

Cell[TextData[{
  "The lattice has four rows and four columns (",
  StyleBox["n", "IT"],
  " = 4)."
}], "BulletListItem",
  CellTags->"B.2"],

Cell[TextData[{
  "The population density is 25% (",
  StyleBox["p", "IT"],
  " = 0.25). Empty sites are represented by zeros."
}], "BulletListItem",
  CellTags->"B.2"],

Cell["\<\
We can see just these two properties without further restriction in \
the following lattice.\
\>", "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["\<\
n = 4; p = 0.25;
SeedRandom[3]
Table[Floor[p + Random[]], {n}, {n}]\
\>", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{0, 0, 0, 1}, {0, 1, 1, 1}, {0, 1, 0, 1}, {0, 0, 0, 1}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
Now, suppose each individual on the lattice is represented by a \
list with five elements:\
\>", "Text",
  CellTags->"B.2"],

Cell["\<\
a randomly chosen integer between 1 and 4, representing the \
direction the individual is facing;\
\>", "BulletListItem",
  CellTags->"B.2"],

Cell["\<\
an integer between 1 and the total number of individuals on the \
lattice, representing the name of the individual;\
\>", "BulletListItem",
  CellTags->"B.2"],

Cell[TextData[{
  "a zero or one denoting a badly or well-behaved individual, such that \
approximately 75% of the individuals are well-behaved (",
  StyleBox["g", "IT"],
  " = 0.75);"
}], "BulletListItem",
  CellTags->"B.2"],

Cell[TextData[{
  "a list of three integers (",
  StyleBox["s", "IT"],
  " = 3) randomly chosen between 1 and 5 (",
  StyleBox["m", "IT"],
  " = 5), representing the individual's meme list; and"
}], "BulletListItem",
  CellTags->"B.2"],

Cell[TextData[{
  "a randomly chosen integer between 1 and 4 (",
  StyleBox["r", "IT"],
  " = 4) representing the individual's starting resources."
}], "BulletListItem",
  CellTags->"B.2"],

Cell[TextData[{
  "We can create a system of such individuals by replacing every 1 with a \
list by using a suitably constructed replacement rule. Doing so completes the \
construction of the example ",
  StyleBox["society", "IT"],
  " matrix given previously."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell[TextData[
"n = 4; p = 0.25; g = 0.75; m = 5; s = 3; r = 4;\nk = 0;\nSeedRandom[3]\nRND \
:= Random[Integer, {1, 4}]\nnewSociety = Table[Floor[p + Random[]], {n}, {n}] \
/.\n  1 \[RuleDelayed] {RND, ++k, Floor[g + Random[]],\n       \
Table[Random[Integer, {1, m}], {s}],\n       Random[Integer, {1, r}]};\n\
TraditionalForm[newSociety]"], "Input",
  CellTags->"B.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.2.2  Extracting Information from Society", "Subsection",
  CellTags->"B.2"],

Cell[TextData[{
  "All the functions that work for the list ",
  StyleBox["person", "IT"],
  " also work for the matrix ",
  StyleBox["society", "IT"],
  ", although you need to be careful to make sure they're doing what you \
want. For example, the functions Length, First, Last, and Rest now will \
operate on the rows of the matrix."
}], "Text",
  CellTags->{"i:18", "B.2"}],

Cell[CellGroupData[{

Cell["First[society]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({0, 0, 0, {3, 1, 1, {2, 3, 4}, 4}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "The function Part that we used in the form ",
  StyleBox["lis", "IT"],
  "[[",
  StyleBox["i", "IT"],
  "]] is general enough to extract elements out of any list. When dealing \
with a matrix, we can use Part to extract the elements of the list elements, \
as long as we specify the ",
  StyleBox["index",
    FontSlant->"Italic"],
  " of the elements we want. For example, if you wanted to extract the meme \
list of the individual named \"1\" in ",
  StyleBox["society", "IT"],
  ", you would want the fourth element of the fourth element of the first \
element of the matrix."
}], "Text",
  CellTags->{"i:19", "B.2"}],

Cell[CellGroupData[{

Cell["society[[1]][[4]][[4]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({2, 3, 4}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
A more pleasing syntax for this combines the indices into a \
sequence and gets rid of extra brackets.\
\>", "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["society[[1, 4, 4]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({2, 3, 4}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
Finally, on those occasions where you need to extract the head of \
an expression, you can refer to its zeroth part. This can be useful to make \
sure that you've extracted the correct expression.\
\>", "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["society[[1, 4, 4, 0]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \(List\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
Position, like Part, applies to matrices as well as lists. In fact, \
Position doesn't just analyze the elements (or rows) of the matrix, but it \
analyzes any expression that exists anywhere within the matrix. For example, \
we can extract the positions of all the empty sites in the matrix. However, \
asking for the position of all zeros in our example is not specific enough.\
\
\>", "Text",
  CellTags->{"i:20", "B.2"}],

Cell[CellGroupData[{

Cell["Position[society, 0]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {1, 3}, {2, 1}, {3, 1}, {3, 3}, {3, 4, 3}, {4, 1}, {4, 
        2}, {4, 3}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
Notice that this returns position {3, 4, 3} which does not \
correspond to an empty site, but rather is in the midst of an individual's \
list. The zero, being the third element of that individual's list, indicates \
that he is behaving badly.\
\>", "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["society[[3, 4]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({1, 6, 0, {2, 1, 5}, 4}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "We can restrict Position to returning only those positions of the matrix \
that are specified by two numbers by providing a third argument or ",
  StyleBox["level specification",
    FontSlant->"Italic"],
  " of {2}."
}], "Text",
  CellTags->{"i:21", "B.2"}],

Cell[CellGroupData[{

Cell["Position[society, 0, {2}]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{1, 1}, {1, 2}, {1, 3}, {2, 1}, {3, 1}, {3, 3}, {4, 1}, {4, 2}, {4, 3}}
      \)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
We discuss level specifications in somewhat more detail later on in \
this appendix.\
\>", "Text",
  CellTags->"B.2"],

Cell[TextData[{
  "Finally notice that Position confirms that the list ",
  StyleBox["person", "IT"],
  " is actually a member of the matrix ",
  StyleBox["society", "IT"],
  "."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["Position[society, person]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{1, 4}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.2.3  Cases and Count", "Subsection",
  CellTags->"B.2"],

Cell[TextData[{
  "Armed with a level specification, Cases and Count can be used to extract \
information from the matrix quite easily. For example, Cases can give us a \
list of the individuals that are present in ",
  StyleBox["society", "IT"],
  "."
}], "Text",
  CellTags->{"i:22", "B.2"}],

Cell[CellGroupData[{

Cell["Cases[society, _List, {2}]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{3, 1, 1, {2, 3, 4}, 4}, {3, 2, 1, {4, 3, 3}, 3}, {2, 3, 1, {4, 3, 4}, 
        1}, {2, 4, 1, {5, 3, 1}, 3}, {1, 5, 1, {5, 3, 5}, 2}, {1, 6, 
        0, {2, 1, 5}, 4}, {4, 7, 1, {4, 5, 5}, 3}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "Recall that Cases can take a transformation rule as its second argument. \
Here is an example of a transformation rule that extracts the meme list of \
all the good individuals in ",
  StyleBox["society", "IT"],
  "."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell[TextData[
"Cases[society, {_, _, 1, x_, _} \[RuleDelayed] x, {2}]"], "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{2, 3, 4}, {4, 3, 3}, {4, 3, 4}, {5, 3, 1}, {5, 3, 5}, {4, 5, 5}}\)], 
  "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
Similarly, Count can tell us how many individuals have resources \
that are less than some given level, provided we supply the level \
specification.\
\>", "Text",
  CellTags->{"i:23", "B.2"}],

Cell[CellGroupData[{

Cell["Count[society, {_, _, _, _, r_} /; r < 3, {2}]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \(2\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
When a simulation run is finished, we generally have a list of \
matrices, one for each time step during which the matrix was updated, instead \
of a single matrix. In those cases, a deeper level specification can be used \
to extract information. The first level of such a list would consist of the \
matrices themselves, the second level would be the rows, and the third level \
would correspond to the site values; thus, a level specification of {3} can \
be used to analyze just the site values. In this way, we can extract \
information (such as the position of an individual or the population's \
average resource level) from each matrix and analyze it as a function of \
time.\
\>", "Text",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.2.4  Rearranging Matrices", "Subsection",
  CellTags->"B.2"],

Cell[TextData[{
  "The optional predicate function given as a second argument to Sort can be \
used to sort lists of lists by any of their elements. By default, Sort \
arranges the rows of a matrix based on the first element of the row. If the \
first elements are identical, it moves to the second element, and so on",
  ". ",
  "For example, here is a list of the individuals in ",
  StyleBox["society",
    FontSlant->"Italic"],
  " sorted by the direction they are facing."
}], "Text",
  CellTags->{"i:24", "B.2"}],

Cell[CellGroupData[{

Cell["Sort[Cases[society, _List, {2}]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{1, 5, 1, {5, 3, 5}, 2}, {1, 6, 0, {2, 1, 5}, 4}, {2, 3, 1, {4, 3, 4}, 
        1}, {2, 4, 1, {5, 3, 1}, 3}, {3, 1, 1, {2, 3, 4}, 4}, {3, 2, 
        1, {4, 3, 3}, 3}, {4, 7, 1, {4, 5, 5}, 3}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
In other applications, it may be necessary to sort these same \
individuals by their resource levels. We can do this by instructing Sort to \
base the order on the last element of the sublists.\
\>", "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["Sort[Cases[society, _List, {2}], (Last[#1] < Last[#2]&)]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({{2, 3, 1, {4, 3, 4}, 1}, {1, 5, 1, {5, 3, 5}, 2}, {4, 7, 1, {4, 5, 5}, 
        3}, {2, 4, 1, {5, 3, 1}, 3}, {3, 2, 1, {4, 3, 3}, 3}, {1, 6, 
        0, {2, 1, 5}, 4}, {3, 1, 1, {2, 3, 4}, 4}}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "Instead of a level specification, RotateLeft and RotateRight can take a \
list as their second argument that tells what to do to ",
  StyleBox["successive levels",
    FontSlant->"Italic"],
  " of the list. (The first level of a list is all those elements that can be \
accessed with one number via Part, as in ",
  StyleBox["lis", "IT"],
  "[[",
  StyleBox["i", "IT"],
  "]]. The second level of a list is those elements that can be accessed with \
two numbers via Part, as in ",
  StyleBox["lis", "IT"],
  "[[",
  StyleBox["i", "IT"],
  ", ",
  StyleBox["j", "IT"],
  "]], etc.) For example, the following RotateLeft moves the first column to \
the last column in the matrix."
}], "Text",
  CellTags->{"i:25", "B.2"}],

Cell[CellGroupData[{

Cell["TraditionalForm[society]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TraditionalForm[RotateLeft[society, {0, 1}]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", \({3, 1, 1, {2, 3, 4}, 4}\), "0"},
            {\({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\), "0"},
            {\({1, 5, 1, {5, 3, 5}, 2}\), "0", \({1, 6, 0, {2, 1, 5}, 4}\), 
              "0"},
            {"0", "0", \({4, 7, 1, {4, 5, 5}, 3}\), "0"}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell["\<\
Rotations of this kind are indispensable for creating the \
neighborhood of a site, which is discussed in detail in the next \
section.\
\>", "Text",
  CellTags->"B.2"],

Cell[TextData[{
  "Another method of rearranging a matrix is to exchange the rows with the \
columns. Transpose is the function that does this. Notice that the first row \
of ",
  StyleBox["society", "IT"],
  " becomes the first column of Transpose[",
  StyleBox["society", "IT"],
  "]."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell["TraditionalForm[Transpose[society]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", "0"},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({1, 5, 1, {5, 3, 5}, 2}\), 
              "0"},
            {"0", \({2, 3, 1, {4, 3, 4}, 1}\), "0", "0"},
            {\({3, 1, 1, {2, 3, 4}, 4}\), \({2, 4, 1, {5, 3, 1}, 3}\), 
              \({1, 6, 0, {2, 1, 5}, 4}\), \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[TextData[{
  "This is important in many different applications. For example, here are \
two ways to extract the resource level from every individual in ",
  StyleBox["society", "IT"],
  ". The first method uses Cases, and the second uses Transpose."
}], "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{

Cell[TextData["Cases[society, x_List \[RuleDelayed] Last[x], {2}]"], "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({4, 3, 1, 3, 2, 4, 3}\)], "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Last[Transpose[Cases[society, _List, {2}]]]", "Input",
  CellTags->"B.2"],

Cell[BoxData[
    \({4, 3, 1, 3, 2, 4, 3}\)], "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.3  Higher Order Functions", "Section",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["B.3.1  Map, MapThread, and Neighborhoods", "Subsection",
  CellTags->"B.3"],

Cell[TextData[{
  "A function can be applied to each element in a list using Map. This is \
useful for transforming all the elements in a list at once, instead of \
looping over the list. For example, this applies the undefined function ",
  StyleBox["h", "IT"],
  " to each of the elements of the given list."
}], "Text",
  CellTags->{"i:26", "B.3"}],

Cell[CellGroupData[{

Cell["Map[h, {2, 1, 3}]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \({h[2], h[1], h[3]}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "Map[",
  StyleBox["function", "IT"],
  ", ",
  StyleBox["expr", "IT"],
  "], can also be written ",
  StyleBox["function", "IT"],
  " /@ ",
  StyleBox["expr", "IT"],
  "."
}], "Text",
  CellTags->"B.3"],

Cell[TextData[{
  "Like Cases and Count, Map can take a level specification. For instance, if \
you wanted to transform society by some function ",
  StyleBox["h", "IT"],
  " applied to each individual or empty site, you could do that using Map \
with a level specification of {2}. We can compare the results of mapping the \
function ",
  StyleBox["h", "IT"],
  " over ",
  StyleBox["society", "IT"],
  ", and mapping it over ",
  StyleBox["society", "IT"],
  " at level {2}."
}], "Text",
  CellTags->{"i:27", "B.3"}],

Cell[CellGroupData[{

Cell["TraditionalForm[society]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Notice that TraditionalForm uses parentheses instead of square \
brackets for function application, to conform to standard mathematical \
notation.\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["TraditionalForm[Map[h, society]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(TraditionalForm
    \`{h({0, 0, 0, {3, 1, 1, {2, 3, 4}, 4}}), 
      h({0, {3, 2, 1, {4, 3, 3}, 3}, {2, 3, 1, {4, 3, 4}, 1}, {2, 4, 
            1, {5, 3, 1}, 3}}), 
      h({0, {1, 5, 1, {5, 3, 5}, 2}, 0, {1, 6, 0, {2, 1, 5}, 4}}), 
      h({0, 0, 0, {4, 7, 1, {4, 5, 5}, 3}})}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TraditionalForm[Map[h, society, {2}]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(h(0)\), \(h(0)\), \(h(0)\), \(h({3, 1, 1, {2, 3, 4}, 4})\)},
            {\(h(0)\), \(h({3, 2, 1, {4, 3, 3}, 3})\), 
              \(h({2, 3, 1, {4, 3, 4}, 1})\), 
              \(h({2, 4, 1, {5, 3, 1}, 3})\)},
            {\(h(0)\), \(h({1, 5, 1, {5, 3, 5}, 2})\), \(h(0)\), 
              \(h({1, 6, 0, {2, 1, 5}, 4})\)},
            {\(h(0)\), \(h(0)\), \(h(0)\), \(h({4, 7, 1, {4, 5, 5}, 3})\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "Related to Map is MapThread, which can be used to ",
  StyleBox["thread",
    FontSlant->"Italic"],
  " or ",
  StyleBox["zip",
    FontSlant->"Italic"],
  " together lists that have the same structure, so that corresponding \
elements are paired up as arguments to a function. We can see the syntax and \
even a simple example in its usage message",
  ". ",
  "Notice that like Map, MapThread takes a level specification."
}], "Text",
  CellTags->{"i:28", "B.3"}],

Cell[CellGroupData[{

Cell["?MapThread", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \("MapThread[f, {{a1, a2, ... }, {b1, b2, ... }, ... }] gives {f[a1, b1, \
... ], f[a2, b2, ... ], ... }. MapThread[f, {expr1, expr2, ... }, n] applies \
f to the parts of the expri at level n."\)], "Print",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "For instance, if we wanted to apply the function ",
  StyleBox["h", "IT"],
  " to the elements of ",
  StyleBox["society", "IT"],
  " paired with the elements of RotateRight[",
  StyleBox["society", "IT"],
  ", {0,1}], we can do so with MapThread. To make the output more readable, \
we look only at the second row of the resulting matrix."
}], "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["society[[2]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \({0, {3, 2, 1, {4, 3, 3}, 3}, {2, 3, 1, {4, 3, 4}, 1}, {2, 4, 
        1, {5, 3, 1}, 3}}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MapThread[h, {society, RotateRight[society, {0,1}]}][[2]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(h[{0, {3, 2, 1, {4, 3, 3}, 3}, {2, 3, 1, {4, 3, 4}, 1}, {2, 4, 
          1, {5, 3, 1}, 3}}, {{2, 4, 1, {5, 3, 1}, 3}, 
        0, {3, 2, 1, {4, 3, 3}, 3}, {2, 3, 1, {4, 3, 4}, 1}}]\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Using the level specification for MapThread, we can pair off the \
elements of the rows instead of the rows themselves.\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["MapThread[h, {society, RotateRight[society, {0,1}]}, 2][[2]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \({h[0, {2, 4, 1, {5, 3, 1}, 3}], h[{3, 2, 1, {4, 3, 3}, 3}, 0], 
      h[{2, 3, 1, {4, 3, 4}, 1}, {3, 2, 1, {4, 3, 3}, 3}], 
      h[{2, 4, 1, {5, 3, 1}, 3}, {2, 3, 1, {4, 3, 4}, 1}]}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "Notice that each element of this matrix is ",
  StyleBox["h", "IT"],
  " applied to the corresponding element of ",
  StyleBox["society", "IT"],
  ", together with its neighbor to the left or west. We use ",
  StyleBox["wraparound",
    FontSlant->"Italic"],
  " boundary conditions, so that the western neighbor of the first element in \
a row corresponds to the last element of the row. We can use other second \
arguments of RotateRight to pair off sites with their northern ({1, 0}), \
eastern ({0, -1}), or southern ({-1, 0}) neighbors, in all cases with \
wraparound boundary conditions."
}], "Text",
  CellTags->{"i:29", "B.3"}],

Cell[TextData[{
  "In fact, we can perform all four rotations at once, to create the ",
  StyleBox["vonNeumann",
    FontSlant->"Italic"],
  " neighborhood of a site, which consists of that site together with its \
northern, eastern, southern, and western neighbors. Instead of applying this \
to our ",
  StyleBox["society", "IT"],
  " example, let's look at a matrix with simpler elements."
}], "Text",
  CellTags->{"i:30", "B.3"}],

Cell[CellGroupData[{

Cell["\<\
mat = {{1, north, 2}, {west, site, east}, {3, south, 4}};
TraditionalForm[mat]\
\>", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"1", "north", "2"},
            {"west", "site", "east"},
            {"3", "south", "4"}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["We generate the matrix of neighborhoods like so.", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["\<\
ngbds = MapThread[List, {mat,
  RotateRight[mat, {1, 0}], RotateRight[mat, {0, -1}],
  RotateRight[mat, {-1, 0}], RotateRight[mat, {0, 1}]}, 2];
TraditionalForm[ngbds]\
\>", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        RowBox[{"(", GridBox[{
              {\({1, 3, north, west, 2}\), \({north, south, 2, site, 1}\), 
                \({2, 4, 1, east, north}\)},
              {\({west, 1, site, 3, east}\), 
                \({site, north, east, south, west}\), 
                \({east, 2, west, 4, site}\)},
              {\({3, west, south, 1, 4}\), \({south, site, 4, north, 3}\), 
                \({4, east, 3, 2, south}\)}
              }], ")"}],
        MatrixForm[ {{{1, 3, north, west, 2}, {north, south, 2, site, 1}, {2, 
          4, 1, east, north}}, {{west, 1, site, 3, east}, {site, north, east, 
          south, west}, {east, 2, west, 4, site}}, {{3, west, south, 1, 4}, {
          south, site, 4, north, 3}, {4, east, 3, 2, south}}}, TableDepth -> 
          2]], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Notice in particular the center element of the resulting lattice.\
\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["ngbds[[2, 2]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \({site, north, east, south, west}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "It contains exactly the sequence of sites we wanted. In fact, every site \
of the ",
  StyleBox["ngbds", "IT"],
  " lattice contains that position's vonNeumann neighborhood. Furthermore, \
there's nothing special about threading List over the matrix of rotations. We \
could just as easily have used a different function ",
  StyleBox["h", "IT"],
  "."
}], "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["\<\
ngbds = MapThread[h, {mat,
  RotateRight[mat, {1, 0}], RotateRight[mat, {0, -1}],
  RotateRight[mat, {-1, 0}], RotateRight[mat, {0, 1}]}, 2];
TraditionalForm[ngbds]\
\>", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(h(1, 3, north, west, 2)\), \(h(north, south, 2, site, 1)\), 
              \(h(2, 4, 1, east, north)\)},
            {\(h(west, 1, site, 3, east)\), 
              \(h(site, north, east, south, west)\), 
              \(h(east, 2, west, 4, site)\)},
            {\(h(3, west, south, 1, 4)\), \(h(south, site, 4, north, 3)\), 
              \(h(4, east, 3, 2, south)\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Notice that there is a lot of repetition of the RotateRight command \
in the preceding input. We can simplify this by mapping RotateRight over the \
various rotations. RotateRight with a second argument of {0, 0} performs no \
rotation.\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["\<\
ngbds = MapThread[h, Map[RotateRight[mat, #]&,
        {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1}}], 2];
TraditionalForm[ngbds]\
\>", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(h(1, 3, north, west, 2)\), \(h(north, south, 2, site, 1)\), 
              \(h(2, 4, 1, east, north)\)},
            {\(h(west, 1, site, 3, east)\), 
              \(h(site, north, east, south, west)\), 
              \(h(east, 2, west, 4, site)\)},
            {\(h(3, west, south, 1, 4)\), \(h(south, site, 4, north, 3)\), 
              \(h(4, east, 3, 2, south)\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "We can gather the preceding commands into a new function definition, ",
  StyleBox["vonNeumann",
    FontSlant->"Italic"],
  ", that applies a given function to a given matrix of neighborhoods."
}], "Text",
  CellTags->"B.3"],

Cell["\<\
vonNeumann[func_, lat_] := 
  MapThread[func, Map[RotateRight[lat, #]&,
          {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1}}], 2];\
\>", "Input",
  CellTags->"B.3"],

Cell[TextData[{
  "Along these same lines, we can rotate the given matrix in other ways to \
get different neighborhoods. Two that occur throughout the book are the ",
  StyleBox["Moore",
    FontSlant->"Italic"],
  " neighborhood, and the ",
  StyleBox["Gaylord\[Dash]Nishidate",
    FontSlant->"Italic"],
  " (or ",
  StyleBox["GN",
    FontSlant->"Italic"],
  ") neighborhood. The Moore neighborhood of a site consists of that site \
along with its north, east, south, west, northeast, southeast, southwest, and \
northwest neighbors. The GN neighborhood adds to these the sites to the \
north, south, east, and west that are two sites away from the site in \
question."
}], "Text",
  CellTags->{"i:31", "B.3"}],

Cell["\<\
Moore[func_, lat_] :=
  MapThread[func, Map[RotateRight[lat, #]&,
           {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},
            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\
\>", "Input",
  CellTags->"B.3"],

Cell["\<\
GN[func_, lat_] :=
  MapThread[func, Map[RotateRight[lat, #]&,
            {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},
             {1, -1}, {-1, -1}, {-1, 1}, {1, 1}, {2, 0},
             {0, -2}, {-2, 0}, {0, 2}}], 2];\
\>", "Input",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.3.2  Nest and NestList", "Subsection",
  CellTags->"B.3"],

Cell[TextData[{
  "When running the simulations in this book, all sites of the lattice are \
updated during the course of one time step. The resulting lattice is then \
updated in the same way, and then the result of that is updated, and so \
forth. This repeated function application can be done in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " using the Nest or NestList functions. NestList[",
  StyleBox["h", "IT"],
  ", ",
  StyleBox["expr", "IT"],
  ", ",
  StyleBox["n", "IT"],
  "] applies ",
  StyleBox["h",
    FontSlant->"Italic"],
  " to ",
  StyleBox["expr", "IT"],
  ", then applies ",
  StyleBox["h", "IT"],
  " to the result, and so on, ",
  StyleBox["n", "IT"],
  " times, and then returns a list of all the ",
  StyleBox["n", "IT"],
  StyleBox[" + 1",
    FontSlant->"Italic"],
  " resulting expressions, beginning with ",
  StyleBox["expr", "IT"],
  "."
}], "Text",
  CellTags->{"i:32", "B.3"}],

Cell[CellGroupData[{

Cell["NestList[h, expr, 3]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \({expr, h[expr], h[h[expr]], h[h[h[expr]]]}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Nest does the same calculations as NestList, but just returns the \
result of the repeated function application, and leaves out all the \
intermediate results. In effect, it returns the last element of \
NestList.\
\>", "Text",
  CellTags->{"i:33", "B.3"}],

Cell[CellGroupData[{

Cell["Nest[h, expr, 3]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(h[h[h[expr]]]\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
There are also some memory savings that Nest exhibits over \
NestList. We discuss these in the next appendix.\
\>", "Text",
  CellTags->"B.3"],

Cell[TextData[{
  "For a more interesting example, recall that we can apply any function to \
the vonNeumann neighborhood of every site in the lattice simultaneously. \
Let's define one such function, ",
  StyleBox["increaseResources", "IT"],
  ", which adds to the resource level of an individual a number equal to the \
number of good individuals other than themselves that populate their \
vonNeumann neighborhood. (Recall that good individuals are those that have a \
1 as the third element of their list.)",
  " ",
  "It should leave empty sites alone. This function might be called a ",
  StyleBox["group effect",
    FontSlant->"Italic"],
  ", as the results depend on each individual's neighborhood as a whole. We \
can define this function with the following two rules."
}], "Text",
  CellTags->"B.3"],

Cell["Clear[increaseResources]", "Input",
  CellTags->"B.3"],

Cell["\<\
increaseResources[{a_, b_, c_, d_, r_}, w_, x_, y_, z_] :=
   {a, b, c, d, r + Count[{w, x, y, z}, {_, _, 1, _, _}]};
increaseResources[0, _, _, _, _] := 0;\
\>", "Input",
  CellTags->"B.3"],

Cell["\<\
We can apply this function \"by hand\" in the traditional manner.\
\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["TraditionalForm[society]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TraditionalForm[vonNeumann[increaseResources, society]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 6}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 5}\), \({2, 3, 1, {4, 3, 4}, 3}\), 
              \({2, 4, 1, {5, 3, 1}, 5}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 3}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 6}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 4}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "To apply this function 10 times, we can simply apply the function ",
  StyleBox["vonNeumann", "IT"],
  "[",
  StyleBox["increaseResources", "IT"],
  ", #]& to the matrix, and then apply that same function to the result, and \
so on, 10 times. Nest returns the result of the final function application."
}], "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["\<\
TraditionalForm[
   Nest[vonNeumann[increaseResources, #]&, society, 10]]\
\>", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 24}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 23}\), \({2, 3, 1, {4, 3, 4}, 21}\), 
              \({2, 4, 1, {5, 3, 1}, 23}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 12}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 24}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 13}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "In most of the models in this book, there are multiple functions being \
applied to the lattice at each time step, so that the ",
  StyleBox["increaseResources", "IT"],
  " step might be followed by a ",
  StyleBox["walk", "IT"],
  " step (applied via the ",
  StyleBox["GN", "IT"],
  " neighborhood function defined in the previous section). In such cases, \
this composition of functions can be given as a single anonymous function to \
Nest, as in the following case. (Since the walk rules have not been defined \
here, we do not evaluate this input.)"
}], "Text",
  CellTags->"B.3"],

Cell["\<\
Nest[GN[walk, 
         vonNeumann[increaseResources, #]]&, society, 10]\
\>", "Input",
  Evaluatable->False,
  CellTags->"B.3"],

Cell[TextData[{
  "Similar to Nest and NestList are FixedPoint and FixedPointList, which can \
be used to stop the repeated application of a function when a specified \
condition is met, although we do not use them in this book. For a description \
of what they are and how they can be used, see the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " book."
}], "Text",
  CellTags->{"i:34", "B.3"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.3.3  Fold and FoldList", "Subsection",
  CellTags->"B.3"],

Cell["\<\
We've seen how Nest and NestList can be used to iterate a function \
of one variable a fixed number of times. When a similar operation needs to be \
done with a function of two variables, Fold and FoldList can be used. We \
learn the syntax of FoldList from its usage message.\
\>", "Text",
  CellTags->{"i:35", "B.3"}],

Cell[CellGroupData[{

Cell["?FoldList", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \("FoldList[f, x, {a, b, ... }] gives {x, f[x, a], f[f[x, a], b], ... }."\
\)], "Print",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "You can think of FoldList as iterating over its third argument. The \
following example uses Power, which is the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function for raising one number to the power of a second number. This \
code folds the Power function over the list {",
  StyleBox["x", "IT"],
  ", ",
  StyleBox["y", "IT"],
  ", ",
  StyleBox["z", "IT"],
  "} starting with ",
  StyleBox["a", "IT"],
  "."
}], "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["FoldList[Power, a, {x, y, z}]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \({a, a\^x, \((a\^x)\)\^y, \((\((a\^x)\)\^y)\)\^z}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Just as Nest returns the last element of NestList, Fold returns the \
last element of FoldList.\
\>", "Text",
  CellTags->{"i:36", "B.3"}],

Cell[CellGroupData[{

Cell["Fold[Power, a, {x, y, z}]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(\((\((a\^x)\)\^y)\)\^z\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "We use Nest, NestList, Fold, and FoldList as a more efficient substitute \
for recursive or procedural techniques in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["B.3.4  Apply and Sequence", "Subsection",
  CellTags->"B.3"],

Cell[TextData[{
  "Up until now, we have used the term \"apply a function\" to casually refer \
to function application. So to \"apply the function ",
  StyleBox["h", "IT"],
  " to the list {1, 2, 3}\" results in the expression ",
  StyleBox["h", "IT"],
  "[{1, 2, 3}]. However, sometimes you want the function to ",
  StyleBox["replace",
    FontSlant->"Italic"],
  " the head of your argument so as to result in ",
  StyleBox["h", "IT"],
  "[1, 2, 3]. To do this, you would use the built-in function Apply."
}], "Text",
  CellTags->{"i:37", "B.3"}],

Cell[CellGroupData[{

Cell["?Apply", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \("Apply[f, expr] or f @@ expr replaces the head of expr by f. Apply[f, \
expr, levelspec] replaces heads in parts of expr specified by levelspec."\)], 
  "Print",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
A list of expressions, for example, could be added together by \
using Apply to replace the head List with the head Plus.\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["Apply[Plus, List[x, y, z]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(x + y + z\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "Summing lists can be useful, for instance, in calculating averages. Recall \
the matrix ",
  StyleBox["society", "IT"],
  " created earlier in this appendix."
}], "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["TraditionalForm[society]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
We can extract a list consisting of each individual's resource \
level.\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell[TextData[
"resources = Cases[society, {_, _, _, _, r_} \[RuleDelayed] r, {2}]"], "Input",\

  CellTags->"B.3"],

Cell[BoxData[
    \({4, 3, 1, 3, 2, 4, 3}\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Then using Apply, we can calculate the average of this list by \
adding the elements and dividing by the number of elements.\
\>", "Text",
  CellTags->{"i:38", "B.3"}],

Cell[CellGroupData[{

Cell["Apply[Plus, resources] / Length[resources] // N", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(2.85714285714285729`\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell["\<\
Apply is not restricted to replacing a head of List, but will \
replace the head of any given expression.\
\>", "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{

Cell["Apply[h2, h[1, 2, 3]]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(h2[1, 2, 3]\)], "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[TextData[{
  "Related to Apply is Sequence, the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operator that denotes a comma-separated series of expressions. By using \
Apply to replace the head of an expression with Sequence, you can effectively \
splice the expression's arguments into another argument list."
}], "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:39", "IndexEntries" -> {{"Sequence", 
    "", ""}}},
  CellTags->{"i:39", "B.3"}],

Cell[CellGroupData[{

Cell["h[1, 2, Apply[Sequence, {3, 4}], 5]", "Input",
  CellTags->"B.3"],

Cell[BoxData[
    \(h[1, 2, 3, 4, 5]\)], "Output",
  CellTags->"B.3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "Appendix B. List and Matrix Essentials"}], "Header"], Inherited, 
      Inherited}, {Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 40, "IndexEntries" -> {{"i:1", 
  "list manipulation", "", ""}, {"i:39", "Sequence", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@UW:0000000000064<01T1T00000000000
00000000003oo`@WV[3oo`000iL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "B.0"->{
    Cell[1731, 51, 52, 1, 92, "ChapterLine",
      CellTags->"B.0"],
    Cell[1786, 54, 62, 1, 153, "Title",
      CellTags->"B.0"],
    Cell[1851, 57, 287, 7, 54, "Text",
      CellTags->"B.0"]},
  "B.1"->{
    Cell[2163, 68, 60, 1, 40, "Section",
      CellTags->"B.1"],
    Cell[2226, 71, 651, 15, 96, "Text",
      CellTags->{"i:1", "B.1"}],
    Cell[2902, 90, 98, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[3003, 93, 197, 6, 38, "Output",
      CellTags->"B.1"],
    Cell[3215, 102, 575, 10, 108, "Text",
      CellTags->"B.1"],
    Cell[3815, 116, 68, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[3886, 119, 76, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[3977, 124, 304, 6, 66, "Text",
      CellTags->"B.1"],
    Cell[4284, 132, 209, 5, 34, "BulletListItem",
      CellTags->"B.1"],
    Cell[4496, 139, 227, 5, 48, "BulletListItem",
      CellTags->"B.1"],
    Cell[4726, 146, 288, 6, 48, "BulletListItem",
      CellTags->"B.1"],
    Cell[5017, 154, 602, 11, 106, "BulletListItem",
      CellTags->"B.1"],
    Cell[5622, 167, 299, 6, 62, "BulletListItem",
      CellTags->"B.1"],
    Cell[5924, 175, 247, 5, 52, "Text",
      CellTags->"B.1"],
    Cell[6196, 184, 53, 1, 40, "Subsection",
      CellTags->"B.1"],
    Cell[6252, 187, 403, 11, 70, "Text",
      CellTags->{"i:2", "B.1"}],
    Cell[6680, 202, 56, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[6739, 205, 68, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[6822, 210, 560, 18, 72, "Text",
      CellTags->"B.1"],
    Cell[7407, 232, 61, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[7471, 235, 147, 3, 52, "Output",
      CellTags->"B.1"],
    Cell[7633, 241, 284, 6, 66, "Text",
      CellTags->"B.1"],
    Cell[7954, 252, 82, 1, 40, "Subsection",
      CellTags->"B.1"],
    Cell[8039, 255, 256, 5, 52, "Text",
      CellTags->{"i:3", "B.1"}],
    Cell[8320, 264, 42, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[8365, 267, 76, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[8456, 272, 107, 4, 24, "Text",
      CellTags->"B.1"],
    Cell[8588, 280, 50, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[8641, 283, 54, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[8710, 288, 427, 8, 80, "Text",
      CellTags->{"i:4", "B.1"}],
    Cell[9162, 300, 65, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[9230, 303, 59, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[9304, 308, 574, 18, 86, "Text",
      CellTags->{"i:5", "B.1"}],
    Cell[9903, 330, 47, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[9953, 333, 62, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[10030, 338, 272, 6, 52, "Text",
      CellTags->"B.1"],
    Cell[10327, 348, 48, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[10378, 351, 62, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[10455, 356, 238, 5, 52, "Text",
      CellTags->"B.1"],
    Cell[10696, 363, 539, 9, 108, "Text",
      CellTags->{"i:6", "B.1"}],
    Cell[11260, 376, 42, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[11305, 379, 76, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[11418, 386, 55, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[11476, 389, 63, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[11554, 394, 394, 7, 80, "Text",
      CellTags->"B.1"],
    Cell[11973, 405, 55, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[12031, 408, 66, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[12112, 413, 198, 5, 38, "Text",
      CellTags->"B.1"],
    Cell[12335, 422, 69, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[12407, 425, 63, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[12519, 433, 72, 1, 40, "Subsection",
      CellTags->"B.1"],
    Cell[12594, 436, 533, 9, 94, "Text",
      CellTags->{"i:7", "B.1"}],
    Cell[13152, 449, 42, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[13197, 452, 76, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[13288, 457, 192, 5, 38, "Text",
      CellTags->"B.1"],
    Cell[13505, 466, 72, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[13580, 469, 64, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[13659, 474, 261, 6, 52, "Text",
      CellTags->"B.1"],
    Cell[13945, 484, 74, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[14022, 487, 55, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[14092, 492, 231, 5, 52, "Text",
      CellTags->{"i:8", "B.1"}],
    Cell[14348, 501, 56, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[14407, 504, 64, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[14486, 509, 427, 8, 80, "Text",
      CellTags->"B.1"],
    Cell[14938, 521, 108, 2, 37, "Input",
      CellTags->"B.1"],
    Cell[15049, 525, 56, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[15120, 530, 276, 6, 52, "Text",
      CellTags->{"i:9", "B.1"}],
    Cell[15421, 540, 56, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[15480, 543, 54, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[15583, 551, 65, 1, 40, "Subsection",
      CellTags->"B.1"],
    Cell[15651, 554, 305, 8, 56, "Text",
      CellTags->{"i:10", "B.1"}],
    Cell[15981, 566, 77, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[16061, 569, 89, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[16165, 574, 450, 8, 80, "Text",
      CellTags->"B.1"],
    Cell[16640, 586, 68, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[16711, 589, 89, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[16815, 594, 201, 5, 38, "Text",
      CellTags->"B.1"],
    Cell[17019, 601, 456, 8, 80, "Text",
      CellTags->{"i:11", "B.1"}],
    Cell[17500, 613, 42, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[17545, 616, 76, 2, 38, "Output",
      CellTags->"B.1"],
    Cell[17658, 623, 80, 1, 37, "Input",
      CellTags->"B.1"],
    Cell[17741, 626, 103, 2, 38, "Output",
      CellTags->"B.1"]},
  "i:1"->{
    Cell[2226, 71, 651, 15, 96, "Text",
      CellTags->{"i:1", "B.1"}]},
  "i:2"->{
    Cell[6252, 187, 403, 11, 70, "Text",
      CellTags->{"i:2", "B.1"}]},
  "i:3"->{
    Cell[8039, 255, 256, 5, 52, "Text",
      CellTags->{"i:3", "B.1"}]},
  "i:4"->{
    Cell[8710, 288, 427, 8, 80, "Text",
      CellTags->{"i:4", "B.1"}]},
  "i:5"->{
    Cell[9304, 308, 574, 18, 86, "Text",
      CellTags->{"i:5", "B.1"}]},
  "i:6"->{
    Cell[10696, 363, 539, 9, 108, "Text",
      CellTags->{"i:6", "B.1"}]},
  "i:7"->{
    Cell[12594, 436, 533, 9, 94, "Text",
      CellTags->{"i:7", "B.1"}]},
  "i:8"->{
    Cell[14092, 492, 231, 5, 52, "Text",
      CellTags->{"i:8", "B.1"}]},
  "i:9"->{
    Cell[15120, 530, 276, 6, 52, "Text",
      CellTags->{"i:9", "B.1"}]},
  "i:10"->{
    Cell[15651, 554, 305, 8, 56, "Text",
      CellTags->{"i:10", "B.1"}]},
  "i:11"->{
    Cell[17019, 601, 456, 8, 80, "Text",
      CellTags->{"i:11", "B.1"}]},
  "B.2"->{
    Cell[17905, 635, 62, 1, 40, "Section",
      CellTags->"B.2"],
    Cell[17970, 638, 323, 6, 66, "Text",
      CellTags->{"i:12", "B.2"}],
    Cell[18296, 646, 158, 4, 38, "Text",
      CellTags->"B.2"],
    Cell[18457, 652, 271, 6, 76, "Input",
      CellTags->"B.2"],
    Cell[18731, 660, 251, 6, 40, "Text",
      CellTags->{"i:13", "B.2"}],
    Cell[19007, 670, 60, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[19070, 673, 459, 10, 78, "Output",
      CellTags->"B.2"],
    Cell[19544, 686, 812, 18, 130, "Text",
      CellTags->"B.2"],
    Cell[20381, 708, 64, 1, 40, "Subsection",
      CellTags->"B.2"],
    Cell[20448, 711, 309, 7, 54, "Text",
      CellTags->"B.2"],
    Cell[20782, 722, 65, 1, 30, "Subsubsection",
      CellTags->"B.2"],
    Cell[20850, 725, 592, 19, 86, "Text",
      CellTags->{"i:14", "B.2"}],
    Cell[21467, 748, 91, 4, 50, "Input",
      CellTags->"B.2"],
    Cell[21561, 754, 83, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[21659, 759, 192, 5, 38, "Text",
      CellTags->"B.2"],
    Cell[21854, 766, 717, 19, 114, "Text",
      CellTags->"B.2"],
    Cell[22574, 787, 414, 7, 80, "Text",
      CellTags->{"i:15", "B.2"}],
    Cell[23013, 798, 67, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[23083, 801, 83, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[23203, 808, 67, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[23273, 811, 83, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[23405, 819, 49, 1, 30, "Subsubsection",
      CellTags->"B.2"],
    Cell[23457, 822, 449, 8, 94, "Text",
      CellTags->{"i:16", "B.2"}],
    Cell[23931, 834, 51, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[23985, 837, 54, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[24054, 842, 762, 24, 104, "Text",
      CellTags->"B.2"],
    Cell[24819, 868, 147, 4, 38, "Text",
      CellTags->"B.2"],
    Cell[24991, 876, 99, 5, 63, "Input",
      CellTags->"B.2"],
    Cell[25093, 883, 98, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[25240, 891, 56, 1, 30, "Subsubsection",
      CellTags->"B.2"],
    Cell[25299, 894, 778, 18, 128, "Text",
      CellTags->{"i:17", "B.2"}],
    Cell[26080, 914, 288, 7, 54, "Text",
      CellTags->"B.2"],
    Cell[26393, 925, 138, 3, 76, "Input",
      CellTags->"B.2"],
    Cell[26534, 930, 101, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[26684, 938, 60, 1, 30, "Subsubsection",
      CellTags->"B.2"],
    Cell[26747, 941, 286, 6, 66, "Text",
      CellTags->"B.2"],
    Cell[27036, 949, 140, 5, 22, "BulletListItem",
      CellTags->"B.2"],
    Cell[27179, 956, 168, 5, 36, "BulletListItem",
      CellTags->"B.2"],
    Cell[27350, 963, 135, 4, 38, "Text",
      CellTags->"B.2"],
    Cell[27510, 971, 111, 5, 63, "Input",
      CellTags->"B.2"],
    Cell[27624, 978, 109, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[27748, 983, 133, 4, 38, "Text",
      CellTags->"B.2"],
    Cell[27884, 989, 150, 4, 34, "BulletListItem",
      CellTags->"B.2"],
    Cell[28037, 995, 168, 4, 34, "BulletListItem",
      CellTags->"B.2"],
    Cell[28208, 1001, 225, 6, 36, "BulletListItem",
      CellTags->"B.2"],
    Cell[28436, 1009, 235, 7, 36, "BulletListItem",
      CellTags->"B.2"],
    Cell[28674, 1018, 188, 5, 36, "BulletListItem",
      CellTags->"B.2"],
    Cell[28865, 1025, 292, 7, 54, "Text",
      CellTags->"B.2"],
    Cell[29182, 1036, 371, 6, 141, "Input",
      CellTags->"B.2"],
    Cell[29556, 1044, 459, 10, 78, "Output",
      CellTags->"B.2"],
    Cell[30076, 1061, 83, 1, 40, "Subsection",
      CellTags->"B.2"],
    Cell[30162, 1064, 377, 9, 68, "Text",
      CellTags->{"i:18", "B.2"}],
    Cell[30564, 1077, 50, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[30617, 1080, 87, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[30719, 1085, 639, 16, 100, "Text",
      CellTags->{"i:19", "B.2"}],
    Cell[31383, 1105, 58, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[31444, 1108, 62, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[31521, 1113, 145, 4, 38, "Text",
      CellTags->"B.2"],
    Cell[31691, 1121, 54, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[31748, 1124, 62, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[31825, 1129, 239, 5, 52, "Text",
      CellTags->"B.2"],
    Cell[32089, 1138, 57, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[32149, 1141, 57, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[32221, 1146, 434, 8, 80, "Text",
      CellTags->{"i:20", "B.2"}],
    Cell[32680, 1158, 56, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[32739, 1161, 145, 3, 52, "Output",
      CellTags->"B.2"],
    Cell[32899, 1167, 286, 6, 52, "Text",
      CellTags->"B.2"],
    Cell[33210, 1177, 51, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[33264, 1180, 76, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[33355, 1185, 277, 7, 54, "Text",
      CellTags->{"i:21", "B.2"}],
    Cell[33657, 1196, 61, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[33721, 1199, 132, 3, 38, "Output",
      CellTags->"B.2"],
    Cell[33868, 1205, 127, 4, 38, "Text",
      CellTags->"B.2"],
    Cell[33998, 1211, 209, 7, 42, "Text",
      CellTags->"B.2"],
    Cell[34232, 1222, 61, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[34296, 1225, 61, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[34406, 1233, 63, 1, 40, "Subsection",
      CellTags->"B.2"],
    Cell[34472, 1236, 293, 7, 54, "Text",
      CellTags->{"i:22", "B.2"}],
    Cell[34790, 1247, 62, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[34855, 1250, 246, 4, 66, "Output",
      CellTags->"B.2"],
    Cell[35116, 1257, 267, 7, 54, "Text",
      CellTags->"B.2"],
    Cell[35408, 1268, 101, 2, 37, "Input",
      CellTags->"B.2"],
    Cell[35512, 1272, 122, 3, 38, "Output",
      CellTags->"B.2"],
    Cell[35649, 1278, 202, 5, 38, "Text",
      CellTags->{"i:23", "B.2"}],
    Cell[35876, 1287, 82, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[35961, 1290, 54, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[36030, 1295, 726, 12, 136, "Text",
      CellTags->"B.2"],
    Cell[36793, 1312, 68, 1, 40, "Subsection",
      CellTags->"B.2"],
    Cell[36864, 1315, 518, 11, 82, "Text",
      CellTags->{"i:24", "B.2"}],
    Cell[37407, 1330, 68, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[37478, 1333, 246, 4, 66, "Output",
      CellTags->"B.2"],
    Cell[37739, 1340, 236, 5, 52, "Text",
      CellTags->"B.2"],
    Cell[38000, 1349, 92, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[38095, 1352, 246, 4, 66, "Output",
      CellTags->"B.2"],
    Cell[38356, 1359, 738, 20, 100, "Text",
      CellTags->{"i:25", "B.2"}],
    Cell[39119, 1383, 60, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[39182, 1386, 459, 10, 78, "Output",
      CellTags->"B.2"],
    Cell[39678, 1401, 80, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[39761, 1404, 459, 10, 78, "Output",
      CellTags->"B.2"],
    Cell[40235, 1417, 178, 5, 38, "Text",
      CellTags->"B.2"],
    Cell[40416, 1424, 318, 9, 56, "Text",
      CellTags->"B.2"],
    Cell[40759, 1437, 71, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[40833, 1440, 459, 10, 78, "Output",
      CellTags->"B.2"],
    Cell[41307, 1453, 285, 6, 54, "Text",
      CellTags->"B.2"],
    Cell[41617, 1463, 96, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[41716, 1466, 74, 2, 38, "Output",
      CellTags->"B.2"],
    Cell[41827, 1473, 79, 1, 37, "Input",
      CellTags->"B.2"],
    Cell[41909, 1476, 74, 2, 38, "Output",
      CellTags->"B.2"]},
  "i:12"->{
    Cell[17970, 638, 323, 6, 66, "Text",
      CellTags->{"i:12", "B.2"}]},
  "i:13"->{
    Cell[18731, 660, 251, 6, 40, "Text",
      CellTags->{"i:13", "B.2"}]},
  "i:14"->{
    Cell[20850, 725, 592, 19, 86, "Text",
      CellTags->{"i:14", "B.2"}]},
  "i:15"->{
    Cell[22574, 787, 414, 7, 80, "Text",
      CellTags->{"i:15", "B.2"}]},
  "i:16"->{
    Cell[23457, 822, 449, 8, 94, "Text",
      CellTags->{"i:16", "B.2"}]},
  "i:17"->{
    Cell[25299, 894, 778, 18, 128, "Text",
      CellTags->{"i:17", "B.2"}]},
  "i:18"->{
    Cell[30162, 1064, 377, 9, 68, "Text",
      CellTags->{"i:18", "B.2"}]},
  "i:19"->{
    Cell[30719, 1085, 639, 16, 100, "Text",
      CellTags->{"i:19", "B.2"}]},
  "i:20"->{
    Cell[32221, 1146, 434, 8, 80, "Text",
      CellTags->{"i:20", "B.2"}]},
  "i:21"->{
    Cell[33355, 1185, 277, 7, 54, "Text",
      CellTags->{"i:21", "B.2"}]},
  "i:22"->{
    Cell[34472, 1236, 293, 7, 54, "Text",
      CellTags->{"i:22", "B.2"}]},
  "i:23"->{
    Cell[35649, 1278, 202, 5, 38, "Text",
      CellTags->{"i:23", "B.2"}]},
  "i:24"->{
    Cell[36864, 1315, 518, 11, 82, "Text",
      CellTags->{"i:24", "B.2"}]},
  "i:25"->{
    Cell[38356, 1359, 738, 20, 100, "Text",
      CellTags->{"i:25", "B.2"}]},
  "B.3"->{
    Cell[42044, 1485, 65, 1, 40, "Section",
      CellTags->"B.3"],
    Cell[42134, 1490, 81, 1, 40, "Subsection",
      CellTags->"B.3"],
    Cell[42218, 1493, 351, 7, 68, "Text",
      CellTags->{"i:26", "B.3"}],
    Cell[42594, 1504, 53, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[42650, 1507, 71, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[42736, 1512, 221, 11, 26, "Text",
      CellTags->"B.3"],
    Cell[42960, 1525, 518, 14, 86, "Text",
      CellTags->{"i:27", "B.3"}],
    Cell[43503, 1543, 60, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[43566, 1546, 459, 10, 78, "Output",
      CellTags->"B.3"],
    Cell[44040, 1559, 190, 5, 38, "Text",
      CellTags->"B.3"],
    Cell[44255, 1568, 68, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[44326, 1571, 331, 7, 66, "Output",
      CellTags->"B.3"],
    Cell[44694, 1583, 73, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[44770, 1586, 540, 11, 78, "Output",
      CellTags->"B.3"],
    Cell[45325, 1600, 483, 13, 68, "Text",
      CellTags->{"i:28", "B.3"}],
    Cell[45833, 1617, 46, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[45882, 1620, 244, 4, 83, "Print",
      CellTags->"B.3"],
    Cell[46141, 1627, 390, 10, 70, "Text",
      CellTags->"B.3"],
    Cell[46556, 1641, 48, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[46607, 1644, 140, 3, 38, "Output",
      CellTags->"B.3"],
    Cell[46784, 1652, 93, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[46880, 1655, 234, 4, 66, "Output",
      CellTags->"B.3"],
    Cell[47129, 1662, 162, 4, 38, "Text",
      CellTags->"B.3"],
    Cell[47316, 1670, 96, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[47415, 1673, 235, 4, 66, "Output",
      CellTags->"B.3"],
    Cell[47665, 1680, 654, 14, 112, "Text",
      CellTags->{"i:29", "B.3"}],
    Cell[48322, 1696, 433, 10, 72, "Text",
      CellTags->{"i:30", "B.3"}],
    Cell[48780, 1710, 122, 4, 50, "Input",
      CellTags->"B.3"],
    Cell[48905, 1716, 229, 7, 64, "Output",
      CellTags->"B.3"],
    Cell[49149, 1726, 83, 1, 24, "Text",
      CellTags->"B.3"],
    Cell[49257, 1731, 211, 6, 76, "Input",
      CellTags->"B.3"],
    Cell[49471, 1739, 873, 17, 64, "Output",
      CellTags->"B.3"],
    Cell[50359, 1759, 110, 4, 24, "Text",
      CellTags->"B.3"],
    Cell[50494, 1767, 49, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[50546, 1770, 85, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[50646, 1775, 402, 10, 72, "Text",
      CellTags->"B.3"],
    Cell[51073, 1789, 208, 6, 76, "Input",
      CellTags->"B.3"],
    Cell[51284, 1797, 510, 11, 64, "Output",
      CellTags->"B.3"],
    Cell[51809, 1811, 279, 6, 52, "Text",
      CellTags->"B.3"],
    Cell[52113, 1821, 170, 5, 63, "Input",
      CellTags->"B.3"],
    Cell[52286, 1828, 510, 11, 64, "Output",
      CellTags->"B.3"],
    Cell[52811, 1842, 244, 6, 42, "Text",
      CellTags->"B.3"],
    Cell[53058, 1850, 174, 5, 63, "Input",
      CellTags->"B.3"],
    Cell[53235, 1857, 714, 17, 112, "Text",
      CellTags->{"i:31", "B.3"}],
    Cell[53952, 1876, 217, 6, 76, "Input",
      CellTags->"B.3"],
    Cell[54172, 1884, 263, 7, 89, "Input",
      CellTags->"B.3"],
    Cell[54472, 1896, 65, 1, 40, "Subsection",
      CellTags->"B.3"],
    Cell[54540, 1899, 925, 30, 116, "Text",
      CellTags->{"i:32", "B.3"}],
    Cell[55490, 1933, 56, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[55549, 1936, 95, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[55659, 1941, 266, 6, 52, "Text",
      CellTags->{"i:33", "B.3"}],
    Cell[55950, 1951, 52, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[56005, 1954, 66, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[56086, 1959, 152, 4, 38, "Text",
      CellTags->"B.3"],
    Cell[56241, 1965, 810, 16, 140, "Text",
      CellTags->"B.3"],
    Cell[57054, 1983, 60, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[57117, 1986, 200, 5, 63, "Input",
      CellTags->"B.3"],
    Cell[57320, 1993, 110, 4, 24, "Text",
      CellTags->"B.3"],
    Cell[57455, 2001, 60, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[57518, 2004, 459, 10, 78, "Output",
      CellTags->"B.3"],
    Cell[58014, 2019, 91, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[58108, 2022, 459, 10, 78, "Output",
      CellTags->"B.3"],
    Cell[58582, 2035, 352, 8, 70, "Text",
      CellTags->"B.3"],
    Cell[58959, 2047, 117, 4, 50, "Input",
      CellTags->"B.3"],
    Cell[59079, 2053, 466, 10, 78, "Output",
      CellTags->"B.3"],
    Cell[59560, 2066, 605, 13, 98, "Text",
      CellTags->"B.3"],
    Cell[60168, 2081, 138, 5, 50, "Input",
      Evaluatable->False,
      CellTags->"B.3"],
    Cell[60309, 2088, 406, 9, 68, "Text",
      CellTags->{"i:34", "B.3"}],
    Cell[60752, 2102, 65, 1, 40, "Subsection",
      CellTags->"B.3"],
    Cell[60820, 2105, 329, 6, 66, "Text",
      CellTags->{"i:35", "B.3"}],
    Cell[61174, 2115, 45, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[61222, 2118, 125, 3, 53, "Print",
      CellTags->"B.3"],
    Cell[61362, 2124, 477, 16, 70, "Text",
      CellTags->"B.3"],
    Cell[61864, 2144, 65, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[61932, 2147, 101, 2, 43, "Output",
      CellTags->"B.3"],
    Cell[62048, 2152, 148, 4, 38, "Text",
      CellTags->{"i:36", "B.3"}],
    Cell[62221, 2160, 61, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[62285, 2163, 75, 2, 41, "Output",
      CellTags->"B.3"],
    Cell[62375, 2168, 227, 7, 40, "Text",
      CellTags->"B.3"],
    Cell[62639, 2180, 66, 1, 40, "Subsection",
      CellTags->"B.3"],
    Cell[62708, 2183, 550, 13, 86, "Text",
      CellTags->{"i:37", "B.3"}],
    Cell[63283, 2200, 42, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[63328, 2203, 200, 4, 68, "Print",
      CellTags->"B.3"],
    Cell[63543, 2210, 164, 4, 38, "Text",
      CellTags->"B.3"],
    Cell[63732, 2218, 62, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[63797, 2221, 62, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[63874, 2226, 208, 6, 40, "Text",
      CellTags->"B.3"],
    Cell[64107, 2236, 60, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[64170, 2239, 459, 10, 78, "Output",
      CellTags->"B.3"],
    Cell[64644, 2252, 114, 4, 24, "Text",
      CellTags->"B.3"],
    Cell[64783, 2260, 115, 3, 37, "Input",
      CellTags->"B.3"],
    Cell[64901, 2265, 74, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[64990, 2270, 177, 4, 38, "Text",
      CellTags->{"i:38", "B.3"}],
    Cell[65192, 2278, 83, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[65278, 2281, 73, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[65366, 2286, 148, 4, 38, "Text",
      CellTags->"B.3"],
    Cell[65539, 2294, 57, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[65599, 2297, 64, 2, 38, "Output",
      CellTags->"B.3"],
    Cell[65678, 2302, 463, 10, 68, "Text",
      CellTags->{"i:39", "B.3"}],
    Cell[66166, 2316, 71, 1, 37, "Input",
      CellTags->"B.3"],
    Cell[66240, 2319, 69, 2, 38, "Output",
      CellTags->"B.3"]},
  "i:26"->{
    Cell[42218, 1493, 351, 7, 68, "Text",
      CellTags->{"i:26", "B.3"}]},
  "i:27"->{
    Cell[42960, 1525, 518, 14, 86, "Text",
      CellTags->{"i:27", "B.3"}]},
  "i:28"->{
    Cell[45325, 1600, 483, 13, 68, "Text",
      CellTags->{"i:28", "B.3"}]},
  "i:29"->{
    Cell[47665, 1680, 654, 14, 112, "Text",
      CellTags->{"i:29", "B.3"}]},
  "i:30"->{
    Cell[48322, 1696, 433, 10, 72, "Text",
      CellTags->{"i:30", "B.3"}]},
  "i:31"->{
    Cell[53235, 1857, 714, 17, 112, "Text",
      CellTags->{"i:31", "B.3"}]},
  "i:32"->{
    Cell[54540, 1899, 925, 30, 116, "Text",
      CellTags->{"i:32", "B.3"}]},
  "i:33"->{
    Cell[55659, 1941, 266, 6, 52, "Text",
      CellTags->{"i:33", "B.3"}]},
  "i:34"->{
    Cell[60309, 2088, 406, 9, 68, "Text",
      CellTags->{"i:34", "B.3"}]},
  "i:35"->{
    Cell[60820, 2105, 329, 6, 66, "Text",
      CellTags->{"i:35", "B.3"}]},
  "i:36"->{
    Cell[62048, 2152, 148, 4, 38, "Text",
      CellTags->{"i:36", "B.3"}]},
  "i:37"->{
    Cell[62708, 2183, 550, 13, 86, "Text",
      CellTags->{"i:37", "B.3"}]},
  "i:38"->{
    Cell[64990, 2270, 177, 4, 38, "Text",
      CellTags->{"i:38", "B.3"}]},
  "i:39"->{
    Cell[65678, 2302, 463, 10, 68, "Text",
      CellTags->{"i:39", "B.3"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"B.0", 67654, 2359},
  {"B.1", 67862, 2366},
  {"i:1", 73374, 2531},
  {"i:2", 73459, 2534},
  {"i:3", 73545, 2537},
  {"i:4", 73630, 2540},
  {"i:5", 73715, 2543},
  {"i:6", 73801, 2546},
  {"i:7", 73888, 2549},
  {"i:8", 73974, 2552},
  {"i:9", 74060, 2555},
  {"i:10", 74147, 2558},
  {"i:11", 74235, 2561},
  {"B.2", 74322, 2564},
  {"i:12", 81750, 2781},
  {"i:13", 81838, 2784},
  {"i:14", 81926, 2787},
  {"i:15", 82015, 2790},
  {"i:16", 82103, 2793},
  {"i:17", 82191, 2796},
  {"i:18", 82281, 2799},
  {"i:19", 82370, 2802},
  {"i:20", 82461, 2805},
  {"i:21", 82550, 2808},
  {"i:22", 82639, 2811},
  {"i:23", 82728, 2814},
  {"i:24", 82817, 2817},
  {"i:25", 82907, 2820},
  {"B.3", 82997, 2823},
  {"i:26", 89944, 3027},
  {"i:27", 90033, 3030},
  {"i:28", 90123, 3033},
  {"i:29", 90213, 3036},
  {"i:30", 90304, 3039},
  {"i:31", 90394, 3042},
  {"i:32", 90485, 3045},
  {"i:33", 90576, 3048},
  {"i:34", 90665, 3051},
  {"i:35", 90754, 3054},
  {"i:36", 90843, 3057},
  {"i:37", 90932, 3060},
  {"i:38", 91022, 3063},
  {"i:39", 91111, 3066}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 52, 1, 92, "ChapterLine",
  CellTags->"B.0"],
Cell[1786, 54, 62, 1, 153, "Title",
  CellTags->"B.0"],
Cell[1851, 57, 287, 7, 54, "Text",
  CellTags->"B.0"],

Cell[CellGroupData[{
Cell[2163, 68, 60, 1, 40, "Section",
  CellTags->"B.1"],
Cell[2226, 71, 651, 15, 96, "Text",
  CellTags->{"i:1", "B.1"}],

Cell[CellGroupData[{
Cell[2902, 90, 98, 1, 37, "Input",
  CellTags->"B.1"],
Cell[3003, 93, 197, 6, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[3215, 102, 575, 10, 108, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[3815, 116, 68, 1, 37, "Input",
  CellTags->"B.1"],
Cell[3886, 119, 76, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[3977, 124, 304, 6, 66, "Text",
  CellTags->"B.1"],
Cell[4284, 132, 209, 5, 34, "BulletListItem",
  CellTags->"B.1"],
Cell[4496, 139, 227, 5, 48, "BulletListItem",
  CellTags->"B.1"],
Cell[4726, 146, 288, 6, 48, "BulletListItem",
  CellTags->"B.1"],
Cell[5017, 154, 602, 11, 106, "BulletListItem",
  CellTags->"B.1"],
Cell[5622, 167, 299, 6, 62, "BulletListItem",
  CellTags->"B.1"],
Cell[5924, 175, 247, 5, 52, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[6196, 184, 53, 1, 40, "Subsection",
  CellTags->"B.1"],
Cell[6252, 187, 403, 11, 70, "Text",
  CellTags->{"i:2", "B.1"}],

Cell[CellGroupData[{
Cell[6680, 202, 56, 1, 37, "Input",
  CellTags->"B.1"],
Cell[6739, 205, 68, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[6822, 210, 560, 18, 72, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[7407, 232, 61, 1, 37, "Input",
  CellTags->"B.1"],
Cell[7471, 235, 147, 3, 52, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[7633, 241, 284, 6, 66, "Text",
  CellTags->"B.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7954, 252, 82, 1, 40, "Subsection",
  CellTags->"B.1"],
Cell[8039, 255, 256, 5, 52, "Text",
  CellTags->{"i:3", "B.1"}],

Cell[CellGroupData[{
Cell[8320, 264, 42, 1, 37, "Input",
  CellTags->"B.1"],
Cell[8365, 267, 76, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[8456, 272, 107, 4, 24, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[8588, 280, 50, 1, 37, "Input",
  CellTags->"B.1"],
Cell[8641, 283, 54, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[8710, 288, 427, 8, 80, "Text",
  CellTags->{"i:4", "B.1"}],

Cell[CellGroupData[{
Cell[9162, 300, 65, 1, 37, "Input",
  CellTags->"B.1"],
Cell[9230, 303, 59, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[9304, 308, 574, 18, 86, "Text",
  CellTags->{"i:5", "B.1"}],

Cell[CellGroupData[{
Cell[9903, 330, 47, 1, 37, "Input",
  CellTags->"B.1"],
Cell[9953, 333, 62, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[10030, 338, 272, 6, 52, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[10327, 348, 48, 1, 37, "Input",
  CellTags->"B.1"],
Cell[10378, 351, 62, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[10455, 356, 238, 5, 52, "Text",
  CellTags->"B.1"],
Cell[10696, 363, 539, 9, 108, "Text",
  CellTags->{"i:6", "B.1"}],

Cell[CellGroupData[{
Cell[11260, 376, 42, 1, 37, "Input",
  CellTags->"B.1"],
Cell[11305, 379, 76, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11418, 386, 55, 1, 37, "Input",
  CellTags->"B.1"],
Cell[11476, 389, 63, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[11554, 394, 394, 7, 80, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[11973, 405, 55, 1, 37, "Input",
  CellTags->"B.1"],
Cell[12031, 408, 66, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[12112, 413, 198, 5, 38, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[12335, 422, 69, 1, 37, "Input",
  CellTags->"B.1"],
Cell[12407, 425, 63, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12519, 433, 72, 1, 40, "Subsection",
  CellTags->"B.1"],
Cell[12594, 436, 533, 9, 94, "Text",
  CellTags->{"i:7", "B.1"}],

Cell[CellGroupData[{
Cell[13152, 449, 42, 1, 37, "Input",
  CellTags->"B.1"],
Cell[13197, 452, 76, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[13288, 457, 192, 5, 38, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[13505, 466, 72, 1, 37, "Input",
  CellTags->"B.1"],
Cell[13580, 469, 64, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[13659, 474, 261, 6, 52, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[13945, 484, 74, 1, 37, "Input",
  CellTags->"B.1"],
Cell[14022, 487, 55, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[14092, 492, 231, 5, 52, "Text",
  CellTags->{"i:8", "B.1"}],

Cell[CellGroupData[{
Cell[14348, 501, 56, 1, 37, "Input",
  CellTags->"B.1"],
Cell[14407, 504, 64, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[14486, 509, 427, 8, 80, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[14938, 521, 108, 2, 37, "Input",
  CellTags->"B.1"],
Cell[15049, 525, 56, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[15120, 530, 276, 6, 52, "Text",
  CellTags->{"i:9", "B.1"}],

Cell[CellGroupData[{
Cell[15421, 540, 56, 1, 37, "Input",
  CellTags->"B.1"],
Cell[15480, 543, 54, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15583, 551, 65, 1, 40, "Subsection",
  CellTags->"B.1"],
Cell[15651, 554, 305, 8, 56, "Text",
  CellTags->{"i:10", "B.1"}],

Cell[CellGroupData[{
Cell[15981, 566, 77, 1, 37, "Input",
  CellTags->"B.1"],
Cell[16061, 569, 89, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[16165, 574, 450, 8, 80, "Text",
  CellTags->"B.1"],

Cell[CellGroupData[{
Cell[16640, 586, 68, 1, 37, "Input",
  CellTags->"B.1"],
Cell[16711, 589, 89, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],
Cell[16815, 594, 201, 5, 38, "Text",
  CellTags->"B.1"],
Cell[17019, 601, 456, 8, 80, "Text",
  CellTags->{"i:11", "B.1"}],

Cell[CellGroupData[{
Cell[17500, 613, 42, 1, 37, "Input",
  CellTags->"B.1"],
Cell[17545, 616, 76, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17658, 623, 80, 1, 37, "Input",
  CellTags->"B.1"],
Cell[17741, 626, 103, 2, 38, "Output",
  CellTags->"B.1"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[17905, 635, 62, 1, 40, "Section",
  CellTags->"B.2"],
Cell[17970, 638, 323, 6, 66, "Text",
  CellTags->{"i:12", "B.2"}],
Cell[18296, 646, 158, 4, 38, "Text",
  CellTags->"B.2"],
Cell[18457, 652, 271, 6, 76, "Input",
  CellTags->"B.2"],
Cell[18731, 660, 251, 6, 40, "Text",
  CellTags->{"i:13", "B.2"}],

Cell[CellGroupData[{
Cell[19007, 670, 60, 1, 37, "Input",
  CellTags->"B.2"],
Cell[19070, 673, 459, 10, 78, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[19544, 686, 812, 18, 130, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[20381, 708, 64, 1, 40, "Subsection",
  CellTags->"B.2"],
Cell[20448, 711, 309, 7, 54, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[20782, 722, 65, 1, 30, "Subsubsection",
  CellTags->"B.2"],
Cell[20850, 725, 592, 19, 86, "Text",
  CellTags->{"i:14", "B.2"}],

Cell[CellGroupData[{
Cell[21467, 748, 91, 4, 50, "Input",
  CellTags->"B.2"],
Cell[21561, 754, 83, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[21659, 759, 192, 5, 38, "Text",
  CellTags->"B.2"],
Cell[21854, 766, 717, 19, 114, "Text",
  CellTags->"B.2"],
Cell[22574, 787, 414, 7, 80, "Text",
  CellTags->{"i:15", "B.2"}],

Cell[CellGroupData[{
Cell[23013, 798, 67, 1, 37, "Input",
  CellTags->"B.2"],
Cell[23083, 801, 83, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23203, 808, 67, 1, 37, "Input",
  CellTags->"B.2"],
Cell[23273, 811, 83, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23405, 819, 49, 1, 30, "Subsubsection",
  CellTags->"B.2"],
Cell[23457, 822, 449, 8, 94, "Text",
  CellTags->{"i:16", "B.2"}],

Cell[CellGroupData[{
Cell[23931, 834, 51, 1, 37, "Input",
  CellTags->"B.2"],
Cell[23985, 837, 54, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[24054, 842, 762, 24, 104, "Text",
  CellTags->"B.2"],
Cell[24819, 868, 147, 4, 38, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[24991, 876, 99, 5, 63, "Input",
  CellTags->"B.2"],
Cell[25093, 883, 98, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25240, 891, 56, 1, 30, "Subsubsection",
  CellTags->"B.2"],
Cell[25299, 894, 778, 18, 128, "Text",
  CellTags->{"i:17", "B.2"}],
Cell[26080, 914, 288, 7, 54, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[26393, 925, 138, 3, 76, "Input",
  CellTags->"B.2"],
Cell[26534, 930, 101, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26684, 938, 60, 1, 30, "Subsubsection",
  CellTags->"B.2"],
Cell[26747, 941, 286, 6, 66, "Text",
  CellTags->"B.2"],
Cell[27036, 949, 140, 5, 22, "BulletListItem",
  CellTags->"B.2"],
Cell[27179, 956, 168, 5, 36, "BulletListItem",
  CellTags->"B.2"],
Cell[27350, 963, 135, 4, 38, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[27510, 971, 111, 5, 63, "Input",
  CellTags->"B.2"],
Cell[27624, 978, 109, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[27748, 983, 133, 4, 38, "Text",
  CellTags->"B.2"],
Cell[27884, 989, 150, 4, 34, "BulletListItem",
  CellTags->"B.2"],
Cell[28037, 995, 168, 4, 34, "BulletListItem",
  CellTags->"B.2"],
Cell[28208, 1001, 225, 6, 36, "BulletListItem",
  CellTags->"B.2"],
Cell[28436, 1009, 235, 7, 36, "BulletListItem",
  CellTags->"B.2"],
Cell[28674, 1018, 188, 5, 36, "BulletListItem",
  CellTags->"B.2"],
Cell[28865, 1025, 292, 7, 54, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[29182, 1036, 371, 6, 141, "Input",
  CellTags->"B.2"],
Cell[29556, 1044, 459, 10, 78, "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30076, 1061, 83, 1, 40, "Subsection",
  CellTags->"B.2"],
Cell[30162, 1064, 377, 9, 68, "Text",
  CellTags->{"i:18", "B.2"}],

Cell[CellGroupData[{
Cell[30564, 1077, 50, 1, 37, "Input",
  CellTags->"B.2"],
Cell[30617, 1080, 87, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[30719, 1085, 639, 16, 100, "Text",
  CellTags->{"i:19", "B.2"}],

Cell[CellGroupData[{
Cell[31383, 1105, 58, 1, 37, "Input",
  CellTags->"B.2"],
Cell[31444, 1108, 62, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[31521, 1113, 145, 4, 38, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[31691, 1121, 54, 1, 37, "Input",
  CellTags->"B.2"],
Cell[31748, 1124, 62, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[31825, 1129, 239, 5, 52, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[32089, 1138, 57, 1, 37, "Input",
  CellTags->"B.2"],
Cell[32149, 1141, 57, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[32221, 1146, 434, 8, 80, "Text",
  CellTags->{"i:20", "B.2"}],

Cell[CellGroupData[{
Cell[32680, 1158, 56, 1, 37, "Input",
  CellTags->"B.2"],
Cell[32739, 1161, 145, 3, 52, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[32899, 1167, 286, 6, 52, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[33210, 1177, 51, 1, 37, "Input",
  CellTags->"B.2"],
Cell[33264, 1180, 76, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[33355, 1185, 277, 7, 54, "Text",
  CellTags->{"i:21", "B.2"}],

Cell[CellGroupData[{
Cell[33657, 1196, 61, 1, 37, "Input",
  CellTags->"B.2"],
Cell[33721, 1199, 132, 3, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[33868, 1205, 127, 4, 38, "Text",
  CellTags->"B.2"],
Cell[33998, 1211, 209, 7, 42, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[34232, 1222, 61, 1, 37, "Input",
  CellTags->"B.2"],
Cell[34296, 1225, 61, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[34406, 1233, 63, 1, 40, "Subsection",
  CellTags->"B.2"],
Cell[34472, 1236, 293, 7, 54, "Text",
  CellTags->{"i:22", "B.2"}],

Cell[CellGroupData[{
Cell[34790, 1247, 62, 1, 37, "Input",
  CellTags->"B.2"],
Cell[34855, 1250, 246, 4, 66, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[35116, 1257, 267, 7, 54, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[35408, 1268, 101, 2, 37, "Input",
  CellTags->"B.2"],
Cell[35512, 1272, 122, 3, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[35649, 1278, 202, 5, 38, "Text",
  CellTags->{"i:23", "B.2"}],

Cell[CellGroupData[{
Cell[35876, 1287, 82, 1, 37, "Input",
  CellTags->"B.2"],
Cell[35961, 1290, 54, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[36030, 1295, 726, 12, 136, "Text",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36793, 1312, 68, 1, 40, "Subsection",
  CellTags->"B.2"],
Cell[36864, 1315, 518, 11, 82, "Text",
  CellTags->{"i:24", "B.2"}],

Cell[CellGroupData[{
Cell[37407, 1330, 68, 1, 37, "Input",
  CellTags->"B.2"],
Cell[37478, 1333, 246, 4, 66, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[37739, 1340, 236, 5, 52, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[38000, 1349, 92, 1, 37, "Input",
  CellTags->"B.2"],
Cell[38095, 1352, 246, 4, 66, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[38356, 1359, 738, 20, 100, "Text",
  CellTags->{"i:25", "B.2"}],

Cell[CellGroupData[{
Cell[39119, 1383, 60, 1, 37, "Input",
  CellTags->"B.2"],
Cell[39182, 1386, 459, 10, 78, "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39678, 1401, 80, 1, 37, "Input",
  CellTags->"B.2"],
Cell[39761, 1404, 459, 10, 78, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[40235, 1417, 178, 5, 38, "Text",
  CellTags->"B.2"],
Cell[40416, 1424, 318, 9, 56, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[40759, 1437, 71, 1, 37, "Input",
  CellTags->"B.2"],
Cell[40833, 1440, 459, 10, 78, "Output",
  CellTags->"B.2"]
}, Open  ]],
Cell[41307, 1453, 285, 6, 54, "Text",
  CellTags->"B.2"],

Cell[CellGroupData[{
Cell[41617, 1463, 96, 1, 37, "Input",
  CellTags->"B.2"],
Cell[41716, 1466, 74, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41827, 1473, 79, 1, 37, "Input",
  CellTags->"B.2"],
Cell[41909, 1476, 74, 2, 38, "Output",
  CellTags->"B.2"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[42044, 1485, 65, 1, 40, "Section",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[42134, 1490, 81, 1, 40, "Subsection",
  CellTags->"B.3"],
Cell[42218, 1493, 351, 7, 68, "Text",
  CellTags->{"i:26", "B.3"}],

Cell[CellGroupData[{
Cell[42594, 1504, 53, 1, 37, "Input",
  CellTags->"B.3"],
Cell[42650, 1507, 71, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[42736, 1512, 221, 11, 26, "Text",
  CellTags->"B.3"],
Cell[42960, 1525, 518, 14, 86, "Text",
  CellTags->{"i:27", "B.3"}],

Cell[CellGroupData[{
Cell[43503, 1543, 60, 1, 37, "Input",
  CellTags->"B.3"],
Cell[43566, 1546, 459, 10, 78, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[44040, 1559, 190, 5, 38, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[44255, 1568, 68, 1, 37, "Input",
  CellTags->"B.3"],
Cell[44326, 1571, 331, 7, 66, "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44694, 1583, 73, 1, 37, "Input",
  CellTags->"B.3"],
Cell[44770, 1586, 540, 11, 78, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[45325, 1600, 483, 13, 68, "Text",
  CellTags->{"i:28", "B.3"}],

Cell[CellGroupData[{
Cell[45833, 1617, 46, 1, 37, "Input",
  CellTags->"B.3"],
Cell[45882, 1620, 244, 4, 83, "Print",
  CellTags->"B.3"]
}, Open  ]],
Cell[46141, 1627, 390, 10, 70, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[46556, 1641, 48, 1, 37, "Input",
  CellTags->"B.3"],
Cell[46607, 1644, 140, 3, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46784, 1652, 93, 1, 37, "Input",
  CellTags->"B.3"],
Cell[46880, 1655, 234, 4, 66, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[47129, 1662, 162, 4, 38, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[47316, 1670, 96, 1, 37, "Input",
  CellTags->"B.3"],
Cell[47415, 1673, 235, 4, 66, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[47665, 1680, 654, 14, 112, "Text",
  CellTags->{"i:29", "B.3"}],
Cell[48322, 1696, 433, 10, 72, "Text",
  CellTags->{"i:30", "B.3"}],

Cell[CellGroupData[{
Cell[48780, 1710, 122, 4, 50, "Input",
  CellTags->"B.3"],
Cell[48905, 1716, 229, 7, 64, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[49149, 1726, 83, 1, 24, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[49257, 1731, 211, 6, 76, "Input",
  CellTags->"B.3"],
Cell[49471, 1739, 873, 17, 64, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[50359, 1759, 110, 4, 24, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[50494, 1767, 49, 1, 37, "Input",
  CellTags->"B.3"],
Cell[50546, 1770, 85, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[50646, 1775, 402, 10, 72, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[51073, 1789, 208, 6, 76, "Input",
  CellTags->"B.3"],
Cell[51284, 1797, 510, 11, 64, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[51809, 1811, 279, 6, 52, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[52113, 1821, 170, 5, 63, "Input",
  CellTags->"B.3"],
Cell[52286, 1828, 510, 11, 64, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[52811, 1842, 244, 6, 42, "Text",
  CellTags->"B.3"],
Cell[53058, 1850, 174, 5, 63, "Input",
  CellTags->"B.3"],
Cell[53235, 1857, 714, 17, 112, "Text",
  CellTags->{"i:31", "B.3"}],
Cell[53952, 1876, 217, 6, 76, "Input",
  CellTags->"B.3"],
Cell[54172, 1884, 263, 7, 89, "Input",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54472, 1896, 65, 1, 40, "Subsection",
  CellTags->"B.3"],
Cell[54540, 1899, 925, 30, 116, "Text",
  CellTags->{"i:32", "B.3"}],

Cell[CellGroupData[{
Cell[55490, 1933, 56, 1, 37, "Input",
  CellTags->"B.3"],
Cell[55549, 1936, 95, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[55659, 1941, 266, 6, 52, "Text",
  CellTags->{"i:33", "B.3"}],

Cell[CellGroupData[{
Cell[55950, 1951, 52, 1, 37, "Input",
  CellTags->"B.3"],
Cell[56005, 1954, 66, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[56086, 1959, 152, 4, 38, "Text",
  CellTags->"B.3"],
Cell[56241, 1965, 810, 16, 140, "Text",
  CellTags->"B.3"],
Cell[57054, 1983, 60, 1, 37, "Input",
  CellTags->"B.3"],
Cell[57117, 1986, 200, 5, 63, "Input",
  CellTags->"B.3"],
Cell[57320, 1993, 110, 4, 24, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[57455, 2001, 60, 1, 37, "Input",
  CellTags->"B.3"],
Cell[57518, 2004, 459, 10, 78, "Output",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58014, 2019, 91, 1, 37, "Input",
  CellTags->"B.3"],
Cell[58108, 2022, 459, 10, 78, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[58582, 2035, 352, 8, 70, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[58959, 2047, 117, 4, 50, "Input",
  CellTags->"B.3"],
Cell[59079, 2053, 466, 10, 78, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[59560, 2066, 605, 13, 98, "Text",
  CellTags->"B.3"],
Cell[60168, 2081, 138, 5, 50, "Input",
  Evaluatable->False,
  CellTags->"B.3"],
Cell[60309, 2088, 406, 9, 68, "Text",
  CellTags->{"i:34", "B.3"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[60752, 2102, 65, 1, 40, "Subsection",
  CellTags->"B.3"],
Cell[60820, 2105, 329, 6, 66, "Text",
  CellTags->{"i:35", "B.3"}],

Cell[CellGroupData[{
Cell[61174, 2115, 45, 1, 37, "Input",
  CellTags->"B.3"],
Cell[61222, 2118, 125, 3, 53, "Print",
  CellTags->"B.3"]
}, Open  ]],
Cell[61362, 2124, 477, 16, 70, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[61864, 2144, 65, 1, 37, "Input",
  CellTags->"B.3"],
Cell[61932, 2147, 101, 2, 43, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[62048, 2152, 148, 4, 38, "Text",
  CellTags->{"i:36", "B.3"}],

Cell[CellGroupData[{
Cell[62221, 2160, 61, 1, 37, "Input",
  CellTags->"B.3"],
Cell[62285, 2163, 75, 2, 41, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[62375, 2168, 227, 7, 40, "Text",
  CellTags->"B.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62639, 2180, 66, 1, 40, "Subsection",
  CellTags->"B.3"],
Cell[62708, 2183, 550, 13, 86, "Text",
  CellTags->{"i:37", "B.3"}],

Cell[CellGroupData[{
Cell[63283, 2200, 42, 1, 37, "Input",
  CellTags->"B.3"],
Cell[63328, 2203, 200, 4, 68, "Print",
  CellTags->"B.3"]
}, Open  ]],
Cell[63543, 2210, 164, 4, 38, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[63732, 2218, 62, 1, 37, "Input",
  CellTags->"B.3"],
Cell[63797, 2221, 62, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[63874, 2226, 208, 6, 40, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[64107, 2236, 60, 1, 37, "Input",
  CellTags->"B.3"],
Cell[64170, 2239, 459, 10, 78, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[64644, 2252, 114, 4, 24, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[64783, 2260, 115, 3, 37, "Input",
  CellTags->"B.3"],
Cell[64901, 2265, 74, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[64990, 2270, 177, 4, 38, "Text",
  CellTags->{"i:38", "B.3"}],

Cell[CellGroupData[{
Cell[65192, 2278, 83, 1, 37, "Input",
  CellTags->"B.3"],
Cell[65278, 2281, 73, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[65366, 2286, 148, 4, 38, "Text",
  CellTags->"B.3"],

Cell[CellGroupData[{
Cell[65539, 2294, 57, 1, 37, "Input",
  CellTags->"B.3"],
Cell[65599, 2297, 64, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]],
Cell[65678, 2302, 463, 10, 68, "Text",
  CellTags->{"i:39", "B.3"}],

Cell[CellGroupData[{
Cell[66166, 2316, 71, 1, 37, "Input",
  CellTags->"B.3"],
Cell[66240, 2319, 69, 2, 38, "Output",
  CellTags->"B.3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

