(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    601575,      10649]*)
(*NotebookOutlinePosition[    622040,      11252]*)
(*  CellTagsIndexPosition[    620847,      11204]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Appendix C", "ChapterLine",
  CellTags->"C.0"],

Cell["Graphics and Efficiency", "Title",
  CellTags->"C.0"],

Cell[TextData[{
  "In this appendix, we discuss two kinds of functions that are useful for \
enhancing the practicality of a simulation. We demonstrate a wide variety of \
graphics commands, employing functions that are either built-in or accessible \
in the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics packages, and can be used to visualize the results of a \
simulation run. We then create an alternative function to Nest and NestList \
that uses less memory than these functions during a simulation run and also \
gives the user more flexibility in the storage and visualization of \
simulation data."
}], "Text",
  CellTags->"C.0"],

Cell[CellGroupData[{

Cell["C.1  Graphics", "Section",
  CellTags->"C.1"],

Cell[TextData[{
  "The ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language is extremely rich in graphics commands and options to alter \
graphical output. Here, we give a brief description of the graphics commands \
used in this book."
}], "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell["C.1.1  RasterArray", "Subsection",
  CellTags->"C.1"],

Cell["\<\
One of the most common ways to visualize a matrix is by displaying \
an array of colored squares. The position of the squares corresponds to the \
position of the individuals and empty sites in the lattice, and the color of \
the squares gives information about some aspect of the individuals. We can \
easily create an array like this by using the built-in function RasterArray, \
which takes a matrix of colors as its argument.\
\>", "Text",
  CellTags->{"i:1", "C.1"}],

Cell["\<\
The colors can be given as shades of gray with the GrayLevel \
function. Other color functions include RGBColor, CMYKColor, and Hue. For \
this example, we begin with the same society used in Appendix B. Recall that \
empty sites are represented by a zero, and individuals have their behavior as \
the third argument to their list.\
\>", "Text",
  CellTags->{"i:2", "C.1"}],

Cell[CellGroupData[{

Cell["\<\
society = {{0, 0, 0, {3, 1, 1, {2, 3, 4}, 4}}, {0, {3, 2, 1, {4, 3, \
3}, 3}, {2, 3, 1, {4, 3, 4}, 1}, {2, 4, 1, {5, 3, 1}, 3}}, {0, {1, 5, 1, {5, \
3, 5}, 2}, 0, {1, 6, 0, {2, 1, 5}, 4}}, {0, 0, 0, {4, 7, 1, {4, 5, 5}, 3}}};
TraditionalForm[society]\
\>", "Input",
  CellTags->"C.1"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0", "0", \({3, 1, 1, {2, 3, 4}, 4}\)},
            {"0", \({3, 2, 1, {4, 3, 3}, 3}\), \({2, 3, 1, {4, 3, 4}, 1}\), 
              \({2, 4, 1, {5, 3, 1}, 3}\)},
            {"0", \({1, 5, 1, {5, 3, 5}, 2}\), "0", 
              \({1, 6, 0, {2, 1, 5}, 4}\)},
            {"0", "0", "0", \({4, 7, 1, {4, 5, 5}, 3}\)}
            }], ")"}], TraditionalForm]], "Output",
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
We observe that the individual named \"6\" is the only individual \
in the matrix that has a behavior of 0, and the rest have behavior 1. Using \
Map, we replace the empty sites with white (GrayLevel[1]) and individuals \
with either gray (GrayLevel[0.5]) or black (GrayLevel[0]) depending on \
whether they have behavior 1 or 0, respectively.\
\>", "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell["\<\
MatrixForm[
  Map[If[# === 0, GrayLevel[1], GrayLevel[#[[3]]/2]]&,
      society, {2}]]\
\>", "Input",
  CellTags->"C.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(GrayLevel[1]\), \(GrayLevel[1]\), \(GrayLevel[1]\), 
              \(GrayLevel[1\/2]\)},
            {\(GrayLevel[1]\), \(GrayLevel[1\/2]\), \(GrayLevel[1\/2]\), 
              \(GrayLevel[1\/2]\)},
            {\(GrayLevel[1]\), \(GrayLevel[1\/2]\), \(GrayLevel[1]\), 
              \(GrayLevel[0]\)},
            {\(GrayLevel[1]\), \(GrayLevel[1]\), \(GrayLevel[1]\), 
              \(GrayLevel[1\/2]\)}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
We can then display the grid as squares of colors using \
RasterArray. (The symbols Show, Graphics, Frame, and AspectRatio are \
described shortly.)\
\>", "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell[TextData[
"Show[Graphics[RasterArray[\n  Map[If[# === 0, GrayLevel[1], \
GrayLevel[#[[3]]/2]]&,\n      society, {2}]]],\n  Frame \[Rule] True, \
AspectRatio \[Rule] Automatic];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002F0000UR000`400?l0
0000o`00003oUP3oool009H0oooo000<0?ooo`8000007@3oool3000001h0
oooo1000000M0?ooo`<000007`3oool3000000@0oooo000;0?ooo`040000
003oool0oooo000001d0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00`3oool000/0oooo00@000000?ooo`3oool000007@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool06`3oool4000000@0oooo000;0?ooo`040000003oool0oooo000001d0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0L0?ooo`80
00007P3oool00`000000oooo000000050?ooo`002`3oool010000000oooo
0?ooo`00000M0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3o
ool00000803oool00`000000oooo0?ooo`0K0?ooo`030000003oool00000
00D0oooo000<0?ooo`8000007@3oool200000200oooo0P00000N0?ooo`<0
00007`3oool2000000D0oooo002F0?ooo`00UP3oool000T0ooooR`000002
0?ooo`002@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`00103oool2
000000<0oooo00<000000?ooo`3oool0Q`3oool100000040oooo0@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`27
0?ooo`4000000@3oool10?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`800000Q`3oool200000080oooo00030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@000001
0?ooo`40oooo00030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00040?oo
o`8000000`3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo
8@20P8030?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo8@20
P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S
0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo00<000000?oo
o`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo
0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo8@20P803
0?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo8@20P8030?oo
o`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40
P8200`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003o
ool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool0
0`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool0
00T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?oo
o`40oooo00090?ooo`800000I03ooolQ0820P0<0oooo0@0000010?ooo`40
oooo00090?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ
0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo
06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000
oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo
00090?ooo`800000I03ooolQ0820P0<0oooo0@0000010?ooo`40oooo0009
0?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo
8@20P8030?ooo`4000000@3oool10?ooo`000`3oool3000000<0oooo00<0
00000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo0004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3ooolQ
0820P0<0oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo
0080oooo0P00001T0?ooob40P8200P3oool200000080oooo00040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08P3ooomR0820P0<0
oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo
00030?ooo`800000103oool00`000000oooo0?ooo`0R0?ooof80P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR
0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo
0280ooooHP20P8030?ooo`4000000@3oool10?ooo`002@3oool2000002<0
ooooHP20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo
0?ooo`0R0?ooof80P8200`3oool100000040oooo0@3oool000T0oooo00<0
00000?ooo`3oool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo0009
0?ooo`030000003oool0oooo0280ooooHP20P8030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`0R0?ooof80P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0280oooo
HP20P8030?ooo`4000000@3oool10?ooo`002@3oool2000002<0ooooHP20
P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R
0?ooof80P8200`3oool100000040oooo0@3oool000T0oooo00<000000?oo
o`3oool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo0280ooooHP20P8030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo
0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`8000008`3ooomR0820P0<0oooo0@000001
0?ooo`40oooo00090?ooo`030000003oool0oooo0280ooooHP20P8030?oo
o`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?ooof80
P8200`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
8P3ooomR0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003o
ool0oooo0280ooooHP20P8030?ooo`4000000@3oool10?ooo`002@3oool0
0`000000oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo0@3oool0
00T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@0000010?oo
o`40oooo00090?ooo`8000008`3ooomR0820P0<0oooo0@0000010?ooo`40
oooo00090?ooo`030000003oool0oooo0280ooooHP20P8030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?ooof80P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR
0820P0<0oooo0@0000010?ooo`40oooo00030?ooo`@000000P3oool00`00
0000oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo0@3oool000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0R0?ooof80
P8200`3oool100000040oooo0@3oool000D0oooo00@000000?ooo`3oool0
oooo0P00000S0?ooof80P8200P3oool200000080oooo00060?ooo`040000
003oool0oooo000002@0oooo8@20P80P0?ooob4000000`3oool100000040
oooo0@3oool000<0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo0@0000010?ooo`40
oooo00040?ooo`8000000`3oool00`000000oooo0?ooo`0R0?ooob40P820
803ooolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`030000003o
ool0oooo0280oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3o
ool000T0oooo00<000000?ooo`3oool08P3ooolQ0820P200oooo8@000003
0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?oo
ob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`80
00008`3ooolQ0820P200oooo8@0000030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo
0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0280oooo8@20
P80P0?ooob4000000`3oool100000040oooo0@3oool000T0oooo00<00000
0?ooo`3oool08P3ooolQ0820P200oooo8@0000030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ0000
00<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0280
oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3oool000T0oooo
0P00000S0?ooob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo
00090?ooo`030000003oool0oooo0280oooo8@20P80P0?ooob4000000`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooolQ
0820P200oooo8@0000030?ooo`4000000@3oool10?ooo`002@3oool00`00
0000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo0@0000010?oo
o`40oooo00090?ooo`030000003oool0oooo0280oooo8@20P80P0?ooob40
00000`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
8P3ooolQ0820P200oooo8@0000030?ooo`4000000@3oool10?ooo`002@3o
ool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo0@00
00010?ooo`40oooo00090?ooo`8000008`3ooolQ0820P200oooo8@000003
0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?oo
ob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo0280oooo8@20P80P0?ooob4000000`3oool100000040
oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooolQ0820P200oooo
8@0000030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?oo
o`0R0?ooob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo0009
0?ooo`030000003oool0oooo0280oooo8@20P80P0?ooob4000000`3oool1
00000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooolQ0820
P200oooo8@0000030?ooo`4000000@3oool10?ooo`002@3oool2000002<0
oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool08P3ooolQ0820P200oooo8@0000030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?ooob40P820803o
oolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0
oooo0280oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3oool0
00<0oooo0`0000030?ooo`030000003oool0oooo0280oooo8@20P80P0?oo
ob4000000`3oool100000040oooo0@3oool000H0oooo00@000000?ooo`3o
ool00000903ooolQ0820P200oooo8@0000030?ooo`4000000@3oool10?oo
o`001P3oool00`000000oooo0?ooo`02000002<0oooo8@20P80P0?ooob40
00000P3oool200000080oooo00040?ooo`8000000`3oool00`000000oooo
0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool000H0oooo00@0
00000?ooo`3oool00000I@3ooolQ0820P0<0oooo0@0000010?ooo`40oooo
00030?ooo`<000000`3oool00`000000oooo0?ooo`1S0?ooob40P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ
0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo
06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000
oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo
0P00001T0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo00<0
00000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo0009
0?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo
8@20P8030?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo8@20
P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S
0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo00<000000?oo
o`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo
0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo8@20P803
0?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo8@20P8030?oo
o`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40
P8200`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003o
ool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool0
0`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool0
00T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?oo
o`40oooo00090?ooo`800000I03ooolQ0820P0<0oooo0@0000010?ooo`40
oooo00090?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ
0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo
06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`00103oool300000080
oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40
oooo00050?ooo`050000003oool0oooo0?ooo`000000I@3ooolQ0820P0<0
oooo0@0000010?ooo`40oooo00030?ooo`@000000P3oool2000006@0oooo
8@20P8020?ooo`8000000P3oool000<0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`270?ooo`4000000@3oool10?ooo`000`3oool0
0`000000oooo000000030?ooo`050000003oool0oooo0?ooo`0000007`3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool07P3oool010000000oooo0?ooo`0000020?ooo`00103o
ool2000000<0ooooR`0000020?ooo`00UP3oool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{150.75, 150.75},
  ImageMargins->{{163.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell[TextData[{
  "Notice that the first row of the matrix is drawn as the bottom row of the \
RasterArray graphic. In order to draw the graphic with the same orientation \
as that in which the matrix is displayed in MatrixForm, the order of the rows \
must be reversed. This is done by replacing ",
  StyleBox["society", "IT"],
  " with Reverse[",
  StyleBox["society", "IT"],
  "]."
}], "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell[TextData[
"Show[Graphics[RasterArray[\n  Map[If[# === 0, GrayLevel[1], \
GrayLevel[#[[3]]/2]]&,\n      Reverse[society], {2}]]],\n  Frame \[Rule] \
True, AspectRatio \[Rule] Automatic];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002F0000UR000`400?l0
0000o`00003oUP3oool009H0oooo000<0?ooo`8000007@3oool3000001h0
oooo1000000M0?ooo`<000007`3oool3000000@0oooo000;0?ooo`040000
003oool0oooo000001d0oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00`3oool000/0oooo00@000000?ooo`3oool000007@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool06`3oool4000000@0oooo000;0?ooo`040000003oool0oooo000001d0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0L0?ooo`80
00007P3oool00`000000oooo000000050?ooo`002`3oool010000000oooo
0?ooo`00000M0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3o
ool00000803oool00`000000oooo0?ooo`0K0?ooo`030000003oool00000
00D0oooo000<0?ooo`8000007@3oool200000200oooo0P00000N0?ooo`<0
00007`3oool2000000D0oooo002F0?ooo`00UP3oool000T0ooooR`000002
0?ooo`002@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0103oool010000000oooo0?ooo`0000020?ooo`00103oool2
000000<0oooo00<000000?ooo`3oool0Q`3oool100000040oooo0@3oool0
00<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`27
0?ooo`4000000@3oool10?ooo`000`3oool010000000oooo0?ooo`000002
0?ooo`800000Q`3oool200000080oooo00030?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@000001
0?ooo`40oooo00030?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00040?oo
o`8000000`3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo
8@20P8030?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo8@20
P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S
0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo00<000000?oo
o`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo
0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo8@20P803
0?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo8@20P8030?oo
o`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40
P8200`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003o
ool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool0
0`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool0
00T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?oo
o`40oooo00090?ooo`800000I03ooolQ0820P0<0oooo0@0000010?ooo`40
oooo00090?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ
0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo
06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000
oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo
00090?ooo`800000I03ooolQ0820P0<0oooo0@0000010?ooo`40oooo0009
0?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo
8@20P8030?ooo`4000000@3oool10?ooo`000`3oool3000000<0oooo00<0
00000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo0004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0H`3ooolQ
0820P0<0oooo0@0000010?ooo`40oooo00040?ooo`030000003oool0oooo
0080oooo0P00001T0?ooob40P8200P3oool200000080oooo00040?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool08P3ooolQ0820P200
oooo8@0000030?ooo`4000000@3oool10?ooo`00103oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0280oooo8@20P80P0?ooob400000
0`3oool100000040oooo0@3oool000<0oooo0P0000040?ooo`030000003o
ool0oooo0280oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3o
ool000T0oooo00<000000?ooo`3oool08P3ooolQ0820P200oooo8@000003
0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?oo
ob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`80
00008`3ooolQ0820P200oooo8@0000030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo
0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0280oooo8@20
P80P0?ooob4000000`3oool100000040oooo0@3oool000T0oooo00<00000
0?ooo`3oool08P3ooolQ0820P200oooo8@0000030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ0000
00<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0280
oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool08P3ooolQ0820P200oooo8@0000030?ooo`400000
0@3oool10?ooo`002@3oool2000002<0oooo8@20P80P0?ooob4000000`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooolQ
0820P200oooo8@0000030?ooo`4000000@3oool10?ooo`002@3oool00`00
0000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo0@0000010?oo
o`40oooo00090?ooo`030000003oool0oooo0280oooo8@20P80P0?ooob40
00000`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
8P3ooolQ0820P200oooo8@0000030?ooo`4000000@3oool10?ooo`002@3o
ool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0oooo0@00
00010?ooo`40oooo00090?ooo`8000008`3ooolQ0820P200oooo8@000003
0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?oo
ob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`03
0000003oool0oooo0280oooo8@20P80P0?ooob4000000`3oool100000040
oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooolQ0820P200oooo
8@0000030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?oo
o`0R0?ooob40P820803ooolQ000000<0oooo0@0000010?ooo`40oooo0009
0?ooo`030000003oool0oooo0280oooo8@20P80P0?ooob4000000`3oool1
00000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooolQ0820
P200oooo8@0000030?ooo`4000000@3oool10?ooo`002@3oool2000002<0
oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool08P3ooolQ0820P200oooo8@0000030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?ooob40P820803o
oolQ000000<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0
oooo0280oooo8@20P80P0?ooob4000000`3oool100000040oooo0@3oool0
00<0oooo100000020?ooo`030000003oool0oooo0280oooo8@20P80P0?oo
ob4000000`3oool100000040oooo0@3oool000@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0R0?ooob40P820803ooolQ000000<0
oooo0@0000010?ooo`40oooo00050?ooo`040000003oool0oooo0?ooo`80
00008`3ooolQ0820P200oooo8@0000020?ooo`8000000P3oool000H0oooo
00@000000?ooo`3oool00000903ooomR0820P0<0oooo0@0000010?ooo`40
oooo00030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo00040?ooo`800000
0`3oool00`000000oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo
0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`030000003oool0oooo0280ooooHP20P803
0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?oo
of80P8200`3oool100000040oooo0@3oool000T0oooo0P00000S0?ooof80
P8200`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0
8P3ooomR0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003o
ool0oooo0280ooooHP20P8030?ooo`4000000@3oool10?ooo`002@3oool0
0`000000oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo0@3oool0
00T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@0000010?oo
o`40oooo00090?ooo`030000003oool0oooo0280ooooHP20P8030?ooo`40
00000@3oool10?ooo`002@3oool2000002<0ooooHP20P8030?ooo`400000
0@3oool10?ooo`002@3oool00`000000oooo0?ooo`0R0?ooof80P8200`3o
ool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR
0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo
0280ooooHP20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000
oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo
00090?ooo`030000003oool0oooo0280ooooHP20P8030?ooo`4000000@3o
ool10?ooo`002@3oool2000002<0ooooHP20P8030?ooo`4000000@3oool1
0?ooo`002@3oool00`000000oooo0?ooo`0R0?ooof80P8200`3oool10000
0040oooo0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0
oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo0280oooo
HP20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?oo
o`0R0?ooof80P8200`3oool100000040oooo0@3oool000T0oooo00<00000
0?ooo`3oool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo00090?oo
o`030000003oool0oooo0280ooooHP20P8030?ooo`4000000@3oool10?oo
o`002@3oool2000002<0ooooHP20P8030?ooo`4000000@3oool10?ooo`00
2@3oool00`000000oooo0?ooo`0R0?ooof80P8200`3oool100000040oooo
0@3oool000T0oooo00<000000?ooo`3oool08P3ooomR0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`030000003oool0oooo0280ooooHP20P803
0?ooo`4000000@3oool10?ooo`000`3oool3000000<0oooo00<000000?oo
o`3oool08P3ooomR0820P0<0oooo0@0000010?ooo`40oooo00060?ooo`04
0000003oool0oooo000002@0ooooHP20P8030?ooo`4000000@3oool10?oo
o`001P3oool00`000000oooo0?ooo`02000002<0ooooHP20P8020?ooo`80
00000P3oool000@0oooo0P0000030?ooo`030000003oool0oooo06<0oooo
8@20P8030?ooo`4000000@3oool10?ooo`001P3oool010000000oooo0?oo
o`00001U0?ooob40P8200`3oool100000040oooo0@3oool000<0oooo0`00
00030?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3o
ool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool1
00000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820
P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0oooo06<0
oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool2000006@0oooo
8@20P8030?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?oo
o`1S0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo00<00000
0?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?oo
o`030000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?oo
o`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040
oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo
0@0000010?ooo`40oooo00090?ooo`800000I03ooolQ0820P0<0oooo0@00
00010?ooo`40oooo00090?ooo`030000003oool0oooo06<0oooo8@20P803
0?ooo`4000000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?oo
ob40P8200`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3o
ool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000
003oool0oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3o
ool00`000000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3o
ool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@000001
0?ooo`40oooo00090?ooo`800000I03ooolQ0820P0<0oooo0@0000010?oo
o`40oooo00090?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`40
00000@3oool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P820
0`3oool100000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3o
oolQ0820P0<0oooo0@0000010?ooo`40oooo00090?ooo`030000003oool0
oooo06<0oooo8@20P8030?ooo`4000000@3oool10?ooo`002@3oool00`00
0000oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool000T0
oooo0P00001T0?ooob40P8200`3oool100000040oooo0@3oool000T0oooo
00<000000?ooo`3oool0H`3ooolQ0820P0<0oooo0@0000010?ooo`40oooo
00090?ooo`030000003oool0oooo06<0oooo8@20P8030?ooo`4000000@3o
ool10?ooo`002@3oool00`000000oooo0?ooo`1S0?ooob40P8200`3oool1
00000040oooo0@3oool000T0oooo00<000000?ooo`3oool0H`3ooolQ0820
P0<0oooo0@0000010?ooo`40oooo00040?ooo`<000000P3oool00`000000
oooo0?ooo`1S0?ooob40P8200`3oool100000040oooo0@3oool000D0oooo
00D000000?ooo`3oool0oooo0000001U0?ooob40P8200`3oool100000040
oooo0@3oool000<0oooo100000020?ooo`800000I03ooolQ0820P080oooo
0P0000020?ooo`000`3oool00`000000oooo000000030?ooo`030000003o
ool0oooo08L0oooo0@0000010?ooo`40oooo00030?ooo`030000003oool0
000000<0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0N0?ooo`040000003oool0oooo00000080oooo00040?ooo`8000000`3o
oon;00000080oooo002F0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{150.75, 150.75},
  ImageMargins->{{163.25, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.1.2  Graphics Primitives, Directives, and Options", "Subsection",
  CellTags->"C.1"],

Cell[TextData[{
  "As with RasterArray, the main syntax for displaying two-dimensional \
graphics objects is Show[Graphics[",
  StyleBox["listOfObjects", "IT"],
  "]]. This ",
  StyleBox["listOfObjects", "IT"],
  " can contain graphics ",
  StyleBox["primitives",
    FontSlant->"Italic"],
  " and graphics ",
  StyleBox["directives",
    FontSlant->"Italic"],
  ". Graphics primitives should be thought of as building blocks from which \
other graphical objects are constructed. Examples of graphics primitives are \
Point, Line, and Polygon. The syntax for these primitives can be found in the \
online help, or by asking the kernel for their usage messages."
}], "Text",
  CellTags->{"i:3", "C.1"}],

Cell[TextData[{
  "Graphics directives are used to alter the display of the graphics \
primitives that follow the directive in the ",
  StyleBox["listOfObjects", "IT"],
  ". For instance, color is a graphics directive, so you can use an RGBColor \
or GrayLevel specification before a Polygon in order to draw a shaded \
polygon. Other directives include PointSize and Thickness."
}], "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell["\<\
Show[Graphics[{GrayLevel[0.7],
                  Polygon[{{0, 0}, {0, 2}, {10, 1}}]}]];\
\>", "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40001i0000BR000`400?l0
0000o`00003oN@3oool007T0oooo00030?ooo`<0/k>cL`3oool000<0oooo
1P2c/k=`0?ooo`000`3oool90;>c/fd0oooo00030?ooo``0/k>cJP3oool0
00<0oooo3`2c/k=W0?ooo`000`3ooolB0;>c/f@0oooo00030?oooaH0/k>c
H03oool000<0oooo6@2c/k=M0?ooo`000`3ooolL0;>c/eX0oooo00030?oo
oal0/k>cE`3oool000<0oooo8P2c/k=D0?ooo`000`3ooolU0;>c/e40oooo
00030?ooobT0/k>cC@3oool000<0oooo;02c/k=:0?ooo`000`3oool_0;>c
/dL0oooo00030?oooc80/k>cA03oool000<0oooo=@2c/k=10?ooo`000`3o
oolh0;>c/ch0oooo00030?oooc`0/k>c>P3oool000<0oooo?`2c/k<g0?oo
o`000`3ooom20;>c/c@0oooo00030?ooodD0/k>c<@3oool000<0ooooB02c
/k<^0?ooo`000`3ooom;0;>c/b/0oooo00030?ooodl0/k>c9`3oool000<0
ooooDP2c/k<T0?ooo`000`3ooomE0;>c/b40oooo00030?oooeP0/k>c7P3o
ool000<0ooooF`2c/k<K0?ooo`000`3ooomN0;>c/aP0oooo00030?ooof80
/k>c503oool000<0ooooI@2c/k<A0?ooo`000`3ooomX0;>c/`h0oooo0003
0?ooof/0/k>c2`3oool000<0ooooKP2c/k<80?ooo`000`3oooma0;>c/`D0
oooo00030?ooog00/k>c1P3oool000<0ooooK@2c/k<90?ooo`000`3ooomZ
0;>c/``0oooo00030?ooofL0/k>c3`3oool000<0ooooH`2c/k<C0?ooo`00
0`3ooomP0;>c/aH0oooo00030?oooed0/k>c6@3oool000<0ooooFP2c/k<L
0?ooo`000`3ooomF0;>c/b00oooo00030?oooe<0/k>c8`3oool000<0oooo
D02c/k<V0?ooo`000`3ooom=0;>c/bT0oooo00030?ooodT0/k>c;@3oool0
00<0ooooAP2c/k<`0?ooo`000`3ooom30;>c/c<0oooo00030?oood00/k>c
=P3oool000<0oooo?02c/k<j0?ooo`000`3oooli0;>c/cd0oooo00030?oo
ocH0/k>c@03oool000<0oooo<P2c/k=40?ooo`000`3oool_0;>c/dL0oooo
00030?ooob`0/k>cBP3oool000<0oooo:@2c/k==0?ooo`000`3ooolU0;>c
/e40oooo00030?ooob80/k>cE03oool000<0oooo7`2c/k=G0?ooo`000`3o
oolL0;>c/eX0oooo00030?oooaP0/k>cGP3oool000<0oooo5@2c/k=Q0?oo
o`000`3ooolB0;>c/f@0oooo00030?ooo`l0/k>cI`3oool000<0oooo2`2c
/k=[0?ooo`000`3oool80;>c/fh0oooo00030?ooo`D0/k>cL@3oool000<0
oooo0P2c/k=d0?ooo`00N@3oool00001\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{121.5, 74.8125},
  ImageMargins->{{181.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell[TextData[{
  "Another powerful way to alter the display of a graphic is to use ",
  StyleBox["options",
    FontSlant->"Italic"],
  ". A graphics option is either a Rule (\[Rule]) or a RuleDelayed (\
\[RuleDelayed]) expression that specifies how a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics function should behave. Many built-in functions have options, \
but for the time being we focus on graphics options. A sequence of options is \
typically given to a function after its usual arguments. Thus, a sequence of \
options is inserted into the Show command as"
}], "Text",
  CellTags->{"i:4", "C.1"}],

Cell[TextData[{
  "Show[Graphics[",
  StyleBox["listOfObjects",
    FontSlant->"Italic"],
  "], ",
  StyleBox["option1",
    FontSlant->"Italic"],
  " \[Rule] ",
  StyleBox["setting1",
    FontSlant->"Italic"],
  ",\n              ",
  StyleBox["option2",
    FontSlant->"Italic"],
  " \[Rule] ",
  StyleBox["setting2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["optionk",
    FontSlant->"Italic"],
  " \[Rule] ",
  StyleBox["settingk",
    FontSlant->"Italic"],
  "]"
}], "Input",
  CellTags->"C.1"],

Cell["\<\
We've already seen an example of graphics options in the \
RasterArray command earlier in this appendix. Frame is an option that if set \
to True will draw a frame around the graphic. AspectRatio specifies the ratio \
of the height of a plot to its width, and a setting of Automatic chooses this \
ratio so that the same distance along both axes is drawn with the same \
length.\
\>", "Text",
  CellTags->{"i:5", "C.1"}],

Cell[CellGroupData[{

Cell[TextData[
"Show[Graphics[\n  {GrayLevel[0.8], Polygon[{{0, 0}, {0, 2}, {10, 1}}]}],\n  \
Frame \[Rule] True,\n  AspectRatio \[Rule] Automatic,\n  PlotLabel \[Rule] \
\"Gray Triangle\"];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005;0000@R000`400?l0
0000o`00003oo`3ooom<0?ooo`00o`3ooom<0?ooo`00D03oool200000280
oooo1000000S0?ooo`<000008P3oool2000002<0oooo0P00000P0?ooo`<0
0000103oool2000003/0oooo001?0?ooo`040000003oool0oooo00000280
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0P0?ooo`04
0000003oool0oooo00000240oooo00@000000?ooo`3oool00000803oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000003X0oooo001?
0?ooo`040000003oool0oooo000002<0oooo00<000000?ooo`3oool08@3o
ool400000240oooo00@000000?ooo`3oool000008@3oool010000000oooo
0?ooo`00000P0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool00000>P3oool004l0oooo00@000000?ooo`3oool00000903oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool000000280oooo0`00000S0?oo
o`8000008@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
000003X0oooo001?0?ooo`040000003oool0oooo00000240oooo00@00000
0?ooo`3oool000008P3oool00`000000oooo0000000R0?ooo`030000003o
ool0oooo0280oooo00@000000?ooo`3oool00000803oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000003X0oooo001@0?ooo`800000
8`3oool2000002@0oooo0P00000S0?ooo`<000008P3oool200000200oooo
0P0000050?ooo`800000>`3oool00?l0ooooC03oool00?l0ooooC03oool0
0?l0ooooC03oool004H0oooo0P00003o0?ooo`@0oooo00150?ooo`040000
003oool0oooo000000<0ooooa@00000j0?ooo`00A@3oool010000000oooo
0?ooo`0000030?ooo`<000000P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P00000j0?ooo`00
A@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo1P3<c<bi0?ooo`030000003oool0oooo03P0oooo00150?ooo`040000
003oool0oooo000000<0oooo0P0000030?oooa40c<c<[P3oool00`000000
oooo0?ooo`0h0?ooo`00AP3oool2000000@0oooo0P0000030?oooa/0c<c<
Y03oool00`000000oooo0?ooo`0h0?ooo`00C03oool00`000000oooo0?oo
o`020?ooobD0c<c<VP3oool00`000000oooo0?ooo`0h0?ooo`00C03oool2
000000<0oooo<03<c<b?0?ooo`030000003oool0oooo03P0oooo001<0?oo
o`030000003oool0oooo0080oooo>P3<c<b50?ooo`030000003oool0oooo
03P0oooo000j0?ooo`800000103oool2000000<0oooo0`0000040?ooo`80
00000`3ooom50<c<c7X0oooo00<000000?ooo`3oool0>03oool003T0oooo
00@000000?ooo`3oool000000`3oool2000000H0oooo00D000000?ooo`3o
ool0oooo000000040?ooodl0c<c<L03oool00`000000oooo0?ooo`0h0?oo
o`00>@3oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo
0?ooo`<000000P3ooomI0<c<c6D0oooo0P00000j0?ooo`00>@3oool01000
0000oooo0?ooo`0000080?ooo`<00000103oool00`000000oooo0?ooo`02
0?ooof@0c<c<F`3oool00`000000oooo0?ooo`0h0?ooo`00>@3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo0P000003
0?ooofh0c<c<D@3oool00`000000oooo0?ooo`0h0?ooo`00>P3oool20000
00T0oooo100000030?ooo`030000003oool0oooo0080ooooN03<c<a70?oo
o`030000003oool0oooo03P0oooo001<0?ooo`8000000`3ooon30<c<c3`0
oooo00<000000?ooo`3oool0>03oool004`0oooo00<000000?ooo`3oool0
0P3ooon=0<c<c380oooo00<000000?ooo`3oool0>03oool004`0oooo0P00
00030?oooiP0c<c<9`3oool00`000000oooo0?ooo`0h0?ooo`00A@3oool3
000000@0oooo00<000000?ooo`3oool00P3ooonR0<c<c1d0oooo00<00000
0?ooo`3oool0>03oool004H0oooo00<000000?ooo`3oool00`3oool20000
00<0oooo[03<c<`C0?ooo`030000003oool0oooo03P0oooo00160?ooo`03
0000003oool0oooo00<0oooo0`0000020?oookL0c<c<1`3oool2000003X0
oooo00160?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3ooonf0<c<c0T0oooo00<000000?ooo`3oool0>03oool004H0oooo00<0
00000?ooo`3oool00`3oool2000000<0oooo[03<c<`C0?ooo`030000003o
ool0oooo03P0oooo00150?ooo`8000001@3oool00`000000oooo0?ooo`02
0?oooj80c<c<7@3oool00`000000oooo0?ooo`0h0?ooo`00C03oool20000
00<0ooooV@3<c<`V0?ooo`030000003oool0oooo03P0oooo001<0?ooo`03
0000003oool0oooo0080ooooS`3<c<``0?ooo`030000003oool0oooo03P0
oooo001<0?ooo`8000000`3ooon50<c<c3X0oooo00<000000?ooo`3oool0
>03oool004`0oooo00<000000?ooo`3oool00P3ooomk0<c<c4@0oooo00<0
00000?ooo`3oool0>03oool003T0oooo0`0000040?ooo`8000000`3oool3
000000@0oooo0P0000030?ooog40c<c<CP3oool00`000000oooo0?ooo`0h
0?ooo`00>P3oool00`000000oooo0?ooo`030?ooo`8000001P3oool01@00
0000oooo0?ooo`3oool0000000@0ooooI`3<c<aH0?ooo`030000003oool0
oooo03P0oooo000j0?ooo`030000003oool0oooo00/0oooo00@000000?oo
o`3oool0oooo0`0000020?oooed0c<c<H@3oool2000003X0oooo000j0?oo
o`030000003oool0oooo00P0oooo0`0000040?ooo`030000003oool0oooo
0080ooooE03<c<a[0?ooo`030000003oool0oooo03P0oooo000j0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool2000000<0
ooooBP3<c<ae0?ooo`030000003oool0oooo03P0oooo000i0?ooo`800000
2P3oool4000000<0oooo00<000000?ooo`3oool00P3ooom00<c<c7l0oooo
00<000000?ooo`3oool0>03oool004`0oooo0P0000030?ooocH0c<c<R@3o
ool00`000000oooo0?ooo`0h0?ooo`00C03oool2000000<0oooo;03<c<bC
0?ooo`030000003oool0oooo03P0oooo001<0?ooo`030000003oool0oooo
0080oooo8P3<c<bM0?ooo`030000003oool0oooo03P0oooo00150?ooo`@0
00000`3oool2000000<0oooo6@3<c<bV0?ooo`030000003oool0oooo03P0
oooo00160?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0P3oool?0<c<c;00oooo00<000000?ooo`3oool0>03oool004L0oooo00<0
00000?ooo`3oool00P3oool300000080oooo1@3<c<`40?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P00000j0?ooo`00B03oool0
10000000oooo0?ooo`3oooo5000003X0oooo00150?ooo`040000003oool0
oooo00000?l0oooo0`3oool004H0oooo0P00003o0?ooo`@0oooo003o0?oo
od`0oooo002I0?ooo`<00000:@3oool3000008<0oooo002J0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool0P03oool008P0oooo1000
00020?ooo`@000000P3oool500000080oooo00<000000?ooo`3oool02@3o
ool300000080oooo100000020?ooo`D0000000<0oooo0000000000000`00
0000103oool000000000003oool200000080oooo100000000`3oool00000
0000000300000080oooo1000001f0?ooo`00Q`3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo07P0oooo00270?ooo`030000003oool00000008000000`3o
ool00`000000oooo0?ooo`020?ooo`@000000P3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3oool400000080oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?oo
o`3oool0oooo1@00001f0?ooo`00Q`3oool00`000000oooo0?ooo`050?oo
o`8000001P3oool01P000000oooo0?ooo`000000oooo000000T0oooo00D0
00000?ooo`000000oooo000000020?ooo`8000001@3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D00000
0?ooo`3oool0oooo0000001f0?ooo`00Q`3oool01@000000oooo0?ooo`3o
ool000000080oooo0P0000000`3oool00000000000020?ooo`<0000000@0
oooo000000000000oooo0P0000080?ooo`060000003oool000000?ooo`00
0000oooo0P0000000`3oool00000000000020?ooo`800000103oool30000
00030?ooo`000000000000<000000`3oool500000080oooo00<000000?oo
o`3oool00P3oool3000007L0oooo00280?ooo`@000006P3oool500000240
oooo00<000000?ooo`3oool0O03oool00;@0oooo00<000000?ooo`3oool0
4`3oool3000007h0oooo003o0?oood`0oooo003o0?oood`0oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{331.75, 66.125},
  ImageMargins->{{65.8125, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
Other options, such as PlotLabel, and their default values can be \
listed by evaluating Options[Graphics]. You can change the default value of \
an option by using the SetOptions command.\
\>", "Text",
  CellTags->{"i:6", "C.1"}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics are typically generated as PostScript, a text-based format which \
is a publishing and printing standard. One graphics option that is often used \
is DisplayFunction, which controls how the graphic is displayed in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". By default, DisplayFunction is set to $DisplayFunction, which causes ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to interpret and display PostScript as a picture like those you've seen \
in the preceding. A setting of DisplayFunction \[Rule] Identity will entirely \
prevent the graphics from being displayed."
}], "Text",
  CellTags->{"i:7", "C.1"}],

Cell["\<\
Later in this appendix, we show how to define a function that uses \
options to change its behavior.\
\>", "Text",
  CellTags->"C.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.1.3  ListPlot", "Subsection",
  CellTags->"C.1"],

Cell[TextData[{
  "When visualizing some value that changes over time, one function that is \
useful is ListPlot. ListPlot takes a list of ",
  StyleBox["y", "IT"],
  " coordinates, and by default takes the ",
  StyleBox["x", "IT"],
  " coordinate to be 1 for the first number, 2 for the second, and so on. It \
returns all these points in a graphic. Thus if you have the value of some \
quantity for every time step in a list ",
  StyleBox["lis", "IT"],
  ", you can visualize this change over time by evaluating ListPlot[",
  StyleBox["lis", "IT"],
  "]."
}], "Text",
  CellTags->{"i:8", "C.1"}],

Cell[TextData[{
  "For example, in many of the models used in this book, an individual \
chooses one of four random directions to face during each time step. The \
following shows one such individual in isolation, where each point {",
  StyleBox["x", "IT"],
  ", ",
  StyleBox["y", "IT"],
  "} in the graph represents the direction ",
  StyleBox["y", "IT"],
  " the individual faced at a given time step ",
  StyleBox["x", "IT"],
  "."
}], "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell[TextData[
"r := Random[Integer, {1, 4}];\nSeedRandom[0];\nListPlot[Table[r, {100}],\n  \
Ticks \[Rule] {{25, 50, 75, 100}, {2, 3, 4}},\n  AxesOrigin \[Rule] {0, \
1}];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000Nb000`400?l0
0000o`00003oa`3oool00<L0oooo000b0?ooo`@000000P3oool3000002<0
oooo0`0000040?ooo`8000008`3oool00`000000oooo0?ooo`020?ooo`<0
00007`3oool3000000@0oooo0P0000040?ooo`8000001`3oool003<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000H0oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`00=@3oool00`000000oooo0?oo
o`03000002<0oooo0`0000030?ooo`040000003oool0oooo000002<0oooo
00@000000?ooo`3oool0oooo0`00000P0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000006
0?ooo`00<P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
000T0?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00H0oooo000c0?ooo`8000000`3oool400000280oooo100000030?ooo`80
00008P3oool400000080oooo1000000N0?ooo`8000001@3oool2000000@0
oooo0P0000070?ooo`00a`3oool000`0oooo00<000000?ooo`3oool0^03o
ool000`0oooo00<000000?ooo`3oool0^03oool000P0oooo]P0000090?oo
o`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo000000060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000h0oooo00<000000?ooo`0000005@3oool20000
00L0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`060?oo
o`80000000H0oooo0000003oool000000?ooo`00000A0?ooo`030000003o
ool0oooo00X0oooo0P0000080?ooo`030000003oool0000000d0oooo000<
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0X0?ooo`030000003oool0oooo02P0oooo00<00000
0?ooo`3oool02`3oool000`0oooo00<000000?ooo`3oool0^03oool000`0
oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0
^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<00000
0?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0
oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0
^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<00000
0?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0
oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0
^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<00000
0?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0
oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0
^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<00000
0?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0
oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0
^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<00000
0?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0
oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0
^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<00000
0?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000D0
oooo100000030?ooo`030000003oool0oooo0;P0oooo00060?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0^03oool000L0oooo00<0
00000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0000000=0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0403oool01@000000oooo0?oo
o`3oool000000080oooo00@000000?ooo`3oool0oooo0P00000B0?ooo`03
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0B0?ooo`00203oool01@000000oooo0?ooo`3oool00000
0;X0oooo00050?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0^03oool000H0oooo0P0000040?ooo`030000003oool0oooo0;P0
oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?ooo`030000003o
ool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?oo
o`030000003oool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0
oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?ooo`030000003o
ool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?oo
o`030000003oool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0
oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?ooo`030000003o
ool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?oo
o`030000003oool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0
oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?ooo`030000003o
ool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?oo
o`030000003oool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0
oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?ooo`030000003o
ool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?oo
o`030000003oool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0
oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?ooo`030000003o
ool0oooo0;P0oooo000<0?ooo`030000003oool0oooo0;P0oooo000<0?oo
o`030000003oool0oooo0;P0oooo00050?ooo`<00000103oool00`000000
oooo0?ooo`2h0?ooo`00203oool01@000000oooo0?ooo`3oool000000;X0
oooo00080?ooo`040000003oool0oooo0?ooo`800000^@3oool000H0oooo
0P0000040?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1P3oool010000000oooo0000003oool2000000030?ooo`000000oooo00D0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0100oooo0P0000000`3oool000000?ooo`080?ooo`03
0000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`040?ooo`8000007`3oool000P0oooo00D000000?ooo`3o
ool0oooo0000002j0?ooo`001@3oool3000000@0oooo00<000000?ooo`3o
ool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<0
00000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool0
00`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3o
ool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<0
00000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool0
00`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3o
ool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<0
00000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool0
00`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3o
ool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<0
00000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool0
00`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3o
ool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<0
00000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool0
00`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3o
ool0^03oool000`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<0
00000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3oool0^03oool0
00`0oooo00<000000?ooo`3oool0^03oool000`0oooo00<000000?ooo`3o
ool0^03oool000H0oooo0`0000030?ooo`030000003oool0oooo0;P0oooo
00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0^03o
ool000D0oooo100000030?ooo`<000000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000030?ooo`8000001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00<0oooo00H000000?ooo`3oool00000
0?ooo`0000070?ooo`030000003oool0oooo00P0oooo0P0000080?ooo`04
0000003oool0oooo0?ooo`800000103oool01@000000oooo0?ooo`3oool0
00000080oooo00D000000?ooo`3oool0oooo0000000;0?ooo`030000003o
ool0oooo00/0oooo0P0000080?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0;0?ooo`00
1@3oool00`000000oooo000000040?ooo`030000003oool0oooo0;P0oooo
00050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0^03o
ool000H0oooo0P0000040?ooo`030000003oool0oooo0;P0oooo00370?oo
o`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{199.812, 123.375},
  ImageMargins->{{128.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell[TextData[{
  "From this picture, it is difficult to get an idea of how an individual has \
changed direction from one time step to the next. In order to do this, we add \
the option setting PlotJoined \[Rule] True to the call to ListPlot, which \
tells ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to draw a line segment between consecutive points."
}], "Text",
  CellTags->{"i:9", "C.1"}],

Cell[CellGroupData[{

Cell[TextData[
"r := Random[Integer, {1, 4}];\nSeedRandom[0];\nListPlot[Table[r, {100}],\n  \
Ticks \[Rule] {{25, 50, 75, 100}, {2, 3, 4}},\n  AxesOrigin \[Rule] {0, 1}, \
PlotJoined \[Rule] True];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000370000Nb000`400?l0
0000o`00003oa`3oool00<L0oooo000b0?ooo`@000000P3oool3000002<0
oooo0`0000040?ooo`8000008`3oool00`000000oooo0?ooo`020?ooo`<0
00007`3oool3000000@0oooo0P0000040?ooo`8000001`3oool003<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000H0oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool08`3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000060?ooo`00=@3oool00`000000oooo0?oo
o`03000002<0oooo0`0000030?ooo`040000003oool0oooo000002<0oooo
00@000000?ooo`3oool0oooo0`00000P0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000006
0?ooo`00<P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
000T0?ooo`040000003oool0oooo00000280oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
00H0oooo000c0?ooo`8000000`3oool400000280oooo100000030?ooo`80
00008P3oool400000080oooo1000000N0?ooo`8000001@3oool2000000@0
oooo0P0000070?ooo`00a`3oool000`0oooo00<000000?ooo`3oool0^03o
ool000`0oooo00<000000?ooo`3oool0^03oool000P0oooo]P0000090?oo
o`00303oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02@3oool00`000000oooo000000060?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000P3oool01@000000
oooo0000003oool0000000h0oooo00<000000?ooo`0000005P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
0180oooo00<000000?ooo`3oool02@3oool2000000P0oooo00<000000?oo
o`0000003@3oool000`0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool000000080
oooo00D000000?ooo`000000oooo0000000>0?ooo`030000003oool00000
01H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0000000B0?ooo`030000003oool0oooo00T0oooo0P0000080?oo
o`030000003oool0000000d0oooo000<0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000040?ooo`030000003oool0000000h0oooo00<000000?ooo`00
00005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool2000000P0
oooo00<000000?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000003P3oool00`000000oooo
0000000F0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`800000
203oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo000000060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool00`000000oooo0000000>0?ooo`030000003o
ool0000001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo0P00
00080?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000040?ooo`030000003oool0000000h0oooo00<00000
0?ooo`0000005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool2
000000P0oooo00<000000?ooo`3oool03@3oool000`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000003P3oool00`00
0000oooo0000000F0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?oo
o`800000203oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo000000060?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000103oool00`000000oooo0000000>0?ooo`03
0000003oool0000001H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0
oooo0P0000080?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000040?ooo`030000003oool0000000h0oooo
00<000000?ooo`0000005P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
2@3oool2000000P0oooo00<000000?ooo`3oool03@3oool000`0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000002P3o
ool00`000000oooo000000060?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`000000103oool00`000000oooo0000000>0?ooo`040000003o
ool0oooo000001D0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0?0?ooo`800000203oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0203oool00`000000oooo
000000080?ooo`030000003oool0oooo00d0oooo000<0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool2000000X0oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000@0oooo00<000000?ooo`0000003P3oool010000000oooo0?oo
o`00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
3`3oool2000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000
203oool00`000000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo0P00000:0?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
00040?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool00000
5@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00l0oooo
0P0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`080?ooo`030000003oool0000000P0oooo
00<000000?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`020?ooo`8000002P3oool00`000000oooo0000
00060?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103o
ool00`000000oooo0000000>0?ooo`040000003oool0oooo000001D0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0?0?ooo`800000
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0203oool00`000000oooo000000080?ooo`030000
003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool2000000X0oooo00<000000?ooo`0000001P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000003P3oool010000000oooo0?ooo`00000E0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool03`3oool2000000P0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`000000203oool00`000000oooo
0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo0P00000:0?ooo`030000003oool0000000H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000040?ooo`030000003o
ool0000000h0oooo00@000000?ooo`3oool000005@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00l0oooo0P0000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0
3@3oool000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`020?ooo`8000002P3oool00`000000oooo000000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000103oool00`000000oooo0000
000>0?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0?0?ooo`800000203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
203oool00`000000oooo000000080?ooo`030000003oool0oooo00d0oooo
000<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool2000000X0oooo00<000000?ooo`0000001P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000@0oooo00<000000?ooo`0000003P3o
ool010000000oooo0?ooo`00000E0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool03`3oool2000000P0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`000000203oool00`000000oooo0?ooo`0=0?ooo`00303o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo0P00
000:0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000040?ooo`030000003oool0000000h0oooo00@0
00000?ooo`3oool000005@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00l0oooo0P0000080?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0000000P0oooo00<000000?ooo`3oool03@3oool000`0oooo00<0
00000?ooo`3oool0103oool2000000<0oooo0P00000:0?ooo`030000003o
ool0000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000h0oooo00@000000?ooo`3oool0
0000503oool2000000L0oooo0P00000@0?ooo`030000003oool0000000L0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0000000T0oooo00<000000?ooo`000000203oool00`000000
oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`040?ooo`800000
0`3oool2000000X0oooo00<000000?ooo`0000001P3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
00003P3oool010000000oooo0?ooo`00000D0?ooo`8000001`3oool20000
0100oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0100oooo00<000000?ooo`0000002@3oool00`00
0000oooo000000080?ooo`030000003oool0oooo00d0oooo000<0?ooo`03
0000003oool0oooo00@0oooo0P0000030?ooo`8000002P3oool00`000000
oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0000000>0?ooo`040000003oool0oooo
000001@0oooo0P0000070?ooo`800000403oool00`000000oooo00000007
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo000000090?ooo`030000003oool0000000P0oooo00<00000
0?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool0103oool20000
00<0oooo0P00000:0?ooo`030000003oool0000000H0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
000000h0oooo00@000000?ooo`3oool00000503oool2000000L0oooo0P00
000@0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0000000T0oooo00<0
00000?ooo`000000203oool00`000000oooo0?ooo`0=0?ooo`00303oool0
0`000000oooo0?ooo`040?ooo`8000000`3oool2000000X0oooo00<00000
0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000003P3oool010000000oooo0?oo
o`00000D0?ooo`8000001`3oool200000100oooo00<000000?ooo`000000
1`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo
00<000000?ooo`0000002@3oool00`000000oooo000000080?ooo`030000
003oool0oooo00d0oooo000<0?ooo`030000003oool0oooo00@0oooo0P00
00030?ooo`8000002P3oool00`000000oooo000000060?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo
0000000>0?ooo`040000003oool0oooo000001@0oooo0P0000070?ooo`80
0000403oool00`000000oooo000000070?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0403oool00`000000oooo000000090?ooo`03
0000003oool0000000P0oooo00<000000?ooo`3oool03@3oool000`0oooo
00<000000?ooo`3oool0103oool2000000<0oooo0P00000:0?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000000h0oooo00@000000?ooo`3o
ool00000503oool2000000L0oooo0P00000@0?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0000000T0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`0=0?ooo`00303oool00`000000oooo0?ooo`040?ooo`80
00000`3oool2000000X0oooo00<000000?ooo`0000001P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`0000003P3oool010000000oooo0?ooo`00000D0?ooo`8000001`3oool2
00000100oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000002@3oool0
0`000000oooo000000080?ooo`030000003oool0oooo00d0oooo000<0?oo
o`030000003oool0oooo00@0oooo0P0000030?ooo`8000002P3oool00`00
0000oooo000000060?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0000000>0?ooo`040000003oool0
oooo000001@0oooo0P0000070?ooo`800000403oool00`000000oooo0000
00070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo000000090?ooo`030000003oool0000000P0oooo00<0
00000?ooo`3oool03@3oool000`0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo000000030?ooo`030000003oool0000000T0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo000000030?ooo`040000003o
ool0oooo00000080oooo00D000000?ooo`3oool0oooo0000000=0?ooo`05
0000003oool0oooo0?ooo`0000004`3oool2000000H0oooo00<000000?oo
o`0000003`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0403oool00`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0000
000>0?ooo`00303oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000002@3oool010000000oooo0?ooo`00
00040?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000
0P3oool01@000000oooo0?ooo`3oool0000000d0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`8000001P3oool00`000000oooo0000000?0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0000000P0oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0000000h0oooo000<
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000090?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`050000
003oool0oooo0?ooo`0000003@3oool01@000000oooo0?ooo`3oool00000
01<0oooo0P0000060?ooo`030000003oool0000000l0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0100oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3o
ool0000000H0oooo00<000000?ooo`0000003P3oool000`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo000000030?ooo`030000003oool0
000000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0000
00030?ooo`040000003oool0oooo00000080oooo00D000000?ooo`3oool0
oooo0000000=0?ooo`050000003oool0oooo0?ooo`0000004`3oool20000
00H0oooo00<000000?ooo`0000003`3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0403oool0
0`000000oooo000000080?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0000000>0?ooo`00303oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`8000001P3oool00`00
0000oooo0000000?0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
000000P0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0000000h0oooo000<0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000090?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000
oooo0?ooo`3oool0000001<0oooo0P0000060?ooo`030000003oool00000
00l0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000203oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000003P3o
ool000D0oooo100000030?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`0000000`3oool00`000000oooo000000090?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000020?ooo`050000003oool0oooo0?ooo`0000003@3oool01@000000
oooo0?ooo`3oool0000001<0oooo0P0000060?ooo`030000003oool00000
00l0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`000000203oool0
1@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`0000003P3o
ool000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000002@3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool01@000000oooo0?ooo`3oool0000000d0
oooo00D000000?ooo`3oool0oooo0000000C0?ooo`8000001P3oool00`00
0000oooo0000000?0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
000000P0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0000000h0oooo00070?ooo`030000003oool0oooo0080oooo0P000002
0?ooo`050000003oool000000?ooo`0000000P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000P3oool01@000000oooo0000003oool0000000<0oooo00@000000?oo
o`3oool000000P3oool01P000000oooo0?ooo`3oool000000?ooo`<00000
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`000000
0`3oool01@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo00000002000000@0oooo00D000000?oo
o`3oool0oooo000000050?ooo`030000003oool0000000P0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000
oooo0000000>0?ooo`00203oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`000000oooo000000020?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0080oooo0P0000060?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo00000008
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?oo
o`3oool000000?ooo`0000003P3oool000D0oooo00@000000?ooo`3oool0
00000`3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo0P0000060?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool0
00H0oooo0P0000040?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00@000000?ooo`3oool00000103oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00D000000?oo
o`000000oooo000000030?ooo`040000003oool0oooo00000080oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`000000203oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool00P3oool2000000H0oooo00<000000?ooo`0000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo0000
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103o
ool01@000000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0000000P0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000
000>0?ooo`00303oool02@000000oooo0?ooo`3oool000000?ooo`000000
oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
00000?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`090000
003oool0oooo0?ooo`000000oooo0000003oool0000000P0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0080oooo0P0000060?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`000000oooo000000040?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo000000080?ooo`050000003oool0oooo
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
3P3oool000`0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`020?ooo`8000001P3oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0
oooo000<0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool0
00000080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00D000000?ooo`000000
oooo000000030?ooo`040000003oool0oooo00000080oooo00T000000?oo
o`3oool0oooo0000003oool000000?ooo`000000203oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0P3oool2000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo
0?ooo`3oool000000080oooo00D000000?ooo`3oool0oooo000000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01@00
0000oooo0000003oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo
000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000>0?oo
o`00303oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000020?ooo`050000003oool000000?oo
o`0000000`3oool010000000oooo0?ooo`0000020?ooo`090000003oool0
oooo0?ooo`000000oooo0000003oool0000000P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo0P0000060?ooo`030000003oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00D00000
0?ooo`000000oooo000000040?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo000000080?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool0
00`0oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000P3oool01@000000oooo0000003oool0
000000<0oooo00@000000?ooo`3oool000000P3oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000080?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`020?oo
o`8000001P3oool00`000000oooo000000030?ooo`050000003oool0oooo
0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`050000003o
ool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000D0
oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo000<
0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool000000080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo00000080oooo00D000000?ooo`000000oooo0000
00030?ooo`040000003oool0oooo00000080oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`000000203oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00P3oool2
000000H0oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3o
ool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool01@000000oooo
0000003oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?oo
o`030000003oool0000000P0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000>0?ooo`00303o
ool02@000000oooo0?ooo`3oool000000?ooo`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool2000000<0oooo00@00000
0?ooo`3oool000000P3oool01@000000oooo0000003oool0000000<0oooo
00@000000?ooo`3oool000000P3oool02@000000oooo0?ooo`3oool00000
0?ooo`000000oooo000000080?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0303oool2000000<0oooo0P0000060?ooo`030000003o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000020?ooo`050000
003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`000000oooo000000040?oo
o`80000000<0oooo0000000000001@3oool00`000000oooo000000080?oo
o`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000003P3oool000`0oooo00T000000?ooo`3oool0oooo
0000003oool000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo0P0000030?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`000000oooo000000030?ooo`040000003oool0oooo00000080
oooo00T000000?ooo`3oool0oooo0000003oool000000?ooo`000000203o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo0P00
00030?ooo`8000001P3oool00`000000oooo000000030?ooo`050000003o
ool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`05
0000003oool000000?ooo`000000103oool2000000030?ooo`0000000000
00D0oooo00<000000?ooo`000000203oool01@000000oooo0?ooo`3oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo
000<0?ooo`090000003oool0oooo0?ooo`000000oooo0000003oool00000
0080oooo00D000000?ooo`3oool0oooo000000030?ooo`8000000`3oool0
10000000oooo0?ooo`0000020?ooo`050000003oool000000?ooo`000000
0`3oool010000000oooo0?ooo`0000020?ooo`090000003oool0oooo0?oo
o`000000oooo0000003oool0000000P0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0<0?ooo`8000000`3oool2000000H0oooo00<0
00000?ooo`0000000`3oool01@000000oooo0?ooo`3oool000000080oooo
00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool01@000000oooo0000003oool00000
00@0oooo0P0000000`3oool00000000000050?ooo`030000003oool00000
00P0oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0
oooo0?ooo`000000oooo0000000>0?ooo`00303oool02@000000oooo0?oo
o`3oool000000?ooo`000000oooo000000020?ooo`050000003oool0oooo
0?ooo`0000000`3oool2000000<0oooo00@000000?ooo`3oool000000P3o
ool01@000000oooo0000003oool0000000<0oooo00@000000?ooo`3oool0
00000P3oool02@000000oooo0?ooo`3oool000000?ooo`000000oooo0000
00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0303o
ool2000000<0oooo0P0000060?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0
oooo00D000000?ooo`000000oooo000000040?ooo`80000000<0oooo0000
000000001@3oool00`000000oooo000000080?ooo`050000003oool0oooo
0?ooo`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
3P3oool000`0oooo00T000000?ooo`3oool0oooo0000003oool000000?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000003
0?ooo`040000003oool0oooo00000080oooo00D000000?ooo`000000oooo
000000030?ooo`040000003oool0oooo00000080oooo00T000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000203oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00`0oooo0P0000030?ooo`8000001P3o
ool00`000000oooo000000030?ooo`050000003oool0oooo0?ooo`000000
0P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`050000003oool000000?oo
o`000000103oool2000000030?ooo`000000000000D0oooo00<000000?oo
o`000000203oool01@000000oooo0?ooo`3oool000000080oooo00L00000
0?ooo`3oool0oooo0000003oool0000000h0oooo000<0?ooo`090000003o
ool0oooo0?ooo`000000oooo0000003oool000000080oooo00D000000?oo
o`3oool0oooo000000030?ooo`8000000`3oool010000000oooo0?ooo`00
00020?ooo`050000003oool000000?ooo`0000000`3oool010000000oooo
0?ooo`0000020?ooo`090000003oool0oooo0?ooo`000000oooo0000003o
ool0000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0<0?ooo`8000000`3oool2000000H0oooo00<000000?ooo`0000000`3o
ool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool01@000000oooo0000003oool0000000@0oooo0P0000000`3o
ool00000000000050?ooo`030000003oool0000000P0oooo00D000000?oo
o`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo
0000000>0?ooo`00303oool02@000000oooo0?ooo`3oool000000?ooo`00
0000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool2
000000<0oooo00@000000?ooo`3oool000000P3oool01@000000oooo0000
003oool0000000<0oooo00@000000?ooo`3oool000000P3oool02@000000
oooo0?ooo`3oool000000?ooo`000000oooo000000080?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0303oool2000000<0oooo0P00
00060?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00D000000?ooo`00
0000oooo000000040?ooo`80000000<0oooo0000000000001@3oool00`00
0000oooo000000080?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000003P3oool000`0oooo00T0
00000?ooo`3oool0oooo0000003oool000000?ooo`0000000P3oool01@00
0000oooo0?ooo`3oool0000000<0oooo0P0000030?ooo`040000003oool0
oooo00000080oooo00D000000?ooo`000000oooo000000030?ooo`040000
003oool0oooo00000080oooo00T000000?ooo`3oool0oooo0000003oool0
00000?ooo`000000203oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00`0oooo0P0000030?ooo`8000001P3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`040?ooo`050000003oool000000?ooo`000000103oool20000
00030?ooo`000000000000D0oooo00<000000?ooo`000000203oool01@00
0000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000h0oooo000<0?ooo`070000003oool0oooo0?ooo`000000
oooo000000020?ooo`030000003oool0000000<0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000P3oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000030?ooo`050000003oool000000?ooo`000000
203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo
0P0000020?ooo`040000003oool0oooo000000D0oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`800000
00@0oooo0000003oool000000`3oool010000000oooo0?ooo`0000080?oo
o`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000003P3oool000`0oooo00<000000?ooo`3oool00P00
00001`3oool000000?ooo`3oool000000?ooo`0000000`3oool010000000
oooo0?ooo`3oool200000080oooo00H000000?ooo`3oool0oooo0000003o
ool2000000040?ooo`000000oooo00000080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000030?ooo`030000003oool000000080oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00/0oooo0P0000020?ooo`040000003oool0oooo000000D0
oooo00@000000?ooo`3oool000000P3oool2000000050?ooo`000000oooo
0000003oool00P0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo0P000000103oool000000?ooo`0000030?ooo`050000
003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0000000>0?oo
o`00303oool00`000000oooo0?ooo`02000000070?ooo`000000oooo0?oo
o`000000oooo000000030?ooo`040000003oool0oooo0?ooo`8000000P3o
ool01P000000oooo0?ooo`3oool000000?ooo`80000000@0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool20000
0080oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`00
00020?ooo`80000000D0oooo0000003oool000000?ooo`02000000030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000000`3oool200000004
0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo00000006
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000h0oooo000<0?ooo`030000003oool0
oooo0080000000L0oooo0000003oool0oooo0000003oool0000000<0oooo
00@000000?ooo`3oool0oooo0P0000020?ooo`060000003oool0oooo0?oo
o`000000oooo0P000000103oool000000?ooo`0000020?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`8000000P3oool010000000oooo0?oo
o`0000050?ooo`040000003oool0oooo00000080oooo0P0000001@3oool0
00000?ooo`000000oooo0080000000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00D000000?oo
o`3oool0oooo000000030?ooo`80000000@0oooo0000003oool000000`3o
ool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`00
00003P3oool000`0oooo00<000000?ooo`3oool00P0000001`3oool00000
0?ooo`3oool000000?ooo`0000000`3oool010000000oooo0?ooo`3oool2
00000080oooo00H000000?ooo`3oool0oooo0000003oool2000000040?oo
o`000000oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo000000030?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0
oooo0P0000020?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool000000P3oool2000000050?ooo`000000oooo0000003oool00P00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000<0oooo
0P000000103oool000000?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`020?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000>0?ooo`00303oool00`00
0000oooo0?ooo`02000000070?ooo`000000oooo0?ooo`000000oooo0000
00030?ooo`040000003oool0oooo0?ooo`8000000P3oool01P000000oooo
0?ooo`3oool000000?ooo`80000000@0oooo0000003oool000000P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02`3oool200000080oooo00@00000
0?ooo`3oool000001@3oool010000000oooo0?ooo`0000020?ooo`800000
00D0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000`3oool2000000040?ooo`000000oooo
000000<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000h0oooo000<0?ooo`030000003oool0oooo0080000000L0
oooo0000003oool0oooo0000003oool0000000<0oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`060000003oool0oooo0?ooo`000000oooo0P00
0000103oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0;0?ooo`8000000P3oool010000000oooo0?ooo`0000050?ooo`04
0000003oool0oooo00000080oooo0P0000001@3oool000000?ooo`000000
oooo0080000000<0oooo0000003oool0103oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`80000000@0oooo0000003oool000000`3oool01@000000oooo
0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000003P3oool000`0
oooo00<000000?ooo`3oool00P0000001`3oool000000?ooo`3oool00000
0?ooo`0000000`3oool010000000oooo0?ooo`3oool200000080oooo00H0
00000?ooo`3oool0oooo0000003oool2000000040?ooo`000000oooo0000
0080oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?oo
o`030000003oool000000080oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P0000020?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000000P3o
ool2000000050?ooo`000000oooo0000003oool00P0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
1@3oool01@000000oooo0?ooo`3oool0000000<0oooo0P000000103oool0
00000?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0000000>0?ooo`00303oool00`000000oooo0?ooo`02
000000070?ooo`000000oooo0?ooo`000000oooo000000030?ooo`040000
003oool0oooo0?ooo`8000000P3oool01P000000oooo0?ooo`3oool00000
0?ooo`80000000@0oooo0000003oool000000P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02`3oool200000080oooo00@000000?ooo`3oool00000
1@3oool010000000oooo0?ooo`0000020?ooo`80000000D0oooo0000003o
ool000000?ooo`02000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000000`3oool2000000040?ooo`000000oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo0080oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0000000h0
oooo000<0?ooo`030000003oool0oooo0080000000L0oooo0000003oool0
oooo0000003oool0000000@0oooo00P000000?ooo`3oool000000?ooo`00
0000oooo000000<0oooo00P000000?ooo`00000000000?ooo`000000oooo
00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo00000003
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0oooo00@0
00000?ooo`3oool000000P3oool2000000050?ooo`000000oooo0000003o
ool00P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
000>0?ooo`00303oool00`000000oooo0?ooo`02000000070?ooo`000000
oooo0?ooo`000000oooo000000040?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`080000003oool000000000003oool00000
0?ooo`0000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000`3oool00`000000oooo000000020?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`05
0000003oool000000?ooo`0000000P3oool00`000000oooo0?ooo`030?oo
o`040000003oool0oooo00000080oooo0P0000001@3oool000000?ooo`00
0000oooo0080000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool000000080oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000003P3oool000`0oooo00<000000?ooo`3oool00P0000001`3oool0
00000?ooo`3oool000000?ooo`000000103oool020000000oooo0?ooo`00
0000oooo0000003oool000000`3oool020000000oooo000000000000oooo
0000003oool000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3o
ool01@000000oooo0000003oool000000080oooo00<000000?ooo`3oool0
0`3oool010000000oooo0?ooo`0000020?ooo`80000000D0oooo0000003o
ool000000?ooo`02000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo000000020?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`000000oooo000000020?ooo`030000
003oool0000000h0oooo000<0?ooo`030000003oool0oooo0080000000L0
oooo0000003oool0oooo0000003oool0000000@0oooo00P000000?ooo`3o
ool000000?ooo`000000oooo000000<0oooo00P000000?ooo`0000000000
0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000030?ooo`030000003oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00/0oooo00D000000?ooo`000000oooo000000020?ooo`030000003oool0
oooo00<0oooo00@000000?ooo`3oool000000P3oool2000000050?ooo`00
0000oooo0000003oool00P0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo
0?ooo`3oool0000000<0oooo00<000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`020?ooo`050000003oool000000?ooo`0000000P3oool0
0`000000oooo0000000>0?ooo`00303oool00`000000oooo0?ooo`020000
00070?ooo`000000oooo0?ooo`000000oooo000000040?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000030?ooo`080000003oool00000
0000003oool000000?ooo`0000020?ooo`030000003oool0oooo0080oooo
00<000000?ooo`0000000`3oool00`000000oooo000000020?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0;0?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0?ooo`030?ooo`040000003oool0oooo00000080oooo0P0000001@3o
ool000000?ooo`000000oooo0080000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`0000003P3oool000`0oooo00<000000?ooo`3oool0
0P0000001`3oool000000?ooo`3oool000000?ooo`000000103oool02000
0000oooo0?ooo`000000oooo0000003oool000000`3oool020000000oooo
000000000000oooo0000003oool000000P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0000000<0oooo00<000000?ooo`0000000P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool02`3oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`0000020?ooo`800000
00D0oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?oo
o`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`000000oooo0000
00020?ooo`030000003oool0000000h0oooo00050?ooo`<00000103oool0
0`000000oooo0?ooo`02000000070?ooo`000000oooo0?ooo`000000oooo
000000040?ooo`080000003oool0oooo0000003oool000000?ooo`000003
0?ooo`080000003oool000000000003oool000000?ooo`0000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`0000000`3oool00`000000
oooo000000020?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0;0?ooo`050000003oool000000?oo
o`0000000P3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo
00000080oooo0P0000001@3oool000000?ooo`000000oooo0080000000<0
oooo0000003oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool000000080oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0000003oool000000080oooo00<000000?ooo`0000003P3oool000P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`80000000L0oooo0000
003oool0oooo0000003oool0000000@0oooo00P000000?ooo`3oool00000
0?ooo`000000oooo000000<0oooo00P000000?ooo`00000000000?ooo`00
0000oooo00000080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo
00D000000?ooo`000000oooo000000020?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000P3oool2000000050?ooo`000000oooo
0000003oool00P0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`020?ooo`050000003oool000000?ooo`0000000P3oool00`000000
oooo0000000>0?ooo`00203oool010000000oooo0?ooo`3oool200000005
0?ooo`00000000000?ooo`0000000P3oool3000000@0oooo00P000000?oo
o`3oool000000?ooo`000000oooo000000<0oooo00P000000?ooo`000000
00000?ooo`000000oooo00000080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
000000L00000103oool00`000000oooo0000000200000080oooo00<00000
0?ooo`0000000`3oool010000000oooo0?ooo`0000020?ooo`80000000D0
oooo0000003oool000000?ooo`02000000030?ooo`000000oooo00@0oooo
100000020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0
oooo000000030?ooo`030000003oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo00<0000000<0oooo0000
003oool00`3oool01@000000oooo0000003oool000000080oooo00<00000
0?ooo`0000003P3oool000H0oooo0P0000040?ooo`050000003oool0oooo
0000003oool00P0000090?ooo`030000003oool000000080oooo00<00000
0?ooo`0000000`3oool010000000oooo0000003oool2000000050?ooo`00
0000oooo0?ooo`000000103oool00`000000oooo000000030?ooo`800000
0`3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`0000000`3oool02`000000oooo0?ooo`000000oooo
0000003oool000000?ooo`000000oooo0080000000@0oooo0000003oool0
0000203oool010000000oooo0?ooo`00000;0?ooo`040000003oool0oooo
000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`080000003o
ool0oooo0000003oool000000?ooo`0000040?ooo`050000003oool00000
0?ooo`0000000P3oool00`000000oooo0000000>0?ooo`00203oool01@00
0000oooo0?ooo`3oool000000080oooo00@000000?ooo`00000000002@3o
ool00`000000oooo000000020?ooo`030000003oool0000000<0oooo00@0
00000?ooo`000000oooo0P0000001@3oool000000?ooo`3oool0000000@0
oooo00<000000?ooo`0000000`3oool2000000<0oooo00<000000?ooo`00
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0000000H0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool00000
00<0oooo00/000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`02000000040?ooo`000000oooo000000P0oooo00@000000?oo
o`3oool000002`3oool010000000oooo0?ooo`0000050?ooo`050000003o
ool0oooo0?ooo`0000000`3oool020000000oooo0?ooo`000000oooo0000
003oool00000103oool01@000000oooo0000003oool000000080oooo00<0
00000?ooo`0000003P3oool000D0oooo0`0000040?ooo`050000003oool0
oooo0000003oool00P0000090?ooo`030000003oool000000080oooo00<0
00000?ooo`0000000`3oool010000000oooo0000003oool2000000050?oo
o`000000oooo0?ooo`000000103oool00`000000oooo000000030?ooo`80
00000`3oool00`000000oooo000000050?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000001P3oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`0000000`3oool02`000000oooo0?ooo`000000
oooo0000003oool000000?ooo`000000oooo0080000000@0oooo0000003o
ool00000203oool010000000oooo0?ooo`00000;0?ooo`040000003oool0
oooo000000D0oooo00D000000?ooo`3oool0oooo000000030?ooo`080000
003oool0oooo0000003oool000000?ooo`0000040?ooo`050000003oool0
00000?ooo`0000000P3oool00`000000oooo0000000>0?ooo`00303oool0
1@000000oooo0?ooo`000000oooo008000002@3oool00`000000oooo0000
00020?ooo`030000003oool0000000<0oooo00@000000?ooo`000000oooo
0P0000001@3oool000000?ooo`3oool0000000@0oooo00<000000?ooo`00
00000`3oool2000000<0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0000000H0oooo00D000000?ooo`3o
ool0oooo000000070?ooo`030000003oool0000000<0oooo00/000000?oo
o`3oool000000?ooo`000000oooo0000003oool000000?ooo`0200000004
0?ooo`000000oooo000000P0oooo00@000000?ooo`3oool000002`3oool0
10000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000
0`3oool020000000oooo0?ooo`000000oooo0000003oool00000103oool0
1@000000oooo0000003oool000000080oooo00<000000?ooo`0000003P3o
ool000`0oooo00D000000?ooo`3oool000000?ooo`02000000T0oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000030?ooo`040000003o
ool000000?ooo`80000000D0oooo0000003oool0oooo000000040?ooo`03
0000003oool0000000<0oooo0P0000030?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool00`3oool00`000000oooo000000060?ooo`05
0000003oool0oooo0?ooo`0000001`3oool00`000000oooo000000030?oo
o`0;0000003oool0oooo0000003oool000000?ooo`000000oooo0000003o
ool00P000000103oool000000?ooo`0000080?ooo`040000003oool0oooo
000000/0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?oo
o`3oool0000000<0oooo00P000000?ooo`3oool000000?ooo`000000oooo
000000@0oooo00D000000?ooo`000000oooo000000020?ooo`030000003o
ool0000000h0oooo000<0?ooo`050000003oool0oooo0000003oool00P00
00090?ooo`030000003oool000000080oooo00<000000?ooo`0000000`3o
ool010000000oooo0000003oool2000000050?ooo`000000oooo0?ooo`00
0000103oool00`000000oooo000000030?ooo`8000000`3oool00`000000
oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00001P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?oo
o`0000000`3oool02`000000oooo0?ooo`000000oooo0000003oool00000
0?ooo`000000oooo0080000000@0oooo0000003oool00000203oool01000
0000oooo0?ooo`00000;0?ooo`040000003oool0oooo000000D0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000040?ooo`050000003oool000000?ooo`0000000P3o
ool00`000000oooo0000000>0?ooo`00303oool01@000000oooo0?ooo`00
0000oooo008000002@3oool00`000000oooo000000020?ooo`030000003o
ool0000000<0oooo00@000000?ooo`000000oooo0P0000001@3oool00000
0?ooo`3oool0000000@0oooo00<000000?ooo`0000000`3oool2000000<0
oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0000000H0oooo00D000000?ooo`3oool0oooo000000070?oo
o`030000003oool0000000<0oooo00/000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`02000000040?ooo`000000oooo0000
00P0oooo00@000000?ooo`3oool000002`3oool010000000oooo0?ooo`00
00050?ooo`050000003oool0oooo0?ooo`0000000`3oool020000000oooo
0?ooo`000000oooo0000003oool00000103oool01@000000oooo0000003o
ool000000080oooo00<000000?ooo`0000003P3oool000`0oooo00D00000
0?ooo`3oool000000?ooo`02000000T0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000030?ooo`040000003oool000000?ooo`800000
00D0oooo0000003oool0oooo000000040?ooo`030000003oool0000000<0
oooo0P0000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo000000060?ooo`050000003oool0oooo0?oo
o`0000001`3oool00`000000oooo000000030?ooo`0;0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool00P000000103oool0
00000?ooo`0000080?ooo`040000003oool0oooo000000/0oooo00@00000
0?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000000<0oooo
00P000000?ooo`3oool000000?ooo`000000oooo000000@0oooo00D00000
0?ooo`000000oooo000000020?ooo`030000003oool0000000h0oooo000<
0?ooo`050000003oool0oooo0000003oool00P0000090?ooo`030000003o
ool000000080oooo00<000000?ooo`0000000`3oool010000000oooo0000
003oool2000000050?ooo`000000oooo0?ooo`000000103oool00`000000
oooo000000030?ooo`8000000`3oool00`000000oooo000000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000001P3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`0000000`3oool02`00
0000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0080
000000@0oooo0000003oool00000203oool010000000oooo0?ooo`00000;
0?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo
000000030?ooo`080000003oool0oooo0000003oool000000?ooo`000004
0?ooo`050000003oool000000?ooo`0000000P3oool00`000000oooo0000
000>0?ooo`00303oool01P000000oooo0?ooo`000000oooo000000/0oooo
0P0000030?ooo`800000103oool2000000030?ooo`000000oooo0080oooo
00<000000?ooo`000000103oool2000000D0oooo00H000000?ooo`3oool0
oooo0000003oool2000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo000000070?ooo`040000003oool0oooo000000L0oooo0P000000
103oool000000?ooo`0000040?ooo`80000000D0oooo0000003oool00000
0?ooo`02000000040?ooo`000000oooo000000T0oooo0P00000<0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`000000103oool00`00
0000oooo000000020?ooo`030000003oool0000000D0oooo0P000000103o
ool000000?ooo`0000030?ooo`030000003oool0oooo00/0oooo000<0?oo
o`060000003oool0oooo0000003oool000002`3oool2000000<0oooo0P00
00040?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo0000
00040?ooo`8000001@3oool01P000000oooo0?ooo`3oool000000?ooo`80
00000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0000000L0
oooo00@000000?ooo`3oool000001`3oool2000000040?ooo`000000oooo
000000@0oooo0P0000001@3oool000000?ooo`000000oooo0080000000@0
oooo0000003oool000002@3oool2000000`0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo000000040?ooo`030000003oool000000080
oooo00<000000?ooo`0000001@3oool2000000040?ooo`000000oooo0000
00<0oooo00<000000?ooo`3oool02`3oool000`0oooo00H000000?ooo`3o
ool000000?ooo`00000;0?ooo`8000000`3oool2000000@0oooo0P000000
0`3oool000000?ooo`020?ooo`030000003oool0000000@0oooo0P000005
0?ooo`060000003oool0oooo0?ooo`000000oooo0P0000030?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`0000001`3oool010000000oooo
0?ooo`0000070?ooo`80000000@0oooo0000003oool00000103oool20000
00050?ooo`000000oooo0000003oool00P000000103oool000000?ooo`00
00090?ooo`800000303oool010000000oooo0?ooo`0000060?ooo`030000
003oool0000000@0oooo00<000000?ooo`0000000P3oool00`000000oooo
000000050?ooo`80000000@0oooo0000003oool000000`3oool00`000000
oooo0?ooo`0;0?ooo`00303oool01P000000oooo0?ooo`000000oooo0000
00/0oooo0P0000030?ooo`800000103oool2000000030?ooo`000000oooo
0080oooo00<000000?ooo`000000103oool2000000D0oooo00H000000?oo
o`3oool0oooo0000003oool2000000<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000070?ooo`040000003oool0oooo000000L0oooo
0P000000103oool000000?ooo`0000040?ooo`80000000D0oooo0000003o
ool000000?ooo`02000000040?ooo`000000oooo000000T0oooo0P00000<
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`000000103o
ool00`000000oooo000000020?ooo`030000003oool0000000D0oooo0P00
0000103oool000000?ooo`0000030?ooo`030000003oool0oooo00/0oooo
000<0?ooo`060000003oool0oooo0000003oool000002`3oool2000000<0
oooo0P0000040?ooo`80000000<0oooo0000003oool00P3oool00`000000
oooo000000040?ooo`8000001@3oool01P000000oooo0?ooo`3oool00000
0?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
000000L0oooo00@000000?ooo`3oool000001`3oool2000000040?ooo`00
0000oooo000000@0oooo0P0000001@3oool000000?ooo`000000oooo0080
000000@0oooo0000003oool000002@3oool2000000`0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo000000040?ooo`030000003oool0
00000080oooo00<000000?ooo`0000001@3oool2000000040?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool02`3oool000`0oooo00H00000
0?ooo`3oool000000?ooo`00000;0?ooo`8000000`3oool2000000@0oooo
0P0000000`3oool000000?ooo`020?ooo`030000003oool0000000@0oooo
0P0000050?ooo`060000003oool0oooo0?ooo`000000oooo0P0000030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`0000001`3oool01000
0000oooo0?ooo`0000070?ooo`80000000@0oooo0000003oool00000103o
ool2000000050?ooo`000000oooo0000003oool00P000000103oool00000
0?ooo`0000090?ooo`800000303oool010000000oooo0?ooo`0000060?oo
o`030000003oool0000000@0oooo00<000000?ooo`0000000P3oool00`00
0000oooo000000050?ooo`80000000@0oooo0000003oool000000`3oool0
0`000000oooo0?ooo`0;0?ooo`00303oool01P000000oooo0?ooo`000000
oooo000000/0oooo0P0000030?ooo`800000103oool2000000030?ooo`00
0000oooo0080oooo00<000000?ooo`000000103oool2000000D0oooo00H0
00000?ooo`3oool0oooo0000003oool2000000<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo000000070?ooo`040000003oool0oooo0000
00L0oooo0P000000103oool000000?ooo`0000040?ooo`80000000D0oooo
0000003oool000000?ooo`02000000040?ooo`000000oooo000000T0oooo
0P00000<0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`00
0000103oool00`000000oooo000000020?ooo`030000003oool0000000D0
oooo0P000000103oool000000?ooo`0000030?ooo`030000003oool0oooo
00/0oooo000<0?ooo`060000003oool0oooo0000003oool000002`3oool2
000000<0oooo0P0000040?ooo`80000000<0oooo0000003oool00P3oool0
0`000000oooo000000040?ooo`8000001@3oool01P000000oooo0?ooo`3o
ool000000?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0000000L0oooo00@000000?ooo`3oool000001`3oool200000004
0?ooo`000000oooo000000@0oooo0P0000001@3oool000000?ooo`000000
oooo0080000000@0oooo0000003oool000002@3oool2000000`0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo000000040?ooo`030000
003oool000000080oooo00<000000?ooo`0000001@3oool2000000040?oo
o`000000oooo000000<0oooo00<000000?ooo`3oool02`3oool000`0oooo
00H000000?ooo`3oool000000?ooo`00000;0?ooo`8000000`3oool20000
00@0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool00000
00@0oooo0P0000050?ooo`060000003oool0oooo0?ooo`000000oooo0P00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000001`3o
ool010000000oooo0?ooo`0000070?ooo`80000000@0oooo0000003oool0
0000103oool2000000050?ooo`000000oooo0000003oool00P000000103o
ool000000?ooo`0000090?ooo`800000303oool010000000oooo0?ooo`00
00060?ooo`030000003oool0000000@0oooo00<000000?ooo`0000000P3o
ool00`000000oooo000000050?ooo`80000000@0oooo0000003oool00000
0`3oool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo0000
00020?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`800000103o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`060?ooo`040000003oool0oooo000000L0oooo0P000000103oool0
00000?ooo`0000040?ooo`8000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool2000000d0oooo00<00000
0?ooo`0000001P3oool00`000000oooo000000050?ooo`8000000`3oool0
0`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3o
ool00`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo00000002
0?ooo`030000003oool0oooo00T0oooo0P0000030?ooo`800000103oool0
10000000oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000000L0oooo0P000000103oool00000
0?ooo`0000040?ooo`8000000P3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000d0oooo00<000000?oo
o`0000001P3oool00`000000oooo000000050?ooo`8000000`3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool0
0`000000oooo0?ooo`0;0?ooo`00303oool00`000000oooo000000020?oo
o`030000003oool0oooo00T0oooo0P0000030?ooo`800000103oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000L0oooo0P000000103oool000000?oo
o`0000040?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000d0oooo00<000000?ooo`00
00001P3oool00`000000oooo000000050?ooo`8000000`3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool00`00
0000oooo0?ooo`0;0?ooo`00303oool00`000000oooo000000020?ooo`03
0000003oool0oooo00T0oooo0P0000030?ooo`800000103oool010000000
oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?oo
o`040000003oool0oooo000000L0oooo0P000000103oool000000?ooo`00
00040?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool2000000d0oooo00<000000?ooo`000000
1P3oool00`000000oooo000000050?ooo`8000000`3oool00`000000oooo
0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000
oooo0?ooo`0;0?ooo`00303oool00`000000oooo000000020?ooo`030000
003oool0oooo00T0oooo0P0000030?ooo`800000103oool010000000oooo
0?ooo`0000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000000L0oooo0P000000103oool000000?ooo`000004
0?ooo`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool2000000d0oooo00<000000?ooo`0000001P3o
ool00`000000oooo000000050?ooo`8000000`3oool00`000000oooo0?oo
o`040?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo
0?ooo`0;0?ooo`00303oool00`000000oooo000000020?ooo`030000003o
ool0oooo00T0oooo0P0000030?ooo`800000103oool010000000oooo0?oo
o`0000030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000L0oooo0P000000103oool000000?ooo`0000040?oo
o`8000000P3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000d0oooo00<000000?ooo`0000001P3oool0
0`000000oooo000000050?ooo`8000000`3oool00`000000oooo0?ooo`04
0?ooo`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?oo
o`0;0?ooo`00303oool00`000000oooo000000020?ooo`030000003oool0
oooo00T0oooo0P0000030?ooo`800000103oool010000000oooo0?ooo`00
00030?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000003o
ool0oooo000000L0oooo0P000000103oool000000?ooo`0000040?ooo`80
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0203oool2000000d0oooo00<000000?ooo`0000001P3oool00`00
0000oooo000000050?ooo`8000000`3oool00`000000oooo0?ooo`040?oo
o`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0;
0?ooo`00303oool00`000000oooo000000020?ooo`030000003oool0oooo
00T0oooo0P0000030?ooo`800000103oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000003oool0
oooo000000L0oooo0P000000103oool000000?ooo`0000040?ooo`800000
0P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000d0oooo00<000000?ooo`0000001P3oool00`000000
oooo000000050?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?oo
o`00303oool00`000000oooo000000020?ooo`030000003oool0oooo00T0
oooo0P0000030?ooo`800000103oool010000000oooo0?ooo`0000030?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
000000L0oooo0P000000103oool000000?ooo`0000040?ooo`8000000P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool2000000d0oooo00<000000?ooo`0000001P3oool00`000000oooo
000000050?ooo`8000000`3oool00`000000oooo0?ooo`040?ooo`040000
003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`00
303oool00`000000oooo000000020?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3o
ool000000?ooo`0000080?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`0000001`3oool010000000oooo0?ooo`3oool2000000D0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`0000001`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?oo
o`3oool02`3oool000`0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`060000003oool0oooo0000003oool00000203oool00`000000oooo0?oo
o`070?ooo`030000003oool0000000L0oooo00@000000?ooo`3oool0oooo
0P0000050?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool00000
00L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P000003
0?ooo`030000003oool0oooo00/0oooo000<0?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo000000070?ooo`040000
003oool0oooo0?ooo`8000001@3oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo000000070?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0
oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`00303oool0
0`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0080oooo00H000000?ooo`3oool00000
0?ooo`0000080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`00
00001`3oool010000000oooo0?ooo`3oool2000000D0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`0000001`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool010000000oooo0?ooo`3oool2000000<0oooo00<000000?ooo`3oool0
2`3oool000`0oooo00<000000?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000
003oool0oooo0000003oool00000203oool00`000000oooo0?ooo`070?oo
o`030000003oool0000000L0oooo00@000000?ooo`3oool0oooo0P000005
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`03
0000003oool0oooo00/0oooo000<0?ooo`030000003oool000000080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool00`000000
oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01P000000oooo0?ooo`000000oooo000000P0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo000000070?ooo`040000003oool0
oooo0?ooo`8000001@3oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool02`3oool00`000000
oooo000000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?oo
o`8000000`3oool00`000000oooo0?ooo`0;0?ooo`001P3oool3000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`020?ooo`060000003oool0oooo
0000003oool00000203oool00`000000oooo0?ooo`070?ooo`030000003o
ool0000000L0oooo00@000000?ooo`3oool0oooo0P0000050?ooo`040000
003oool0oooo000000<0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0000000L0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000003oool0
oooo00/0oooo00070?ooo`030000003oool0oooo0080oooo00<000000?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`020?ooo`060000003oool0oooo0000003oool00000
203oool00`000000oooo0?ooo`070?ooo`030000003oool0000000L0oooo
00@000000?ooo`3oool0oooo0P0000050?ooo`040000003oool0oooo0000
00<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00@00000
0?ooo`3oool0oooo0P0000030?ooo`030000003oool0oooo00/0oooo0005
0?ooo`@000000`3oool300000080oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool3000000D0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<00000203o
ool00`000000oooo0?ooo`070?ooo`<000001`3oool010000000oooo0?oo
o`3oool2000000D0oooo00@000000?ooo`3oool000000`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo00/0oooo0`0000070?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`8000000`3oool0
0`000000oooo0?ooo`0;0?ooo`001@3oool00`000000oooo000000040?oo
o`030000003oool0oooo0;P0oooo00050?ooo`030000003oool0000000@0
oooo00<000000?ooo`3oool0^03oool000H0oooo0P0000040?ooo`030000
003oool0oooo0;P0oooo00370?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{199.812, 123.375},
  ImageMargins->{{128.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell[TextData[{
  "If you give ListPlot a list of ordered pairs instead of a list, it plots \
each ordered pair {",
  StyleBox["x", "IT"],
  ", ",
  StyleBox["y", "IT"],
  "} as a point with the given ",
  StyleBox["x", "IT"],
  " and ",
  StyleBox["y", "IT"],
  " coordinates."
}], "Text",
  CellTags->"C.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.1.4  Graphics Packages", "Subsection",
  CellTags->"C.1"],

Cell[TextData[{
  "In addition to built-in graphics functions, there are many more functions \
defined in the standard packages that ship with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". In order to automatically load the graphics packages, we load the \
Graphics ",
  StyleBox["master package",
    FontSlant->"Italic"],
  ", which the following input does."
}], "Text",
  CellTags->{"i:10", "C.1"}],

Cell["<<Graphics`", "Input",
  CellTags->"C.1"],

Cell["\<\
This loads the names of the package-defined graphics functions into \
the kernel, so that when they are used, the associated package is loaded. \
Without first loading the master package, the examples in this section will \
not work.\
\>", "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell["MultipleListPlot", "Subsubsection",
  CellTags->"C.1"],

Cell[TextData[{
  "We have already seen how to plot the value of some quantity as a function \
of time by using ListPlot. If we want to simultaneously plot the values of \
several quantities over the same period of time, in order to see how each \
changes with respect to the others, MultipleListPlot can be used. Giving \
MultipleListPlot a sequence of lists, it plots each list as ListPlot would, \
using different symbols instead of points for the different data sets. For \
instance, suppose we know that the resource levels for two individuals \
satisfy the following, for ",
  StyleBox["n", "IT"],
  " = 1 and ",
  StyleBox["n", "IT"],
  " = 2."
}], "Text",
  CellTags->{"i:11", "C.1"}],

Cell["\<\
resources[n_] := (SeedRandom[n];
          NestList[(Random[Real, {-1, 1}] + #&), 0, 300])\
\>", "Input",
  CellTags->"C.1"],

Cell["\<\
We can plot the resource levels of these two individuals over time \
on the same set of axes using MultipleListPlot, which uses diamonds and stars \
to represent the two different data sets.\
\>", "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell[TextData[
"MultipleListPlot[resources[1], resources[2],\n  AxesLabel \[Rule] {\"time\", \
\"values\"}];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0000[2000`400?l0
0000o`00003o6`3oool00`000000oooo0?ooo`3o0?ooodP0oooo000K0?oo
o`030000003oool0oooo0?l0ooooB03oool001/0oooo0P00003o0?oooaX0
oooo00<000000?ooo`000000;03oool001/0oooo00<000000?ooo`3oool0
o`3ooolI0?ooo`<00000;03oool001/0oooo00<000000?ooo`3oool0o`3o
oolH0?ooo`D00000:`3oool001/0oooo00<000000?ooo`3oool0o`3ooolH
0?ooo`H00000:P3oool001/0oooo0P00003o0?oooaT0oooo1000000/0?oo
o`006`3oool00`000000oooo0?ooo`3o0?oooaT0oooo00<000000?ooo`00
0000;03oool001/0oooo00<000000?ooo`3oool0o`3ooolB0?ooo`800000
1@3oool00`000000oooo0?ooo`0/0?ooo`006`3oool00`000000oooo0?oo
o`3o0?ooo`D0oooo00<000000?ooo`3oool02`3oool2000003<0oooo000K
0?ooo`800000o`3oool50?ooo`<000002P3oool600000340oooo000K0?oo
o`030000003oool0oooo0?l0oooo0@3oool6000000/0oooo0P0000001P3o
ool00000000000000000oooo000002h0oooo000K0?ooo`030000003oool0
oooo0?l0oooo1`00000:0?ooo`T0000000@0oooo0000003oool00000:P3o
ool000P0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`000005
0?ooo`030000003oool0oooo0?h0oooo00<000000?ooo`0000001@00000;
0?ooo`030000003oool0oooo00T00000:P3oool000P0oooo00<000000?oo
o`3oool00`3oool2000000H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`3m0?ooo`X000003@3oool2000000030?ooo`000000oooo
0080oooo00<000000?ooo`3oool0:@3oool000030?ooo`000000000000<0
00000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo0`00003m0?ooo`X00000503oool00`000000oooo0?ooo`0Y0?ooo`00
2@3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo
0?ooo`330?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
1@00000<0?ooo`800000<`3oool000X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<80oooo0`00
000j0?ooo`H000003P3oool200000380oooo00070?ooo`@00000203oool4
000000@0oooo00<000000?ooo`3oool0`@3oool4000000D0oooo00<00000
0?ooo`3oool0<@3oool3000000040?ooo`0000000000000000X0oooo0P00
00000`3oool000000000000200000340oooo000K0?ooo`800000``3oool3
000000@0oooo0`00000b0?ooo`<000000P3oool00`000000oooo0?ooo`0:
0?ooo`8000000`3oool00`000000oooo0000000_0?ooo`006`3oool00`00
0000oooo0?ooo`320?ooo`8000001@3oool300000300oooo1000000?0?oo
o`@000000P3oool3000002l0oooo000K0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool00`0000060?ooo`030000003oool0oooo02h0
oooo1@0000060?ooo`030000003oool0oooo00`0oooo1000000^0?ooo`00
6`3oool00`000000oooo0?ooo`2m0?ooo`<0000000@0oooo000000000000
00001`3oool00`000000oooo0?ooo`0]0?ooo`@000001P3oool3000000h0
oooo00<000000?ooo`3oool0;P3oool001/0oooo00<000000?ooo`3oool0
_@3oool300000080oooo00<000000?ooo`0000000P3oool00`000000oooo
00000003000002l0oooo0P0000060?ooo`@000003P3oool00`000000oooo
0?ooo`0^0?ooo`006`3oool200000;l0oooo00<000000?ooo`3oool00P3o
ool:000003P0oooo100000050?ooo`800000=`3oool001/0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`040?ooo`X00000>@3oool3
000000H0oooo0P00000f0?ooo`006`3oool00`000000oooo0?ooo`2k0?oo
o`<0000000<0oooo0000003oool00`3oool020000000oooo0?ooo`000000
oooo0000003oool00000>`3oool3000000@0oooo100000080?ooo`030000
003oool0oooo02X0oooo000K0?ooo`030000003oool0oooo0;/0oooo1`00
00030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0=`3o
ool5000000@0oooo00<000000?ooo`3oool01`3oool3000002/0oooo000K
0?ooo`800000_@3oool7000000040?ooo`0000000000000000@0oooo0`00
000]0?ooo`030000003oool0oooo00T0oooo1000000<0?ooo`D00000:`3o
ool001/0oooo00<000000?ooo`3oool0_03oool7000000060?ooo`000000
00000000003oool000000P3oool3000002`0oooo0`00000;0?ooo`<00000
0P3oool2000000L0oooo1@00000/0?ooo`006`3oool00`000000oooo0?oo
o`2k0?ooo`P000000P3oool500000080oooo00<000000?ooo`3oool0:P3o
ool4000000`0oooo0P0000030?ooo`8000001@3oool5000002d0oooo000K
0?ooo`030000003oool0oooo0;`0oooo0`0000020?ooo`030000003oool0
oooo00H00000<03oool3000000`0oooo0`0000000`3oool0000000000002
000000D0oooo0`00000^0?ooo`006`3oool200000;X0oooo00D000000?oo
o`3oool0oooo000000070?ooo`D00000<@3oool00`000000oooo0?ooo`0:
0?ooo`@000000P3oool00`000000oooo0?ooo`060?ooo`8000000P3oool0
0`000000oooo0?ooo`0Y0?ooo`006`3oool00`000000oooo0?ooo`2h0?oo
o`@00000103oool00`000000oooo0?ooo`030?ooo`030000003oool00000
00@0oooo00<000000?ooo`3oool0>@3oool3000000/0oooo1P00000Z0?oo
o`006`3oool00`000000oooo0?ooo`2g0?ooo`H000000P3oool3000000X0
oooo0`0000000`3oool000000?ooo`0h0?ooo`040000003oool000000000
00P0oooo1`00000Z0?ooo`004`3oool3000000D0oooo00<000000?ooo`3o
ool0J03oool2000000030?ooo`000000oooo04X0oooo1P0000000`3oool0
000000000002000000T0oooo1`00000i0?ooo`@00000203oool300000003
0?ooo`000000oooo02X0oooo000F0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0J@3oool4000004T0oooo100000000`3oool00000
0?ooo`020?ooo`<000002P3oool6000002P0oooo00<000000?ooo`3oool0
3@3oool6000000P0oooo00<000000?ooo`3oool0;03oool000d0oooo1@00
00040?ooo`030000003oool0oooo0080oooo0`00001X0?ooo`@00000AP3o
ool200000080oooo0`0000070?ooo`030000003oool0oooo00X0oooo1@00
000I0?ooo`800000303oool3000000l0oooo100000070?ooo`030000003o
ool0oooo02h0oooo000C0?ooo`<000001@3oool00`000000oooo0?ooo`1T
0?ooo`8000000`3oool2000004H0oooo1`00000E0?ooo`@000006@3oool3
000000/0oooo1000000?0?ooo`<000001`3oool3000002l0oooo000C0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0I@3oool20000
04T0oooo200000020?ooo`030000003oool0oooo0140oooo0`00000J0?oo
o`8000001P3oool00`000000oooo0?ooo`030?ooo`<000003P3oool30000
00P0oooo0`00000_0?ooo`004`3oool4000000@0oooo00<000000?ooo`3o
ool0I03oool4000004T0oooo1`000000103oool0000000000000000B0?oo
o`8000006P3oool2000000H0oooo0`0000040?ooo`8000003`3oool30000
00L0oooo00<000000?ooo`000000<03oool001/0oooo0P00001V0?ooo`03
0000003oool0oooo00<0oooo0`0000140?ooo`030000003oool0oooo00<0
000000@0oooo00000000000000004@3oool3000001P0oooo1P0000030?oo
o`@000000`3oool3000000d0oooo00@000000?ooo`0000000000203oool2
00000340oooo000K0?ooo`030000003oool0oooo06X0oooo100000130?oo
o`040000003oool0oooo0?ooo`8000000`3oool00`000000oooo0?ooo`0@
0?ooo`<0000000@0oooo0000003oool000004`3oool7000000@0oooo0`00
00020?ooo`@000003@3oool3000000030?ooo`000000oooo00D0oooo0`00
000a0?ooo`006`3oool00`000000oooo0?ooo`1U0?ooo`800000103oool4
00000440oooo0`000000103oool0000000000000000G0?ooo`030000003o
ool0000000@000004P3oool7000000@0oooo100000020?ooo`<000003@3o
ool6000000H0oooo0P00000a0?ooo`006`3oool00`000000oooo0?ooo`1V
0?ooo`<000000P3oool2000004<0oooo0`0000020?ooo`800000603oool6
000001<0oooo0`0000060?ooo`D000000`3oool00`000000oooo0?ooo`0:
0?ooo`050000003oool000000000003oool00`0000050?ooo`@00000<03o
ool001/0oooo00<000000?ooo`3oool0DP3oool200000140oooo1@000007
0?ooo`030000003oool0000003d0oooo00<000000?ooo`0000000P00000J
0?ooo`D000004`3oool3000000D0oooo1@00000A0?ooo`D0000000<0oooo
0000003oool01@3oool400000300oooo000K0?ooo`800000E03oool20000
0140oooo1@0000060?ooo`<000000P3oool2000003X0oooo0`00000L0?oo
o`030000003oool00000008000004@3oool00`000000oooo000000070?oo
o`<000004P3oool9000000D0oooo0`00000`0?ooo`006`3oool00`000000
oooo0?ooo`1B0?ooo`@000003@3oool2000000<0oooo00<000000?ooo`3o
ool01P3oool3000000<0oooo1000000h0?ooo`8000007@3oool400000100
oooo0`0000090?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool01P0000050?ooo`030000003oool0oooo02l0oooo000K0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool03P3oool3000000030?oo
o`000000oooo00<0oooo00@000000?ooo`000000oooo1@0000000`3oool0
000000000004000005D0oooo1@00000@0?ooo`<000003`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0000000<0oooo1P00000f0?ooo`00
6`3oool00`000000oooo0?ooo`1B0?ooo`8000003P3oool800000080oooo
1@000000103oool000000000003oool8000001H0oooo00<000000?ooo`00
0000>`3oool400000180oooo00<000000?ooo`3oool0103oool00`000000
oooo000000040?ooo`030000003oool00000008000002`3oool5000000<0
oooo1`00000c0?ooo`006`3oool200000580oooo1P00000:0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool9000000030?oo
o`000000000000<00000603oool4000001T0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo
1@0000020?ooo`H00000303oool5000000@0oooo1@00000c0?ooo`006`3o
ool00`000000oooo0?ooo`0?0?ooo`@00000@`3oool3000000P0oooo0`00
00090?ooo`030000003oool0000000T000006`3oool00`000000oooo0?oo
o`0H0?ooo`<00000;`3oool00`000000oooo0?ooo`03000000H0oooo3@00
000<0?ooo`H000000P3oool6000003<0oooo000K0?ooo`030000003oool0
oooo00l0oooo100000100?ooo`H00000203oool00`000000oooo0?ooo`0<
0?ooo`<0000000<0oooo0000000000000`3oool00`000000oooo0?ooo`0E
0?ooo`@000006@3oool4000002<0oooo00<000000?ooo`3oool0203oool8
000000H0oooo1@0000000`3oool0000000000003000000l0oooo00<00000
0?ooo`000000103oool3000000030?ooo`000000oooo0380oooo000K0?oo
o`030000003oool0oooo00l0oooo1@0000100?ooo`H000001`3oool20000
00h0oooo00<000000?ooo`0000002000000;0?ooo`800000203oool40000
01X0oooo0`00000R0?ooo`<000002@3oool3000000030?ooo`0000000000
00800000203oool2000000<0oooo1000000:0?ooo`030000003oool00000
00X0oooo00<000000?ooo`3oool0=03oool001/0oooo0P00000A0?ooo`80
0000@@3oool5000000X0oooo0P00000;0?ooo`030000003oool000000080
oooo0P0000030?ooo`040000003oool00000000000/0oooo0P0000070?oo
o`D000006P3oool00`000000oooo0?ooo`0P0?ooo`@000002P3oool00`00
0000oooo00000004000000l0oooo00<000000?ooo`3oool02@3oool40000
0400oooo000K0?ooo`030000003oool0oooo0100oooo0P0000150?ooo`03
0000003oool0000000L0oooo100000080?ooo`030000003oool000000080
00000P3oool3000000<0oooo100000090?ooo`@000001@3oool00`000000
oooo00000002000000030?ooo`000000oooo03`0oooo0`0000090?ooo`03
0000003oool0oooo00@000003`3oool00`000000oooo0?ooo`0:0?ooo`@0
0000@03oool001/0oooo00<000000?ooo`3oool0C@3oool2000000030?oo
o`000000000000H0oooo0P0000060?ooo`030000003oool0000000X0oooo
1P0000000`3oool000000?ooo`050?ooo`@00000203oool00`000000oooo
0?ooo`060?ooo`L00000603oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00L0oooo0`0000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00`3oool3000000`0oooo1000000o0?ooo`001`3o
ool4000000<0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0000003d0oooo0P000000103oool000000000
003oool2000000030?ooo`0000000000008000001@3oool2000000/0oooo
1000000;0?ooo`030000003oool0oooo00L0oooo100000070?ooo`030000
003oool0oooo00@000005P3oool3000002H0oooo0P0000060?ooo`@00000
2`3oool3000000@0oooo0`00000=0?ooo`030000003oool0oooo03l0oooo
00080?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool03P3oool3000003/0oooo00<0
00000?ooo`0000001@000000103oool000000000003oool3000000D0oooo
0`00000;0?ooo`030000003oool000000140oooo00@000000?ooo`000000
oooo0`0000070?ooo`8000000`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0000000L0oooo1000000U0?ooo`@000001P3oool4000000T0
oooo100000050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0?`3oool000030?ooo`000000000000<000000`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo0`0000090?ooo`030000
003oool0oooo0080oooo1000000j0?ooo`<000000P3oool00`000000oooo
0?ooo`0>00000200oooo1P0000070?ooo`@000000P3oool00`000000oooo
0?ooo`0;0?ooo`<000001P3oool5000002D0oooo100000060?ooo`D00000
203oool4000005H0oooo000:0?ooo`030000003oool0oooo00H0oooo0`00
00050?ooo`030000003oool0oooo00P0oooo100000030?ooo`050000003o
ool000000?ooo`000000>03oool3000000X0oooo00<000000?ooo`000000
100000000`3oool000000?ooo`0P0?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`0@0?ooo`@000001@3oool4000002H0
oooo100000070?ooo`@000002@3oool2000000H0oooo0P0000000`3oool0
0000000000070?ooo`030000003oool000000480oooo00070?ooo`040000
003oool0oooo000000P0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`00000g0?ooo`80000000<0oooo0000003oool0203oool800000280
oooo00<000000?ooo`0000000P3oool2000000/0oooo00<000000?ooo`00
0000303oool00`000000oooo0?ooo`050?ooo`<000009P3oool4000000T0
oooo0P00000C0?ooo`80000000<0oooo0000000000001P3oool300000480
oooo00080?ooo`8000002@3oool4000000@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0h0?ooo`040000003oool0oooo000000P0
oooo2@00000J0?ooo`D000000P3oool2000000040?ooo`000000oooo0?oo
o`800000103oool00`000000oooo0?ooo`030?ooo`<00000303oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo02D0oooo0`00000K0?oo
o`040000003oool000000?ooo`H00000103oool500000440oooo000K0?oo
o`800000203oool2000000T0oooo00<000000?ooo`3oool0>03oool00`00
0000oooo00000003000000L0oooo1`00000L0?ooo`@0000000<0oooo0000
000000000`0000000`3oool0000000000003000000030?ooo`0000000000
008000000`3oool4000003d0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`0A0?ooo`<0000000<0oooo0000000000000P000000
0`3oool00000000000030?ooo`<00000@`3oool001/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`02000000P0oooo00<000000?oo
o`000000<@3oool00`000000oooo000000040?ooo`@000002@3oool40000
0080oooo00<000000?ooo`3oool06@3oool7000000040?ooo`0000000000
000000<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03l0oooo0`0000020?ooo`@000004P3oool4
000000030?ooo`000000000000D000000P3oool400000480oooo000K0?oo
o`030000003oool0oooo00@0oooo1`0000070?ooo`<00000<@3oool40000
00030?ooo`000000oooo00D00000203oool5000000030?ooo`000000oooo
01/0oooo1`000000103oool000000000000000020?ooo`8000003P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool000000380oooo2P00000C
0?ooo`030000003oool0oooo008000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0480oooo000K0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool01P000000oooo0?ooo`000000
oooo00000080oooo0`00000b0?ooo`80000000<0oooo0000000000001000
000;0?ooo`80000000@0oooo00000000000000007P3oool500000080oooo
00<000000?ooo`3oool00P3oool2000000h0oooo00<000000?ooo`3oool0
1@3oool2000000030?ooo`000000oooo0300oooo2000000D0?ooo`040000
003oool000000?ooo`@000001P3oool00`000000oooo0?ooo`120?ooo`00
6`3oool2000000X0oooo1`0000030?ooo`030000003oool0oooo0340oooo
1`00000=0?ooo`8000000P3oool00`000000oooo0?ooo`0N0?ooo`@00000
1P3oool4000000`0oooo100000040?ooo`H000000`3oool2000002/0oooo
2000000D0?ooo`<0000000<0oooo0000000000000`00001:0?ooo`006`3o
ool00`000000oooo0?ooo`050?ooo`8000000`3oool00`000000oooo0000
0004000003P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0?ooo`0O0?ooo`@000001P3oool00`000000oooo0?ooo`080?ooo`030000
003oool000000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
000000040?ooo`@00000:`3oool7000001@0oooo0`0000000`3oool00000
0?ooo`0400000080oooo00<000000?ooo`000000A03oool001/0oooo00<0
00000?ooo`3oool01P3oool2000000<0oooo1@00000b0?ooo`80000000H0
oooo0000003oool000000?ooo`00000h0?ooo`030000003oool0oooo00P0
oooo0P0000070?ooo`<000000P3oool2000000P0oooo00<000000?ooo`3o
ool00P3oool4000002l0oooo0`00000E0?ooo`<000000`3oool01P000000
oooo0?ooo`3oool000000?ooo`800000A03oool001/0oooo00<000000?oo
o`3oool01@3oool4000000030?ooo`0000000000008000006P3oool30000
00@0oooo0P00000@0?ooo`030000003oool0000000@0000000<0oooo0000
003oool02@3oool3000000@0oooo0P0000040?ooo`8000008@3oool30000
00<0oooo0`000000103oool000000000003oool2000000<0oooo1@000000
0`3oool000000000000=0?ooo`8000001P3oool4000000<0oooo0P000004
0?ooo`8000006@3oool010000000oooo0?ooo`0000040?ooo`@000000P3o
ool3000000@0oooo0`0000000`3oool0000000000003000000<0oooo2000
000>0?ooo`<00000103oool2000000@0oooo0P00000V0?ooo`006`3oool0
0`000000oooo0?ooo`020?ooo`8000000P3oool300000080oooo0`000005
0?ooo`030000003oool0000001@0oooo0`0000001@3oool000000?ooo`3o
ool0000000T0oooo00@000000?ooo`3oool000000`3oool8000000/0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000240oooo00<000000?ooo`3oool01@3oool40000
0080oooo00@000000?ooo`3oool0oooo2000000E0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`00000H0?ooo`8000001`3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo00000080oooo1P0000050?ooo`<0000000<0oooo0000003o
ool04P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool08`3oool001/0oooo0P0000040?oo
o`80000000<0oooo0000000000000P0000000`3oool000000?ooo`060?oo
o`<000005@3oool400000080oooo00<000000?ooo`3oool0103oool00`00
0000oooo0000000:000000030?ooo`000000000000<0000000<0oooo0000
003oool01`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?oo
o`030?ooo`<000000P3oool010000000oooo0?ooo`0000030?ooo`@00000
0P3oool2000001H0oooo00D000000?ooo`3oool0oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool30000
00P0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`000002
0?ooo`H00000103oool6000001<0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02<0oooo
000K0?ooo`030000003oool0oooo00<0oooo1@00000;0?ooo`<000004P3o
ool700000080oooo00<000000?ooo`3oool0103oool7000000<0oooo00<0
00000?ooo`00000010000000103oool000000000000000080?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000Q0?ooo`030000003oool0oooo0080oooo100000020?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01000000F
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0F0?ooo`8000002@3oool00`000000oooo
0?ooo`03000000<0oooo00<000000?ooo`3oool00P00000:0?ooo`030000
003oool0oooo0180oooo0P0000030?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000009@3oool001/0oooo00<000000?ooo`3o
ool00`3oool2000000h0oooo0P00000C0?ooo`@000000P3oool010000000
oooo0?ooo`0000060?ooo`<0000000<0oooo0000000000000P0000050?oo
o`040000003oool0oooo0?ooo`D000001`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
8@3oool00`000000oooo0?ooo`020?ooo`D0000000D0oooo0000003oool0
oooo000000030?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`05
0000003oool000000?ooo`0000002`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
603oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000R0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0S0?ooo`006`3oool2000000030?ooo`000000
oooo0180oooo00<000000?ooo`3oool04@3oool4000000<0oooo0P000008
0?ooo`030000003oool0oooo008000001`3oool010000000oooo0?ooo`3o
ool3000000P0oooo0P0000050?ooo`800000103oool200000240oooo0P00
00040?ooo`D000000P3oool2000000@0oooo0`0000070?ooo`L0000000<0
oooo0000000000002@3oool2000000@0oooo0P0000040?ooo`8000008P3o
ool2000000<0oooo100000030?ooo`@000007P3oool3000000@0oooo0P00
00040?ooo`8000009P3oool001/0oooo1000000X0?ooo`<000003@3oool0
0`000000oooo000000040?ooo`060000003oool0oooo0000003oool00000
0`3oool4000003l0oooo100000070?ooo`D0000000<0oooo000000000000
0`3oool00`000000oooo00000007000004@0oooo1000000;0?ooo`800000
AP3oool001/0oooo1@00000W0?ooo`@000000`3oool00`000000oooo0000
00060?ooo`<000001@3oool00`000000oooo0?ooo`02000000@0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`080?ooo`@000000P3o
ool200000080oooo00<000000?ooo`0000000P0000000`3oool000000000
0002000001@0oooo0`0000060?ooo`030000003oool0000002@0oooo1@00
000;0?ooo`800000A@3oool001/0oooo00<000000?ooo`000000503oool0
0`000000oooo0?ooo`0@0?ooo`@000000P3oool010000000oooo0?ooo`3o
ool2000000@0oooo00<000000?ooo`0000000P0000030?ooo`P000000`3o
ool00`000000oooo0?ooo`1=0?ooo`L000000P3oool400000080oooo0`00
000E0?ooo`<000001@3oool400000280oooo00@000000?ooo`0000000000
303oool4000004@0oooo000K0?ooo`040000003oool000000?ooo`800000
4@3oool200000140oooo100000020?ooo`80000000<0oooo000000000000
0P0000030?ooo`H000000P3oool300000080oooo00<000000?ooo`3oool0
DP3oool4000000030?ooo`000000oooo00<0oooo10000000103oool00000
0?ooo`00000E0?ooo`D000001@3oool400000240oooo1000000=0?ooo`03
0000003oool0oooo02/0oooo0`0000020?ooo`D0000000H0oooo0000003o
ool000000?ooo`0000020?ooo`@000000`3oool001/0oooo0`000000103o
ool0000000000000000@0?ooo`<00000403oool9000000030?ooo`000000
oooo00@0oooo1@0000020?ooo`@00000F03oool4000000H0oooo1@00000Q
0?ooo`@000008@3oool4000003/0oooo00@000000?ooo`3oool000000`3o
ool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000003oool0
000000L0oooo000D0?ooool00000;P00000;0?ooo`030000003oool0oooo
00@0oooo00X000000?ooo`3oool0oooo0000003oool000000?ooo`000000
oooo1@0000030?ooo`006`3oool7000000<0oooo00<000000?ooo`3oool0
1P3oool010000000oooo0?ooo`3oool200000080oooo0`0000080?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0000000L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`3oool900000080oooo100000080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`030?ooo`80
000000<0oooo0000003oool01`3oool2000000P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000002@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo00/000000?ooo`3oool0oooo0000003o
ool000000?ooo`000000oooo000000030?ooo`030000003oool0oooo0040
oooo000K0?ooo`L000004@3oool200000080oooo0P00000K0?ooo`<00000
1`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0000000P00000
0P3oool3000001H0oooo00<000000?ooo`3oool0203oool4000000T0oooo
0P00001C0?ooo`@000000`3oool200000080oooo1P0000020?ooo`<00000
103oool001/0oooo1@00000C0?ooo`L000002P3oool00`000000oooo0000
00090?ooo`040000003oool000000?ooo`@000001@3oool4000001H0oooo
00<000000?ooo`3oool0?@3oool3000000030?ooo`000000oooo00H00000
0P3oool6000001<0oooo1P0000060?ooo`@000001`3oool4000005<0oooo
00<000000?ooo`3oool05P3oool001/0oooo1000000E0?ooo`040000003o
ool0oooo000000`0oooo0`0000050?ooo`040000003oool0oooo0?ooo`@0
000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000?@3oool500000080oooo1P0000000`3oool0000000000005000001<0
oooo00<000000?ooo`3oool010000000103oool000000?ooo`0000020?oo
o`030000003oool0oooo00H0oooo0`00001E0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03`3oool001/0oooo00<000000?ooo`00
00009P3oool3000000D0oooo100000000`3oool000000?ooo`020?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03P3oool3000003h0
oooo2`0000020?ooo`L000005@3oool6000000030?ooo`000000000000<0
oooo00<000000?ooo`000000103oool4000001L0oooo00<000000?ooo`3o
ool0E03oool001/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0B0?ooo`8000002`3oool010000000oooo0000000000050?ooo`L0
000000@0oooo0000003oool000003P3oool300000100oooo00<000000?oo
o`3oool0?P3oool500000080oooo0P0000040?ooo`D000003`3oool40000
00@0oooo00<000000?ooo`3oool00P3oool400000080oooo0`0000040?oo
o`D00000503oool4000005D0oooo000K0?ooo`030000003oool0oooo00@0
00004P3oool4000000X0oooo100000070?ooo`T000003@3oool400000580
oooo200000060?ooo`<000003`3oool5000000T0oooo00@000000?ooo`3o
ool0oooo3000000B0?ooo`8000000P3oool00`000000oooo0?ooo`1E0?oo
o`006`3oool700000140oooo1P0000090?ooo`@000002P3oool200000003
0?ooo`0000000000008000003@3oool3000005<0oooo1`00000I0?ooo`D0
0000203oool010000000oooo0?ooo`3oool4000000030?ooo`0000000000
00<000003P3oool2000000D0oooo0P0000000`3oool000000?ooo`1F0?oo
o`006`3oool6000001<0oooo1P0000001P3oool000000?ooo`000000oooo
000000<0oooo0`0000060?ooo`8000000`3oool400000100oooo00<00000
0?ooo`3oool03P3oool00`000000oooo000000120?ooo`@0000000<0oooo
0000003oool01`3oool00`000000oooo0?ooo`0>0?ooo`@000003P3oool3
000000030?ooo`000000000000<000000P3oool2000000/0oooo0P000003
0?ooo`@00000F03oool001/0oooo00<000000?ooo`0000000P00000D0?oo
o`L0000000<0oooo0000000000000`000000103oool00000000000000008
0?ooo`8000000P3oool400000200oooo1@00000m0?ooo`030000003oool0
oooo0080oooo0P00000;0?ooo`8000003@3oool00`000000oooo00000003
000000D0oooo0P0000070?ooo`030000003oool00000008000001@3oool4
000000T0oooo100000030?ooo`030000003oool0oooo05P0oooo000K0?oo
o`040000003oool0oooo000001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`P0000000<0oooo0000003oool01P3oool400000080oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00T0oooo1@00000k0?ooo`@00000403oool3000000`0oooo2000
00040?ooo`80000000<0oooo0000003oool01@3oool2000000L0oooo1000
00070?ooo`<0000000<0oooo000000000000G@3oool001/0oooo00D00000
0?ooo`3oool0oooo0000000L0?ooo`030000003oool0000000D000003P3o
ool00`000000oooo0?ooo`050?ooo`<000002P3oool4000000/0oooo1000
000j0?ooo`D00000403oool2000000h0oooo1@0000050?ooo`D000001`3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0`00
00020?ooo`800000G03oool001/0oooo0P0000000`3oool0000000000002
000001P0oooo0P0000030?ooo`D000003P3oool00`000000oooo00000005
0?ooo`@000001P3oool00`000000oooo00000004000000X0oooo00@00000
0?ooo`3oool00000>P3oool600000140oooo00<000000?ooo`3oool0303o
ool010000000oooo0?ooo`0000070?ooo`D000001P3oool00`000000oooo
0?ooo`0@0?ooo`X0000000<0oooo0000003oool0EP3oool001/0oooo00<0
00000?ooo`0000001@00000F0?ooo`@000000`3oool5000000d0oooo1000
00030?ooo`030000003oool0000000<000001@3oool7000000T0oooo0`00
00020?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool01000
000A0?ooo`8000006`3oool00`000000oooo0?ooo`040?ooo`040000003o
ool0000000000180oooo00<000000?ooo`0000000P0000030?ooo`<00000
E`3oool001/0oooo00<000000?ooo`3oool01@00000E0?ooo`L0000000@0
oooo0000003oool00000403oool010000000oooo0?ooo`3oool8000000@0
oooo1@0000001@3oool000000?ooo`3oool0000000L0oooo0`000000103o
ool0000000000000000_0?ooo`040000003oool0000000000080oooo0`00
00020?ooo`<000004P3oool2000001X0oooo00<000000?ooo`3oool0103o
ool5000000P0oooo00<000000?ooo`0000001`3oool400000080oooo1@00
001F0?ooo`006`3oool010000000oooo0?ooo`3oool5000001D0oooo1P00
00030?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@00
0000103oool000000000000000050?ooo`<00000103oool3000000L0oooo
00<000000?ooo`3oool00`00000Z0?ooo`040000003oool0oooo0?ooo`X0
00000`3oool00`000000oooo0?ooo`0A0?ooo`<00000803oool4000000T0
oooo0`0000040?ooo`040000003oool0oooo0?ooo`D0000000<0oooo0000
00000000F03oool001/0oooo0P0000030?ooo`@00000503oool800000180
oooo2@0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00`3oool4000000/0oooo00<000000?ooo`3oool0:03oool300000003
0?ooo`000000000000D0000000@0oooo0000000000000000603oool30000
00T0oooo00<000000?ooo`000000503oool00`000000oooo000000090?oo
o`@000000`3oool2000000030?ooo`000000000000H00000F@3oool001/0
oooo00<000000?ooo`3oool00`3oool3000001D0oooo00D000000?ooo`3o
ool0oooo0000000D0?ooo`<0000000<0oooo0000000000001@00000<0?oo
o`H00000<P3oool00`000000oooo0?ooo`0300000080oooo0`0000000`3o
ool00000000000020?ooo`040000003oool0oooo000001H0oooo0P000008
0?ooo`D000002P3oool2000000P0oooo00<000000?ooo`3oool02@3oool5
000000030?ooo`00000000000080000000<0oooo0000003oool00`00001K
0?ooo`001`3oool4000000<0oooo0P0000030?ooo`<000001@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02h0oooo0`0000000`3o
ool000000?ooo`06000000<0oooo0P0000050?ooo`H000002`3oool00`00
0000oooo0?ooo`0S0?ooo`<000000P3oool300000080oooo0`0000000`3o
ool00000000000030?ooo`<000005P3oool2000000L0oooo1P00000:0?oo
o`8000004@3oool5000000060?ooo`00000000000000003oool000001@3o
ool2000005/0oooo00080?ooo`030000003oool0oooo00<0oooo0P000006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0100oooo0`000004
0?ooo`H0000000<0oooo0000000000000P0000030?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool02@3oool3000002<0oooo10000000
0`3oool0000000000002000000030?ooo`000000000000H0000000<0oooo
0000000000000P00000E0?ooo`@000001P3oool5000000X0oooo1000000A
0?ooo`050000003oool0oooo0000003oool0100000050?ooo`@00000FP3o
ool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`<00000103oool4000001T0oooo0`00000B0?ooo`030000003oool0
oooo00@0oooo2P0000020?ooo`<00000103oool00`000000oooo00000003
0?ooo`8000000`3oool3000002@0oooo0`0000020?ooo`P0000000<0oooo
0000000000001@00000G0?ooo`<000001`3oool3000000`0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo06<0oooo000:0?ooo`030000003oool0oooo00H0oooo0`0000050?oo
o`030000003oool0oooo00@0oooo1@00000H0?ooo`<00000403oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo0?ooo`D0000000<0oooo
0000000000000`3oool3000000030?ooo`000000oooo00D0000000@0oooo
0000000000000000103oool00`000000oooo0?ooo`0T0?ooo`050000003o
ool0oooo0000003oool01P0000020?ooo`H00000603oool4000000L0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`1S0?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool01@3oool4000001T0oooo00<000000?ooo`3oool0
3P3oool300000080oooo100000040?ooo`80000000<0oooo000000000000
1@3oool00`000000oooo0000000;000002d0oooo0`0000000`3oool00000
00000002000000D0oooo00<000000?ooo`0000008@3oool00`000000oooo
0000000R0?ooo`0:0000003oool000000000003oool000000?ooo`000000
oooo00000680oooo00080?ooo`8000002@3oool4000000@0oooo00<00000
0?ooo`3oool01P3oool4000002P0oooo100000000`3oool0000000000003
000000H0oooo0`0000060?ooo`P0000000<0oooo000000000000;`3oool7
000000D0oooo00<000000?ooo`3oool07P3oool010000000oooo0?ooo`3o
ool3000002<0oooo1@000000103oool0000000000000001R0?ooo`006`3o
ool00`000000oooo0?ooo`070?ooo`<000006@3oool00`000000oooo0?oo
o`0=0?ooo`P000001P3oool4000000L0oooo0`0000000`3oool000000?oo
o`030?ooo`030000003oool0oooo02h0oooo1@0000060?ooo`8000000P3o
ool00`000000oooo0?ooo`0J0?ooo`8000000P3oool400000240oooo2P00
001R0?ooo`006`3oool2000000T0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo00000002000000l0oooo00<000000?ooo`0000000`000007
0?ooo`<000002@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
000000<0oooo100000040?ooo`<0000000@0oooo00000000000000006P3o
ool400000080oooo00<000000?ooo`3oool08P3oool020000000oooo0?oo
o`000000oooo0000003oool00000H`3oool001/0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0C0?ooo`H000004@3oool3000000T0
oooo0P00000B0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool08@3oool500000080oooo100000050?ooo`80000000@0oooo00000000
000000006@3oool4000000<0oooo00<000000?ooo`3oool08P3oool01@00
0000oooo0?ooo`000000oooo00<00000H`3oool001/0oooo00<000000?oo
o`3oool01P3oool00`000000oooo00000002000001@0oooo0`0000000`3o
ool000000?ooo`0B0?ooo`030000003oool0oooo00L0oooo0`00000?0?oo
o`040000003oool00000000000D0oooo0`00000Q0?ooo`H000000`3oool3
000000D0oooo00D000000?ooo`3oool0oooo0000000I0?ooo`<000000P3o
ool00`000000oooo0?ooo`0X0?ooo`H00000HP3oool001/0oooo00<00000
0?ooo`3oool01@3oool700000180oooo1@00000O0?ooo`8000003@3oool6
000000D0oooo0`00000Q0?ooo`<0000000@0oooo00000000000000000`3o
ool00`000000oooo0?ooo`0S0?ooo`80000000<0oooo0000000000000`00
000X0?ooo`030000003oool0000006@0oooo000K0?ooo`8000001P3oool8
00000140oooo1@0000000`3oool000000?ooo`0Z0?ooo`D0000000<0oooo
0000003oool01@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00<00000:03oool4000000030?ooo`000000000000<000009`3oool0
0`000000oooo0000001T0?ooo`006`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00@00000403oool5000000040?ooo`0000000000
000000d0oooo00<000000?ooo`3oool06@3oool7000002l0oooo00<00000
0?ooo`3oool0:P3oool6000008l0oooo000K0?ooo`030000003oool0oooo
00/0oooo0P00000A0?ooo`8000000P3oool4000000`0oooo0`00000K0?oo
o`H00000:P3oool00`000000oooo0?ooo`0`0?ooo`@00000T03oool001/0
oooo00<000000?ooo`3oool02P3oool4000000030?ooo`000000oooo00d0
oooo00<000000?ooo`3oool00P3oool3000000`0oooo0`00000L0?ooo`04
0000003oool0oooo000000T0oooo00<000000?ooo`3oool07P3oool30000
0300oooo1000002A0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`P0
00003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool09`3oool3000001l0oooo0`0000350?ooo`00
6`3oool2000000X0oooo2000000<0?ooo`8000001P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02P0oooo1000000O0?ooo`030000
003oool0oooo0<@0oooo000K0?ooo`030000003oool0oooo00X0oooo0P00
0000103oool000000?ooo`00000=0?ooo`8000001@3oool3000000/0oooo
0P00000Z0?ooo`@00000i@3oool001/0oooo00<000000?ooo`3oool02P3o
ool200000180oooo00<000000?ooo`3oool00`3oool3000000X0oooo0`00
000Z0?ooo`@00000i@3oool001/0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00X0oooo0P00000[
0?ooo`<00000i@3oool001/0oooo0P00000?0?ooo`030000003oool00000
00`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0Y0?oo
o`<000007P3oool00`000000oooo0?ooo`350?ooo`006`3oool00`000000
oooo0?ooo`0=0?ooo`D000002P3oool200000400oooo0`00000M0?ooo`<0
0000aP3oool001<0oooo0`0000050?ooo`030000003oool0oooo00d0oooo
1@00000:0?ooo`800000@@3oool00`000000oooo0?ooo`0L0?ooo`<00000
aP3oool001H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0>0?ooo`@000002`3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool0a@3oool001H0oooo00<00000
0?ooo`3oool00P3oool300000100oooo00<000000?ooo`3oool04P3oool3
000000T0oooo00<000000?ooo`3oool0o`3ooolD0?ooo`004`3oool30000
00D0oooo00<000000?ooo`3oool06P3oool00`000000oooo000000080?oo
o`<00000203oool3000002h0oooo00<000000?ooo`3oool0h`3oool001<0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0000000@00000203oool00`000000oooo0?ooo`070?ooo`<0
0000;@3oool3000001/0oooo00<000000?ooo`3oool0aP3oool001<0oooo
100000040?ooo`030000003oool0oooo01H0oooo2000000B0?ooo`800000
;@3oool4000001/0oooo0P0000370?ooo`006`3oool00`000000oooo0?oo
o`0A0?ooo`040000003oool0oooo0?ooo`T000004@3oool3000002h0oooo
0`00000J0?ooo`<00000a`3oool001/0oooo0P00000A0?ooo`<0000000<0
oooo0000000000001@0000000`3oool000000?ooo`0B0?ooo`800000;`3o
ool00`000000oooo0?ooo`0H0?ooo`@00000a`3oool001/0oooo00<00000
0?ooo`3oool0403oool300000080oooo1P00000<0?ooo`030000003oool0
oooo0540oooo100000380?ooo`006`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool000000080oooo00H000000?ooo`3oool000000?ooo`00
000:0?ooo`<000001`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool02@3oool300000<T0oooo000K
0?ooo`030000003oool0oooo0180oooo100000040?ooo`<00000203oool4
000000H0oooo0P00000`0?ooo`<000002P3oool3000000T0oooo0`00003:
0?ooo`006`3oool200000180oooo1P0000030?ooo`<000002@3oool30000
00D0oooo0`00000`0?ooo`<000002@3oool4000000X0oooo0P00003:0?oo
o`006`3oool00`000000oooo0?ooo`0B0?ooo`D0000000D0oooo0000003o
ool0oooo0000000;0?ooo`030000003oool0oooo00<0oooo1000000a0?oo
o`030000003oool0oooo00L0oooo1P0000050?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0a`3oool001/0oooo00<000000?ooo`3o
ool04`3oool3000000040?ooo`0000000000000001@0oooo0`00000j0?oo
o`P000000`3oool3000000@0oooo0P0000380?ooo`006`3oool00`000000
oooo0?ooo`0B0?ooo`P000003P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo03X0oooo1`0000020?ooo`@0000000<0oooo0000003o
ool00`0000380?ooo`006`3oool00`000000oooo0?ooo`0A0?ooo`D00000
00@0oooo00000000000000003@3oool3000000@0oooo00<000000?ooo`3o
ool0?03oool6000000<0oooo1P0000000`3oool00000000000380?ooo`00
6`3oool200000180oooo1@0000020?ooo`030000003oool0oooo00/0oooo
100000030?ooo`<00000=`3oool00`000000oooo0?ooo`040?ooo`040000
003oool00000000000D0oooo1@0000000`3oool000000?ooo`380?ooo`00
6`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool000000180oooo
0`0000000`3oool000000?ooo`03000003<0oooo00<000000?ooo`3oool0
0`0000030?ooo`030000003oool0oooo00<000001`3oool300000</0oooo
000K0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`0000000P00
00000`3oool000000?ooo`0b0?ooo`<0000000@0oooo0000000000000000
0P3oool7000000@0oooo00@000000?ooo`3oool0oooo0P00003;0?ooo`00
6`3oool00`000000oooo0?ooo`0Y0?ooo`@00000=03oool8000000030?oo
o`00000000000080000000<0oooo0000000000000`000000103oool00000
0000000000020?ooo`800000b`3oool001/0oooo0P00000Z0?ooo`D00000
=03oool4000000030?ooo`00000000000080oooo0`0000020?ooo`T00000
0P3oool00`000000oooo0?ooo`390?ooo`006`3oool00`000000oooo0?oo
o`0X0?ooo`L00000=03oool400000080oooo0P0000000`3oool000000?oo
o`030?ooo`@0000000<0oooo0000000000000P00003=0?ooo`00203oool0
0`000000oooo0?ooo`030?ooo`8000000`3oool3000000D0oooo00<00000
0?ooo`3oool09`3oool4000000040?ooo`0000000000000003D0oooo1`00
00070?ooo`8000000`3oool300000<d0oooo00080?ooo`030000003oool0
oooo00<0oooo0P0000060?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0:03oool300000080oooo00<000000?ooo`3oool0=@3oool3
000000030?ooo`000000000000d0oooo0`00003<0?ooo`002@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo0`00000Y0?oo
o`<00000>P3oool00`000000oooo0?ooo`03000000`0oooo0`00003<0?oo
o`002@3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000
oooo0?ooo`0Y0?ooo`<00000>@3oool00`000000oooo0?ooo`05000000`0
oooo00<000000?ooo`3oool0b`3oool000X0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0=`3oool9000000P0oooo00<000000?ooo`3oool0
c`3oool000L0oooo100000080?ooo`@00000103oool00`000000oooo0?oo
o`1S0?ooo`@0000000@0oooo000000000000oooo0P0000070?ooo`<00000
d03oool001/0oooo00<000000?ooo`3oool0I03oool3000000@0oooo00<0
00000?ooo`3oool01@3oool400000=00oooo000K0?ooo`800000IP3oool0
0`000000oooo0?ooo`0;0?ooo`<00000d@3oool001/0oooo00<000000?oo
o`3oool0M03oool00`000000oooo0?ooo`3@0?ooo`006`3oool00`000000
oooo0?ooo`3o0?ooodP0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o
0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo
003o0?ooofH0oooo003o0?ooofH0oooo003o0?ooofH0oooo000;0?ooo`80
00000`3oool5000000030?ooo`000000000000<0000000<0oooo00000000
00000`0000020?ooo`@0000000<0oooo0000000000000P00003o0?ooocX0
oooo000;0?ooo`8000000`3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`000008
0?ooo`030000003oool0oooo0?l0oooo>03oool000X0oooo00@000000?oo
o`00000000000P3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00D0000000<0oooo0000000000000P00
003o0?ooocX0oooo000:0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo0000003o0?ooocd0
oooo00090?ooo`8000000P3oool200000080oooo0`0000040?ooo`030000
003oool0oooo0080000000<0oooo0000000000000`3oool300000080oooo
1000003o0?ooocX0oooo000H0?ooo`030000003oool0oooo0?l0ooooB`3o
ool001H0oooo0`00003o0?ooodd0oooo003o0?ooofH0oooo003o0?ooofH0
oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->False,
  ImageSize->{357.25, 172.75},
  ImageMargins->{{63.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
Other options to MultipleListPlot allow us to connect the data \
points with lines that allow us to dfferentiate between them, instead of \
using different symbols for the points.\
\>", "Text",
  CellTags->{"i:12", "C.1"}],

Cell[CellGroupData[{

Cell[TextData[
"MultipleListPlot[resources[1], resources[2],\n  AxesLabel \[Rule] {\"time\", \
\"values\"},\n  SymbolShape \[Rule] None,\n  PlotJoined \[Rule] True];"], 
  "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0000[2000`400?l0
0000o`00003o6`3oool00`000000oooo0?ooo`3o0?ooodP0oooo000K0?oo
o`030000003oool0oooo0?l0ooooB03oool001/0oooo0P00003o0?ooodT0
oooo000K0?ooo`030000003oool0oooo0?l0oooo6P3oool00`000000oooo
0?ooo`0[0?ooo`006`3oool00`000000oooo0?ooo`3o0?oooaX0oooo00<0
00000?ooo`3oool0:`3oool001/0oooo00<000000?ooo`3oool0o`3ooom8
0?ooo`006`3oool200000?l0oooo6P3oool00`000000oooo0?ooo`0/0?oo
o`006`3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3o
ool0:P3oool001/0oooo00<000000?ooo`3oool0o`3ooom80?ooo`006`3o
ool00`000000oooo0?ooo`3o0?oooa<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0/0?ooo`006`3oool200000?l0oooo1P3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0:@3oool001/0oooo00<000000?ooo`3oool0o`3oool20?oo
o`040000003oool0oooo000000h0oooo00D000000?ooo`000000oooo0000
000_0?ooo`006`3oool00`000000oooo0?ooo`3o0?ooo`80oooo00@00000
0?ooo`3oool00000303oool200000080oooo00<000000?ooo`000000;`3o
ool000P0oooo00<000000?ooo`3oool00`3oool2000000<0oooo0`000005
0?ooo`030000003oool0oooo0?l0oooo0P3oool2000000030?ooo`000000
00000440oooo00080?ooo`030000003oool0oooo00<0oooo0P0000060?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0oP3oool00`00
0000oooo0?ooo`03000000030?ooo`000000oooo00`0oooo0P0000000`3o
ool000000000000_0?ooo`0000<0oooo0000000000000`0000030?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool300000?h0
oooo00<000000?ooo`0000000P3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool000T0oooo
00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?ooo`3oool0
oP3oool00`000000oooo000000020?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool0<03oool000X0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0>03oool3000000@0oooo00<000000?ooo`3oool0303o
ool010000000oooo00000000000_0?ooo`001`3oool4000000P0oooo1000
00040?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0=`3o
ool010000000oooo0000000000040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`006`3o
ool200000<@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0?P3o
ool001/0oooo00<000000?ooo`3oool0`P3oool2000000H0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00d0oooo0P00000_0?ooo`006`3oool00`000000oooo0?ooo`2n0?oo
o`070000003oool0oooo0?ooo`000000oooo000000050?ooo`030000003o
ool0oooo02l0oooo0P0000080?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0=03oool001/0oooo00<000000?ooo`3oool0_P3oool0
1`000000oooo0?ooo`3oool000000?ooo`000000103oool00`000000oooo
0000000`0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
?P3oool001/0oooo00<000000?ooo`3oool0_P3oool01`000000oooo0?oo
o`3oool000000?ooo`000000103oool00`000000oooo0000000`0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0d0?ooo`006`3oool200000;l0oooo00L000000?ooo`3oool0
oooo0000003oool000000080oooo00D000000?ooo`000000oooo0000000`
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0d0?ooo`006`3oool00`000000oooo0?ooo`2n0?oo
o`80000000D0oooo0000003oool0oooo000000020?ooo`050000003oool0
00000?ooo`000000<03oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03d0oooo000K0?ooo`030000003oool0oooo0;`0oooo0P000000
103oool000000?ooo`0000030?ooo`050000003oool000000?ooo`000000
0P3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0d0?ooo`006`3o
ool00`000000oooo0?ooo`2l0?ooo`80000000@0oooo0000003oool00000
0`3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Z0?ooo`00
6`3oool200000;d0oooo0P000000103oool000000?ooo`0000030?ooo`80
000000<0oooo0000000000000P3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool2000002`0
oooo000K0?ooo`030000003oool0oooo0;`0oooo0P000000103oool00000
0?ooo`0000030?ooo`80000000<0oooo0000000000000P3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`040000003oool000000000
02`0oooo000K0?ooo`030000003oool0oooo0;`0oooo00H000000?ooo`3o
ool000000?ooo`0000040?ooo`040000003oool0000000000080oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01@3oool010000000oooo0000
0000000/0?ooo`006`3oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo0080oooo0P00000:0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`8000000P3o
ool00`000000oooo0?ooo`0Y0?ooo`006`3oool200000;`0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0303oool01@000000oooo0?ooo`3o
ool0000000P0oooo0P0000020?ooo`030000003oool0oooo02T0oooo000K
0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`000000103oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool0
0`000000oooo0?ooo`0Y0?ooo`006`3oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0^0?ooo`004`3oool3000000D0
oooo00<000000?ooo`3oool0^03oool2000000030?ooo`000000oooo0100
oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`0=0?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`0^
0?ooo`005P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0B@3oool01@000000oooo0000003oool0
00000140oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;P3o
ool000d0oooo1@0000040?ooo`030000003oool0oooo0080oooo0`00001Y
0?ooo`030000003oool0000004/0oooo00<000000?ooo`3oool00P00000A
0?ooo`040000003oool00000000001/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0>0?ooo`8000002@3oool00`000000oooo0?oo
o`0^0?ooo`004`3oool3000000D0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`160?ooo`80000000<0oooo0000000000000`3oool0
0`000000oooo0?ooo`0A0?ooo`<000006`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00h0oooo0P0000090?ooo`030000003oool0
oooo02h0oooo000C0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`140?ooo`80000000<0oooo0000
000000000`3oool00`000000oooo0?ooo`0A0?ooo`<000006`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0^0?ooo`004`3oool4000000@0
oooo00<000000?ooo`3oool0IP3oool010000000oooo0?ooo`0000180?oo
o`80000000<0oooo0000000000000`3oool00`000000oooo0?ooo`0A0?oo
o`040000003oool0oooo000001T0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0P000009
0?ooo`030000003oool0oooo02h0oooo000K0?ooo`800000JP3oool00`00
0000oooo0?ooo`150?ooo`040000003oool000000?ooo`8000005`3oool0
10000000oooo0?ooo`00000H0?ooo`80000000<0oooo0000003oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo0P00
00080?ooo`800000<03oool001/0oooo00<000000?ooo`3oool0I@3oool2
000000D0oooo00<000000?ooo`3oool0@P3oool01P000000oooo0?ooo`00
0000oooo000001X0oooo00<000000?ooo`3oool0503oool00`000000oooo
000000020?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo00@000000?ooo`3oool00000203oool00`000000
oooo0?ooo`0_0?ooo`006`3oool00`000000oooo0?ooo`1V0?ooo`040000
003oool0oooo000004L0oooo00@000000?ooo`3oool00000703oool00`00
0000oooo0000000D0?ooo`8000000`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0000000@0oooo00<000000?ooo`3oool03@3oool01000
0000oooo0000000000070?ooo`800000<@3oool001/0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`110?ooo`040000003oool0oooo
000001`0oooo00<000000?ooo`000000503oool2000000<0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo000000040?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool01@3oool200000340oooo000K0?oo
o`800000IP3oool00`000000oooo000000050?ooo`030000003oool0oooo
0440oooo00@000000?ooo`3oool00000703oool010000000oooo00000000
000B0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0300oooo000K0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0403oool2000000T0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool000000180oooo00<00000
0?ooo`3oool0103oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool00`000000oooo0?ooo`0<0?ooo`070000003oool000000?ooo`00
0000oooo000000060?ooo`030000003oool0oooo0300oooo000K0?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`00
00004P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`00000D0?ooo`8000001@3oool0
0`000000oooo0?ooo`0`0?ooo`006`3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool000002P3oool0
10000000oooo0?ooo`3oool200000080oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool010000000oooo0?ooo`0000030?ooo`040000
003oool0oooo000000d0oooo00D000000?ooo`000000oooo000000040?oo
o`050000003oool0oooo0?ooo`000000<`3oool001/0oooo00<000000?oo
o`3oool0D`3oool2000001`0oooo00<000000?ooo`0000000`3oool20000
00030?ooo`000000oooo03@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`00000?0?ooo`030000003o
ool0000000@0oooo00<000000?ooo`3oool00P00000c0?ooo`006`3oool2
000006@0oooo0P0000080?ooo`<000002`3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`00000000000`3oool010000000oooo0?ooo`00000G0?ooo`800000
00<0oooo0000003oool0<P3oool001/0oooo00<000000?ooo`3oool0E03o
ool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`0000000P3oool3000001P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo
0P0000070?ooo`040000003oool00000000000<0oooo00<000000?ooo`00
00003P3oool00`000000oooo0?ooo`0n0?ooo`006`3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00T0oooo00@000000?ooo`3oool0oooo0P0000070?ooo`03
0000003oool0000000@0oooo00<000000?ooo`000000C`3oool001/0oooo
00<000000?ooo`3oool0403oool2000004@0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`080?ooo`<000002P3oool2000001D0oooo
00@000000?ooo`3oool000006P3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo000000040?ooo`030000003oool0000004l0oooo000K0?ooo`80
00004@3oool00`000000oooo0?ooo`0o0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01X0oooo00@000000?ooo`3oool000006P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00T0oooo00@00000
0?ooo`3oool000002@3oool2000000H0oooo00<000000?ooo`3oool02`3o
ool300000400oooo000K0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`8000009@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo0P000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`1>0?ooo`006`3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0000004<0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000001T0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`050000003oool0
00000?ooo`0000002P3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0@03oool000L0oooo10000003
0?ooo`8000000`3oool3000000D0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0m0?ooo`040000003oool0oooo00000080oooo00D0
00000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`040000
003oool00000000000/0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`100?ooo`00203oool00`000000oooo0?ooo`030?ooo`800000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04l0oooo
00@000000?ooo`3oool00000=03oool00`000000oooo0000000T0?ooo`03
0000003oool0oooo02D0oooo0`0000070?ooo`040000003oool000000000
00/0oooo00<000000?ooo`3oool0E@3oool000030?ooo`000000000000<0
00000`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo0`00000?0?ooo`040000003oool0oooo000003X0oooo00<000000?oo
o`000000403oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0U0?ooo`<000001`3oool010000000oooo0?ooo`00000P
0?ooo`030000003oool0oooo0400oooo000:0?ooo`030000003oool0oooo
00H0oooo0`0000050?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0>`3oool01@000000oooo0000003oool0000000P0oooo00L00000
0?ooo`3oool0oooo0000003oool0000002H0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0000000L0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`100?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool02@3oool200000480oooo00D000000?ooo`3oool0
oooo0000000<0?ooo`030000003oool0oooo0280oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo04T0oooo00080?ooo`8000002@3oool4000000@0
oooo00<000000?ooo`3oool03`3oool010000000oooo0?ooo`00000j0?oo
o`800000303oool00`000000oooo000000020?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool20000
00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`110?ooo`006`3oool200000100oooo00<000000?ooo`3o
ool0?03oool010000000oooo0000000000090?ooo`040000003oool0oooo
0?ooo`8000007P3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0B0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`190?ooo`006`3oool00`000000oooo0?ooo`090?ooo`800000@@3o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool000000080oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000001d0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool00`3oool4000004T0oooo
000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3o
ool2000000<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02P3oool2000000H0oooo00<000000?ooo`3oool0:P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000603oool010000000
oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool0@P3oool001/0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0:`3oool5000001D0oooo0P0000020?ooo`8000000P3oool00`000000
oooo0?ooo`180?ooo`006`3oool2000000H0oooo0P0000001@3oool00000
0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo000000020?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00`3oool2000002h0oooo0P0000000`3oool0
00000?ooo`0L0?ooo`800000B@3oool001/0oooo00<000000?ooo`3oool0
1@3oool2000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0b0?ooo`8000000P3oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool010000000oooo
0?ooo`0000040?ooo`800000;P3oool2000001L0oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0480oooo000K0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P00000j0?ooo`<00000@P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0000000d0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0D0?ooo`040000003oool0oooo00000500oooo000K0?ooo`03
0000003oool0oooo00D0oooo00@000000?ooo`00000000000`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0140oooo0`0000040?oo
o`8000004P3oool2000000<0oooo00@000000?ooo`3oool00000203oool3
000000@0oooo0P0000040?ooo`8000008@3oool3000000<0oooo0`000002
0?ooo`040000003oool00000000000@0oooo00<000000?ooo`0000000`3o
ool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000000@0oooo
00<000000?ooo`3oool01@3oool4000000<0oooo0P0000040?ooo`800000
6P3oool00`000000oooo0?ooo`040?ooo`@000000P3oool3000000@0oooo
0P00000<0?ooo`8000004P3oool3000000@0oooo0P0000040?ooo`800000
9P3oool001/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo01@0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0@0?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000:0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000Q0?ooo`030000003o
ool0oooo00D0oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo
00<000000?ooo`0000002@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000001T0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`040000003oool0
oooo00000080oooo0P00000=0?ooo`030000003oool0oooo0140oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02<0oooo000K0?ooo`8000001@3oool00`000000oooo
0?ooo`0T0?ooo`80000000D0oooo0000003oool0oooo0000000=0?ooo`03
0000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`00000Q0?ooo`030000003oool0oooo00@0oooo0P00
00020?ooo`040000003oool0oooo000000L0oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00
00020?ooo`800000303oool00`000000oooo0?ooo`0B0?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0S0?ooo`006`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0140oooo0`000000103oool000000000000000020?ooo`03
0000003oool0oooo00P0oooo0P0000040?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000008@3oool0
0`000000oooo0?ooo`020?ooo`<0000000@0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`020?ooo`<00000203oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool00`0000030?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool03`3oool2000000<0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000U0?ooo`006`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000008@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080000000D0oooo0000003oool0oooo00000004
0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool000000`3o
ool00`000000oooo0?ooo`060?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000P0?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`02000000d0oooo00<000000?ooo`3oool04@3oool0
10000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool08`3oool001/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0Q0?ooo`@000000`3oool2000000T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool2000000D0oooo0P00
00040?ooo`8000008@3oool2000000@0oooo100000030?ooo`8000001`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0
1`3oool2000000@0oooo0P0000040?ooo`8000008P3oool2000000<0oooo
100000030?ooo`80000000<0oooo0000003oool02`3oool00`000000oooo
0?ooo`0?0?ooo`<00000103oool2000000@0oooo0P00000V0?ooo`006`3o
ool2000001H0oooo00<000000?ooo`3oool04@3oool01@000000oooo0?oo
o`3oool0000000`0oooo0P0000060?ooo`030000003oool0000005d0oooo
00<000000?ooo`3oool00`0000000`3oool00000000000160?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0@`3oool001/0oooo00<0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00/0oooo0P0000050?ooo`800000H@3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`130?ooo`006`3oool00`000000oooo0000
00030?ooo`030000003oool0oooo0280oooo00<000000?ooo`000000403o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo05L0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`8000000`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
NP3oool001/0oooo00@000000?ooo`3oool00000503oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0
oooo000000050?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`040?ooo`040000003oool00000
0?ooo`80000000<0oooo0000003oool07`3oool2000002@0oooo00<00000
0?ooo`3oool0>`3oool300000080oooo1@0000001P3oool000000?ooo`00
0000oooo00000080oooo100000030?ooo`006`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0oooo02/0oooo0P0000050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`040?ooo`070000003oool000000?ooo`000000oooo0000000H0?oo
o`800000203oool00`000000oooo0?ooo`1P0?ooo`040000003oool0oooo
000000<0oooo00/000000?ooo`3oool0oooo0000003oool000000?ooo`00
0000oooo000000070?ooo`00503ooooo000002h000002`3oool00`000000
oooo0?ooo`040?ooo`0:0000003oool0oooo0?ooo`000000oooo0000003o
ool000000?ooo`D000000`3oool001/0oooo0P0000000`3oool000000000
000D0?ooo`030000003oool0oooo01@0oooo0P0000030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02`3o
ool2000000030?ooo`000000oooo00<0oooo0P0000020?ooo`030000003o
ool000000180oooo00<000000?ooo`3oool0303oool010000000oooo0?oo
o`00000M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
00/000000?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000
00030?ooo`030000003oool0oooo0040oooo000K0?ooo`030000003oool0
00000340oooo0P0000040?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0EP3oool01@000000oooo000000000000oooo008000000P3o
ool010000000oooo0?ooo`3oool2000001P0oooo00<000000?ooo`3oool0
J@3oool4000000<0oooo0P0000020?ooo`H000000P3oool3000000@0oooo
000K0?ooo`030000003oool0000001X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo00@0
00000?ooo`00000000000P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00000:0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool05P3oool001/0oooo0`00000F0?ooo`030000003oool0oooo0080
00004`3oool010000000oooo0?ooo`3oool2000000<0oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0n0?ooo`060000003oool00000
0?ooo`000000oooo0P0000000`3oool000000?ooo`020?ooo`<0000000<0
oooo0000003oool0503oool01@000000oooo0?ooo`3oool0000000P0oooo
00<000000?ooo`3oool01`3oool2000001H0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00l0oooo
000K0?ooo`030000003oool000000340oooo00@000000?ooo`0000000000
0P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo03h0oooo
00H000000?ooo`000000oooo0000003oool2000000030?ooo`000000oooo
00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`230?oo
o`006`3oool010000000oooo0?ooo`00000F0?ooo`030000003oool00000
00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0n0?ooo`040000003oool0oooo0?ooo`<0000000<0oooo
0000003oool08P3oool010000000oooo0?ooo`0000040?ooo`8000001`3o
ool00`000000oooo0000001]0?ooo`006`3oool01P000000oooo0?ooo`00
0000oooo000001@0oooo00@000000?ooo`0000000000503oool2000000D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo03h0oooo00@000000?ooo`3oool0oooo0P0000000`3o
ool00000000000090?ooo`030000003oool0oooo00d0oooo00D000000?oo
o`3oool0oooo0000000=0?ooo`8000002@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo05D0oooo000K0?ooo`80000000@0oooo0000
003oool000008`3oool00`000000oooo0?ooo`070?ooo`050000003oool0
oooo0?ooo`0000004P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0000003h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00d0oooo1@00000C0?ooo`8000005`3o
ool00`000000oooo0?ooo`1G0?ooo`006`3oool01P000000oooo0?ooo`00
0000oooo000001@0oooo00D000000?ooo`3oool0oooo000000090?ooo`80
0000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool03P3oool00`000000oooo0000000n0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01@3oool010000000
oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000001P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05D0oooo000K0?oo
o`060000003oool0oooo0000003oool00000603oool01`000000oooo0?oo
o`3oool000000?ooo`0000003@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0000000n0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0303oool01P000000oooo0?ooo`000000oooo000000h0oooo00D00000
0?ooo`000000oooo000000060?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`1E0?ooo`006`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000006`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0000000?0?ooo`030000003oool0000003h0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool08`3oool2000000@0oooo
0P00001I0?ooo`006`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00005`3oool01`000000oooo0?ooo`000000oooo0000003oool00`00000@
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo000000020?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`000000?03oool00`000000oooo0000000]0?ooo`<000001P3oool3
000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo05D0oooo000K0?ooo`8000000P3oool00`00
0000oooo0000000G0?ooo`040000003oool0oooo0?ooo`8000000`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01P3oool01P000000oooo000000000000oooo000000/0oooo
00D000000?ooo`3oool0oooo0000000k0?ooo`800000503oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`00
00004P3oool01@000000oooo0000003oool0000000D0oooo00<000000?oo
o`3oool0E@3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0000001d0oooo00<000000?ooo`00
00001P3oool01P000000oooo000000000000oooo000000/0oooo00D00000
0?ooo`3oool0oooo0000000k0?ooo`030000003oool0oooo04d0oooo00D0
00000?ooo`3oool000000?ooo`03000005P0oooo000K0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool05@3oool010000000oooo0000
003oool2000001X0oooo00D000000?ooo`000000oooo000000060?ooo`06
0000003oool0oooo0000003oool000002`3oool01@000000oooo0?ooo`3o
ool0000003<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000
003oool0oooo02d0oooo0P0000070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1P0?ooo`006`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool06P3oool01@000000oooo000000000000oooo00800000
1P3oool01@000000oooo0?ooo`000000oooo0080000000<0oooo0000003o
ool01`3oool01@000000oooo0?ooo`3oool000000300oooo00@000000?oo
o`3oool000000`3oool010000000oooo0?ooo`00000F0?ooo`800000303o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo05P0oooo
000K0?ooo`8000001@3oool00`000000oooo0?ooo`0^0?ooo`060000003o
ool0oooo0?ooo`000000oooo0P0000000`3oool00000000000060?ooo`03
0000003oool0oooo0080000000@0oooo0000003oool00000203oool01@00
0000oooo0?ooo`3oool0000002/0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0200000080oooo00@000000?ooo`3oool00000<03o
ool2000001@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000
001J0?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo02h0oooo00H000000?ooo`3oool0oooo0000003oool2000000040?oo
o`000000oooo000000@0oooo00<000000?ooo`3oool00P3oool010000000
oooo0000003oool2000000L0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00D000000?oo
o`000000oooo000000020?ooo`040000003oool0oooo000001P0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`8000004P3o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0600oooo
00070?ooo`@000000`3oool2000000<0oooo0`0000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0;@3oool200000080oooo00<0
00000?ooo`0000000P3oool00`000000oooo000000040?ooo`030000003o
ool0oooo0080oooo00@000000?ooo`000000oooo0P0000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0903oool010000000oooo
0?ooo`3oool200000080oooo00`000000?ooo`00000000000?ooo`000000
oooo0000003oool000000?ooo`00000H0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0600oooo00080?ooo`030000003oool0oooo00<0oooo
0P0000060?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0]0?ooo`8000000P3oool2000000D0oooo
00@000000?ooo`3oool0oooo0P0000040?ooo`060000003oool000000000
003oool000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo02@0oooo00@000000?ooo`3oool0oooo0P0000020?ooo`030000003o
ool000000080oooo00L000000?ooo`000000oooo0000003oool000000240
oooo00<000000?ooo`3oool08@3oool2000000<0oooo00<000000?ooo`3o
ool0H`3oool000T0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`<000001@3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00l0oooo00L000000?ooo`000000oooo0000003oool00000
00H0oooo00@000000?ooo`3oool000001@3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0T0?ooo`060000003oool0oooo0000003oool0
00000P3oool00`000000oooo0?ooo`020?ooo`070000003oool000000?oo
o`000000oooo0000000I0?ooo`030000003oool0oooo02T0oooo00H00000
0?ooo`3oool000000?ooo`0000020?ooo`030000003oool0oooo0600oooo
000:0?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000006P3oool00`000000oooo0?oo
o`0?0?ooo`070000003oool000000?ooo`000000oooo000000060?ooo`04
0000003oool0oooo000000P0oooo00H000000?ooo`3oool000000?ooo`00
00020?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0903o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000@0oooo
00L000000?ooo`000000oooo0000003oool0000001T0oooo00<000000?oo
o`3oool0:P3oool01`000000oooo0?ooo`3oool000000?ooo`000000H`3o
ool000L0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000006P3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0080000000<0
oooo0000003oool01@3oool010000000oooo0?ooo`0000080?ooo`060000
003oool0oooo0000003oool000000P3oool00`000000oooo000000040?oo
o`030000003oool0oooo02@0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo000000050?ooo`80000000<0oooo0000000000008P3oool0
0`000000oooo0?ooo`0Q0?ooo`8000000`3oool00`000000oooo0?ooo`1S
0?ooo`00203oool2000000T0oooo100000040?ooo`030000003oool0oooo
00D0oooo00@000000?ooo`00000000006@3oool200000100oooo00<00000
0?ooo`3oool00P0000090?ooo`030000003oool0000000/0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000040?ooo`030000003oool0
oooo02<0oooo00D000000?ooo`000000oooo000000020?ooo`8000001P3o
ool01@000000oooo0?ooo`3oool0000001X0oooo00<000000?ooo`3oool0
:@3oool010000000oooo0?ooo`0000020?ooo`800000H`3oool001/0oooo
00<000000?ooo`3oool01@3oool010000000oooo00000000000I0?ooo`80
0000403oool00`000000oooo0?ooo`02000000T0oooo00<000000?ooo`00
00002`3oool00`000000oooo000000020?ooo`8000001P3oool00`000000
oooo0?ooo`0R0?ooo`050000003oool000000?ooo`0000000P3oool20000
00H0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`030000003oool0
oooo0980oooo000K0?ooo`8000001`3oool00`000000oooo0000000H0?oo
o`030000003oool000000100oooo00@000000?ooo`3oool000002P3oool2
000000`0oooo00D000000?ooo`00000000000?ooo`02000000H0oooo00<0
00000?ooo`3oool08P3oool01@000000oooo0000003oool0000000<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`1T0?ooo`006`3oool00`000000oooo0?ooo`060?ooo`040000003o
ool0oooo000001H0oooo0P0000000`3oool000000?ooo`0?0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool02`3oool01P000000oooo
000000000000oooo000000H0oooo00<000000?ooo`3oool08P3oool01000
0000oooo00000000000[0?ooo`030000003oool0000002`0oooo00<00000
0?ooo`000000I03oool001/0oooo00<000000?ooo`3oool01P3oool01000
0000oooo0?ooo`00000F0?ooo`80000000<0oooo0000003oool03P3oool0
0`000000oooo0?ooo`0K0?ooo`060000003oool000000000003oool00000
1P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00800000
:`3oool00`000000oooo0?ooo`2C0?ooo`006`3oool00`000000oooo0?oo
o`060?ooo`040000003oool0oooo000001D0oooo00<000000?ooo`000000
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01/0oooo
00@000000?ooo`0000000000203oool00`000000oooo0?ooo`0Q0?ooo`05
0000003oool0oooo0?ooo`000000;`3oool00`000000oooo0000002?0?oo
o`006`3oool2000000X0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool06`3oool010000000oooo0000000000080?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0;`3oool00`000000oooo0000002A
0?ooo`006`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0T03oool001/0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0000000B0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0a03oool001/0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0000000A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0a03oool001/0oooo
00<000000?ooo`3oool02P3oool2000000040?ooo`000000oooo000000h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`340?ooo`006`3oool2000000/0oooo0P000000103oool00000
0?ooo`00000>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0a03oool001/0oooo00<000000?ooo`3oool0
2`3oool01@000000oooo0000003oool0000000h0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`0000007`3oool00`000000oooo0?ooo`340?ooo`00
6`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0000000h0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02X0oooo0P00000N0?ooo`030000003oool0oooo0<D0oooo
000K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`000000303o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0:P3oool2000001h0oooo00<000000?ooo`3oool0a@3o
ool001/0oooo0P00000?0?ooo`030000003oool0000000`0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo02X0oooo0P00000N0?ooo`030000003oool0oooo0<D0oooo000K0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
0<D0oooo000C0?ooo`<000001@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`350?ooo`005P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo0<D0oooo000F0?ooo`030000003oool0oooo0080oooo0`00
000@0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`350?ooo`004`3oool3
000000D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0aP3oool001<0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`0000002@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`360?oo
o`004`3oool4000000@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`030?ooo`060000003oool0oooo0000003oool000002@3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`360?ooo`006`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0080oooo0P0000001@3o
ool000000000003oool0000000X0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0aP3oool001/0oooo0P00000B0?ooo`030000003oool0oooo
0080oooo0P0000001@3oool000000000003oool0000000X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo01T0oooo0P0000380?ooo`006`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0080oooo0P000000103oool000000?ooo`00000;
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0H0?ooo`800000b03oool001/0oooo00<000000?oo
o`3oool04@3oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000/0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo01L0oooo0`0000380?ooo`00
6`3oool00`000000oooo0?ooo`0A0?ooo`050000003oool000000?ooo`00
00000P3oool2000000030?ooo`000000oooo00X0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool200000<T0oooo000K0?ooo`800000
4P3oool01@000000oooo0000003oool000000080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`80
0000b@3oool001/0oooo00<000000?ooo`3oool04P3oool2000000050?oo
o`000000oooo0?ooo`0000003P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool0203oool00`000000
oooo0000000<0?ooo`800000b@3oool001/0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo000000030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00P0oooo0`0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo0080oooo0P0000390?ooo`006`3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0000001<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00P0oooo0P00
00000`3oool00000000000050?ooo`050000003oool0oooo0?ooo`000000
b`3oool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo008000001@3o
ool00`000000oooo0?ooo`0200000</0oooo000K0?ooo`800000:@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool01P3oool010000000oooo0?ooo`3oool2000000D0oooo00<0
00000?ooo`3oool00P00003;0?ooo`006`3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo0P0000020?ooo`800000b`3oool001/0oooo
00<000000?ooo`3oool0:03oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo0380oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`030000003oool0oooo00<0oooo00P000000?ooo`3oool0oooo0000003o
ool000000?ooo`800000b`3oool001/0oooo00<000000?ooo`3oool0:@3o
ool01@000000oooo0000003oool0000003H0oooo00<000000?ooo`3oool0
0P0000030?ooo`030000003oool0oooo00<0oooo00T000000?ooo`3oool0
oooo0000003oool000000?ooo`000000c03oool001/0oooo0P00000Z0?oo
o`030000003oool0000000800000=P3oool01@000000oooo0000003oool0
000000<0oooo00<000000?ooo`3oool00`3oool200000080oooo00@00000
0?ooo`0000000000c@3oool001/0oooo00<000000?ooo`3oool0:@3oool0
1@000000oooo0000003oool0000003H0oooo00T000000?ooo`000000oooo
0000003oool000000?ooo`0000001P3oool01@000000oooo0?ooo`000000
oooo00800000c@3oool000P0oooo00<000000?ooo`3oool00`3oool20000
00<0oooo0`0000050?ooo`030000003oool0oooo02T0oooo0P00000i0?oo
o`030000003oool000000080oooo0`0000070?ooo`050000003oool0oooo
0000003oool00P00003=0?ooo`00203oool00`000000oooo0?ooo`030?oo
o`8000001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0>03oool200000080oooo0`0000070?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0b`3oool0
00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`<00000:P3oool00`000000oooo0?ooo`0h0?ooo`8000000P3oool30000
00L0oooo00<000000?ooo`000000d@3oool000T0oooo00<000000?ooo`3o
ool01`3oool3000000D0oooo00<000000?ooo`3oool0I@3oool01`000000
oooo0?ooo`3oool000000?ooo`000000203oool200000=40oooo000:0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo00`0oooo0P00003A0?oo
o`001`3oool4000000P0oooo100000040?ooo`030000003oool0oooo07@0
oooo0P00003A0?ooo`006`3oool00`000000oooo0?ooo`1d0?ooo`030000
003oool0oooo0=00oooo000K0?ooo`800000o`3ooom90?ooo`006`3oool0
0`000000oooo0?ooo`3o0?ooodP0oooo000K0?ooo`030000003oool0oooo
0?l0ooooB03oool00?l0ooooIP3oool00?l0ooooIP3oool00?l0ooooIP3o
ool00?l0ooooIP3oool00?l0ooooIP3oool00?l0ooooIP3oool00?l0oooo
IP3oool00?l0ooooIP3oool00?l0ooooIP3oool000/0oooo0P0000030?oo
o`D0000000<0oooo0000000000000`0000000`3oool00000000000030000
0080oooo100000000`3oool000000000000200000?l0oooo>P3oool000/0
oooo0P0000030?ooo`040000003oool0oooo000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool0o`3ooolh0?ooo`002P3oool010000000oooo00000000
00020?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01@0000000`3oool000000000000200000?l0oooo
>P3oool000X0oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000
oooo0?ooo`0000030?ooo`030000003oool000000?l0oooo?@3oool000T0
oooo0P0000020?ooo`8000000P3oool3000000@0oooo00<000000?ooo`3o
ool00P0000000`3oool00000000000030?ooo`<000000P3oool400000?l0
oooo>P3oool001P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`005P3o
ool300000?l0ooooC@3oool00?l0ooooIP3oool00?l0ooooIP3oool00001
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->False,
  ImageSize->{357.312, 172.812},
  ImageMargins->{{63.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
Notice that these two plots don't allow us to know which line \
refers to which set of data points. To do this, we can add a legend to this \
plot by using another package: PlotLegend.\
\>", "Text",
  CellTags->"C.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["PlotLegend", "Subsubsection",
  CellTags->"C.1"],

Cell[TextData[{
  "PlotLegend is an option that allows us to add a legend to plots that use \
different styles for different data. It gives a graphical representation of \
which style goes with which data set. For instance, suppose resources[1] is \
the resource list of an individual we have labeled as ",
  StyleBox["Type a",
    FontSlant->"Italic"],
  ", and resources[2] corresponds to an individual that is ",
  StyleBox["Type b",
    FontSlant->"Italic"],
  ". We can add a PlotLegend to the preceding graphic that illustrates that \
correspondence."
}], "Text",
  CellTags->{"i:13", "C.1"}],

Cell[CellGroupData[{

Cell[TextData[
"MultipleListPlot[resources[1], resources[2],\n  AxesLabel \[Rule] {\"time\", \
\"values\"},\n  SymbolShape \[Rule] None,\n  PlotJoined \[Rule] True,\n  \
PlotLegend \[Rule] {\"Type a\", \"Type b\"}];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0000VR000`400?l0
0000o`00003oo`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00
o`3ooomV0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood40oooo000R
0?ooo`800000o`3ooom20?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od40oooo000R0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3o
ool0UP3oool00280oooo00<000000?ooo`3oool0Y`3oool2000009L0oooo
000R0?ooo`800000o`3ooom20?ooo`008P3oool00`000000oooo0?ooo`3o
0?oood40oooo000R0?ooo`030000003oool0oooo0:<0oooo00@000000?oo
o`3oool00000V@3oool00280oooo00<000000?ooo`3oool0X`3oool01P00
0000oooo0?ooo`000000oooo000009L0oooo000R0?ooo`800000V@3oool0
10000000oooo0?ooo`00002T0?ooo`00403oool00`000000oooo0?ooo`03
0?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0V03oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo09P0oooo000@
0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`050000003oool0
oooo0?ooo`000000V@3oool5000000H0oooo00<000000?ooo`3oool00P00
002I0?ooo`002@3oool5000000<0oooo00<000000?ooo`3oool02P3oool0
10000000oooo0?ooo`3oool2000009P0oooo0P0000000`3oool000000000
00070?ooo`80000000<0oooo0000003oool0V03oool00140oooo00<00000
0?ooo`3oool01`3oool3000000@0oooo00<000000?ooo`3oool0U`3oool2
000000030?ooo`000000000000P0oooo00<000000?ooo`3oool0V@3oool0
0180oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool08@3oool20000
00030?ooo`000000000000T0oooo00<000000?ooo`3oool0V03oool000l0
oooo100000080?ooo`@000000`3oool00`000000oooo0?ooo`1c0?ooo`03
0000003oool0oooo0200oooo0`0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00P00002I0?ooo`008P3oool2000007@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0K0?ooo`800000
103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo09L0oooo
000R0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0X@3oool00280oooo00<000000?ooo`3oool0L@3oool0
10000000oooo0000000000030?ooo`800000703oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0:40oooo000R0?ooo`030000003oool0
oooo0740oooo00@000000?ooo`00000000000P3oool00`000000oooo0000
000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2K0?ooo`008P3oool200000780oooo00D00000
0?ooo`00000000000?ooo`02000000030?ooo`000000oooo01/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`2Q0?ooo`008P3oool0
0`000000oooo0?ooo`1a0?ooo`80000000<0oooo0000003oool00P000000
0`3oool000000?ooo`0J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0X@3oool00280oooo00<000000?ooo`3oool0K`3oool40000
0080oooo0`0000000`3oool000000?ooo`0J0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2E0?oo
o`008P3oool200000700oooo100000020?ooo`<0000000<0oooo0000003o
ool06P3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000001@3oool2000009L0oooo000R0?ooo`030000003oool0oooo06l0
oooo100000020?ooo`<0000000<0oooo0000003oool06P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo0`00002G0?ooo`00
8P3oool00`000000oooo0?ooo`1_0?ooo`040000003oool0000000000080
oooo0`0000000`3oool000000?ooo`0J0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01@3oool300000300ooooGP0000090?ooo`00
8P3oool00`000000oooo0?ooo`1_0?ooo`040000003oool00000000000L0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo0`00000`0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool01`3oool00280oooo0P00001`0?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`060?ooo`040000003oool0oooo000000@0oooo0`00000`0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0KP3oool200000080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01@3oool200000340oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`070?ooo`006`3oool3000000@0oooo
00<000000?ooo`3oool0K@3oool300000080oooo00<000000?ooo`3oool0
1@3oool2000001P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`070?ooo`007P3oool01@000000oooo0?oo
o`3oool0000006l0oooo0`00000:0?ooo`800000603oool00`000000oooo
0?ooo`080?ooo`800000103oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool001D0oooo1@00
00040?ooo`040000003oool0oooo0?ooo`800000@03oool00`000000oooo
0?ooo`0[0?ooo`8000002`3oool200000100oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`1J0?ooo`030000
003oool0oooo00L0oooo000K0?ooo`<00000103oool00`000000oooo0?oo
o`0n0?ooo`800000:@3oool4000000030?ooo`000000oooo00X0oooo0P00
000@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0FP3oool00`000000oooo0?ooo`070?ooo`006`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool0:P3oool4000000030?ooo`000000oooo00X0oooo00<00000
0?ooo`0000003P3oool2000000L0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`070?ooo`006`3oool40000
00<0oooo0P00000m0?ooo`030000003oool0oooo02X0oooo1000000=0?oo
o`030000003oool0000000h0oooo0P0000030?ooo`050000003oool0oooo
0?ooo`0000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`0o0?ooo`800000:03oool30000
0100oooo00<000000?ooo`3oool02`3oool3000000<0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`030000003oool0oooo0080oooo0P00000c
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool0
0280oooo00<000000?ooo`3oool0?@3oool2000002X0oooo0P00000A0?oo
o`800000303oool00`000000oooo000000030?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`800000103oool2000003<0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000
oooo0?ooo`0k0?ooo`800000;03oool200000140oooo0P00000<0?ooo`03
0000003oool0000000<0oooo0P0000020?ooo`030000003oool0oooo00L0
oooo0P0000040?ooo`800000<`3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`800000<P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo02X0oooo0P00000A0?ooo`<00000
2P3oool010000000oooo0?ooo`0000030?ooo`8000000P3oool00`000000
oooo0?ooo`060?ooo`040000003oool00000000000<0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo
00L0oooo000R0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0303oool010000000oooo0?ooo`00000U0?ooo`030000003oool0oooo
0140oooo0P00000:0?ooo`050000003oool0oooo0?ooo`0000000P3oool2
000000030?ooo`000000oooo00L0oooo0`0000000`3oool000000?ooo`02
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool00P00000P0?oo
o`030000003oool0oooo0180oooo0P00000:0?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo00000000000:0?ooo`060000003o
ool0oooo0000003oool00000=@3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo00L000000?ooo`3oool0oooo0000003oool00000
0080oooo0P0000090?ooo`8000000P3oool00`000000oooo0000000e0?oo
o`030000003oool0oooo02T0oooo0`0000030?ooo`@000009`3oool00`00
0000oooo0?ooo`070?ooo`008P3oool200000340oooo0P00000?0?ooo`03
0000003oool0000002@0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00<000000?ooo`00
00000P3oool2000000d0oooo0`00000e0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`0000001@3oool2000000D0oooo0`0000000`3oool00000
0?ooo`02000000030?ooo`000000oooo00d0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`000000103oool00`000000oooo000000020?ooo`800000
1`3oool2000003`0oooo00<000000?ooo`3oool09@3oool3000000<0oooo
00<000000?ooo`3oool00P3oool4000000<0oooo100000070?ooo`@00000
503oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P00
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0000000@0oooo00<0
00000?ooo`0000000P3oool2000004D0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000/0oooo00D000000?ooo`3o
ool0oooo0000000C0?ooo`030000003oool0oooo00L0oooo000R0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool01@3oool2000000D0oooo00<000000?ooo`0000000P3oool2000004D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0200000080
oooo00<000000?ooo`3oool00P0000020?ooo`030000003oool0oooo0080
00000P3oool00`000000oooo0?ooo`02000000X0oooo00L000000?ooo`3o
ool0oooo0000003oool0000000<0oooo00H000000?ooo`3oool0oooo0000
003oool5000000L0oooo00D000000?ooo`3oool0oooo0000000C0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`8000002@3oool2000002H0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00@0oooo0`0000060?ooo`050000
003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo02@0oooo00T000000?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000`3oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?oo
o`0000004`3oool00`000000oooo0?ooo`070?ooo`003`3oool4000000<0
oooo0P0000030?ooo`<00000103oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0000000`0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0000000h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`<000001P3oool01@000000
oooo0?ooo`3oool0000004H0oooo00<000000?ooo`3oool0903oool01000
0000oooo0000003oool3000000040?ooo`00000000000?ooo`D000000`3o
ool3000000P0oooo1000000D0?ooo`030000003oool0oooo00L0oooo000@
0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`050000003oool0
oooo0?ooo`000000B`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0D0?ooo`8000001@3oool3000000H0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo02@0oooo1@00
000I0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01`3o
ool000T0oooo1@0000030?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool0oooo0P0000090?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool07`3oool2000001D0oooo00<000000?ooo`3oool05@3o
ool2000000@0oooo0`00000B0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool0@@3oool2000001L0oooo00<000000?ooo`3oool01`3o
ool00180oooo00<000000?ooo`3oool01P3oool3000000@0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0000000R0?ooo`@00000103oool0
0`000000oooo0?ooo`02000001L0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`0F0?ooo`800000103oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool0
00l0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo008000001P3oool0
1@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`8000000`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`070?ooo`00403oool2000000T0oooo10000003
0?ooo`030000003oool0oooo00@0oooo0P00000`0?ooo`8000004P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`000000103oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01`3o
ool00280oooo0P0000060?ooo`040000003oool0oooo000002<0oooo0`00
00080?ooo`030000003oool0oooo01D0oooo00@000000?ooo`3oool00000
4`3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo00000140
oooo00D000000?ooo`3oool0oooo0000000n0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3o
ool0203oool00`000000oooo0000000Q0?ooo`040000003oool000000000
00H0oooo00<000000?ooo`0000004P3oool2000000D0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0H0?ooo`040000003oool0oooo
000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool0
0280oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool00P3oool00`00
0000oooo000000040?ooo`030000003oool0oooo00H0oooo00D000000?oo
o`3oool0oooo0000000J0?ooo`@00000303oool00`000000oooo00000002
000004<0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`020?ooo`@00000903oool20000
0240oooo00<000000?ooo`3oool00P3oool00`000000oooo000000070?oo
o`030000003oool0oooo0080oooo0P0000030?ooo`030000003oool0oooo
01P0oooo1000000<0?ooo`060000003oool0oooo0000003oool000000P3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo05X0oooo00<0
00000?ooo`3oool01`3oool00280oooo0P0000040?ooo`050000003oool0
00000?ooo`0000008@3oool010000000oooo00000000000_0?ooo`030000
003oool0oooo00H0oooo0P00000K0?ooo`8000004P3oool010000000oooo
0?ooo`00000o0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool01`3oool00280oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`070?ooo`<00000103oool2000000h0oooo00<000000?ooo`000000
0P0000040?ooo`800000103oool2000000d0oooo0`0000030?ooo`<00000
103oool2000000`0oooo00<000000?ooo`0000000`0000030?ooo`800000
103oool2000000`0oooo1@0000020?ooo`<00000103oool3000000d0oooo
0`0000040?ooo`800000103oool2000002X0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000d0oooo00<000000?ooo`3oool01@3oool20000
00040?ooo`000000oooo0?ooo`80000000<0oooo0000003oool0103oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`030?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`07
0?ooo`008P3oool2000000<0oooo0P00000D0?ooo`@000000P3oool00`00
0000oooo0?ooo`060?ooo`050000003oool000000?ooo`0000000`3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`050?ooo`800000
00T0oooo0000003oool0oooo0000003oool000000?ooo`0000000P3oool0
0`000000oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000/0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`020000
00030?ooo`000000oooo00<0oooo00<000000?ooo`0000002@3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo01D0oooo0`000003
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`0000000P00
00020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0?ooo`020?ooo`<000000`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`03000000<0oooo00@0
00000?ooo`3oool000001@3oool2000000L0oooo0P0000030?ooo`040000
003oool0oooo00000080oooo00@000000?ooo`3oool00000:@3oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo00L0oooo000R0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000
oooo000000020?ooo`8000000P3oool00`000000oooo0?ooo`0300000003
0?ooo`000000000000D0oooo00@000000?ooo`3oool00000103oool01000
0000oooo0?ooo`0000020?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo008000002P3oool00`000000oooo000000020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0?ooo`00000@0?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
1`3oool00280oooo00D000000?ooo`3oool0oooo0000000C0?ooo`@00000
0`3oool2000000L0oooo00<000000?ooo`3oool01P3oool2000000D0oooo
0P0000040?ooo`8000003@3oool2000000@0oooo1@0000020?ooo`800000
00<0oooo0000000000001P3oool010000000oooo0?ooo`0000020?ooo`80
0000103oool2000000@0oooo0P00000>0?ooo`8000000`3oool4000000<0
oooo0P00000>0?ooo`<00000103oool2000000@0oooo0P00000Z0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool00280oooo
0P00000I0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
<`3oool01P000000oooo0000003oool000000?ooo`800000:P3oool00`00
0000oooo0?ooo`050?ooo`800000?`3oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0000003D0oooo00<000000?ooo`3oool00P0000000`3oool0
00000?ooo`0b0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000=@3oool0
0`000000oooo0?ooo`020?ooo`80000000<0oooo0000003oool03@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool08`3oool300000080oooo1@0000001P3oool000000?ooo`00
0000oooo00000080oooo1000000>0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool01`3oool00280oooo0P0000020?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo0080oooo1000000>0?ooo`800000103o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02<0oooo00@0
00000?ooo`3oool000000`3oool02`000000oooo0?ooo`3oool000000?oo
o`000000oooo0000003oool000000180oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`070?ooo`007P3ooone000000L0oooo00<00000
0?ooo`3oool0103oool02P000000oooo0?ooo`3oool000000?ooo`000000
oooo0000003oool5000000h0oooo00<000000?ooo`3oool0FP3oool00`00
0000oooo0?ooo`070?ooo`008P3oool2000001/0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?oo
o`@000000P3oool2000000030?ooo`000000oooo00T0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0103oool02`000000oooo0?ooo`3oool0
00000?ooo`000000oooo0000003oool0000000<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00L0
oooo000R0?ooo`8000003@3oool00`000000oooo000000070?ooo`060000
003oool0oooo0?ooo`000000oooo0P0000080?ooo`030000003oool0oooo
0380oooo100000020?ooo`040000003oool00000000000d0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool08`3oool4000000<0oooo0P000002
0?ooo`H000000P3oool3000000l0oooo00<000000?ooo`3oool0FP3oool0
0`000000oooo0?ooo`070?ooo`008P3oool2000001L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02@0oooo1P0000020?ooo`8000003@3oool00`000000oooo000000050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`070?ooo`008P3oool2000001h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0T0?ooo`H0
00000`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0FP3oool00`000000
oooo0?ooo`070?ooo`008P3oool00`000000oooo0000000>0?ooo`030000
003oool0oooo00`0oooo0`00000:0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0903oool00`000000oooo00000003000000@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`040000
003oool0oooo0?ooo`800000F03oool00`000000oooo0?ooo`0Y0?ooo`<0
00000`3oool4000002L0oooo00<000000?ooo`3oool01`3oool00280oooo
00@000000?ooo`00000000002`3oool010000000oooo0000000000060?oo
o`030000003oool0oooo0080oooo0P0000000`3oool000000?ooo`0:0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0903oool01P00
0000oooo000000000000oooo000000@0oooo00<000000?ooo`3oool01`3o
ool010000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool01`3oool00280oooo1000000>0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P3oool2000000d0oooo00<000000?ooo`3oool0
1`3oool2000002@0oooo00<000000?ooo`3oool04P3oool010000000oooo
00000000000:0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`00
0000oooo0000001:0?ooo`030000003oool0oooo02D0oooo0`0000030?oo
o`030000003oool0oooo0080oooo100000030?ooo`@000001`3oool50000
01<0oooo00<000000?ooo`3oool01`3oool00280oooo00@000000?ooo`00
00000000503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00L0oooo0P00000T0?ooo`030000003oool0oooo01<0oooo0P00000:0?oo
o`030000003oool0oooo00X0oooo00@000000?ooo`3oool00000C03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`000000
2`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo00L0
oooo000R0?ooo`040000003oool0000000000100oooo00D000000?ooo`00
0000oooo000000080?ooo`8000002@3oool2000000T0oooo0P00000T0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`020?ooo`800000G03oool00`000000oooo0?ooo`020?oo
oad000001`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000`3o
ool01P000000oooo0?ooo`3oool000000?ooo`D000001`3oool4000001@0
oooo00<000000?ooo`3oool01`3oool00280oooo00D000000?ooo`000000
oooo0000000=0?ooo`030000003oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0
oooo0P0000000`3oool000000?ooo`050?ooo`030000003oool0000002<0
oooo0P00000;0?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool2000004X0
oooo00<000000?ooo`3oool0903oool02@000000oooo0000003oool00000
0?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo000000030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`070?ooo`008P3oool3000000030?oo
o`000000oooo00`0oooo00@000000?ooo`0000000000403oool00`000000
oooo0?ooo`030?ooo`@000001P3oool00`000000oooo0000000S0?ooo`80
0000503oool00`000000oooo0?ooo`0:0?ooo`8000002P3oool300000004
0?ooo`000000oooo000004X0oooo00<000000?ooo`3oool0903oool01000
0000oooo0000003oool3000000040?ooo`00000000000?ooo`D000000`3o
ool3000000T0oooo0`00000D0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`050000003oool0oooo0?ooo`000000403oool00`000000oooo0?oo
o`0>0?ooo`800000103oool4000000H0oooo00<000000?ooo`0000008`3o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00X0oooo1@00
001<0?ooo`030000003oool0oooo02@0oooo1@00000a0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`050000003oool0oooo0?ooo`0000003P3o
ool00`000000oooo0?ooo`0?0?ooo`<00000103oool01P000000oooo0000
00000000oooo000000@0oooo00<000000?ooo`000000703oool00`000000
oooo000000020?ooo`030000003oool0000000d0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`070?ooo`00
8P3oool200000080oooo00<000000?ooo`3oool06`3oool00`000000oooo
00000003000000@0oooo00H000000?ooo`00000000000?ooo`0000040?oo
o`030000003oool0000001X0oooo00@000000?ooo`000000oooo0P000000
103oool000000?ooo`00000=0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02@3oool2000005D0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`070?ooo`008P3oool01@000000oooo0?ooo`3o
ool0000001d0oooo00<000000?ooo`000000100000020?ooo`030000003o
ool0oooo0080000000<0oooo0000003oool00`3oool010000000oooo0?oo
o`00000I0?ooo`040000003oool000000?ooo`80000000@0oooo0000003o
ool00000503oool00`000000oooo0?ooo`0B0?ooo`050000003oool0oooo
0?ooo`0000000`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool01`3oool000l0oooo100000030?oo
o`8000000`3oool3000000@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0J0?ooo`050000003oool000000000003oool00P000002
0?ooo`030000003oool0oooo0080000000<0oooo0000003oool00`3oool0
10000000oooo0?ooo`00000F0?ooo`050000003oool0oooo0000003oool0
1@0000000`3oool000000000000Z0?ooo`040000003oool0oooo000000<0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo00L0oooo000@0?ooo`030000003oool0oooo00<0oooo
0P0000060?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0I0?ooo`80000000<0oooo0000000000000P3oool200000004
0?ooo`000000oooo0?ooo`@00000103oool010000000oooo0?ooo`00000F
0?ooo`050000003oool000000000003oool00P000000103oool000000000
003oool2000000h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00L0oooo000A0?ooo`030000003o
ool0oooo00X0oooo00@000000?ooo`3oool0oooo0P0000030?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0203oool3000000030?oo
o`000000oooo0080oooo0P0000030?ooo`040000003oool000000?ooo`80
00000P3oool010000000oooo0?ooo`00000F0?ooo`060000003oool00000
0000003oool000000P3oool2000000030?ooo`000000000000h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0B0?ooo`80000000<0
oooo000000000000DP3oool00`000000oooo0?ooo`1J0?ooo`030000003o
ool0oooo00L0oooo000B0?ooo`030000003oool0oooo00H0oooo0`000004
0?ooo`030000003oool0oooo0080oooo0P00000?0?ooo`030000003oool0
oooo00P0oooo00D000000?ooo`000000oooo000000030?ooo`8000001@3o
ool00`000000oooo00000002000000050?ooo`000000oooo0?ooo`000000
5P3oool010000000oooo0000003oool2000000<0oooo00@000000?ooo`00
00000000:@3oool01@000000oooo0000003oool000000540oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`070?ooo`003`3oool01000
0000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00P3oool2000000l0oooo00<000000?ooo`3oool0203oool0
0`000000oooo000000050?ooo`8000001`3oool3000000030?ooo`000000
oooo0080oooo00<000000?ooo`3oool04`3oool3000000030?ooo`000000
000000<0oooo00<000000?ooo`000000:`3oool2000000030?ooo`000000
oooo0500oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`07
0?ooo`00403oool2000000T0oooo100000030?ooo`030000003oool0oooo
0080oooo0P00000?0?ooo`8000002@3oool00`000000oooo000000050?oo
o`8000001`3oool4000000@0oooo00<000000?ooo`3oool04`3oool30000
00030?ooo`000000oooo00<0oooo00<000000?ooo`0000003`3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01`3oool00280oooo0P0000030?ooo`8000003P3oool3000000T0
oooo00<000000?ooo`3oool01@3oool2000000L0oooo100000040?ooo`03
0000003oool0oooo01<0oooo0P0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool03@3oool01@000000oooo0000003oool00000
01P0oooo0P00001B0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool01`3oool00280oooo00<000000?ooo`3oool00P3oool00`000000
oooo0000000=0?ooo`<000002@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo00D0oooo100000040?ooo`030000003oool0oooo0180
oooo00<000000?ooo`0000006P3oool2000001X0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00L0
oooo000R0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
3@3oool3000000T0oooo00<000000?ooo`3oool03P3oool3000000D0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0000002:0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool01`3oool00280oooo0P00
00050?ooo`030000003oool0000000X0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0>0?ooo`<000001@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
J`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo00L0oooo
000R0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000002P3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0K03oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo00D0oooo0P00000:0?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0K03oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo00D0oooo100000080?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo08X0ooooGP0000090?ooo`008P3oool2000000H0oooo00@0
00000?ooo`0000000000203oool01@000000oooo0?ooo`3oool0000000L0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0?40oooo000R0?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`0000000000203oool01@000000oooo0?ooo`3oool00000
00L0oooo00<000000?ooo`3oool05`3oool2000001<0oooo00<000000?oo
o`3oool0l@3oool00280oooo00<000000?ooo`3oool01`3oool2000000P0
oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3b0?oo
o`008P3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`3b0?ooo`008P3oool2000000P0oooo00<000000?ooo`000000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo0?80oooo000K0?ooo`<00000103oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`3b0?ooo`007P3oool0
1@000000oooo0?ooo`3oool0000000/0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0?80oooo000N0?ooo`040000003oool0oooo0?ooo`8000002P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0lP3oool001/0oooo0`000004
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?<0oooo000K0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3c0?ooo`006`3oool4000000<0
oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`3oool30000
00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0l`3oool00280
oooo0P00000:0?ooo`030000003oool0oooo00@000001P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03@3oool200000?D0oooo000R0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0100000060?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0=0?ooo`800000
m@3oool00280oooo00<000000?ooo`3oool02@3oool010000000oooo0000
003oool3000000H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00d0oooo0P00003e0?ooo`008P3o
ool00`000000oooo0?ooo`090?ooo`<0000000@0oooo0000003oool00000
1P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`800000
m@3oool00280oooo0P00000;0?ooo`80000000<0oooo0000003oool01`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0103oool2000000L0oooo0P00003e0?ooo`008P3oool0
0`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000003oool0203oool0
1@000000oooo0?ooo`3oool0000001d0oooo00<000000?ooo`3oool0103o
ool2000000@0oooo00<000000?ooo`3oool00P00003e0?ooo`008P3oool0
0`000000oooo0?ooo`0:0?ooo`8000002`3oool010000000oooo0?ooo`00
000N0?ooo`030000003oool0oooo00@0oooo0P0000002@3oool000000?oo
o`3oool000000?ooo`000000oooo0000003e0?ooo`008P3oool2000000/0
oooo00<000000?ooo`3oool02P3oool010000000oooo0?ooo`00000O0?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`00000000000P3oool0
0`000000oooo0000003g0?ooo`008P3oool00`000000oooo0?ooo`0G0?oo
o`040000003oool0oooo000001l0oooo00<000000?ooo`0000000`3oool0
1@000000oooo000000000000oooo0080000000<0oooo0000003oool0mP3o
ool00280oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00
000O0?ooo`030000003oool0000000<0oooo00L000000?ooo`0000000000
0?ooo`000000oooo00800000m`3oool00280oooo00<000000?ooo`3oool0
5`3oool2000000030?ooo`000000oooo01h0oooo100000020?ooo`070000
003oool0oooo0000003oool000000?ooo`0200000?L0oooo000R0?ooo`80
0000603oool400000200oooo0`0000020?ooo`030000003oool0oooo00<0
000000<0oooo0000003oool0m`3oool00280oooo00<000000?ooo`3oool0
5`3oool2000000030?ooo`000000oooo01l0oooo100000000`3oool00000
0?ooo`020?ooo`80000000<0oooo0000003oool0m`3oool00100oooo00<0
00000?ooo`3oool00`3oool2000000<0oooo0`0000040?ooo`030000003o
ool0oooo01L0oooo0P00000R0?ooo`@0000000<0oooo0000003oool00P3o
ool2000000030?ooo`000000oooo0?L0oooo000@0?ooo`030000003oool0
oooo00<0oooo0P0000060?ooo`050000003oool0oooo0?ooo`0000006P3o
ool00`000000oooo0?ooo`0P0?ooo`D00000103oool2000000030?ooo`00
0000oooo0?L0oooo000A0?ooo`030000003oool0oooo00X0oooo00@00000
0?ooo`3oool0oooo0P00000l0?ooo`050000003oool000000?ooo`000000
103oool200000?X0oooo000A0?ooo`030000003oool0oooo00L0oooo0`00
00040?ooo`030000003oool0oooo03/0oooo00D000000?ooo`000000oooo
000000040?ooo`800000nP3oool00180oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04@0oooo0P00
003j0?ooo`003`3oool4000000P0oooo100000030?ooo`800000A@3oool0
0`000000oooo0?ooo`3i0?ooo`008P3oool00`000000oooo0?ooo`3o0?oo
od40oooo000R0?ooo`030000003oool0oooo0?l0oooo@@3oool00280oooo
00<000000?ooo`3oool0o`3ooom10?ooo`00o`3ooomV0?ooo`00o`3ooomV
0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3o
oomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`004P3oool2000000<0
oooo1@0000000`3oool0000000000003000000030?ooo`000000000000<0
00000P3oool4000000030?ooo`000000000000800000o`3ooolc0?ooo`00
4P3oool2000000<0oooo00@000000?ooo`3oool00000103oool01@000000
oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`3o0?oooc40oooo000A0?ooo`040000003oool00000
00000080oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`05000000030?ooo`000000000000800000o`3o
oolc0?ooo`004@3oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`000000o`3ooolf0?ooo`00
403oool200000080oooo0P0000020?ooo`<00000103oool00`000000oooo
0?ooo`02000000030?ooo`000000000000<0oooo0`0000020?ooo`@00000
o`3ooolc0?ooo`007`3oool00`000000oooo0?ooo`3o0?oood@0oooo000M
0?ooo`<00000o`3ooom60?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00
o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->False,
  ImageSize->{357.438, 154.5},
  ImageMargins->{{63.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
There are other options that affect where a legend is drawn with \
respect to the rest of the graphic (LegendPosition), its size (LegendSize), \
whether it is drawn as a shadow box (LegendShadow), and many others.\
\>", 
  "Text",
  CellTags->{"i:14", "C.1"}],

Cell["\<\
You can get more information about these options by asking for \
their usage messages, or by looking in the online help for the \
Graphics`Legend` package.\
\>", "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell[TextData[
"MultipleListPlot[resources[1], resources[2],\n  AxesLabel \[Rule] {\"time\", \
\"values\"},\n  SymbolShape \[Rule] None,\n  PlotJoined \[Rule] True,\n  \
PlotLegend \[Rule] {\"Type a\", \"Type b\"},\n  LegendOrientation \[Rule] \
Horizontal,\n  LegendSize \[Rule] {1, 0.3},\n  LegendPosition \[Rule] {-1, \
-0.8},\n  LegendShadow \[Rule] {-0.05, -0.07}];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U0000VR000`400?l0
0000o`00003oo`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00
o`3ooomV0?ooo`00o`3ooomV0?ooo`00203ooonV00000;L0oooo00080?oo
ojH00000]`3oool000P0ooooYP00002g0?ooo`00203ooonV00000;L0oooo
00080?ooojH00000]`3oool000P0ooooYP00002g0?ooo`00203ooon_0000
0:h0oooo00080?ooo`T00000Y@3oool00`000000oooo0?ooo`2/0?ooo`00
203oool900000:D0oooo00<000000?ooo`3oool0[03oool000P0oooo2@00
002U0?ooo`030000003oool0oooo0:`0oooo00080?ooo`T00000Y@3oool0
0`000000oooo0?ooo`2/0?ooo`00203oool900000:D0oooo00<000000?oo
o`3oool0[03oool000P0oooo2@00002U0?ooo`030000003oool0oooo0:`0
oooo00080?ooo`T00000Y@3oool00`000000oooo0?ooo`2/0?ooo`00203o
ool9000000/0oooo@`0000090?ooo`8000000P3oool00`000000oooo0?oo
o`0200000080oooo00<000000?ooo`3oool00P0000020?ooo`030000003o
ool0oooo008000000P3oool00`000000oooo0?ooo`0200000080oooo00<0
00000?ooo`3oool00P0000020?ooo`030000003oool0oooo008000000P3o
ool00`000000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P00
00020?ooo`030000003oool0oooo008000003@3oool00`000000oooo0?oo
o`2/0?ooo`00203oool900000:D0oooo00<000000?ooo`3oool0[03oool0
00P0oooo2@00002U0?ooo`030000003oool0oooo0:`0oooo00080?ooo`T0
0000Y@3oool00`000000oooo0?ooo`2/0?ooo`00203oool900000:D0oooo
00<000000?ooo`3oool0[03oool000P0oooo2@00002U0?ooo`030000003o
ool0oooo0:`0oooo00080?ooo`T00000Y@3oool00`000000oooo0?ooo`2/
0?ooo`00203oool900000:D0oooo00<000000?ooo`3oool0[03oool000P0
oooo2@00002U0?ooo`030000003oool0oooo0:`0oooo00080?ooo`T00000
803oool3000000<0oooo100000120?ooo`<000000`3oool4000002l0oooo
00<000000?ooo`3oool0[03oool000P0oooo2@00000Q0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool0[03o
ool000P0oooo2@00000L0?ooo`<000000`3oool00`000000oooo0?ooo`02
0?ooo`@000000`3oool4000000L0oooo1@00000Z0?ooo`<000000`3oool0
0`000000oooo0?ooo`020?ooo`@000000`3oool4000000L0oooo1000000L
0?ooo`030000003oool0oooo0:`0oooo00080?ooo`T000007@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00L000000?oo
o`3oool0oooo0000003oool0000000/0oooo00@000000?ooo`3oool00000
;03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00D000000?oo
o`3oool0oooo0000000K0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0<P3oool000P0oooo2@00000M0?ooo`070000003oool0oooo
0?ooo`000000oooo000000030?ooo`060000003oool0oooo0?ooo`000000
oooo1@0000070?ooo`@00000;03oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`3oool000000?ooo`D00000
1`3oool01@000000oooo0?ooo`3oool0000001/0oooo00<000000?ooo`3o
ool0[03oool000P0oooo2@00000K0?ooo`090000003oool000000?ooo`00
0000oooo0000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0X0?ooo`090000003oool000000?ooo`000000oooo0000003oool0
000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000001/0
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0c0?ooo`00
403oool00`000000oooo0?ooo`0I0?ooo`040000003oool000000?ooo`<0
000000@0oooo000000000000oooo1@0000030?ooo`<000002@3oool30000
02X0oooo00@000000?ooo`000000oooo0`000000103oool000000000003o
ool5000000<0oooo0`0000080?ooo`@00000703oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0340oooo000@0?ooo`030000003oool0
oooo01T0oooo1@0000170?ooo`D000006@3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<`3oool0
0100oooo00<000000?ooo`3oool0PP3oool2000001l0oooo00<000000?oo
o`3oool0H@3oool010000000oooo0?ooo`00000;0?ooo`800000103oool0
10000000oooo0?ooo`00000b0?ooo`00403oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0oooo0640oooo00@000000?ooo`3oool000003P3o
ool3000003H0oooo000@0?ooo`030000003oool0oooo0:<0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`02000000030?ooo`000000
000000X0oooo00H000000?ooo`00000000000?ooo`00000f0?ooo`00403o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05h0oooo00@0
00000?ooo`000000oooo0P0000000`3oool000000?ooo`0=0?ooo`030000
003oool0oooo03D0oooo000@0?ooojL00000:P3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool000000080oooo00<000000?ooo`0000002P3o
ool00`000000oooo000000020?ooo`030000003oool0oooo03@0oooo000J
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2b0?ooo`030000003oool0oooo0380oooo00@00000
0?ooo`0000000000103oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo03D0oooo000G0?ooo`@00000203oool4000000D0oooo0P00002b
0?ooo`8000001P3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03@0oooo000/0?ooo`030000003oool0oooo
0:h0oooo00H000000?ooo`3oool000000?ooo`0000050?ooo`030000003o
ool0oooo02X0oooo0P0000080?ooo`030000003oool0oooo04<0oooo000/
0?ooo`030000003oool0oooo0:h0oooo00H000000?ooo`3oool000000?oo
o`0000040?ooo`030000003oool0000002/0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03X0oooo
000/0?ooo`800000[`3oool020000000oooo0?ooo`000000oooo0000003o
ool000000P3oool00`000000oooo0000000[0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0@P3oool002`0oooo00<000000?ooo`3o
ool0[03oool01@000000oooo0000003oool000000080oooo00<000000?oo
o`0000000P3oool00`000000oooo0000000[0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?oo
o`00;03oool00`000000oooo0?ooo`2/0?ooo`<0000000<0oooo0000003o
ool00P3oool200000080oooo00@000000?ooo`3oool00000:@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`00;03oool200000:d0
oooo0`0000000`3oool000000?ooo`020?ooo`@000000`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`060?ooo`800000<`3oool002`0oooo
00<000000?ooo`3oool0[03oool3000000030?ooo`000000oooo00<0oooo
0`0000030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
0`00000c0?ooo`00;03oool00`000000oooo0?ooo`2[0?ooo`040000003o
ool0oooo0?ooo`8000002P3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00/0oooo00D000000?ooo`3oool0oooo000000080?ooo`04
0000003oool0oooo00000380oooo000/0?ooo`800000ZP3oool00`000000
oooo000000030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`0;0?ooo`050000003oool0oooo0?oo
o`000000203oool010000000oooo0?ooo`00000b0?ooo`008`3oool30000
00H0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo000000030?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0<`3oool002H0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`1P0?ooo`800000A@3oool3000000030?ooo`000000oooo00l0
oooo00<000000?ooo`0000009@3oool00`000000oooo0?ooo`0=0?ooo`04
0000003oool00000000000L0oooo00<000000?ooo`3oool0=03oool001d0
oooo1@0000040?ooo`030000003oool0oooo00<0oooo0P00002T0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool200000100oooo0`00000H0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool03@3oool20000
00T0oooo00<000000?ooo`3oool0=03oool002<0oooo0`0000060?ooo`03
0000003oool0oooo0600oooo0P0000100?ooo`80000000@0oooo0000003o
ool000000P3oool00`000000oooo0?ooo`0?0?ooo`<00000603oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0P0000090?oo
o`030000003oool0oooo03@0oooo000S0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0G03oool2000004@0oooo0P000000103oool0
00000?ooo`0000020?ooo`030000003oool0oooo00l0oooo00@000000?oo
o`3oool000005`3oool2000000D0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0=03oool002<0oooo100000050?ooo`800000H03oool01000
0000oooo0?ooo`00000n0?ooo`040000003oool000000?ooo`8000005@3o
ool010000000oooo0?ooo`00000D0?ooo`050000003oool000000?ooo`00
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000f0?ooo`00
;03oool00`000000oooo0?ooo`1L0?ooo`80000000<0oooo0000003oool0
@03oool01P000000oooo0?ooo`000000oooo000001P0oooo00<000000?oo
o`0000004P3oool01@000000oooo0000003oool0000000D0oooo0P000004
0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool000001`3o
ool2000003L0oooo000/0?ooo`030000003oool0oooo05l0oooo00D00000
0?ooo`3oool0oooo0000000m0?ooo`040000003oool0oooo000001X0oooo
00<000000?ooo`0000004@3oool00`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo0P0000040?ooo`030000003oool0oooo00/0oooo
00@000000?ooo`00000000001P3oool00`000000oooo0000000g0?ooo`00
;03oool2000005d0oooo00@000000?ooo`0000000000203oool00`000000
oooo0?ooo`0f0?ooo`040000003oool0oooo000001/0oooo00<000000?oo
o`000000403oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000030?ooo`030000003oool0oooo00/0oooo0`0000020?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0=`3oool002`0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0703oool00`000000oooo0000000@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo000000020?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`000000oooo0`0000030?oo
o`030000003oool0oooo03L0oooo000/0?ooo`030000003oool0oooo05/0
oooo00@000000?ooo`3oool000001P3oool01@000000oooo0?ooo`3oool0
000000D0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
1@000000oooo0?ooo`3oool000000080oooo00@000000?ooo`3oool00000
303oool4000000@0oooo00@000000?ooo`0000000000>P3oool002`0oooo
0P00001<0?ooo`030000003oool0000000`0oooo00<000000?ooo`3oool0
1`3oool010000000oooo0?ooo`0000040?ooo`030000003oool000000080
00005P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo008000000P3oool010000000oooo0?ooo`00000?0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`000000>P3oool002`0
oooo00<000000?ooo`3oool0C@3oool4000000P0oooo0P00000:0?ooo`80
00000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool00P0000060?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`000000303oool00`00
0000oooo0?ooo`140?ooo`00;03oool00`000000oooo0?ooo`0>0?ooo`80
0000>`3oool010000000oooo00000000000:0?ooo`030000003oool0oooo
00P0oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3o
ool2000001@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000203o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0000005<0oooo
000/0?ooo`8000003`3oool00`000000oooo0?ooo`0l0?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0000000E0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
0P0000000`3oool000000?ooo`080?ooo`8000001@3oool00`000000oooo
0?ooo`0:0?ooo`800000AP3oool001L0oooo100000030?ooo`8000000`3o
ool3000000H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0h0?ooo`070000003oool0oooo0?ooo`000000oooo000000070?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00@000000?ooo`00000000002@3oool2000000D0oooo00<000000?oo
o`3oool0DP3oool001P0oooo00<000000?ooo`3oool00`3oool2000000H0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool00`3oool010000000
oooo0?ooo`00000Y0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0P0?ooo`800000203oool01000
0000oooo0000000000090?ooo`8000004P3oool00`000000oooo0?ooo`15
0?ooo`004@3oool5000000<0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`8000004@3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo0080oooo0P0000040?oo
o`030000003oool0oooo00<0oooo0P00000A0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool08@3oool3000000L0oooo00@000000?oo
o`3oool00000I@3oool001X0oooo00<000000?ooo`3oool01P3oool30000
00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo03H0oooo0`0000000`3oool000000?ooo`060?oo
o`040000003oool0oooo00000280oooo00@000000?ooo`3oool000003@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`0000001P3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo04H0oooo000G0?ooo`040000003oool0oooo000000P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?oo
o`02000000L0oooo00@000000?ooo`3oool0oooo0P00000J0?ooo`030000
003oool0oooo0080oooo0P0000050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
AP3oool001P0oooo0P0000090?ooo`@000001@3oool2000000P0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`00000d0?ooo`030000
003oool00000008000002P3oool010000000oooo00000000000L0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0503oool200000080oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`170?ooo`00;03oool00`000000oooo
0?ooo`070?ooo`030000003oool0000000L0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0?0?ooo`050000003oool0oooo0?ooo`00
00007P3oool2000000L0oooo00D000000?ooo`3oool0oooo0000000A0?oo
o`030000003oool0000000D0oooo00<000000?ooo`3oool09P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000004P3oool2000000D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`170?ooo`00;03oool0
0`000000oooo0?ooo`040?ooo`80000000<0oooo0000003oool00`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool000001P3oool2000000X0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0W0?ooo`D000005P3o
ool3000000030?ooo`000000000004h0oooo000/0?ooo`800000203oool0
1@000000oooo0000003oool0000001L0oooo0`0000040?ooo`800000503o
ool3000000T0oooo0`0000040?ooo`800000103oool2000001`0oooo0`00
00030?ooo`<00000103oool2000000P0oooo0P0000070?ooo`030000003o
ool0oooo0080oooo0P0000050?ooo`@000000`3oool2000000@0oooo0P00
000F0?ooo`80000000<0oooo0000003oool00P3oool400000080oooo0`00
00040?ooo`80000000<0oooo0000000000002`3oool00`000000oooo0?oo
o`0;0?ooo`<00000103oool2000000@0oooo0P00000]0?ooo`00;03oool0
0`000000oooo0?ooo`040?ooo`030000003oool0000000<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`040000003oool0
oooo00000080oooo00<000000?ooo`3oool0503oool00`000000oooo0000
00070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000L0?ooo`030000003oool0oooo00D0
oooo00@000000?ooo`00000000000P3oool01@000000oooo0?ooo`3oool0
000000X0oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`00000F0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000020?ooo`05
0000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0B0?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0Z0?ooo`00;03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01d0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0000000<000002P3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool00000703oool00`000000oooo0?ooo`050?ooo`04
0000003oool0oooo00000080oooo00H000000?ooo`3oool0oooo0000003o
ool2000000030?ooo`000000000000H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`000000
0P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool30000
0140oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo02X0oooo000/0?ooo`8000001@3oool0
0`000000oooo0?ooo`0:0?ooo`800000403oool300000080oooo0P000002
0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000000P3o
ool00`000000oooo0?ooo`040?ooo`800000203oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000703oool00`000000oooo0?ooo`020?ooo`@0000000<0oooo00000000
00000P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01@3oool00`000000oooo000000040?ooo`030000003oool0oooo
00L0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00`00
00030?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0
3P3oool2000000<0oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`00000/0?ooo`00;03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo01d0oooo00L000000?ooo`3oool0oooo0000003oool0
00000080oooo00<000000?ooo`3oool01`3oool2000000@0oooo00@00000
0?ooo`00000000003@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool00000703oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000`3oool400000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000L0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool00`3oool01000
0000oooo0?ooo`00000<0?ooo`030000003oool0oooo00l0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`030000
003oool0oooo02X0oooo000/0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool03P3oool5000000040?ooo`0000000000000000L0oooo
0P0000001@3oool000000?ooo`3oool0000000T0oooo00<000000?ooo`3o
ool01P3oool2000000D0oooo0P0000040?ooo`800000703oool2000000@0
oooo1@0000020?ooo`8000001`3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`060?oo
o`800000103oool2000000@0oooo0P00000N0?ooo`8000000`3oool40000
00<0oooo0P00000<0?ooo`030000003oool0oooo00d0oooo0`0000040?oo
o`800000103oool2000002d0oooo000/0?ooo`<000000P3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0000000l0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0000001B0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P0000110?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0B03oool002`0oooo0P00000C0?ooo`03
0000003oool0oooo00l0oooo0`0000020?ooo`050000003oool0oooo0?oo
o`0000001@3oool00`000000oooo000000040?ooo`030000003oool0oooo
0500oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0
00000?ooo`000000oooo0000000G0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0F03oool300000080oooo1@0000001P3oool00000
0?ooo`000000oooo00000080oooo1000000<0?ooo`00;03oool300000080
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00h0oooo0P00001A0?ooo`050000003oool0oooo0?oo
o`000000103oool01@000000oooo0000003oool0000001H0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`0e0?ooo`040000003oool0
oooo000000<0oooo00/000000?ooo`3oool0oooo0000003oool000000?oo
o`000000oooo0000000@0?ooo`009@3ooooo000001H000002@3oool00`00
0000oooo0?ooo`040?ooo`0:0000003oool0oooo0?ooo`000000oooo0000
003oool000000?ooo`D00000303oool002`0oooo0P0000000`3oool00000
0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00@000000?ooo`000000
oooo0P00000<0?ooo`800000603oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00X0oooo0P000000103oool000000?ooo`3oool20000
00070?ooo`000000oooo0?ooo`000000oooo0000000@0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`000000903oool01@000000oooo0?oo
o`3oool0000002H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`0;0000003oool0oooo0?ooo`000000oooo0000003oool0
00000?ooo`0000000`3oool00`000000oooo0?ooo`0:0?ooo`00;03oool2
000001@0oooo00D000000?ooo`3oool0oooo0000000D0?ooo`800000103o
ool00`000000oooo0?ooo`1G0?ooo`040000003oool0000000000080oooo
100000030?ooo`8000005@3oool010000000oooo0?ooo`0000040?ooo`05
0000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`1:0?oo
o`@000000`3oool200000080oooo1P0000020?ooo`<000003@3oool002`0
oooo0P00000E0?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0000000200000280oooo00<000000?oo
o`3oool0>03oool01P000000oooo0000003oool000000?ooo`<00000103o
ool010000000oooo00000000000C0?ooo`060000003oool0oooo0000003o
ool000003`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool07`3oool002`0oooo0P00000E0?ooo`04
0000003oool00000000001H0oooo0P0000000`3oool000000?ooo`0>0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0>03oool01000
0000oooo0000003oool4000001`0oooo00<000000?ooo`3oool01@3oool0
10000000oooo0?ooo`3oool2000000P0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01P0oooo000/
0?ooo`050000003oool000000?ooo`0000004P3oool01@000000oooo0?oo
o`3oool0000000P0oooo0`0000060?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo03P0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0
00000?ooo`070?ooo`8000003P3oool00`000000oooo000000060?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool200000003
0?ooo`000000oooo01<0oooo00<000000?ooo`3oool0F03oool002`0oooo
0`0000000`3oool000000?ooo`0A0?ooo`8000000P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0000000l0oooo00<000000?ooo`3oool0
303oool00`000000oooo0000000i0?ooo`030000003oool0oooo01`0oooo
00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo
00<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo05/0oooo000/0?ooo`050000003oool00000
0?ooo`0000006@3oool010000000oooo0000000000020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000>@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo00D0
00000?ooo`000000oooo000000050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`0000001P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo00<000000?ooo`000000F`3oool002`0oooo00H0
00000?ooo`3oool000000?ooo`00000E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`0000003@3oool00`000000
oooo0000000g0?ooo`030000003oool0000001h0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo000000070?ooo`8000001`3oool00`000000
oooo0?ooo`070?ooo`8000000P3oool00`000000oooo0?ooo`02000005/0
oooo000/0?ooo`80000000@0oooo0000003oool00000603oool300000080
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00H0oooo00D000000?ooo`000000oooo0000000:0?oo
o`050000003oool0oooo0?ooo`000000=P3oool200000180oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01P3oool01`000000oooo0?ooo`00
0000oooo0000003oool00`00001K0?ooo`00;03oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo01<0oooo00D000000?ooo`3oool0oooo
0000000H0?ooo`050000003oool000000?ooo`0000001P3oool01@000000
oooo0000003oool0000000X0oooo00D000000?ooo`3oool0oooo0000000^
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool07@3oool2
000000X0oooo0P0000060?ooo`030000003oool0000001<0oooo0`000003
0?ooo`030000003oool0oooo05T0oooo000/0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool04`3oool010000000oooo0?ooo`00000G
0?ooo`<0000000<0oooo0000000000001P3oool010000000oooo0000003o
ool2000000030?ooo`000000oooo00H0oooo00D000000?ooo`3oool0oooo
0000000W0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01P3oool01@000000oooo0?ooo`000000oooo00800000GP3oool0
02`0oooo0P0000040?ooo`030000003oool0oooo02X0oooo00@000000?oo
o`3oool0oooo0`0000000`3oool00000000000050?ooo`080000003oool0
oooo0?ooo`000000oooo0000003oool2000000H0oooo00D000000?ooo`3o
ool0oooo0000000W0?ooo`090000003oool0oooo0?ooo`000000oooo0000
003oool000000080oooo00@000000?ooo`3oool00000803oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0140oooo0P00000:0?ooo`03
0000003oool0oooo05d0oooo000G0?ooo`@000000`3oool2000000<0oooo
0`0000060?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
:@3oool200000080oooo0P0000020?ooo`030000003oool0000000@0oooo
00P000000?ooo`3oool0oooo0000003oool000000?ooo`8000001P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool00P0000020?ooo`<000000P3oool01P000000oooo00000000
0000oooo000001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
0P3oool00`000000oooo000000050?ooo`030000003oool0oooo05d0oooo
000H0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00h0oooo0P0000020?ooo`030000003o
ool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`00000000000P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool08@3oool01@000000oooo
0000003oool000000080oooo0P0000030?ooo`060000003oool000000000
003oool00000@03oool01@000000oooo0000003oool0000006L0oooo000I
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool2
000000D0oooo0P00000I0?ooo`030000003oool0oooo00d0oooo00@00000
0?ooo`000000oooo0P0000060?ooo`040000003oool0oooo000000L0oooo
00<000000?ooo`3oool00P0000040?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool08@3oool01@000000oooo0000003oool000000080
oooo00<000000?ooo`3oool00P3oool01P000000oooo000000000000oooo
000001L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000I@3oool0
01X0oooo00<000000?ooo`3oool01P3oool3000000H0oooo00<000000?oo
o`3oool0103oool3000001P0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`03000000H0oooo00<000000?ooo`000000203oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`0P0?ooo`80000000L0oooo0000003oool0oooo0000003o
ool0000000D0oooo00@000000?ooo`0000000000603oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01l0oooo00<000000?ooo`000000
0P0000000`3oool000000?ooo`1T0?ooo`005`3oool010000000oooo0?oo
o`0000080?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
103oool3000001P0oooo0P00000>0?ooo`030000003oool0oooo00800000
1`3oool00`000000oooo0000000;0?ooo`8000000P3oool00`000000oooo
000000050?ooo`030000003oool0oooo01l0oooo0P000000103oool00000
0?ooo`3oool2000000H0oooo00@000000?ooo`3oool00000603oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00@000000?oo
o`3oool0oooo0`00001V0?ooo`00603oool2000000T0oooo100000050?oo
o`8000001P3oool00`000000oooo0000000E0?ooo`80000000<0oooo0000
003oool03@3oool010000000oooo0?ooo`0000080?ooo`800000303oool3
000000030?ooo`000000000000H0oooo00<000000?ooo`3oool07`3oool2
000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0F0?ooo`<000000`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0000006H0oooo000/0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`0000005@3oool2000000030?ooo`000000oooo
00d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?oo
o`060000003oool000000000003oool000001P3oool00`000000oooo0?oo
o`0N0?ooo`040000003oool00000000005<0oooo00<000000?ooo`3oool0
IP3oool002`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
000D0?ooo`050000003oool000000?ooo`0000003@3oool00`000000oooo
0?ooo`0H0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3o
ool07P3oool010000000oooo0?ooo`00000W0?ooo`030000003oool0oooo
0080000000<0oooo0000003oool0S@3oool002`0oooo0P0000080?ooo`04
0000003oool0oooo00000100oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00@000000?oo
o`3oool00000203oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0S`3oool002`0oooo00<000000?oo
o`3oool0203oool00`000000oooo0000000@0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`2?0?ooo`00;03oool00`000000oooo0?ooo`080?ooo`80
000000@0oooo0000000000000000303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0;h0oooo000/0?ooo`80
00002P3oool00`000000oooo0?ooo`02000000`0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`2n0?ooo`00
;03oool00`000000oooo0?ooo`0<0?ooo`800000303oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
9P3oool2000001d0oooo00<000000?ooo`3oool0_P3oool002`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0V0?ooo`800000703oool00`000000oooo0?ooo`2o0?ooo`00;03oool2
000000d0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09P3oool2
000001`0oooo00<000000?ooo`3oool0_`3oool002<0oooo0`0000060?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0;l0oooo000V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0_`3oool002H0oooo
00<000000?ooo`3oool00`3oool2000000l0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0<00oooo000S0?ooo`<000001P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000203o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`300?ooo`008`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool00P3oool01P000000oooo0?ooo`000000oooo000000T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0`03oool002<0oooo1000
00050?ooo`800000403oool010000000oooo0?ooo`3oool2000000050?oo
o`00000000000?ooo`0000002@3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool05P3oool00`000000
oooo000000320?ooo`00;03oool00`000000oooo0?ooo`0?0?ooo`040000
003oool0oooo0?ooo`80000000@0oooo0000003oool000002P3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool05@3oool00`000000oooo000000320?ooo`00;03oool00`000000
oooo0?ooo`0?0?ooo`040000003oool0000000000080oooo0P0000000`3o
ool000000?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00T0oooo0P0000330?ooo`00;03oool200000140oooo0`0000020?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00P0oooo0P00000;0?ooo`80
0000``3oool002`0oooo00<000000?ooo`3oool0403oool00`000000oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00P0oooo
0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0080oooo
0P0000330?ooo`00;03oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool000000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`0000000000
103oool01@000000oooo0?ooo`3oool000000<D0oooo000/0?ooo`800000
9@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02000000@0oooo
00<000000?ooo`3oool00P0000350?ooo`00;03oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3o
ool010000000oooo0?ooo`0000050?ooo`060000003oool0oooo0000003o
ool000000P3oool010000000oooo0000003oool200000<D0oooo000/0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool00P00000a0?oo
o`80000000<0oooo000000000000103oool00`000000oooo0?ooo`020?oo
o`080000003oool0oooo0000003oool000000?ooo`0000360?ooo`00;03o
ool2000002H0oooo00@000000?ooo`0000000000<P3oool010000000oooo
0000000000040?ooo`030000003oool0oooo0080oooo0P0000000`3oool0
00000?ooo`0200000<L0oooo000H0?ooo`030000003oool0oooo00<0oooo
0P0000030?ooo`<000001P3oool00`000000oooo0?ooo`0U0?ooo`800000
=03oool01P000000oooo000000000000oooo00000080oooo00<000000?oo
o`3oool00`3oool010000000oooo0000003oool200000<L0oooo000H0?oo
o`030000003oool0oooo00<0oooo0P0000060?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0c0?oo
o`80000000D0oooo000000000000oooo000000060?ooo`8000000`3oool0
0`000000oooo0?ooo`350?ooo`006@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo0P00001M0?ooo`050000003oool0oooo
0000003oool00P0000070?ooo`030000003oool0oooo0<T0oooo000I0?oo
o`030000003oool0oooo00L0oooo0`0000060?ooo`030000003oool0oooo
05`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0<T0oooo000J0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000003oool0oooo0<T0oooo000G0?ooo`@00000203oool4000000D0oooo
0P00003o0?ooocP0oooo000/0?ooo`030000003oool0oooo0?l0oooo=`3o
ool002`0oooo00<000000?ooo`3oool0o`3ooolg0?ooo`00o`3ooomV0?oo
o`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV
0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00703oool2000000<0oooo
1@0000000`3oool0000000000003000000030?ooo`000000000000<00000
0P3oool4000000030?ooo`000000000000800000o`3ooolY0?ooo`00703o
ool2000000<0oooo00@000000?ooo`3oool00000103oool01@000000oooo
0?ooo`3oool000000080oooo00@000000?ooo`3oool00000203oool00`00
0000oooo0?ooo`3o0?ooobL0oooo000K0?ooo`040000003oool000000000
0080oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`05000000030?ooo`000000000000800000o`3ooolY
0?ooo`006`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000000<0oooo00<000000?ooo`000000o`3oool/0?ooo`006P3o
ool200000080oooo0P0000020?ooo`<00000103oool00`000000oooo0?oo
o`02000000030?ooo`000000000000<0oooo0`0000020?ooo`@00000o`3o
oolY0?ooo`00:@3oool00`000000oooo0?ooo`3o0?ooocX0oooo000W0?oo
o`<00000o`3oooll0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00o`3o
oomV0?ooo`00o`3ooomV0?ooo`00o`3ooomV0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->False,
  ImageSize->{357.438, 154.5},
  ImageMargins->{{63.375, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bar Chart", "Subsubsection",
  CellTags->"C.1"],

Cell["\<\
Another graphics function that is used throughout this book is \
BarChart. As with MultipleListPlot, BarChart takes a list or a sequence of \
lists, and produces a graphic displaying those data sets.\
\>", "Text",
  CellTags->{"i:15", "C.1"}],

Cell[TextData[{
  "For example, suppose that in some model, individuals can switch from one \
group to another, and we are interested in the number of individuals in a \
particular group as a function of time. Say we have already extracted the \
number of individuals in each group for every time step, and have the results \
in two lists: ",
  StyleBox["group1", "IT"],
  " and ",
  StyleBox["group2.", "IT"]
}], "Text",
  CellTags->"C.1"],

Cell["\<\
group1 = {10,11,10,11,10,9,8,9,10,9,8,7,6,5,6,7,8,9,8,7,8};
group2 = {10,9,10,9,10,11,12,11,10,11,12,13,14,15,
                                   14,13,12,11,12,13,12};\
\>", "Input",
  CellTags->"C.1"],

Cell["Plotting these data as a bar chart is straightforward.", "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{

Cell[TextData[
"BarChart[group1, group2, AxesLabel \[Rule] {\"time\", \"count\"},\n  Ticks \
\[Rule] {Range[0, 20, 2], Range[0, 14, 2]}];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000460000XB000`400?l0
0000o`00003oo`3oool70?ooo`00o`3oool70?ooo`00o`3oool70?ooo`00
o`3oool70?ooo`00703oool400000140oooo0`00000A0?ooo`8000004P3o
ool2000000h0oooo0`0000040?ooo`8000002`3oool3000000<0oooo1000
000:0?ooo`<00000103oool3000000X0oooo0`0000040?ooo`8000002`3o
ool3000000@0oooo0P00000;0?ooo`@000000`3oool200000300oooo000M
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03`3oool0
10000000oooo0?ooo`00000@0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000002l0oooo000N0?ooo`030000003oool0
oooo00l0oooo1000000@0?ooo`040000003oool0oooo00000100oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo1000000;0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000`0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02d0oooo000O
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`0000004@3oool3
00000180oooo0P00000?0?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool00`000000oooo0000
000<0?ooo`030000003oool0oooo0080oooo0`00000<0?ooo`030000003o
ool0oooo00<0oooo0P00000>0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0;@3oool001`0oooo00@000000?ooo`3oool00000
403oool00`000000oooo0000000A0?ooo`030000003oool0oooo0140oooo
00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`000000303oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
000:0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
0000;`3oool001d0oooo0P00000B0?ooo`8000004P3oool300000140oooo
0P00000>0?ooo`8000001@3oool2000000/0oooo0P0000050?ooo`800000
2`3oool2000000D0oooo0P00000;0?ooo`8000001@3oool3000000X0oooo
0P0000050?ooo`800000303oool2000000@0oooo0P00000`0?ooo`00o`3o
ool70?ooo`004@3oool00`000000oooo0?ooo`3b0?ooo`004@3oool00`00
0000oooo0?ooo`3I0?ooo`<000000P3oool5000000060?ooo`000000oooo
0000003oool000000P3oool4000000<0oooo000A0?ooo`030000003oool0
oooo0=T0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000L0oooo000A0?oo
om<000002@3oool00`000000oooo0?ooo`040?ooo`0:0000003oool0oooo
0?ooo`000000oooo0000003oool000000?ooo`D000000`3oool00140oooo
0P0000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000400000000I_l006Ko000000/0oooo00<000000?ooo`3o
ool0103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo0000
003oool0000000<0oooo00<000000?ooo`3oool00@3oool00140oooo0P00
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000400000000I_l006Ko000000X0oooo100000030?ooo`800000
0P3oool600000080oooo0`0000040?ooo`004@3oool2000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000@0
0000001Vo`00I_l000002`3oool00`000000oooo0?ooo`0F0?ooo`004@3o
ool2000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000@00000001Vo`00I_l000002`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00l0oooo000A0?ooo`8000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000@0
0000001Vo`00I_l00000903oool00140oooo0P0000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000400000000
I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001000000006Ko001V
o`00000T0?ooo`004@3oool2000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l00000
903oool00140oooo0P0000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000400000000I_l006Ko000002@0oooo
000A0?ooo`8000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001000000006Ko001Vo`00000T0?ooo`004@3o
ool2000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000@00000001Vo`00I_l00000903oool00140oooo0P00
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000400000000I_l006Ko000002@0oooo00090?ooo`@00000103o
ool2000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000@00000001Vo`00I_l00000903oool000X0oooo00<0
00000?ooo`3oool0103oool2000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l00000
903oool000/0oooo00<000000?ooo`3oool00`3oool2000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000@0
0000001Vo`00I_l00000903oool000`0oooo00<000000?ooo`3oool00P3o
ool2000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000@00000001Vo`00I_l00000903oool000T0oooo00@0
00000?ooo`3oool00000103oool2000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l0
0000903oool000X0oooo0P0000050?ooo`8000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001000000006Ko
001Vo`00000T0?ooo`004@3oool2000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l0
0000903oool00140oooo0P0000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko000002@0
oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001000000006Ko001Vo`00000T0?ooo`00
4@3oool2000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000@00000001Vo`00I_l00000903oool00140oooo
0P0000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000400000000I_l006Ko000002@0oooo000A0?ooo`800000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00@00000001Vo`00I_l00000903oool00140oooo0P0000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000040000
0000I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001000000006Ko
001Vo`00000T0?ooo`004@3oool2000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l0
0000903oool00140oooo0P0000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko000002@0
oooo000:0?ooo`<00000103oool2000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l0
0000903oool000/0oooo00<000000?ooo`3oool00`3oool2000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00@00000001Vo`00I_l00000903oool000T0oooo100000040?ooo`800000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001000000006Ko001Vo`00000T0?ooo`002@3oool00`000000oooo
000000050?ooo`8000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001000000006Ko001Vo`00000T0?ooo`00
2@3oool00`000000oooo000000050?ooo`8000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001000000006Ko
001Vo`00000T0?ooo`002P3oool2000000D0oooo0P0000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000040000
0000I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001000000006Ko
001Vo`00000T0?ooo`004@3oool2000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l0
0000903oool00140oooo0P0000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko000002@0
oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001000000006Ko001Vo`00000T0?ooo`00
4@3oool2000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000H0
0000001Vo`00I_l006Ko0000003oool5000000<006Ko00<000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000D00000001Vo`00I_l006Ko00000005
0?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko
000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001@00000006Ko001Vo`00I_l0000000D0oooo00L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000@00000001Vo`00I_l00000903oool00140
oooo0P0000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000050000
0000I_l006Ko001Vo`0000001@3oool01`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000D00000001Vo`00I_l006Ko
000000050?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000400000000
I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0oooo00L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00I_l00000903o
ool000X0oooo0P0000050?ooo`8000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0oooo00L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000@00000001Vo`00I_l00000903oool0
00T0oooo00@000000?ooo`3oool00000103oool2000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000D00000001Vo`00I_l006Ko00000005
0?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko
000002@0oooo00090?ooo`040000003oool0oooo000000@0oooo0P000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000060000
0000I_l006Ko001Vo`000000oooo1@000003001Vo`030000003oool0oooo
00<0oooo00H00000001Vo`00I_l006Ko0000003oool5000000<006Ko00<0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001000000006Ko001Vo`00000T0?ooo`002@3o
ool3000000D0oooo0P0000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00004
00000000I_l006Ko000002@0oooo00090?ooo`030000003oool0oooo00D0
oooo0P0000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`07
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000400000000I_l0
06Ko000002@0oooo000:0?ooo`<00000103oool2000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000@00000001Vo`00I_l00000903oool00140oooo
0P0000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko
000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0oooo
00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001V
o`0000001@3oool01`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000@00000001Vo`00I_l00000903oool00140
oooo0P0000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`07
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000400000000I_l0
06Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00H00000001Vo`00I_l006Ko0000003oool5000000<006Ko00<000000?oo
o`3oool00`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0600000000I_l006Ko001Vo`000000
oooo1@000003001Vo`030000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000H00000001Vo`00I_l006Ko0000003oool50000
00<006Ko00<000000?ooo`0000000`3o00001000000006Ko001Vo`00000T
0?ooo`004@3oool2000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1@00000006Ko001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000@00000001Vo`00I_l00000903oool00140
oooo0P0000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo00000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000070000
0000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko
001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000
oooo000000030?l0000500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001V
o`00I_l006Ko000000050?ooo`0700000000I_l006Ko001Vo`000000oooo
000000030?l0000400000000I_l006Ko000002@0oooo000A0?ooo`800000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000500000000I_l006Ko001V
o`0000001@3oool01`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0
oooo00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000
001Vo`00I_l00000903oool00140oooo0P0000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001Vo`00
0000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo0000
00030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l00007
00000000I_l006Ko001Vo`000000oooo000000030?l0000500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000D00000001Vo`00I_l006Ko000000050?ooo`070000
0000I_l006Ko001Vo`000000oooo000000030?l0000400000000I_l006Ko
000002@0oooo000:0?ooo`8000001@3oool2000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0oooo00L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000@00000001Vo`00
I_l00000903oool000T0oooo00@000000?ooo`3oool00000103oool20000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00
I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001V
o`0000001@3oool01`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001@00000006Ko001Vo`00
I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000@00000001Vo`00I_l00000903oool000T0oooo00@000000?ooo`3o
ool00000103oool2000000<0o`0000L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l0
06Ko0000003oool0000000<0o`0000H00000001Vo`00I_l006Ko0000003o
ool5000000<006Ko00<000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001P00000006Ko001Vo`00I_l000000?ooo`D00000
0`00I_l00`000000oooo0?ooo`030?ooo`0500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01P00000006Ko001Vo`00I_l000000?ooo`D000000`00I_l00`000000
oooo000000030?l0000600000000I_l006Ko001Vo`000000oooo1@000003
001Vo`030000003oool0oooo00<0oooo00H00000001Vo`00I_l006Ko0000
003oool50000008006Ko00<000000?ooo`3oool08P3oool000X0oooo0P00
00050?ooo`8000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001@00000006Ko001Vo`00I_l0000000D0oooo
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L00000001V
o`00I_l006Ko0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0700000000I_l0
06Ko001Vo`000000oooo000000030?l0000500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0400000000I_l006Ko000002@0oooo0009
0?ooo`040000003oool0oooo000000@0oooo0P0000030?l0000700000000
I_l006Ko001Vo`000000oooo000000030?l0000700000000I_l006Ko001V
o`000000oooo000000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l0000700000000I_l006Ko001Vo`000000oooo000000030?l0
000700000000I_l006Ko001Vo`000000oooo000000030?l0000500000000
I_l006Ko001Vo`0000001@3oool01`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00@00000
001Vo`00I_l00000903oool000X0oooo0P0000050?ooo`8000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1@00000006Ko001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko
0000003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0700000000I_l006Ko001Vo`000000oooo0000
00030?l0000500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0400000000I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001@00
000006Ko001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000
003oool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0700000000I_l006Ko001Vo`000000oooo00000003
0?l0000500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`04
00000000I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`000000
06Ko001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?oo
o`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o
00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001@000000
06Ko001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000003o
ool0000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l0
000500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`040000
0000I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko
001Vo`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l0
00000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`00
00000`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o0000
1`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001@00000006Ko
001Vo`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000003oool0
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l00005
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0400000000
I_l006Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001`00000006Ko001Vo`00I_l00000
0?ooo`0000000`3o00001`00000006Ko001Vo`00I_l000000?ooo`000000
0`3o00001`00000006Ko001Vo`00I_l000000?ooo`0000000`3o00001`00
000006Ko001Vo`00I_l000000?ooo`0000000`3o00001@00000006Ko001V
o`00I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000003oool00000
00<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l000050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0400000000I_l0
06Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o0005000000030?ooo`000000o`000080o`00
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`001@0000000`3o
ool000000?l000020?l0000600000000I_l006Ko001Vo`000000oooo1@00
0003001Vo`030000003oool0oooo00<0oooo00H00000001Vo`00I_l006Ko
0000003oool5000000<006Ko00<000000?ooo`0000000`3o00001P000000
06Ko001Vo`00I_l000000?ooo`D000000`00I_l00`000000oooo0?ooo`03
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0600000000
I_l006Ko001Vo`000000oooo1@000003001Vo`030000003oool0oooo00<0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01000000006Ko001Vo`00000T0?ooo`004@3oool2
000000<0o`0000L00000001Vo`00I_l006Ko0000003oool0000000<0o`00
00<000000?ooo`3oool00`3oool01@000000o`000?l0003o0000000000<0
06Ko00<000000?ooo`0000000`3o00000`000000oooo0?ooo`030?ooo`05
0000003o0000o`000?l0000000000`00I_l00`000000oooo0?ooo`030?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00L00000001Vo`00I_l006Ko0000003oool0000000<0
o`0000D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00@00000001Vo`00I_l00000903o
ool00140oooo0P0000030?l0000700000000I_l006Ko001Vo`000000oooo
000000030?l000030000003oool0oooo00<0oooo00D000000?l0003o0000
o`0000000003001Vo`030000003oool0000000<0o`0000<000000?ooo`3o
ool00`3oool01@000000o`000?l0003o0000000000<006Ko00<000000?oo
o`3oool00`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0700000000I_l006Ko001Vo`000000
oooo000000030?l0000500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0400000000I_l0
06Ko000002@0oooo000A0?ooo`8000000`3o00001`00000006Ko001Vo`00
I_l000000?ooo`0000000`3o00000`000000oooo0?ooo`030?ooo`050000
003o0000o`000?l0000000000`00I_l00`000000oooo000000030?l00003
0000003oool0oooo00<0oooo00D000000?l0003o0000o`0000000003001V
o`030000003oool0oooo00<0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01`00000006Ko001V
o`00I_l000000?ooo`0000000`3o00001@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1000000006Ko001Vo`00000T0?ooo`004@3oool2000000<0o`0000L00000
001Vo`00I_l006Ko0000003oool0000000<0o`0000<000000?ooo`3oool0
0`3oool01@000000o`000?l0003o0000000000<006Ko00<000000?ooo`00
00000`3o00000`000000oooo0?ooo`030?ooo`050000003o0000o`000?l0
000000000`00I_l00`000000oooo0?ooo`030?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00@00000001Vo`00I_l00000903oool00140oooo0P000003
0?l0000700000000I_l006Ko001Vo`000000oooo000000030?l000030000
003oool0oooo00<0oooo00D000000?l0003o0000o`0000000003001Vo`03
0000003oool0000000<0o`0000<000000?ooo`3oool00`3oool01@000000
o`000?l0003o0000000000<006Ko00<000000?ooo`3oool00`3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0700000000I_l006Ko001Vo`000000oooo000000030?l00005
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0400000000I_l006Ko000002@0oooo0003
0?ooo`<00000103oool2000000D0oooo0P0000030?l0000700000000I_l0
06Ko001Vo`000000oooo000000030?l000030000003oool0oooo00<0oooo
00D000000?l0003o0000o`0000000003001Vo`030000003oool0000000<0
o`0000<000000?ooo`3oool00`3oool01@000000o`000?l0003o00000000
00<006Ko00<000000?ooo`3oool00`3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0700000000
I_l006Ko001Vo`000000oooo000000030?l0000500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0400000000I_l006Ko000002@0oooo00040?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000103oool2000000<0o`0000L0
0000001Vo`00I_l006Ko0000003oool0000000<0o`0000<000000?ooo`3o
ool00`3oool01@000000o`000?l0003o0000000000<006Ko00<000000?oo
o`0000000`3o00000`000000oooo0?ooo`030?ooo`050000003o0000o`00
0?l0000000000`00I_l00`000000oooo0?ooo`030?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00L00000001Vo`00I_l006Ko0000003oool0000000<0o`0000D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00@00000001Vo`00I_l00000903oool000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000040?ooo`X00000
00<0oooo0000003o00000P3o00000`000000oooo0?ooo`030?ooo`T00000
00<0oooo0000003o00000P3o00000`000000oooo0?ooo`030?ooo`T00000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0600000000I_l006Ko001Vo`000000oooo2@00
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00@00000001Vo`00I_l00000903oool000@0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00P0
oooo00D000000?l0003o0000o`000000000?0?ooo`050000003o0000o`00
0?l0000000004`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00003`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0400000000I_l006Ko000002@0oooo00040?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`08
0?ooo`050000003o0000o`000?l0000000003`3oool01@000000o`000?l0
003o0000000001<0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000l0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01000000006Ko001Vo`00000T0?ooo`000`3oool2000000D0oooo0P00
00050?ooo`030000003oool0oooo00P0oooo00D000000?l0003o0000o`00
0000000?0?ooo`050000003o0000o`000?l0000000004`3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000003`3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0400000000I_l006Ko000002@0
oooo000A0?ooo`030000003oool0oooo00P0oooo00D000000?l0003o0000
o`000000000?0?ooo`050000003o0000o`000?l0000000004`3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000003`3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00D00000001Vo`00I_l006Ko000000050?ooo`0400000000I_l006Ko0000
02@0oooo000A0?ooo`030000003oool0oooo00P0oooo00D000000?l0003o
0000o`000000000?0?ooo`050000003o0000o`000?l0000000004`3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000003`3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0400000000I_l006Ko
000002@0oooo000A0?ooo`030000003oool0oooo00P0oooo00D000000?l0
003o0000o`000000000?0?ooo`050000003o0000o`000?l0000000004`3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000003`3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0400000000I_l0
06Ko000002@0oooo000A0?ooo`030000003oool0oooo00P0oooo00D00000
0?l0003o0000o`000000000?0?ooo`050000003o0000o`000?l000000000
4`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000003`3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001V
o`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0400000000
I_l006Ko000002@0oooo000A0?ooo`030000003oool0oooo00P0oooo00D0
00000?l0003o0000o`000000000?0?ooo`050000003o0000o`000?l00000
00004`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000003`3o
ool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`040000
0000I_l006Ko000002@0oooo000A0?ooo`030000003oool0oooo00P0oooo
1@00000?0?ooo`D000004`3oool5000000D0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`D000003`3oool5000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@000000
06Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko00000005
0?ooo`D000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0400000000I_l006Ko000002@0
oooo000A0?ooo`030000003oool0oooo03h0oooo00D00000001Vo`00I_l0
06Ko0000000S0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000003`3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`040000
0000I_l006Ko000002@0oooo000A0?ooo`030000003oool0oooo03h0oooo
00D00000001Vo`00I_l006Ko0000000S0?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000003`3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0400000000I_l006Ko000002@0oooo000A0?ooo`030000
003oool0oooo03h0oooo00D00000001Vo`00I_l006Ko0000000S0?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000003`3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0400000000I_l006Ko000002@0
oooo000A0?ooo`030000003oool0oooo03h0oooo00D00000001Vo`00I_l0
06Ko0000000S0?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000003`3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`040000
0000I_l006Ko000002@0oooo000A0?ooo`030000003oool0oooo03h0oooo
00D00000001Vo`00I_l006Ko0000000S0?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000003`3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0400000000I_l006Ko000002@0oooo00030?ooo`<00000
0`3oool4000000@0oooo00<000000?ooo`3oool0?P3oool01@00000006Ko
001Vo`00I_l0000002<0oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l00000
00D0oooo00D00000001Vo`00I_l006Ko0000000?0?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo
00@00000001Vo`00I_l00000903oool000@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03h0oooo
00D00000001Vo`00I_l006Ko0000000S0?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000003`3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0400000000I_l006Ko000002@0oooo00040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool2000003l0oooo
1@00000S0?ooo`D000001@3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`D000003`3oool5000000D0oooo
00D00000001Vo`00I_l006Ko000000050?ooo`@00000903oool000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0700oooo00D00000001Vo`00I_l006Ko000000050?ooo`05
00000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0
000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000008`3oool01@00000006Ko001Vo`00I_l0000002d0
oooo00040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1`0?ooo`0500000000I_l006Ko001V
o`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D00000
001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`000000
1@3oool01@00000006Ko001Vo`00I_l0000002<0oooo00D00000001Vo`00
I_l006Ko0000000]0?ooo`000`3oool2000000D0oooo0P0000050?ooo`03
0000003oool0oooo0700oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000008`3oool01@00000006Ko001Vo`00I_l00000
02d0oooo000A0?ooo`030000003oool0oooo0700oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000008`3oool01@000000
06Ko001Vo`00I_l0000002d0oooo000A0?ooo`030000003oool0oooo0700
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`00
00008`3oool01@00000006Ko001Vo`00I_l0000002d0oooo000A0?ooo`03
0000003oool0oooo0700oooo00D00000001Vo`00I_l006Ko000000050?oo
o`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00
I_l0000000D0oooo00D00000001Vo`00I_l006Ko000000050?ooo`050000
0000I_l006Ko001Vo`0000008`3oool01@00000006Ko001Vo`00I_l00000
02d0oooo000A0?ooo`030000003oool0oooo0700oooo00D00000001Vo`00
I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool0
1@00000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000008`3oool01@000000
06Ko001Vo`00I_l0000002d0oooo000A0?ooo`030000003oool0oooo0700
oooo1@0000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000000D0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`D000008`3oool5000002d0oooo000A0?ooo`030000003oool0
oooo07X0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000
I_l006Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000005l0
oooo000A0?ooo`030000003oool0oooo07X0oooo00D00000001Vo`00I_l0
06Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00
000006Ko001Vo`00I_l0000005l0oooo000A0?ooo`030000003oool0oooo
07X0oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l0
06Ko001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000005l0oooo
000A0?ooo`030000003oool0oooo07X0oooo00D00000001Vo`00I_l006Ko
000000050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@000000
06Ko001Vo`00I_l0000005l0oooo000A0?ooo`030000003oool0oooo07X0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`0000001@3oool01@00000006Ko001Vo`00I_l0000005l0oooo000A
0?ooo`030000003oool0oooo07X0oooo00D00000001Vo`00I_l006Ko0000
00050?ooo`0500000000I_l006Ko001Vo`0000001@3oool01@00000006Ko
001Vo`00I_l0000005l0oooo00030?ooo`<00000103oool3000000@0oooo
00<000000?ooo`3oool0NP3oool01@00000006Ko001Vo`00I_l0000000D0
oooo00D00000001Vo`00I_l006Ko000000050?ooo`0500000000I_l006Ko
001Vo`000000G`3oool000@0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo07X0oooo00D00000001V
o`00I_l006Ko000000050?ooo`0500000000I_l006Ko001Vo`0000001@3o
ool01@00000006Ko001Vo`00I_l0000005l0oooo00040?ooo`030000003o
ool0oooo0080oooo100000040?ooo`800000N`3oool5000000D0oooo00D0
0000001Vo`00I_l006Ko000000050?ooo`D00000G`3oool000@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo08@0oooo00D00000001Vo`00I_l006Ko0000001Y0?ooo`00103o
ool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo00<0
00000?ooo`3oool0Q03oool01@00000006Ko001Vo`00I_l0000006T0oooo
00030?ooo`8000001@3oool2000000D0oooo00<000000?ooo`3oool0Q03o
ool01@00000006Ko001Vo`00I_l0000006T0oooo000A0?ooo`030000003o
ool0oooo08@0oooo00D00000001Vo`00I_l006Ko0000001Y0?ooo`004@3o
ool00`000000oooo0?ooo`240?ooo`0500000000I_l006Ko001Vo`000000
J@3oool00140oooo00<000000?ooo`3oool0Q03oool01@00000006Ko001V
o`00I_l0000006T0oooo000A0?ooo`030000003oool0oooo08@0oooo00D0
0000001Vo`00I_l006Ko0000001Y0?ooo`004@3oool00`000000oooo0?oo
o`240?ooo`D00000J@3oool00140oooo00<000000?ooo`3oool0lP3oool0
0140oooo00<000000?ooo`3oool0lP3oool00140oooo00<000000?ooo`3o
ool0lP3oool00?l0oooo1`3oool00?l0oooo1`3oool00?l0oooo1`3oool0
0?l0oooo1`3oool00?l0oooo1`3oool00?l0oooo1`3oool00?l0oooo1`3o
ool00?l0oooo1`3oool000@0oooo0`0000030?ooo`<000000P3oool50000
00040?ooo`00000000000?ooo`8000000P3oool300000>L0oooo00030?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool000000080oooo00@000000?ooo`3oool000000P3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0i03oool000<0oooo
00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0
oooo0?ooo`000000j@3oool000<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000<0oooo00<000000?ooo`0000000P3oool010000000oooo
0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000j@3oool000@0
oooo100000020?ooo`<0000000@0oooo000000000000oooo0P0000000`3o
ool000000000000300000080oooo1000003W0?ooo`00703oool00`000000
oooo0?ooo`3W0?ooo`00703oool00`000000oooo0?ooo`3W0?ooo`00o`3o
ool70?ooo`00o`3oool70?ooo`00o`3oool70?ooo`00o`3oool70?ooo`00
\
\>"], "Graphics",
  Evaluatable->False,
  ImageSize->{262.25, 161.75},
  ImageMargins->{{101, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]],

Cell["\<\
In the Graphics`Graphics` package, a number of variations on the \
standard BarChart are defined. For example, even though individuals are \
switching between group 1 and group 2 in our example, the total population \
remains the same. Thus, it makes sense to plot the size of each group as a \
percentage of the total population. We can do this with a PercentileBarChart.\
\
\>", "Text",
  CellTags->{"i:16", "C.1"}],

Cell[CellGroupData[{

Cell[TextData[
"PercentileBarChart[group1, group2,\n  AxesLabel \[Rule] {\"time\", \"density\
\"},\n  BarStyle \[Rule] {GrayLevel[0.4], GrayLevel[0.8]}];"], "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000590000/B000`400?l0
0000o`00003oo`3ooom:0?ooo`00o`3ooom:0?ooo`008`3oool3000000X0
oooo100000080?ooo`<000002`3oool3000000P0oooo0`00000;0?ooo`80
00002P3oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool3000000L0
oooo0`0000040?ooo`8000000`3oool3000000<0oooo0`0000040?ooo`<0
00000`3oool400000080oooo0`0000030?ooo`<00000103oool3000000@0
oooo0`0000020?ooo`<000000`3oool3000000@0oooo0`0000040?ooo`80
00000`3oool3000000@0oooo00<000000?ooo`3oool00`3oool3000000@0
oooo0P0000030?ooo`<000000`3oool3000000@0oooo100000030?ooo`80
00000`3oool400000080oooo0`00000V0?ooo`00903oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`090?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool002@0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00L0oooo1000000;0?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`080?ooo`04
0000003oool0oooo000000T0oooo0`0000070?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`@000000`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0`3oool3000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0U0?ooo`00903oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00L0oooo0P00000:0?ooo`030000003oool0000000T0oooo
0`00000:0?ooo`<000002`3oool00`000000oooo0?ooo`090?ooo`800000
2@3oool010000000oooo0?ooo`0000070?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01@3oool01@00
0000oooo0?ooo`3oool0000000D0oooo0P0000050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`<000001@3oool00`000000oooo0?ooo`020?ooo`<00000103oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool2000000@0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000060?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000002L0
oooo000T0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`070?ooo`030000003oool0000000T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00L0oooo00@000000?ooo`3oool00000203oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo0080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`000002
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`0U0?ooo`008`3oool2000000`0oooo0P00
00090?ooo`<000002`3oool2000000T0oooo1000000:0?ooo`<00000203o
ool4000000X0oooo0P00000:0?ooo`8000001`3oool2000000D0oooo0P00
00030?ooo`800000103oool2000000D0oooo0P0000050?ooo`8000000`3o
ool2000000@0oooo0`0000040?ooo`8000001@3oool2000000<0oooo0P00
00040?ooo`@000000`3oool2000000D0oooo0`0000020?ooo`800000103o
ool4000000<0oooo0P0000050?ooo`8000000`3oool2000000D0oooo0P00
00050?ooo`800000103oool2000000@0oooo0P0000030?ooo`8000009`3o
ool001l0oooo00<000000?ooo`3oool0o`3ooolX0?ooo`007`3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo000O0?ooo`030000003oool0oooo0?l0
oooo3`3oool300000080oooo1@0000001P3oool000000?ooo`000000oooo
00000080oooo100000030?ooo`007`3oool00`000000oooo0?ooo`3o0?oo
o`l0oooo00@000000?ooo`3oool000000`3oool02`000000oooo0?ooo`3o
ool000000?ooo`000000oooo0000003oool0000000L0oooo000O0?ooool0
00002000000:0?ooo`030000003oool0oooo00@0oooo00X000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo1@0000030?ooo`007`3o
ool2000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0103oool02`000000oooo0?oo
o`3oool000000?ooo`000000oooo0000003oool0000000<0oooo00<00000
0?ooo`3oool00@3oool001l0oooo0P00000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH00`000000oooo0?ooo`080?ooo`@000000`3oool20000
0080oooo1P0000020?ooo`<00000103oool001l0oooo0P00000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo01H0oooo000O0?ooo`8000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00l0oooo000O0?ooo`8000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00<000000?ooo`3oool08P3o
ool001l0oooo0P00000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
0`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP030000003oool0oooo0280oooo000O0?ooo`80
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00<000000?ooo`3o
ool08P3oool001l0oooo0P00000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP030000003oool0oooo0280oooo000O
0?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00<00000
0?ooo`3oool08P3oool000T0oooo0`0000040?ooo`800000103oool30000
00H0oooo0P00000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH00`00
0000oooo0?ooo`0R0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`0000001P3oool20000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP030000003oool0oooo
0280oooo000:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool3000000H0oooo0P00000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH00`000000oooo0?ooo`0R0?ooo`002P3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo0`0000070?oo
o`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00<000000?oo
o`3oool08P3oool000X0oooo00<000000?ooo`3oool00P3oool010000000
oooo0?ooo`0000020?ooo`030000003oool0000000L0oooo0P00000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH00`000000oooo0?ooo`0R0?oo
o`002@3oool2000000D0oooo0P0000030?ooo`<000001`3oool2000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP030000003oool0oooo0280
oooo000O0?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00<000000?ooo`3oool08P3oool001l0oooo0P00000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP030000003oool0
oooo0280oooo000O0?ooo`8000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00<000000?ooo`3oool08P3oool001l0oooo0P00000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH00`000000oooo0?ooo`0R0?ooo`00
7`3oool2000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP030000
003oool0oooo0280oooo000O0?ooo`8000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00<000000?ooo`3oool08P3oool001l0oooo0P000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH00`000000oooo0?ooo`0R
0?ooo`002@3oool4000000<0oooo0P0000040?ooo`<000001P3oool20000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP030000003oool0oooo
0280oooo000:0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo000000060?ooo`8000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00<000000?ooo`3oool08P3oool000/0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo
0?ooo`<000001P3oool2000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP030000003oool0oooo0280oooo000<0?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool00`0000070?ooo`8000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00<000000?ooo`3oool08P3oool0
00T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000L0oooo0P00000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH00`000000oooo0?ooo`0R0?ooo`002P3oool2
000000@0oooo0P0000030?ooo`<000001`3oool2000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP030000003oool0oooo0280oooo000O0?oo
o`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00<000000?oo
o`3oool08P3oool001l0oooo0P00000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP030000003oool0oooo0280oooo
000O0?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00<0
00000?ooo`3oool08P3oool001l0oooo0P00000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP030000003oool0oooo00/0000000<0
oooo0000001VIVH0201VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@3<c<`00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP030000003oool0oooo0280
oooo000O0?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00<000000?ooo`3oool08P3oool001l0oooo0P00000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool00000
2@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@3<c<`00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP030000003oool0
oooo0280oooo00090?ooo`<00000103oool2000000@0oooo0`0000060?oo
o`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00<000000?oo
o`3oool08P3oool000`0oooo00@000000?ooo`3oool000000P3oool01`00
0000oooo0?ooo`3oool000000?ooo`0000001P3oool2000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@3<c<`00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP030000003oool0oooo0280oooo000<
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0oooo
0`0000060?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002P0000020?ooo`030000003<c<`0c<c<00L0c<c<00<000000?ooo`00
00002P0000020?ooo`030000001VIVH0IVIV00L0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP030000003oool0oooo0280oooo000:0?ooo`8000000`3oool01000
0000oooo0?ooo`0000020?ooo`<000001`3oool2000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP030000003oool0oooo0280oooo000<0?oo
o`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?oo
o`0000070?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00<000000?ooo`3oool08P3oool000T0oooo0`0000040?ooo`8000000`3o
ool3000000L0oooo0P00000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3o
ool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP030000003oool0oooo0280oooo000O0?oo
o`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00<000000?oo
o`3oool08P3oool001l0oooo0P00000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@00000
0?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH00`000000oooo
0?ooo`0;000000030?ooo`000000c<c<00P0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo00/0
000000<0oooo0000001VIVH0201VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00<000000?ooo`3oool02`0000000`3o
ool0000006IVIP0806IVIP030000003oool0oooo0280oooo000O0?ooo`80
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo0000000906IVIP040000003o
ool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0IVIV00<000000?ooo`3o
ool08P3oool001l0oooo0P00000906IVIP040000003oool0oooo000000T0
IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@1VIVH00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0IVIV00@0
00000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@3<
c<`00`000000oooo0000000906IVIP030000003oool0oooo0280oooo000O
0?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo00000009
06IVIP040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0IVIV00<00000
0?ooo`3oool08P3oool000X0oooo0`0000030?ooo`800000103oool30000
00H0oooo0P00000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo
0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IVIP04
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@1VIVH00`00
0000oooo0?ooo`0R0?ooo`002`3oool01@000000oooo0?ooo`3oool00000
0080oooo00L000000?ooo`3oool0oooo0000003oool0000000H0oooo0P00
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000000906IV
IP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH0
10000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@1VIVH00`000000oooo0?oo
o`0R0?ooo`002@3oool400000080oooo00@000000?ooo`3oool000000`3o
ool3000000H0oooo0P00000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP03
0000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`00
0000oooo0000000:00000080oooo00<0000006IVIP1VIVH01`1VIVH00`00
0000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002P0000020?ooo`030000003<c<`0c<c<00L0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
0000000:00000080oooo00<0000006IVIP1VIVH01`1VIVH00`000000oooo
0000000:00000080oooo00<000000<c<c03<c<`01`3<c<`00`000000oooo
0000000:000002@0oooo00090?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool000000P3oool3000000L0oooo0P00000906IVIP040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo000000090<c<c0040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@1V
IVH00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002@3o
ool00`000000oooo000000030?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`0000001`3oool2000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@1VIVH010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0c<c<00@000000?ooo`3oool000002@1V
IVH00`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0030000003oool0oooo0280oooo000:0?ooo`800000103o
ool2000000<0oooo0`0000070?ooo`8000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0IVIV00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
06IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1V
IVH00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0IVIV00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00<000000?ooo`3oool08P3oool001l0oooo0P000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@1VIVH00`000000oooo000000090<c<c004
0000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`00000906IVIP030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@1VIVH00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R
0?ooo`007`3oool2000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`00000906IVIP030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0030000003oool0oooo0280oooo000O0?ooo`8000002@1VIVH010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV00@000000?oo
o`3oool000002@1VIVH00`000000oooo0000000906IVIP040000003oool0
oooo000000T0IVIV00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0IVIV
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00<000000?ooo`3oool08P3oool001l0oooo
0P00000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`00
00002@1VIVH010000000oooo0?ooo`00000906IVIP030000003oool00000
00T0IVIV00<000000?ooo`3oool02`0000000`3oool000000<c<c0080<c<
c0030000003oool0oooo00/0000000<0oooo0000001VIVH0201VIVH00`00
0000oooo0?ooo`0;000000030?ooo`000000c<c<00P0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool0
2`0000000`3oool000000<c<c0080<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`00
7`3oool2000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000
oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<000000?oo
o`0000002@1VIVH010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
000906IVIP040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0030000
003oool0oooo0280oooo000O0?ooo`8000002@1VIVH010000000oooo0?oo
o`00000906IVIP030000003oool0000000T0IVIV00@000000?ooo`3oool0
00002@1VIVH00`000000oooo0000000906IVIP040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0IVIV00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00<000000?ooo`3oool08P3oool001l0oooo0P000009
06IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@1V
IVH010000000oooo0?ooo`00000906IVIP030000003oool0000000T0IVIV
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@1VIVH01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R
0?ooo`007`3oool2000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0IVIV00<0
00000?ooo`0000002@1VIVH010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo0000000906IVIP040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0030000003oool0oooo0280oooo00090?ooo`<00000103oool2000000@0
oooo0`0000060?ooo`8000002@1VIVH010000000oooo0?ooo`00000906IV
IP030000003oool0000000T0IVIV00@000000?ooo`3oool000002@1VIVH0
0`000000oooo0000000906IVIP040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0IVIV00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00<000000?ooo`3oool08P3oool000`0oooo00@000000?ooo`3oool0
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000001P3oool2
000000T0IVIV00@000000?ooo`3oool000002@1VIVH00`000000oooo0000
000906IVIP040000003oool0oooo000000T0IVIV00<000000?ooo`000000
2@1VIVH010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000000906IV
IP040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0030000003oool0
oooo0280oooo000<0?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool0oooo0`0000060?ooo``000000P3oool00`000000IVIV06IV
IP0706IVIP030000003oool0000000X000000P3oool00`000000IVIV06IV
IP0706IVIP030000003oool0000000X000000P3oool00`000000c<c<0<c<
c0070<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo0000000:00000080oooo00<000000<c<c03<c<`0
1`3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00<000000?ooo`3oool08P3oool000T0oooo0`00
00030?ooo`040000003oool0oooo00000080oooo0`0000070?ooo`800000
2@3<c<`010000000oooo0?ooo`00000906IVIP030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@1VIVH00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool0
8P3oool000T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?oo
o`0000020?ooo`030000003oool0000000L0oooo0P0000090<c<c0040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`00000906IVIP030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002@3o
ool4000000<0oooo0P0000030?ooo`<000001`3oool2000000T0c<c<00@0
00000?ooo`3oool000002@1VIVH00`000000oooo000000090<c<c0040000
003oool0oooo000000T0IVIV00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0030000003oool0oooo0280oooo000O
0?ooo`8000002@3<c<`010000000oooo0?ooo`00000906IVIP030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@1VIVH00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<00000
0?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0oooo
000000T0IVIV00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
000906IVIP030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0
c<c<00@000000?ooo`3oool000002@1VIVH00`000000oooo000000090<c<
c0040000003oool0oooo000000T0IVIV00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo0280
oooo000O0?ooo`8000002@3<c<`00`000000oooo0?ooo`0;000000030?oo
o`000000c<c<00P0c<c<00<000000?ooo`3oool02`0000000`3oool00000
0<c<c0080<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<00000
0?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo0280
oooo000O0?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00<000000?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0030000003oool0
oooo0280oooo000:0?ooo`800000103oool2000000@0oooo0`0000060?oo
o`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<000000?oo
o`3oool08P3oool000T0oooo00@000000?ooo`3oool000000P3oool01000
0000oooo0?ooo`0000030?ooo`030000003oool0000000H0oooo0P000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R
0?ooo`002@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo000000<0oooo0`0000060?ooo`8000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00<000000?ooo`3oool08P3oool000T0oooo0`000003
0?ooo`040000003oool0oooo00000080oooo0`0000070?ooo`8000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool08P3o
ool000T0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0000000L0oooo0P0000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002P3oool3
000000<0oooo0P0000030?ooo`<000001`3oool2000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0030000003oool0oooo0280oooo000O0?oo
o`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<000000?oo
o`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo0280oooo
000O0?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<0
00000?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool20000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo
0280oooo000O0?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00<000000?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002P3o
ool00`000000oooo0?ooo`030?ooo`800000103oool3000000H0oooo0P00
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`00`000000oooo0?oo
o`0R0?ooo`002P3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000<0oooo00<000000?ooo`0000001P3oool2000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0030000003oool0oooo0280oooo000;
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?oo
o`3oool3000000H0oooo0P0000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`00`000000oooo0?ooo`0R0?ooo`002`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`0000070?ooo`800000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool0
8P3oool000`0oooo00@000000?ooo`3oool000000P3oool01P000000oooo
0?ooo`000000oooo000000L0oooo0P0000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002@3oool4000000<0
oooo0P0000030?ooo`<000001`3oool2000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0030000003oool0oooo0280oooo000O0?ooo`800000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool0
8P3oool001l0oooo0P0000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0030000003oool0oooo0280oooo000O0?oo
o`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<000000?oo
o`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo0280oooo
000O0?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<0
00000?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002P3oool20000
00@0oooo0P0000040?ooo`<000001P3oool2000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0030000003oool0oooo0280oooo00090?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo000000060?ooo`8000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00<000000?ooo`3oool08P3oool000T0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`<000001P3o
ool2000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0030000003o
ool0oooo0280oooo000:0?ooo`8000000`3oool010000000oooo0?ooo`00
00020?ooo`<000001`3oool2000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0030000003oool0oooo0280oooo00090?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo
000000070?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00<000000?ooo`3oool08P3oool000X0oooo0P0000040?ooo`8000000`3o
ool3000000L0oooo0P0000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0030000003oool0oooo0280oooo000O0?oo
o`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<000000?oo
o`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool2000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo0280oooo
000O0?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00<0
00000?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`007`3oool20000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0030000003oool0oooo
0280oooo000O0?ooo`8000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00<000000?ooo`3oool08P3oool001l0oooo0P0000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`002@3o
ool3000000@0oooo0P0000040?ooo`<000001P3oool2000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0030000003oool0oooo0280oooo000<
0?ooo`040000003oool0oooo00000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000H0oooo0P0000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`00`000000oooo0?ooo`0R0?ooo`002P3oool300000080oooo
00@000000?ooo`3oool000000`3oool3000000H0oooo0P0000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`00
2@3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo0000
0080oooo0`0000070?ooo`8000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00<000000?ooo`3oool08P3oool000T0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0
000000L0oooo0P0000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
0`000000oooo0?ooo`0R0?ooo`002P3oool2000000@0oooo0P0000030?oo
o`<000001`3oool2000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`000000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0030000003oool0oooo0280oooo000O0?ooo`8000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00<000000?ooo`3oool08P3oool001l0oooo
0P0000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`00`000000oooo
0?ooo`0R0?ooo`007`3oool2000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?oo
o`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0
000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo0000
00090<c<c0030000003oool0oooo0280oooo000O0?ooo`8000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool08P3oool0
01l0oooo0P0000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`00`00
0000oooo0?ooo`0R0?ooo`007`3oool2000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool00000
2@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0
c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<
c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`0
0`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<0
00000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000
003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000
oooo000000090<c<c0030000003oool0oooo0280oooo000O0?ooo`800000
2@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0
c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<
c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`0
10000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@0
00000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000
003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000
oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?oo
o`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool0
8P3oool001l0oooo0P0000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003o
ool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo
000000090<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`00
00002@3<c<`010000000oooo0?ooo`0000090<c<c0030000003oool00000
00T0c<c<00@000000?ooo`3oool000002@3<c<`00`000000oooo00000009
0<c<c0040000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<
c<`00`000000oooo0?ooo`0R0?ooo`000`3oool3000000@0oooo0P000004
0?ooo`800000103oool3000000H0oooo0P0000090<c<c0040000003oool0
oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?oo
o`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool0
00002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo0000
00T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`000009
0<c<c0030000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<
c<`00`000000oooo000000090<c<c0040000003oool0oooo000000T0c<c<
00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`0000090<c<c003
0000003oool0000000T0c<c<00@000000?ooo`3oool000002@3<c<`00`00
0000oooo000000090<c<c0040000003oool0oooo000000T0c<c<00<00000
0?ooo`0000002@3<c<`00`000000oooo0?ooo`0R0?ooo`00103oool00`00
0000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo000000060?ooo`8000002@3<
c<`010000000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<
00@000000?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c004
0000003oool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`01000
0000oooo0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@00000
0?ooo`3oool000002@3<c<`00`000000oooo000000090<c<c0040000003o
ool0oooo000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo
0?ooo`0000090<c<c0030000003oool0000000T0c<c<00@000000?ooo`3o
ool000002@3<c<`00`000000oooo000000090<c<c0040000003oool0oooo
000000T0c<c<00<000000?ooo`0000002@3<c<`010000000oooo0?ooo`00
00090<c<c0030000003oool0000000T0c<c<00<000000?ooo`3oool08P3o
ool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000<0oooo0`0000060?ooo``00000
0P3oool;000000030?ooo`000000000000T000000P3oool;000000030?oo
o`000000000000T000000P3oool;000000030?ooo`000000000000T00000
0P3oool;000000030?ooo`000000000000T000000P3oool;000000030?oo
o`000000000000T000000P3oool;000000030?ooo`000000000000T00000
0P3oool;000000030?ooo`000000000000T000000P3oool;000000030?oo
o`000000000000T000000P3oool;000000030?ooo`000000000000T00000
0P3oool;000000030?ooo`000000000000T00000903oool000@0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo0`0000070?ooo`030000003oool0oooo0?l0
oooo:03oool000@0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`0000001`3oool00`000000oooo0?ooo`3o0?ooobP0oooo00030?ooo`80
00001@3oool2000000@0oooo0P0000030?ooo`<000001`3oool00`000000
oooo0?ooo`3o0?ooobP0oooo003o0?ooodX0oooo003o0?ooodX0oooo003o
0?ooodX0oooo003o0?ooodX0oooo003o0?ooodX0oooo003o0?ooodX0oooo
003o0?ooodX0oooo000^0?ooo`<00000o`3ooolI0?ooo`00;`3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo000<0?ooo`D0000000<0oooo00000000
00000P000000103oool000000000003oool2000000030?ooo`0000000000
008000000P3oool500000080oooo0`0000030?ooo`030000003oool0oooo
0?l0oooo5`3oool000/0oooo00L000000?ooo`3oool0oooo0000003oool0
000000D0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`3o0?oooaL0oooo000;0?ooo`060000003o
ool0oooo0?ooo`000000oooo1@0000001@3oool000000?ooo`3oool00000
0080oooo100000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0000003o0?oooaP0oooo000;0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003oool0
00000080oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000o`3o
oolH0?ooo`00303oool400000080oooo0`0000000`3oool0000000000003
00000080oooo100000030?ooo`8000000`3oool4000000040?ooo`000000
00000?ooo`800000o`3ooolG0?ooo`003`3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo0?l0oooo7@3oool000h0oooo0P00000E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolM0?oo
o`00o`3ooom:0?ooo`00o`3ooom:0?ooo`00\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->False,
  ImageSize->{329.375, 177.75},
  ImageMargins->{{85, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.1.5  GraphicsArray", "Subsection",
  CellTags->"C.1"],

Cell[TextData[{
  "The GraphicsArray function is used when you want to display a table of \
complete graphics. The syntax is Show[GraphicsArray[",
  StyleBox["matrixOfGraphics", "IT"],
  "]]. Here is a simple example, combining two of the graphics we've already \
created. Notice that we use the DisplayFunction option to suppress the \
graphics from being displayed until the very end."
}], "Text",
  CellTags->{"i:17", "C.1"}],

Cell[CellGroupData[{

Cell[TextData[
"g1 = MultipleListPlot[resources[1], resources[2],\n  AxesLabel \[Rule] \
{\"time\", \"values\"},\n  SymbolShape \[Rule] None,\n  PlotJoined \[Rule] \
True,\n  PlotLegend \[Rule] {\"Type a\", \"Type b\"},\n  LegendOrientation \
\[Rule] Horizontal,\n  LegendSize \[Rule] {1, 0.3},\n  LegendPosition \[Rule] \
{-1, -0.8},\n  LegendShadow \[Rule] {-0.05, -0.07},\n  DisplayFunction \
\[Rule] Identity];\ng2 = PercentileBarChart[group1, group2,\n  PlotLabel \
\[Rule] \"Density vs. Time\", \n  Ticks \[Rule] None,\n  BarStyle \[Rule] \
{GrayLevel[0.4], GrayLevel[0.8]},\n  DisplayFunction \[Rule] Identity];\n\
Show[GraphicsArray[{g1, g2}],\n  DisplayFunction \[Rule] $DisplayFunction];"],
   "Input",
  CellTags->"C.1"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006U0000Sb000`400?l0
0000o`00003oo`3ooonV0?ooo`00o`3ooonV0?ooo`00o`3ooonV0?ooo`00
o`3ooonV0?ooo`00f`3oool00`000000oooo0?ooo`370?ooo`00f`3oool0
0`000000oooo0?ooo`370?ooo`00f`3oool00`000000oooo0?ooo`370?oo
o`00f`3ooono000000/0oooo000>0?oooeT00000M03oool2000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000706IVIP8000001`1VIVH2000000L0IVIV0P00000706IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000706IVIP030000003oool0oooo00T0oooo000>0?oooeT00000M03o
ool2000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000706IVIP8000001`1VIVH2000000L0IVIV0P00
000706IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000706IVIP030000003oool0oooo00T0oooo000>
0?oooeT00000M03oool2000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000706IVIP8000001`1VIVH2
000000L0IVIV0P00000706IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000706IVIP030000003oool0
oooo00T0oooo000>0?oooeT00000M03oool2000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IV
IP8000001`1VIVH2000000L0IVIV0P00000706IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IV
IP030000003oool0oooo00T0oooo000>0?oooeT00000M03oool2000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000706IVIP8000001`1VIVH2000000L0IVIV0P00000706IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000706IVIP030000003oool0oooo00T0oooo000>0?oooeh00000
K`3oool2000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000706IVIP8000001`1VIVH2000000L0IVIV
0P00000706IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000706IVIP030000003oool0oooo00T0oooo
000>0?ooo`D00000F03oool00`000000oooo0?ooo`1]0?ooo`8000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000L0IVIV00<000000?ooo`3oool02@3oool000h0oooo1@00001H
0?ooo`030000003oool0oooo06d0oooo0P00000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH2
000000L0IVIV0P00000706IVIP8000001`1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH0
0`000000oooo0?ooo`090?ooo`003P3oool5000005P0oooo00<000000?oo
o`3oool0K@3oool2000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000706IVIP8000001`1VIVH20000
00L0IVIV0P00000706IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000706IVIP030000003oool0oooo
00T0oooo000>0?ooo`D00000F03oool00`000000oooo0?ooo`1]0?ooo`80
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool000h0oooo
1@00001H0?ooo`030000003oool0oooo06d0oooo0P00000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1`1VIVH2000000L0IVIV0P00000706IVIP8000001`1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1`1VIVH00`000000oooo0?ooo`090?ooo`003P3oool5000005P0oooo00<0
00000?ooo`3oool0K@3oool2000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000706IVIP8000001`1V
IVH2000000L0IVIV0P00000706IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000706IVIP030000003o
ool0oooo00T0oooo000>0?ooo`D00000F03oool00`000000oooo0?ooo`1]
0?ooo`8000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2
000000L0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool0
00h0oooo1@0000060?ooob@00000103oool200000080oooo00<000000?oo
o`3oool00P0000020?ooo`030000003oool0oooo008000000P3oool00`00
0000oooo0?ooo`0200000080oooo00<000000?ooo`3oool00P0000020?oo
o`030000003oool0oooo008000001@3oool00`000000oooo0?ooo`1]0?oo
o`8000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH20000
00L0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool000h0
oooo1@00001H0?ooo`030000003oool0oooo06d0oooo0P00000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001`1VIVH2000000L0IVIV0P00000706IVIP8000001`1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001`1VIVH00`000000oooo0?ooo`090?ooo`003P3oool5000005P0oooo
00<000000?ooo`3oool0K@3oool2000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IVIP800000
1`1VIVH2000000L0IVIV0P00000706IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IVIP030000
003oool0oooo00T0oooo000>0?ooo`D00000F03oool00`000000oooo0?oo
o`1]0?ooo`8000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000L0IVIV0P00000706IVIP8000001`1V
IVH2000000L0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000L0IVIV00<000000?ooo`3oool02@3o
ool000h0oooo1@00001H0?ooo`030000003oool0oooo06d0oooo0P000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001`1VIVH2000000L0IVIV0P00000706IVIP8000001`1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001`1VIVH00`000000oooo0?ooo`090?ooo`003P3oool50000
05P0oooo00<000000?ooo`3oool0K@3oool2000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IV
IP8000001`1VIVH2000000L0IVIV0P00000706IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IV
IP030000003oool0oooo00T0oooo000>0?ooo`D00000F03oool00`000000
oooo0?ooo`1]0?ooo`8000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000L0IVIV0P00000706IVIP80
00001`1VIVH2000000L0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000L0IVIV00<000000?ooo`3o
ool02@3oool000h0oooo1@00001H0?ooo`030000003oool0oooo06d0oooo
0P00000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001`1VIVH2000000L0IVIV0P00000706IVIP800000
1`1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001`1VIVH00`000000oooo0?ooo`090?ooo`003P3o
ool5000000/0oooo0`0000030?ooo`@000007`3oool3000000<0oooo1000
000J0?ooo`030000003oool0oooo06d0oooo0P00000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001`1V
IVH2000000L0IVIV0P00000706IVIP8000001`1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001`1V
IVH00`000000oooo0?ooo`090?ooo`003P3oool5000000`0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1]
0?ooo`8000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2
000000L0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool0
00h0oooo1@0000070?ooo`<000000`3oool00`000000oooo0?ooo`020?oo
o`@000000`3oool4000000L0oooo1@0000070?ooo`<000000`3oool00`00
0000oooo0?ooo`020?ooo`@000000`3oool4000000L0oooo100000070?oo
o`030000003oool0oooo06d0oooo0P00000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH20000
00L0IVIV0P00000706IVIP8000001`1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH00`00
0000oooo0?ooo`090?ooo`003P3oool5000000P0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?oo
o`000000oooo0000000;0?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000;0?ooo`050000003oool0oooo0?oo
o`0000001P3oool00`000000oooo0?ooo`1]0?ooo`8000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00L0IVIV00<000000?ooo`3oool02@3oool000h0oooo1@0000080?ooo`07
0000003oool0oooo0?ooo`000000oooo000000030?ooo`060000003oool0
oooo0?ooo`000000oooo1@0000070?ooo`@000002@3oool01`000000oooo
0?ooo`3oool000000?ooo`0000000`3oool01P000000oooo0?ooo`3oool0
00000?ooo`D000001`3oool01@000000oooo0?ooo`3oool0000000H0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0h0?ooo`800000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000L0IVIV00<000000?ooo`3oool02@3oool00180oooo00<0
00000?ooo`3oool0103oool02@000000oooo0000003oool000000?ooo`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01@3o
ool02@000000oooo0000003oool000000?ooo`000000oooo000000030?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`030000003o
ool0oooo00D0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000
003oool0oooo0300oooo00<000000?ooo`000000>P3oool2000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000706IVIP8000001`1VIVH2000000L0IVIV0P00000706IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo
0000000706IVIP030000003oool0oooo00T0oooo000B0?ooo`030000003o
ool0oooo00@0oooo00@000000?ooo`000000oooo0`000000103oool00000
0000003oool5000000<0oooo0`0000090?ooo`<000001`3oool010000000
oooo0000003oool3000000040?ooo`00000000000?ooo`D000000`3oool3
000000P0oooo100000070?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool00`3oool010000000oooo0?ooo`00000i0?ooo`8000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<0
00000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003o
ool0000000L0IVIV00<000000?ooo`3oool02@3oool00180oooo00<00000
0?ooo`3oool0103oool5000002@0oooo1@00000I0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0:03oool00`000000oooo00000006
0?ooo`030000003oool0000003T0oooo0P00000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH2
000000L0IVIV0P00000706IVIP8000001`1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000L0000000<0oooo
0000001VIVH01@1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH0
0`000000oooo0?ooo`090?ooo`004P3oool00`000000oooo0?ooo`1:0?oo
o`8000002P3oool00`000000oooo0?ooo`0W0?ooo`@000001P3oool20000
03X0oooo0P00000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001`1VIVH2000000L0IVIV0P00000706IV
IP8000001`1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0c<c<00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001`1VIVH00`000000oooo0?ooo`090?oo
o`004P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02L0
oooo100000040?ooo`040000003oool0oooo000003X0oooo0P00000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001`1VIVH2000000L0IVIV0P00000706IVIP8000001`1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0c<c<00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001`1VIVH00`000000oooo0?ooo`090?ooo`004P3ooomJ00000140
oooo00<000000?ooo`3oool05@3oool2000000030?ooo`000000oooo00<0
oooo0P00000l0?ooo`8000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000L0IVIV0P00000706IVIP80
00001`1VIVH2000000L0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo000000060<c<c0030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000L0IVIV00<000000?ooo`3o
ool02@3oool001`0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo04h0oooo00@000000?ooo`3oool0
0000503oool200000080oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0i0?ooo`8000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000L0IVIV0P00000706IVIP80
00001`1VIVH2000000L0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo000000060<c<c0030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo0000000606IVIP030000003oool0000000L0IVIV00<000000?ooo`3o
ool02@3oool001T0oooo100000080?ooo`@000000`3oool00`000000oooo
0?ooo`1>0?ooo`040000003oool0oooo000001@0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo03T0oooo0P00000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001`1VIVH2000000L0IVIV0P00000706IVIP8000001`1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo00000007000000030?ooo`000000c<c<
00D0c<c<00<000000?ooo`0000001`0000000`3oool0000006IVIP0506IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001`1VIVH00`000000oooo0?ooo`090?ooo`00;03oool00`000000
oooo0?ooo`1<0?ooo`030000003oool000000080oooo0P00000B0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000m0?oo
o`8000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH20000
00L0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool002`0
oooo00<000000?ooo`3oool0C03oool010000000oooo0000003oool30000
0180oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000003d0oooo0P00000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001`1VIVH2000000L0IVIV0P000007
06IVIP8000001`1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001`1VIVH00`000000oooo0?ooo`09
0?ooo`00;03oool00`000000oooo0?ooo`1<0?ooo`<0000000@0oooo0000
0000000000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo03l0oooo0P00000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001`1VIVH2000000L0IVIV0P000007
06IVIP8000001`1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo0000000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001`1VIVH00`000000oooo0?ooo`09
0?ooo`00;03oool00`000000oooo0?ooo`1;0?ooo`<0000000<0oooo0000
000000000P00000B0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0g0?ooo`8000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00L0IVIV00<000000?ooo`3oool02@3oool002`0oooo00<000000?ooo`3o
ool0B`3oool3000000050?ooo`00000000000?ooo`0000004P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000000<0oooo0P00000i0?oo
o`8000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH20000
00L0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool002`0
oooo00<000000?ooo`3oool0B`3oool010000000oooo0000003oool20000
00030?ooo`000000oooo0140oooo00<000000?ooo`3oool00`3oool00`00
0000oooo000000030?ooo`800000>@3oool2000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000706IV
IP8000001`1VIVH2000000L0IVIV0P00000706IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo000000070000
00030?ooo`000000c<c<00D0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000L0000000<0oooo0000
001VIVH01@1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001`0000000`3oool0000006IVIP0606IV
IP030000003oool0oooo00T0oooo000/0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool2000003T0
oooo0P00000606IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001`1VIVH2000000L0IVIV0P00000706IVIP80
00001`1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0IVIV00<000000?ooo`00
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
c<c<00<000000?ooo`0000001`1VIVH00`000000oooo0?ooo`090?ooo`00
9@3oool3000000@0oooo00<000000?ooo`3oool0BP3oool2000000030?oo
o`000000oooo00<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo0P00000i0?ooo`800000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo000000060<c<c0030000
003oool0000000L0IVIV00<000000?ooo`3oool02@3oool002P0oooo00D0
00000?ooo`3oool0oooo0000001;0?ooo`<0000000<0oooo0000003oool0
0`3oool00`000000oooo0000000@0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0i0?ooo`800000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001P1VIVH00`000000oooo000000060<c<c0030000
003oool0000000L0IVIV00<000000?ooo`3oool02@3oool001l0oooo1@00
00040?ooo`040000003oool0oooo0?ooo`800000:P3oool2000001h0oooo
0`0000060?ooo`<000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`80
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo000000060<c<c003
0000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool002D0oooo
0`0000040?ooo`030000003oool0oooo04L0oooo0`0000000`3oool00000
0?ooo`060?ooo`8000002P3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`80
00001P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000L0IVIV0P00000706IVIP8000001`1VIVH2000000L0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo0000000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo000000060<c<c003
0000003oool0000000L0IVIV00<000000?ooo`3oool02@3oool002D0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo01`0oooo0`0000000`3oool000000?ooo`060?ooo`800000
2@3oool200000080oooo00<000000?ooo`0000001`3oool01@000000oooo
0?ooo`3oool0000003/0oooo0P00000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001`1VIVH;000000L0
IVIV0P00000706IVIP030000003oool0000000H0IVIV00<000000?ooo`00
00001`0000000`3oool000000<c<c0050<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001`0000000`3oool0
000006IVIP0506IVIP030000003oool0000000L0000000<0oooo0000003<
c<`01@3<c<`00`000000oooo00000008000000/0oooo000U0?ooo`@00000
0`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01X0oooo
0`00000:0?ooo`030000003oool0oooo00H0oooo0`0000020?ooo`030000
003oool0000000H0oooo0P0000030?ooo`030000003oool0oooo03T0oooo
0P00000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001`1VIVH2000000L0c<c<0P00000706IVIP800000
1`1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P1VIVH00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`090?ooo`00;03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo01/0oooo0P00
000;0?ooo`8000001`3oool300000080oooo00<000000?ooo`0000001P3o
ool200000080oooo0P00000k0?ooo`8000001P1VIVH00`000000oooo0000
000606IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo0000000606IVIP030000003oool0000000L0IVIV0P00
00070<c<c08000001`1VIVH2000000L0IVIV00<000000?ooo`0000001P1V
IVH00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0IVIV00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000L0c<c<00<0
00000?ooo`3oool02@3oool002`0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0L0?ooo`8000002`3oool2000000L0oooo00<00000
0?ooo`0000000P3oool00`000000oooo000000080?ooo`030000003oool0
000003`0oooo0P00000606IVIP030000003oool0000000H0IVIV00<00000
0?ooo`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0IVIV00<000000?ooo`0000001`1VIVH2000000L0c<c<0P000007
06IVIP8000001`1VIVH00`000000oooo0000000606IVIP030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P1VIVH00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`09
0?ooo`00;03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00D0oooo0P0000000`3oool000000?ooo`0J0?ooo`030000003oool0oooo
00X0oooo0P0000070?ooo`080000003oool0oooo0000003oool000000?oo
o`0000050?ooo`060000003oool0oooo0000003oool00000?03oool20000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000706IVIP8000001`3<c<`2000000L0IVIV0P00000706IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000000606IV
IP030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000070<c<c0030000003oool0oooo00T0oooo000/0?ooo`03
0000003oool0oooo02/0oooo00H000000?ooo`00000000000?ooo`00000E
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`02000000030?ooo`000000000000H0oooo00<00000
0?ooo`0000000P00000l0?ooo`8000001P1VIVH00`000000oooo00000006
06IVIP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo0000000606IVIP030000003oool0000000L0IVIV0P000007
0<c<c08000001`1VIVH2000000L0IVIV00<000000?ooo`0000001P1VIVH0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0IVIV00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000L0c<c<00<00000
0?ooo`3oool02@3oool002`0oooo00<000000?ooo`3oool0;03oool30000
00030?ooo`000000oooo01@0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080000000<0oooo0000
000000001P3oool00`000000oooo0?ooo`02000003`0oooo0P00000606IV
IP030000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`00
0000oooo0000000606IVIP030000003oool0000000H0IVIV00<000000?oo
o`0000002@0000070<c<c0/000001`1VIVH00`000000oooo000000070000
00030?ooo`000000c<c<00D0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001`0000000`3oool000000<c<c0050<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`00
0000oooo0?ooo`090?ooo`00;03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo01T0oooo0P0000030?ooo`8000001`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`020?ooo`<000000P3oool200000003
0?ooo`000000000004L0oooo0P00000606IVIP030000003oool0000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001`3<c<`2000000L0
c<c<0P0000070<c<c08000001`1VIVH00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000
oooo0?ooo`090?ooo`00;03oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01P0oooo0P00000:0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00P3oool2000000<0oooo
0P0000000`3oool00000000000040?ooo`030000003oool0oooo0400oooo
0P00000606IVIP030000003oool0000000H0IVIV00<000000?ooo`000000
1P1VIVH00`000000oooo0000000606IVIP030000003oool0000000H0IVIV
00<000000?ooo`0000001`3<c<`2000000L0c<c<0P0000070<c<c0800000
1`1VIVH00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`090?ooo`006@3o
ool4000000<0oooo0P0000030?ooo`<00000103oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool010000000oooo0?oo
o`3oool3000000<0oooo00@000000?ooo`3oool00000B03oool2000000H0
IVIV00<000000?ooo`0000001P1VIVH00`000000oooo0000000606IVIP03
0000003oool0000000H0IVIV00<000000?ooo`0000001P1VIVH00`000000
oooo000000070<c<c08000001`3<c<`2000000L0c<c<0P00000706IVIP03
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c0030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo00<0oooo0P0000060?ooo`050000003oool0oooo0?ooo`00
00008`3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0
oooo00@000000?ooo`3oool0oooo0P0000040?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0@03oool2000000H0IVIV00<000000?oo
o`0000001P1VIVH00`000000oooo0000000606IVIP030000003oool00000
00H0IVIV00<000000?ooo`0000001P1VIVH00`000000oooo000000070<c<
c08000001`3<c<`2000000L0c<c<0P00000706IVIP030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<
c0030000003oool0oooo00T0oooo000C0?ooo`D000000`3oool00`000000
oooo0?ooo`0:0?ooo`040000003oool0oooo0?ooo`8000001@3oool20000
01P0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000>
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00d0oooo0P0000020?ooo`8000003@3o
ool00`000000oooo0?ooo`100?ooo`T0000000<0oooo0000001VIVH01@1V
IVH00`000000oooo00000007000000030?ooo`000000IVIV00D0IVIV00<0
00000?ooo`0000001`0000000`3oool000000<c<c0060<c<c08000001`3<
c<`2000000L0c<c<2P0000000`3oool000000<c<c0050<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo0?oo
o`090?ooo`00703oool00`000000oooo0?ooo`060?ooo`<00000103oool0
0`000000oooo0?ooo`020?ooo`030000003oool0000001T0oooo0P000004
0?ooo`030000003oool0oooo00X0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000@0oooo00D000000?ooo`3oool0
oooo0000000@0?ooo`8000000P3oool00`000000oooo0?ooo`1?0?ooo`80
00001P3<c<`00`000000oooo0000000606IVIP030000003oool0000000H0
c<c<00<000000?ooo`0000001P1VIVH00`000000oooo000000060<c<c003
0000003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000L0c<c<00<000000?ooo`3oool02@3oool001T0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo01h0oooo0P0000040?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`05
0000003oool0oooo0?ooo`0000004@3oool010000000oooo0?ooo`000009
0?ooo`800000AP3oool2000000H0c<c<00<000000?ooo`0000001P1VIVH0
0`000000oooo000000060<c<c0030000003oool0000000H0IVIV00<00000
0?ooo`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`2
000000L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000070<c<c0030000003oool0
oooo00T0oooo000J0?ooo`8000002@3oool4000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00`0oooo00@000000?ooo`3oool000004@3oool010000000oooo0?ooo`00
00090?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`8000001P3<
c<`00`000000oooo0000000606IVIP030000003oool0000000H0c<c<00<0
00000?ooo`0000001P1VIVH00`000000oooo000000060<c<c0030000003o
ool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000L0c<c<00<000000?ooo`3oool02@3oool002`0oooo00X00000
0?ooo`3oool000000?ooo`000000oooo0000003oool00000103oool30000
00@0oooo0P0000080?ooo`<00000103oool3000000<0oooo0P0000040?oo
o`<0000000<0oooo0000003oool00`0000040?ooo`8000001@3oool40000
00<0oooo0P0000040?ooo`800000103oool5000000040?ooo`0000000000
000000<0oooo1@0000000`3oool000000?ooo`03000000@0oooo0P000004
0?ooo`800000<`3oool2000000H0c<c<00<000000?ooo`0000001P1VIVH0
0`000000oooo000000060<c<c0030000003oool0000000H0IVIV00<00000
0?ooo`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`2
000000L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000070<c<c0030000003oool0
oooo00T0oooo000/0?ooo`050000003oool0oooo0000003oool00`000000
0`3oool000000?ooo`060?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0103oool3000000@0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00D0
oooo0P0000001@3oool000000000003oool0000000D0oooo0P0000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000103o
ool3000000D0oooo00<000000?ooo`3oool0100000070?ooo`040000003o
ool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0`0?ooo`8000001P3<c<`00`000000oooo0000000606IVIP03
0000003oool0000000H0c<c<00<000000?ooo`0000001P1VIVH00`000000
oooo000000060<c<c0030000003oool0000000L0c<c<0P0000070<c<c080
00001`3<c<`2000000L0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000L0c<c<00<000000?ooo`3o
ool02@3oool002`0oooo00<000000?ooo`3oool03P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0oooo00@0oooo0`0000040?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool2000000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`05
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`0`0?ooo`8000001P3<c<`00`000000oooo
00000007000000030?ooo`000000c<c<00D0c<c<00<000000?ooo`000000
1`0000000`3oool000000<c<c0050<c<c0030000003oool0000000L0c<c<
0P0000070<c<c08000001`3<c<`2000000L0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000L0c<c<
00<000000?ooo`3oool02@3oool002`0oooo00D000000?ooo`3oool0oooo
000000090?ooo`<000000`3oool010000000oooo0?ooo`0000050?ooo`04
0000003oool0oooo000000@0oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo1000
00020?ooo`040000003oool00000000000<0oooo00D000000?ooo`000000
oooo000000020?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000001@3oool200000080oooo0`0000030?ooo`050000003oool0
oooo0000003oool00P0000020?ooo`8000000`3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo00000380oooo0P0000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001`3<c<`2000000L0c<c<0P0000070<c<c08000001`3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001`3<c<`00`000000oooo0?ooo`090?ooo`00;03oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00`3oool010000000oooo0?ooo`0000030?ooo`040000003oool00000
0?ooo`800000103oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`030?ooo`@000000`3oool3000000050?ooo`000000oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo
0?ooo`0000000P3oool010000000oooo0?ooo`0000050?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0<03oool2000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`20000
00L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000070<c<c0030000003oool0oooo
00T0oooo000/0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool4000000<0oooo0P0000020?ooo`800000103oool2000000D0
oooo0P0000040?ooo`800000103oool2000000@0oooo100000030?ooo`80
000000<0oooo0000003oool00`3oool2000000@0oooo0P0000040?ooo`80
00001@3oool2000000<0oooo100000020?ooo`<000001@3oool3000000@0
oooo0P0000040?ooo`800000<`3oool2000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c080
00001`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c003
0000003oool0oooo00T0oooo000/0?ooo`030000003oool0oooo00l0oooo
0`0000040?ooo`030000003oool0oooo008000009P3oool2000000030?oo
o`000000oooo0240oooo00<000000?ooo`3oool0@P3oool2000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c0030000003oool0oooo00T0oooo000/0?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`000000103oool00`000000oooo0000
0002000002L0oooo0`00000R0?ooo`030000003oool0oooo0180oooo0`00
00020?ooo`D0000000H0oooo0000003oool000000?ooo`0000020?ooo`@0
00006P3oool2000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`2000000L0
c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000070<c<c0030000003oool0oooo00T0
oooo000/0?ooo`<000001`3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool09P3oool010000000
oooo0?ooo`3oool3000000`0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0H0?ooo`040000003oool0oooo000000<0oooo00/00000
0?ooo`3oool0oooo0000003oool000000?ooo`000000oooo0000000N0?oo
o`8000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`20000
00L0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000L0c<c<00<000000?ooo`3oool02@3oool002T0
ooooO00000060?ooo`030000003oool0oooo00@0oooo00X000000?ooo`3o
ool0oooo0000003oool000000?ooo`000000oooo1@00000J0?ooo`800000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000L0c<c<00<000000?ooo`3oool02@3oool002`0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool00`000000oooo0?ooo`0200000080oooo00@000000?ooo`3o
ool0oooo0P0000020?ooo`050000003oool0oooo0?ooo`0000000`3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`00
00001P0000030?ooo`060000003oool0oooo0?ooo`000000oooo0`000002
0?ooo`8000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D0
00000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`00
00000`3oool01@000000oooo0?ooo`3oool0000000T0oooo00<000000?oo
o`3oool0103oool02`000000oooo0?ooo`3oool000000?ooo`000000oooo
0000003oool0000000<0oooo00<000000?ooo`3oool0603oool2000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c0030000003oool0oooo00T0oooo000/0?ooo`800000
4P3oool2000000H0oooo00<000000?ooo`3oool08@3oool2000000050?oo
o`00000000000?ooo`0000004`3oool00`000000oooo0?ooo`0Q0?ooo`@0
00000`3oool200000080oooo1P0000020?ooo`<000006`3oool2000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c0030000003oool0oooo00T0oooo000/0?ooo`800000
203oool00`000000oooo000000040?ooo`040000003oool0oooo0?ooo`80
000000<0oooo0000003oool0303oool00`000000oooo0?ooo`0G0?ooo`80
000000D0oooo000000000000oooo0000000;0?ooo`030000003oool00000
00h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0]0?oo
o`8000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`20000
00L0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000L0c<c<00<000000?ooo`3oool02@3oool002`0
oooo0`0000070?ooo`<000002@3oool2000000H0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0G0?ooo`040000003oool000000000
00X0oooo00<000000?ooo`0000000`3oool00`000000oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo0P0000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001`3<c<`2000000L0c<c<0P0000070<c<c08000001`3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001`3<c<`00`000000oooo0?ooo`090?ooo`00;03oool3000000d0
oooo00<000000?ooo`3oool00`3oool2000000H0oooo00<000000?ooo`3o
ool0103oool2000001T0oooo00@000000?ooo`0000000000103oool00`00
0000oooo0?ooo`030?ooo`<000001@3oool010000000oooo0?ooo`00001E
0?ooo`8000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`2
000000L0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000L0c<c<00<000000?ooo`3oool02@3oool0
02`0oooo0`00000B0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0103oool2000001T0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0<0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`000000C03oool2000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`2
000000L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000070<c<c0030000003oool0
oooo00T0oooo000/0?ooo`030000003oool0000000T0oooo00D000000?oo
o`000000oooo000000060?ooo`040000003oool0oooo000000<0oooo0P00
00050?ooo`800000603oool200000180oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0oooo00@0oooo0P00001;0?ooo`800000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000L0c<c<00<000000?ooo`3oool02@3oool002`0oooo00<0
00000?ooo`0000002@3oool3000000030?ooo`000000oooo00D0oooo00@0
00000?ooo`3oool000000`3oool3000000@0oooo0P00000H0?ooo`800000
3@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00800000
2P3oool2000004/0oooo0P0000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<
0P0000070<c<c08000001`3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo
0?ooo`090?ooo`00;03oool00`000000oooo0000000:0?ooo`030000003o
ool0oooo00T0oooo0`0000020?ooo`<00000103oool00`000000oooo0000
000D0?ooo`040000003oool00000000000P0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0000004d0oooo
0P0000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001`3<c<`2000000L0c<c<0P0000070<c<c0800000
1`3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`090?ooo`00;03o
ool010000000oooo0?ooo`00000C0?ooo`030000003oool0000000800000
0P3oool4000000<0oooo00<000000?ooo`0000004@3oool2000000030?oo
o`000000oooo00800000203oool00`000000oooo0?ooo`0@0?ooo`800000
0P3oool3000004d0oooo0P0000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<
0P0000070<c<c08000001`3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo
0?ooo`090?ooo`006@3oool4000000<0oooo0P0000030?ooo`<00000103o
ool010000000oooo0?ooo`00000C0?ooo`030000003oool0000000800000
0P3oool00`000000oooo0000000200000080oooo00<000000?ooo`000000
4@3oool4000000030?ooo`000000000000d0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`050?ooo`800000DP3oool2000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c0030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo00<0oooo0P0000060?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0000000D00000
00@0oooo00000000000000000P3oool00`000000oooo0000000?0?ooo`03
0000003oool0000000H000003@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0CP3oool2000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c0030000003oool0oooo00T0oooo000K0?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool0oooo0P0000000`3oool0
00000?ooo`0:0?ooo`030000003oool0oooo00D0oooo0`0000020?ooo`80
00000P3oool4000000040?ooo`000000oooo000000l0oooo100000000`3o
ool0000000000002000000T0oooo00<000000?ooo`3oool04@3oool20000
0500oooo0P0000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<0P0000070<c<
c08000001`3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`090?oo
o`00703oool00`000000oooo0?ooo`060?ooo`<00000103oool00`000000
oooo0?ooo`02000000X0oooo00<000000?ooo`3oool01@3oool300000080
oooo0P0000030?ooo`D0000000<0oooo0000003oool03P3oool400000080
oooo0`0000090?ooo`030000003oool0oooo0100oooo00<000000?ooo`00
0000D03oool2000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`2000000L0
c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000070<c<c0030000003oool0oooo00T0
oooo000I0?ooo`040000003oool0oooo000000P0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`02000000X0oooo0P0000060?ooo`80
00000`3oool2000000@0oooo100000000`3oool000000?ooo`0>0?ooo`@0
00000P3oool2000000d0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0000001@0?ooo`8000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000L0c<c<0P0000070<c<c080
00001`3<c<`2000000L0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000L0c<c<00<000000?ooo`3o
ool02@3oool001X0oooo0P0000090?ooo`@000000`3oool01P000000oooo
0?ooo`000000oooo000000P0oooo0`0000060?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00`3oool300000080oooo00<000000?oo
o`3oool03@3oool2000000030?ooo`000000oooo0080oooo00<000000?oo
o`3oool02P3oool200000100oooo0P00001@0?ooo`8000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00L0c<c<00<000000?ooo`3oool02@3oool002`0oooo00H000000?ooo`3o
ool000000?ooo`0000080?ooo`<000001@3oool00`000000oooo0?ooo`09
0?ooo`<000000P3oool00`000000oooo0?ooo`0<0?ooo`<000004@3oool2
00000140oooo00<000000?ooo`3oool0C`3oool2000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000007
0<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000007
0<c<c0030000003oool0oooo00T0oooo000/0?ooo`030000003oool0oooo
0080oooo0P0000070?ooo`030000003oool0000000D0oooo00<000000?oo
o`3oool02@3oool2000000<0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0000000A0?ooo`800000H`3oool2000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<
c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<
c0030000003oool0oooo00T0oooo000/0?ooo`030000003oool0oooo0080
oooo0P0000070?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0MP3oool2000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c080
00001`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c003
0000003oool0oooo00T0oooo000/0?ooo`030000003oool0oooo0080oooo
0`0000050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07H0
oooo0P0000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<0P0000070<c<c080
00001`3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`090?ooo`00
;03oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0MP3oool2000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c0030000003oool0oooo00T0oooo000/0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo00l0oooo0P00000<0?ooo`03
0000003oool0oooo07H0oooo0P0000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`2000000L0
c<c<0P0000070<c<c08000001`3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000
oooo0?ooo`090?ooo`00;03oool00`000000oooo0?ooo`040?ooo`800000
103oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00l0
oooo0P00000;0?ooo`030000003oool0oooo07L0oooo0P0000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001`3<c<`2000000L0c<c<0P0000070<c<c08000001`3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001`3<c<`00`000000oooo0?ooo`090?ooo`009@3oool3000000@0oooo
00<000000?ooo`3oool0103oool2000000@0oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0M`3oool2000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c080
00001`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c003
0000003oool0oooo00T0oooo000X0?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0M`3oool2000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<
c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<
c0030000003oool0oooo00T0oooo000X0?ooo`040000003oool0oooo0?oo
o`8000001P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D00000
0?ooo`3oool0oooo0000000C0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0M`3oool2000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<
c<`2000000L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000070<c<c0030000003o
ool0oooo00T0oooo000U0?ooo`<00000103oool00`000000oooo0?ooo`05
0?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?oo
o`3oool0000001<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1g0?ooo`8000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000L0c<c<0P0000070<c<c0800000
1`3<c<`2000000L0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000L0c<c<00<000000?ooo`3oool0
2@3oool002D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000800000103oool01@000000oooo0?oo
o`3oool0000001<0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`1g0?ooo`8000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000L0c<c<0P0000070<c<c0800000
1`3<c<`2000000L0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000L0c<c<00<000000?ooo`3oool0
2@3oool002D0oooo100000030?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`0000000P0000040?ooo`050000003oool0oooo0?ooo`000000
4`3oool00`000000oooo0?ooo`080?ooo`800000N@3oool2000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c0030000003oool0oooo00T0oooo000/0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`0000000P0000040?ooo`050000003o
ool0oooo0?ooo`0000004`3oool00`000000oooo0?ooo`080?ooo`800000
N@3oool2000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000070<c<c08000001`3<c<`2000000L0c<c<
0P0000070<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000070<c<c0030000003oool0oooo00T0oooo
000/0?ooo`030000003oool0oooo00D0oooo1@0000040?ooo`030000003o
ool0oooo008000004`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo0P00001i0?ooo`8000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000L0c<c<0P00
00070<c<c08000001`3<c<`2000000L0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000L0c<c<00<0
00000?ooo`3oool02@3oool002`0oooo00<000000?ooo`3oool01P3oool3
000000D0oooo00@000000?ooo`3oool00000503oool00`000000oooo0?oo
o`020?ooo`8000000P3oool010000000oooo00000000001i0?ooo`800000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000L0c<c<00<000000?ooo`3oool02@3oool002`0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0000001@0oooo00<000000?ooo`3oool00P3oool3000000050?ooo`00
000000000?ooo`000000N@3oool2000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c0800000
1`3<c<`2000000L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000070<c<c0030000
003oool0oooo00T0oooo000/0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`0000005@3oool010000000oooo0?ooo`3oool3000000030?oo
o`000000000007/0oooo0P0000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<
0P0000070<c<c08000001`3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo
0?ooo`090?ooo`00;03oool00`000000oooo0?ooo`0?0?ooo`<000005@3o
ool200000080oooo0`0000000`3oool000000000001k0?ooo`8000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000L0c<c<00<000000?ooo`3oool02@3oool002`0oooo00<00000
0?ooo`3oool03`3oool2000001H0oooo0`0000001@3oool000000?ooo`00
0000oooo00800000N`3oool2000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<
c<`2000000L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000070<c<c0030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo00<0oooo0P000003
0?ooo`<00000103oool00`000000oooo0?ooo`0?0?ooo`8000005P3oool3
000000050?ooo`000000oooo0000003oool00P00001k0?ooo`8000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000L0c<c<00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool00`3oool2000000H0oooo00D000000?ooo`3oool0oooo0000
000A0?ooo`030000003oool0oooo01D0oooo100000020?ooo`040000003o
ool00000000007/0oooo0P0000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<
0P0000070<c<c08000001`3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo
0?ooo`090?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo0?ooo`800000403oool00`000000oooo0?ooo`0E0?ooo`040000
003oool00000000000<0oooo00<000000?ooo`3oool0N`3oool2000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000070<c<c0030000003oool0oooo00T0oooo000K0?ooo`030000
003oool0oooo00L0oooo0`0000040?ooo`030000003oool0oooo02L0oooo
00@000000?ooo`00000000000`3oool00`000000oooo0?ooo`1k0?ooo`80
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000L0c<c<0P0000070<c<c08000001`3<c<`2000000L0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000
oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`00
00001P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0
c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c003
0000003oool0000000L0c<c<00<000000?ooo`3oool02@3oool001`0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0N`3oool2000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000060<c<c0030000003oool0000000H0c<c<00<000000?ooo`000000
1P3<c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<
00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000
003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo
000000070<c<c0030000003oool0oooo00T0oooo000I0?ooo`@00000203o
ool4000000<0oooo00<000000?ooo`3oool0[03oool2000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00070<c<c08000001`3<c<`2000000L0c<c<0P0000070<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00060<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<
c<`00`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<0
00000?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003o
ool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo0000
00070<c<c0030000003oool0oooo00T0oooo000/0?ooo`030000003oool0
oooo0:`0oooo0P0000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001`3<c<`2000000L0c<c<0P000007
0<c<c08000001`3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo00000006
0<c<c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`0
0`000000oooo000000060<c<c0030000003oool0000000H0c<c<00<00000
0?ooo`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool0
000000H0c<c<00<000000?ooo`0000001`3<c<`00`000000oooo0?ooo`09
0?ooo`00f`3oool2000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000070<c<c08000001`3<c<`20000
00L0c<c<0P0000070<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000060<c<c0030000003oool00000
00H0c<c<00<000000?ooo`0000001P3<c<`00`000000oooo000000060<c<
c0030000003oool0000000H0c<c<00<000000?ooo`0000001P3<c<`00`00
0000oooo000000060<c<c0030000003oool0000000H0c<c<00<000000?oo
o`0000001P3<c<`00`000000oooo000000070<c<c0030000003oool0oooo
00T0oooo003K0?ooo`T0000000<0oooo0000000000001P0000000`3oool0
000000000006000000030?ooo`000000000000H0000000<0oooo00000000
00001P0000000`3oool000000000000R000000030?ooo`000000000000H0
000000<0oooo0000000000001P0000000`3oool000000000000600000003
0?ooo`000000000000H0000000<0oooo0000000000001P0000000`3oool0
000000000006000000030?ooo`000000000000H0000000<0oooo00000000
00001P0000000`3oool0000000000006000000030?ooo`000000000000H0
000000<0oooo0000000000001P0000000`3oool0000000000007000000/0
oooo003K0?ooo`030000003oool0oooo0<L0oooo003K0?ooo`030000003o
ool0oooo0<L0oooo003K0?ooo`030000003oool0oooo0<L0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo000L0?ooo`8000000`3oool5000000030?oo
o`000000000000<0000000<0oooo0000000000000`0000020?ooo`@00000
00<0oooo0000000000000P00003o0?ooofT0oooo000L0?ooo`8000000`3o
ool010000000oooo0?ooo`0000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo
0>l0oooo0`00001d0?ooo`006`3oool010000000oooo0000000000020?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01@0000000`3oool000000000000200000?80oooo00<00000
0?ooo`3oool0L`3oool001/0oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool000000=00oooo
1@0000030?ooo`@0000000@0oooo000000000000oooo0P0000000`3oool0
00000000000200000080oooo1@0000020?ooo`<000000`3oool00`000000
oooo0?ooo`090?ooo`8000000`3oool4000000<0oooo0P00000:0?ooo`<0
00000P3oool5000000060?ooo`000000oooo0000003oool000000P3oool4
000003/0oooo000J0?ooo`8000000P3oool200000080oooo0`0000040?oo
o`030000003oool0oooo0080000000<0oooo0000000000000`3oool30000
0080oooo1000003>0?ooo`070000003oool0oooo0?ooo`000000oooo0000
00050?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080
oooo00<000000?ooo`3oool02@3oool2000000H0oooo00@000000?ooo`3o
ool0oooo0P00000;0?ooo`030000003oool0oooo00<0oooo00/000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo0000000o0?ooo`00
:@3oool00`000000oooo0?ooo`3O0?ooo`060000003oool0oooo0?ooo`00
0000oooo1@0000001@3oool000000?ooo`3oool000000080oooo10000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000090?ooo`040000003oool0000000000080oooo1000
000@0?ooo`030000003oool0oooo00<0oooo00X000000?ooo`3oool0oooo
0000003oool000000?ooo`000000oooo1@00000k0?ooo`009`3oool30000
0>40oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000090?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool03`3oool01@000000oooo0000003oool0000000<0oooo00/000000?oo
o`3oool0oooo0000003oool000000?ooo`000000oooo000000030?ooo`03
0000003oool0oooo03T0oooo003o0?ooo``0oooo00D000000?ooo`3oool0
oooo000000020?ooo`<0000000<0oooo0000000000000`0000020?ooo`@0
00000`3oool2000000<0oooo10000000103oool000000000003oool20000
00L0oooo0P0000020?ooo`80000000<0oooo0000000000000P00000>0?oo
o`050000003oool000000?ooo`0000000P3oool200000080oooo1P000002
0?ooo`<00000?03oool00?l0oooo2`3oool5000001/0oooo00<000000?oo
o`3oool09P3oool5000004d0oooo003o0?ooobH0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo04L0
oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?ooojH0oooo003o0?oo
ojH0oooo003o0?ooojH0oooo0000\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->False,
  ImageSize->{421, 143},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.1.6  Animation", "Subsection",
  CellTags->"C.1"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows us to generate a sequence of graphics and view it as a movie or \
animation. The most common way to animate graphics is simply to generate a \
sequence of graphics using Map or Table. When all the graphics have been \
generated, double-click on any one of them. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will then show them, one by one, in a flip-book style of animation. \
Unfortunately, having all these graphics collected in the same notebook can \
be very memory and/or disk intensive."
}], "Text",
  CellTags->{"i:18", "C.1"}],

Cell[TextData[{
  "With the new technology available in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 3 front end, we can generate these graphics one at a time, and \
have each new graphic displace the old one. In this way, we can generate the \
flip-book animation \"on the fly,\" without having to save these graphics to \
disk at all. The next section describes the front end programming techniques \
necessary to accomplish this."
}], "Text",
  CellTags->{"i:19", "C.1"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.2  Animations and Front End Programming", "Section",
  CellTags->"C.2"],

Cell[TextData[{
  "On all platforms, the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " version 3 front end supports a number of commands that enable a kernel \
program to do almost anything that a user would do in a typical session. From \
creating notebooks and cells to cutting and pasting to printing, the front \
end can do all these things under control of the kernel. This section gives a \
brief introduction to front end programming. For more information, refer to ",
  
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s online documentation."
}], "Text",
  CellTags->{"i:20", "C.2"}],

Cell[TextData[{
  "One of the major changes in version 3 of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is that notebooks are simply expressions. As a result, the kernel can be \
used to create and manipulate notebook expressions. In this section, we \
describe how to create and manipulate graphics cells from the kernel, \
allowing us to animate graphics on the fly. We generate them by creating a \
new notebook and then repeatedly replacing the contents of that notebook with \
the next graphics cell."
}], "Text",
  CellTags->"C.2"],

Cell[CellGroupData[{

Cell["Creating a New Notebook", "Subsubsection",
  CellTags->"C.2"],

Cell[TextData[{
  "The animation will run in a new window in the front end. To create a new \
notebook window, we can use the built-in function NotebookCreate. Evaluating \
the following input cell causes a new untitled notebook to open in the front \
end. We store the result in a variable (",
  StyleBox["nb", "IT"],
  ") so we can access that same notebook with subsequent kernel commands."
}], "Text",
  CellTags->{"i:21", "C.2"}],

Cell["nb = NotebookCreate[];", "Input",
  CellTags->"C.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Writing Information to a Notebook", "Subsubsection",
  CellTags->"C.2"],

Cell[TextData[{
  "There are a number of notebook functions that allow us to put information \
into a notebook: NotebookPut, NotebookApply, NotebookWrite, CellPrint, and so \
on. We use NotebookWrite, which typically takes two arguments. The first \
argument indicates to which open notebook you are writing, and the second \
argument indicates the expression to be written into that notebook. The \
expression is typically a string, a Cell, or a list of Cell expressions. We \
discuss Cell expressions shortly. This example writes a string corresponding \
to a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function call into the notebook."
}], "Text",
  CellTags->{"i:22", "C.2"}],

Cell[TextData[
"NotebookWrite[nb,\n             \"ListPlot[resources[1],PlotJoined \[Rule] \
True]\"];"], "Input",
  CellTags->"C.2"],

Cell[TextData[{
  "NotebookWrite can also be used to replace any selected cells with the data \
to be written. Thus, you can replace the contents of the notebook ",
  StyleBox["nb", "IT"],
  " by first selecting the entire notebook, which the following code does."
}], "Text",
  CellTags->{"i:23", "C.2"}],

Cell["SelectionMove[nb, All, Notebook]", "Input",
  CellTags->"C.2"],

Cell["\<\
After this selection, use NotebookWrite to write the new data in \
place of the old.\
\>", "Text",
  CellTags->"C.2"],

Cell["\<\
NotebookWrite[nb,
         \"MultipleListPlot[resources[1], resources[2]]\"];\
\>", "Input",
  CellTags->"C.2"],

Cell["\<\
Thus, we can get a simple flip-book animation of an input cell by \
replacing old input cells with new ones. Running this in the online version \
of the book, notice that there is never more than one cell in the animation \
notebook at a time.\
\>", "Text",
  CellTags->"C.2"],

Cell["\<\
nb2 = NotebookCreate[];
Table[SelectionMove[nb2, All, Notebook];
      NotebookWrite[nb2, ToString[i]], {i, 1, 10}];\
\>", "Input",
  CellTags->"C.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Graphics Cells", "Subsubsection",
  CellTags->"C.2"],

Cell[TextData[{
  "In order to use the preceding technique to animate graphics cells, we must \
first learn the syntax of such cells. These cells are ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expressions, just as notebooks are. A typical graphics cell has the \
following syntax."
}], "Text",
  CellTags->{"i:24", "C.2"}],

Cell[TextData[{
  "Cell[GraphicsData[\"PostScript\", ",
  StyleBox["postscriptText",
    FontSlant->"Italic"],
  "], \"Graphics\"]"
}], "Input",
  CellTags->"C.2"],

Cell[TextData[{
  "The variable ",
  StyleBox["postscriptText", "IT"],
  " refers to the PostScript that generates the picture, which is really just \
a long string. One way to access the PostScript text behind graphics is by \
changing the setting of the DisplayFunction option to the function \
DisplayString, which has the effect of returning just the PostScript string \
for the graphic. For example, here we generate the PostScript string \
corresponding to the RasterArray earlier in this appendix."
}], "Text",
  CellTags->{"i:25", "C.2"}],

Cell[TextData[
"society = {{0, 0, 0, {3, 1, 1, {2, 3, 4}, 4}}, {0, {3, 2, 1, {4, 3, 3}, 3}, \
{2, 3, 1, {4, 3, 4}, 1}, {2, 4, 1, {5, 3, 1}, 3}}, {0, {1, 5, 1, {5, 3, 5}, \
2}, 0, {1, 6, 0, {2, 1, 5}, 4}}, {0, 0, 0, {4, 7, 1, {4, 5, 5}, 3}}};\nstr = \
Show[Graphics[RasterArray[\n  Map[If[# === 0, GrayLevel[1], \
GrayLevel[#[[3]]/2]]&,\n      society, {2}]]],\n  Frame \[Rule] True,\n  \
AspectRatio \[Rule] Automatic,\n  DisplayFunction \[Rule] DisplayString];"], 
  "Input",
  CellTags->"C.2"],

Cell["\<\
Now that we have this string, we can plug it into the preceding \
format for graphics cells and write it into the notebook, replacing any cells \
that were in the notebook already.\
\>", "Text",
  CellTags->"C.2"],

Cell["\<\
nb = NotebookCreate[];
SelectionMove[nb, All, Notebook];
NotebookWrite[nb,
      Cell[GraphicsData[\"PostScript\", str], \"Graphics\"]];\
\>", "Input",
  CellTags->"C.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Subsubsection",
  CellTags->"C.2"],

Cell["\<\
Iterating this process, we can generate animations as graphics are \
generated, keeping only the last graphic that has been generated in this way. \
In the next section, we discuss how to add this capability into your \
simulations, so that your societies can be shown changing as the changes are \
taking place during the simulation run.\
\>", "Text",
  CellTags->"C.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.3  Simulations in Limited Memory", "Section",
  CellTags->"C.3"],

Cell["\<\
In this section, we introduce a custom function which can replace \
the Nest and NestList functions that allows us to focus on simulation results \
without a lot of worrying about how much memory the simulation will use. It \
also allows us to save information at various times during the simulation, as \
well as to view graphics during the simulation run. Most important, it does \
all this with as little change to the simulation program as possible.\
\>", 
  "Text",
  CellTags->{"i:38", "C.3"}],

Cell[CellGroupData[{

Cell["C.3.1  NestListEffects", "Subsection",
  CellTags->"C.3"],

Cell["\<\
Throughout the book, we use NestList to apply a model's rule sets \
iteratively. As a result, it returns a list of every lattice configuration of \
the simulation run. If we chose to use Nest instead of NestList, it would \
only return the last step in the simulation. This results in considerable \
savings in memory consumption.\
\>", "Text",
  CellTags->"C.3"],

Cell[TextData[{
  "To illustrate this, we use one of the programs from Chapter 5, the ",
  StyleBox["neighborhood", "IT"],
  " program, with both Nest and NestList. We call the version that uses \
NestList, ",
  StyleBox["neighborhoodNL", "IT"],
  ", and the program that uses Nest, ",
  StyleBox["neighborhoodN", "IT"],
  "."
}], "Text",
  CellTags->"C.3"],

Cell["\<\
neighborhoodNL[n_, p_, v_, w_, t_] := 
Module[  (* program goes here *)
  NestList[GN[walk, Moore[movestay, #]]&, society, t]]\
\>", "Input",
  CellTags->"C.3"],

Cell["\<\
neighborhoodN[n_, p_, v_, w_, t_] := 
Module[  (* program goes here *)
  Nest[GN[walk, Moore[movestay, #]]&, society, t]]\
\>", "Input",
  CellTags->"C.3"],

Cell["\<\
We can check how memory-intensive each of these functions is by \
using the built-in functions MemoryInUse and MaxMemoryUsed.\
\>", "Text",
  CellTags->{"i:26", "C.3"}],

Cell[CellGroupData[{

Cell["\<\
m1 = {MemoryInUse[], MaxMemoryUsed[]};
len = Length[Flatten[neighborhoodNL[20, 0.60, 1, 2, 1000]]];
m2 = {MemoryInUse[], MaxMemoryUsed[]};
{len, m2 - m1}\
\>", "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \({651651, {1688, 7798392}}\)], "Output",
  CellTags->"C.3"]
}, Open  ]],

Cell[TextData[{
  "We see that during the simulation, almost 8Mb of memory is consumed, \
although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " frees most of the memory when the simulation has completed. Compare this \
with the results from using Nest in a fresh kernel session."
}], "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{

Cell["\<\
m1 = {MemoryInUse[], MaxMemoryUsed[]};
len = Length[Flatten[neighborhoodN[20, 0.60, 1, 2, 1000]]];
m2 = {MemoryInUse[], MaxMemoryUsed[]};
{len, m2 - m1}\
\>", "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \({653, {1672, 81120}}\)], "Output",
  CellTags->"C.3"]
}, Open  ]],

Cell["\<\
So Nest uses slightly more than 81K or 0.08Mb of memory, a savings \
factor of nearly 100 over NestList.\
\>", "Text",
  CellTags->"C.3"],

Cell["\<\
Besides using Nest and NestList, there is a third possibility: \
NestListEffects. This function, defined at the end of this appendix, enables \
us to do two things: it allows us to specify what lattice configurations \
should be returned with greater flexibility than NestList or Nest; and it \
allows us to generate side effects during the course of the function \
application, such as printing the memory that is in use, or generating a \
graphic corresponding to the current lattice configuration. These two \
features are controlled through options to NestListEffects named ReturnValues \
and SideEffects, respectively.\
\>", "Text",
  CellTags->{"i:27", "C.3"}],

Cell[TextData[{
  "Instead of returning every element of NestList, you can return every ",
  StyleBox["k", "IT"],
  "th element by setting the ReturnValues option to {(#1 &), ",
  StyleBox["k", "IT"],
  "}. In order to return every ",
  StyleBox["k", "IT"],
  "th element after applying the function ",
  StyleBox["g", "IT"],
  " to those elements, set ReturnValues to {",
  StyleBox["g", "IT"],
  ", ",
  StyleBox["k", "IT"],
  "}. The function ",
  StyleBox["g",
    FontSlant->"Italic"],
  " actually takes two arguments, where the second argument is the position \
that the current element would have in the output of NestList. To illustrate \
this, we use the following simple example."
}], "Text",
  CellTags->{"i:28", "C.3"}],

Cell[CellGroupData[{

Cell["NestList[# + 2 &, 0, 10]", "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \({0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20}\)], "Output",
  CellTags->"C.3"]
}, Open  ]],

Cell["\<\
Setting ReturnValues to {(#1 &), 3} returns every third element of \
the corresponding NestList function, starting with the second element.\
\>", 
  "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{

Cell[TextData[
"NestListEffects[# + 2 &, 0, 10,\n  ReturnValues \[Rule] {(#1 &), 3}]"], 
  "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \({2, 8, 14, 20}\)], "Output",
  CellTags->"C.3"]
}, Open  ]],

Cell[TextData[{
  "The SideEffects option is set to a list of ordered pairs, each of which \
functions in the same way as the setting of ReturnValues does. Each ordered \
pair {",
  StyleBox["gi", "IT"],
  ", ",
  StyleBox["ki", "IT"],
  "} consists of a function of two arguments and an integer that specifies \
how often to apply the function. For example, here's a side effect that \
displays the step number during every other step. The function ",
  StyleBox["effect1", "IT"],
  " uses Print to display each of these step numbers on a line by itself, and \
then the final result is returned."
}], "Text",
  CellTags->{"i:29", "C.3"}],

Cell[CellGroupData[{

Cell[TextData[
"effect1[x_, counter_] := Print[counter];\nNestListEffects[# + 2 &, 0, 10,\n  \
ReturnValues \[Rule] {(#1 &), 3},\n  SideEffects \[Rule] {{effect1, 2}}]"], 
  "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \(0\)], "Print",
  CellTags->"C.3"],

Cell[BoxData[
    \(2\)], "Print",
  CellTags->"C.3"],

Cell[BoxData[
    \(4\)], "Print",
  CellTags->"C.3"],

Cell[BoxData[
    \(6\)], "Print",
  CellTags->"C.3"],

Cell[BoxData[
    \(8\)], "Print",
  CellTags->"C.3"],

Cell[BoxData[
    \({2, 8, 14, 20}\)], "Output",
  CellTags->"C.3"]
}, Open  ]],

Cell["\<\
Another possible side effect would be to display a graphic \
representing the lattice configuration to a notebook window, replacing the \
contents of that window in the process. In this way, we can run an animation \
during the simulation run itself without having to save every graphic first. \
In the following, we explore the code that does this.\
\>", "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{

Cell["Adding Effects to a Simulation", "Subsubsection",
  CellTags->"C.3"],

Cell[TextData[{
  "After changing NestList to NestListEffects in the simulation code, there \
is one more thing we need to do: allow the user to pass options to \
NestListEffects. We do this by changing the left-hand side of the simulation \
program's definition so that the last optional arguments are saved in a \
sequence named ",
  StyleBox["opts", "IT"],
  ". For example, if we call this new program ",
  StyleBox["neighborhoodNLE", "IT"],
  ", then the new left-hand side of the program should look like the \
following. Notice that ",
  StyleBox["opts", "IT"],
  " will match zero or more arguments (options) because of the triple blank \
(___)."
}], "Text",
  CellTags->{"i:30", "C.3"}],

Cell["neighborhoodNLE[n_, p_, v_, w_, t_, opts___]", "Input",
  CellTags->"C.3"],

Cell[TextData[{
  "Then these options can be passed directly to NestListEffects by refering \
to ",
  StyleBox["opts", "IT"],
  "."
}], "Text",
  CellTags->"C.3"],

Cell["\<\
NestListEffects[
        GN[walk, Moore[movestay, #]]&, society, t, opts]\
\>", "Input",
  CellTags->"C.3"],

Cell[TextData[{
  "Now this new function, ",
  StyleBox["neighborhoodNLE", "IT"],
  ", is ready to accept ReturnValues and SideEffects options."
}], "Text",
  CellTags->"C.3"],

Cell["\<\
neighborhoodNLE[n_, p_, v_, w_, t_, opts___] := 
Module[  (* program goes here *)
  NestListEffects[
       GN[walk, Moore[movestay, #]]&, society, t, opts]]\
\>", "Input",
  CellTags->"C.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kernel Memory Savings", "Subsubsection",
  CellTags->"C.3"],

Cell["\<\
Replacing NestList with NestListEffects in this way achieves almost \
as much memory savings as Nest afforded.\
\>", "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{

Cell[TextData[
"m1 = {MemoryInUse[], MaxMemoryUsed[]};\nlen = \
Length[Flatten[neighborhoodNLE[20, 0.60, 1, 2, 1000,\n                        \
     ReturnValues \[Rule] {(#1 &), 99}]]];\nm2 = {MemoryInUse[], \
MaxMemoryUsed[]};\n{len, m2 - m1}"], "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \({6985, {2672, 197280}}\)], "Output",
  CellTags->"C.3"]
}, Open  ]],

Cell["\<\
This uses just less than 200K, which is slightly more than Nest, \
but still drastically less than NestList, and with much more flexibility and \
control of the values returned from the run.\
\>", "Text",
  CellTags->"C.3"],

Cell[TextData[{
  "Another possible setting for ReturnValues would not return the entire \
lattice, but some value or values extracted from it. For example, the number \
of empty sites should remain constant for each time step in this model, and \
we can check that that is happening by applying Count[#, 0, {2}]& to the \
lattice every so often. The following example does that, and also uses an \
effect named ",
  StyleBox["printCounter", "IT"],
  ", defined at the end of this appendix, to display the simulation's \
progress."
}], "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{

Cell[TextData[
"neighborhoodNLE[20, 0.60, 1, 2, 100, \n  ReturnValues \[Rule] {Count[#, 0, \
{2}]&, 20},\n  SideEffects \[Rule] {{printCounter, 10}}]"], "Input",
  CellTags->"C.3"],

Cell["0 10 20 30 40 50 60 70 80 90 ", "Print",
  CellTags->"C.3"],

Cell[BoxData[
    \({153, 153, 153, 153, 153}\)], "Output",
  CellTags->"C.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Front End Memory Savings", "Subsubsection",
  CellTags->"C.3"],

Cell["\<\
Notice that this technique not only allows the kernel to save \
memory, but also the front end. For example, this gives us the ability to \
generate a graphic during each time step, and replace it with a new graphic \
during the next time step. In this way, we see the animation as it develops, \
without having to save possibly thousands of memory-hungry graphics.\
\>", 
  "Text",
  CellTags->{"i:31", "C.3"}],

Cell[TextData[
"displayLattice[nb_, lat_, counter_] := \nModule[{str},\n  SelectionMove[nb, \
All, Notebook];\n  str = Show[Graphics[RasterArray[\n    lat /. {0 \[Rule] \
RGBColor[0.7, 0.7, 0.7],\n           {_, {1}} \[Rule] RGBColor[0, 1, 0],\n    \
       {_, {2}} \[Rule] RGBColor[0, 0, 1]}]],\n    PlotLabel \[Rule] \
(\"lattice after time step \" <> \n                  ToString[counter]),\n    \
AspectRatio \[Rule] Automatic,\n    DisplayFunction \[Rule] DisplayString];\n \
 NotebookWrite[nb,\n     Cell[GraphicsData[\"PostScript\", str], \
\"Graphics\"]];]"], "Input",
  CellTags->"C.3"],

Cell[TextData[
"nb = NotebookCreate[];\nneighborhoodNLE[20, 0.60, 1, 2, 100, \n  SideEffects \
\[Rule] {{displayLattice[nb, #1, #2]&, 1}}];"], "Input",
  CellTags->"C.3"],

Cell["\<\
Using multiple side effects, we can easily set up more than one \
animation running at the same time, each being updated at different \
intervals, as well as having data written into files or other actions \
occurring simultaneously.\
\>", "Text",
  CellTags->"C.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.3.2  Options and Genetic Algorithms", "Subsection",
  CellTags->"C.3"],

Cell["\<\
In addition to ReturnValues and SideEffects, one can add other \
options to the simulation programs. For instance, in all the examples in this \
book we have the simulations beginning with random lattice configurations. In \
some applications, such as applying genetic algorithms, it may be necessary \
to define the initial configuration by hand or as the result of some other \
calculation.\
\>", "Text",
  CellTags->{"i:32", "C.3"}],

Cell["\<\
One way to do this is to add an option to the simulation program \
that will enable the user to specify an initial configuration instead of \
always beginning with a random configuration. Say we want to call such an \
option InitialConfiguration. The default value for this option should be \
Automatic, meaning that a random configuration will be used. If the setting \
is something other than Automatic, the setting itself should be used as the \
starting lattice for the simulation.\
\>", "Text",
  CellTags->{"i:33", "C.3"}],

Cell[TextData[{
  "To do this, we first define the default value. For the program name, we \
use yet another variant of the neighborhood model, ",
  StyleBox["neighborhoodOpts", "IT"],
  ", which stands for \"neighborhood with options.\""
}], "Text",
  CellTags->"C.3"],

Cell[TextData[
"Options[neighborhoodOpts] =\n                      {InitialConfiguration \
\[Rule] Automatic};"], "Input",
  CellTags->"C.3"],

Cell[TextData[{
  "Next, we need to add the code that reads the value of the option and then \
acts accordingly. Since options are expressions with head Rule, we can \
extract the setting for InitialConfiguration using ReplaceAll (/.) and save \
it in a new local variable called ",
  StyleBox["initConfig", "IT"],
  ". Then, if this is set to Automatic, the code generates a random lattice \
configuration; otherwise, it uses the setting that the user specifies."
}], "Text",
  CellTags->"C.3"],

Cell[TextData[
"neighborhoodOpts[n_, p_, v_, w_, t_, opts___] := \nModule[{RND, initConfig, \
society},\n   RND := Random[Integer, {1, 4}];\n   initConfig = \
InitialConfiguration /.\n                    {opts} /. \
Options[neighborhoodOpts];\n   society = If[initConfig === Automatic,\n     \
Table[Floor[p + Random[]], {n}, {n}] /. \n         1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, w}], {v}]},\n     initConfig];\n\n  (* program goes \
here *)\n\n  NestList[GN[walk, Moore[movestay, #]]&, society, t]]"], "Input",
  CellTags->"C.3"],

Cell["\<\
This enables one to pass in a configuration that was, for example, \
output from some previous simulation run, perhaps after altering it in some \
way. This is exactly how one might add genetic algorithms to a simulation. \
For example, here we run the same simulation in two ways. The first method is \
to run the entire simulation for 100 time steps. The second method is to run \
the simulation for 20 time steps, pass the resulting lattice configuration \
through as the initial configuration for the next 20 time steps, and so on. \
As you might expect, both methods result in the same final \
configuration.\
\>", "Text",
  TaggingRules:>{"IndexingCellTag" -> "i:34", "IndexEntries" -> {{
    "genetic algorithms", "", ""}}},
  CellTags->{"i:34", "C.3"}],

Cell[CellGroupData[{

Cell[TextData[
"SeedRandom[0];\nconfig1 = Last[neighborhoodNL[20, 0.60, 1, 2, 100]];\n\n\
SeedRandom[0];\nconfig2 = Nest[Last[neighborhoodOpts[20, 0.60, 1, 2, 20,\n    \
          InitialConfiguration \[Rule] #]]&, Automatic, 5];\n\nconfig1 === \
config2"], "Input",
  CellTags->"C.3"],

Cell[BoxData[
    \(True\)], "Output",
  CellTags->"C.3"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.4  Programs in the Appendix", "Section",
  CellTags->"C.4"],

Cell[CellGroupData[{

Cell["C.4.1  NestListEffects, ReturnValues, and SideEffects", "Subsection",
  CellTags->"C.4"],

Cell[TextData[
"NestListEffects::usage = \"NestListEffects[f, expr, n, ReturnValues \[Rule] \
{g, k}] returns a list of every kth element of NestList[f, expr, n] after the \
application of g. NestListEffects[f, expr, n, SideEffects \[Rule] {{g1, k1}, \
{g2, k2},...}] applies gi after every ki steps, but does not effect return \
values.\";"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:35", "IndexEntries" -> {{
    "NestListEffects", "", ""}, {"ReturnValues", "", ""}, {"SideEffects", "", 
    ""}}},
  CellTags->{"i:35", "C.4"}],

Cell["\<\
ReturnValues::usage = \"ReturnValues is an option to \
NestListEffects that determines what is returned and how often.\";\
\>", 
  "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:35", "IndexEntries" -> {{
    "NestListEffects", "", ""}, {"ReturnValues", "", ""}, {"SideEffects", "", 
    ""}}},
  CellTags->"C.4"],

Cell["\<\
SideEffects::usage = \"SideEffects is an option to NestListEffects \
that applies functions without effecting return values.\";\
\>", "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:35", "IndexEntries" -> {{
    "NestListEffects", "", ""}, {"ReturnValues", "", ""}, {"SideEffects", "", 
    ""}}},
  CellTags->"C.4"],

Cell[TextData[
"Options[NestListEffects] =\n                 {ReturnValues \[Rule] {#&, 1}, \
SideEffects\[Rule]{}};"], "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:35", "IndexEntries" -> {{
    "NestListEffects", "", ""}, {"ReturnValues", "", ""}, {"SideEffects", "", 
    ""}}},
  CellTags->"C.4"],

Cell["\<\
NestListEffects[f_, expr_, n_, opts___] :=
If[({ReturnValues, SideEffects} /. {opts} /. 
         Options[NestListEffects]) === {{#&, 1}, {}},
  NestList[f, expr, n],
  (* else *)
  Module[{c = 0, lis = {}, side, ret},
    {ret, side} = {ReturnValues, SideEffects} /.
                       {opts} /. Options[NestListEffects];
    If[side === {}, side = {{Null, Infinity}}];
    Nest[(
      If[Mod[c, ret[[-1]]] === 0,
         lis = Join[lis, {First[ret][#, c]}]];
      Table[If[Mod[c, side[[i, -1]]] === 0,
               side[[i, 1]][#, c]],
        {i,Length[side]}];
      c++; #)&[f[#]]&, expr, n];
    lis]
];\
\>", "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:35", "IndexEntries" -> {{
    "NestListEffects", "", ""}, {"ReturnValues", "", ""}, {"SideEffects", "", 
    ""}}},
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.4.2  neighborhoodNL", "Subsection",
  CellTags->"C.4"],

Cell[TextData[
"neighborhoodNL[n_, p_, v_, w_, t_] := \nModule[{walk, movestay, society, \
RND, Moore, GN},\n  RND := Random[Integer, {1, 4}];\n  society = \
Table[Floor[p + Random[]], {n}, {n}] /. \n        1 \[RuleDelayed] {RND, \
Table[Random[Integer, {1, w}], {v}]};\n  movestay[0, __] := 0;\n  \
movestay[{a_, b_}, res__] := \n     {a * Round[1 - Count[Map[Count[b - \
#[[2]], 0]&,\n       {res} /. 0 \[Rule] {0, 0}], _?(# >= v / 2 &)] / 8.], b}; \
                    \n  walk[{1,a_},0,_,_,_,{4,_},_,_,_,_,_,_,_] := {RND,a};\n\
  walk[{1,a_},0,_,_,_,_,_,_,{2,_},_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,{3,_},_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a_},_,0,_,_,{3,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,{1,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,{4,_},_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a_},_,_,0,_,_,{4,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,{2,_},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,{1,_},_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a_},_,_,_,0,_,_,{1,_},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,{3,_},_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,{2,_}] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{x_,a_},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,_},{4,_},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,_},{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a_},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a_},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a_},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a_},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestList[GN[walk, Moore[movestay, #]]&, society, t]]"], "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.4.3  neighborhoodN", "Subsection",
  CellTags->"C.4"],

Cell[TextData[{
  "neighborhoodN[n_, p_, v_, w_, t_] := \nModule[{walk, movestay, society, \
RND, Moore, GN},\n",
  "  RND := Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], \
{n}, {n}] /. \n        1 \[RuleDelayed] {RND, Table[Random[Integer, {1, w}], \
{v}]};\n  movestay[0, __] := 0;\n  movestay[{a_, b_}, res__] := \n     {a * \
Round[1 - Count[Map[Count[b - #[[2]], 0]&,\n       {res} /. 0 \[Rule] {0, \
0}], _?(# >= v / 2 &)] / 8.], b};                     \n",
  "  walk[{1,a_},0,_,_,_,{4,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,{2,_},_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,{3,_},_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a_},_,0,_,_,{3,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,{1,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,{4,_},_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a_},_,_,0,_,_,{4,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,{2,_},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,{1,_},_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a_},_,_,_,0,_,_,{1,_},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,{3,_},_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,{2,_}] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{x_,a_},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,_},{4,_},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,_},{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a_},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a_},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a_},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a_},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 Nest[GN[walk, Moore[movestay, #]]&, society, t]]"
}], "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.4.4  neighborhoodNLE", "Subsection",
  CellTags->"C.4"],

Cell[TextData[{
  "neighborhoodNLE[n_, p_, v_, w_, t_, opts___] := \nModule[{walk, movestay, \
society, RND, Moore, GN},\n",
  "  RND := Random[Integer, {1, 4}];\n  society = Table[Floor[p + Random[]], \
{n}, {n}] /. \n        1 \[RuleDelayed] {RND, Table[Random[Integer, {1, w}], \
{v}]};\n  movestay[0, __] := 0;\n  movestay[{a_, b_}, res__] := \n     {a * \
Round[1 - Count[Map[Count[b - #[[2]], 0]&,\n       {res} /. 0 \[Rule] {0, \
0}], _?(# >= v / 2 &)] / 8.], b};                     \n",
  "  walk[{1,a_},0,_,_,_,{4,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,{2,_},_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,{3,_},_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a_},_,0,_,_,{3,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,{1,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,{4,_},_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a_},_,_,0,_,_,{4,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,{2,_},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,{1,_},_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a_},_,_,_,0,_,_,{1,_},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,{3,_},_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,{2,_}] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{x_,a_},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,_},{4,_},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,_},{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a_},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a_},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a_},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a_},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestListEffects[\n        GN[walk, Moore[movestay, #]]&, society, t, opts]]"
}], "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.4.5  neighborhoodOpts", "Subsection",
  CellTags->"C.4"],

Cell[TextData[
"neighborhoodOpts[n_, p_, v_, w_, t_, opts___] := \nModule[{walk, movestay, \
society, RND,\n                                   Moore, GN, initConfig},\n  \
RND := Random[Integer, {1, 4}];\n  initConfig = InitialConfiguration /.\n     \
                 {opts} /. Options[neighborhoodOpts];\n  society = \
If[initConfig === Automatic,\n    Table[Floor[p + Random[]], {n}, {n}] /. \n  \
      1 \[RuleDelayed] {RND, Table[Random[Integer, {1, w}], {v}]},\n    \
initConfig];\n  movestay[0, __] := 0;\n  movestay[{a_, b_}, res__] := \n     \
{a * Round[1 - Count[Map[Count[b - #[[2]], 0]&,\n       {res} /. 0 \[Rule] \
{0, 0}], _?(# >= v / 2 &)] / 8.], b};                     \n  \
walk[{1,a_},0,_,_,_,{4,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,{2,_},_,_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,{3,_},_,_,_] := {RND,a};\n  \
walk[{1,a_},0,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{2,a_},_,0,_,_,{3,_},_,_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,{1,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,{4,_},_,_] := {RND,a};\n  \
walk[{2,a_},_,0,_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{3,a_},_,_,0,_,_,{4,_},_,_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,{2,_},_,_,_,_,_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,{1,_},_] := {RND,a};\n  \
walk[{3,a_},_,_,0,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{4,a_},_,_,_,0,_,_,{1,_},_,_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,{3,_},_,_,_,_] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,{2,_}] := {RND,a};\n  \
walk[{4,a_},_,_,_,0,_,_,_,_,_,_,_,_] := 0;\n  \
walk[{x_,a_},_,_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,{3,_},{4,_},_,_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,_},_,_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},{1,_},_,_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,{4,_},_,{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,_,_,{1,_},{2,_},_,_,_,_,_,_,_,_] := 0;\n  \
walk[0,{3,a_},_,_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,{4,a_},_,_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,{1,a_},_,_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,{2,a_},_,_,_,_,_,_,_,_] := {RND,a};\n  \
walk[0,_,_,_,_,_,_,_,_,_,_,_,_] := 0;\n  Moore[func_, lat_] :=\n    \
MapThread[func, Map[RotateRight[lat, #]&,\n           {{0, 0}, {1, 0}, {0, \
-1}, {-1, 0}, {0, 1},\n            {1, -1}, {-1, -1}, {-1, 1}, {1, 1}}], 2];\n\
  GN[func_, lat_] :=\n    MapThread[func, Map[RotateRight[lat, #]&,\n         \
   {{0, 0}, {1, 0}, {0, -1}, {-1, 0}, {0, 1},\n             {1, -1}, {-1, \
-1}, {-1, 1}, {1, 1}, {2, 0},\n             {0, -2}, {-2, 0}, {0, 2}}], 2];\n \
 NestList[GN[walk, Moore[movestay, #]]&, society, t]]"], "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["C.4.6  printCounter and printMemory", "Subsection",
  CellTags->"C.4"],

Cell["\<\
printCounter[lat_, counter_] :=
  WriteString[\"stdout\", counter, \" \"];\
\>", "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:36", "IndexEntries" -> {{
    "printCounter", "", ""}}},
  CellTags->{"i:36", "C.4"}],

Cell["\<\
printMemory[lat_, counter_] := 
 (Print[];
  Print[\"After \", counter, \" steps:\"];
  Print[\"Date:          \", Date[]];
  Print[\"MemoryInUse:   \", MemoryInUse[]];
  Print[\"MaxMemoryUsed: \", MaxMemoryUsed[]];
  Print[]);\
\>", "Input",
  TaggingRules:>{"IndexingCellTag" -> "i:37", "IndexEntries" -> {{
    "printMemory", "", ""}}},
  CellTags->{"i:37", "C.4"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{500, 350},
WindowMargins->{{4, Automatic}, {Automatic, -2}},
PrintingStartingPageNumber->1,
PageHeaders->{{Cell[ 
        TextData[ {
          StyleBox[ 
            CounterBox[ "Page"], "PageNumber"], "     ", 
          "Appendix C. Graphics and Efficiency"}], "Header"], Inherited, 
      Inherited}, {Inherited, Inherited, Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 39, "IndexEntries" -> {{"i:34", 
  "genetic algorithms", "", ""}, {"i:35", "NestListEffects", "", ""}, {
  "i:35", "ReturnValues", "", ""}, {"i:35", "SideEffects", "", ""}, {"i:35", 
  "NestListEffects", "", ""}, {"i:35", "ReturnValues", "", ""}, {"i:35", 
  "SideEffects", "", ""}, {"i:35", "NestListEffects", "", ""}, {"i:35", 
  "ReturnValues", "", ""}, {"i:35", "SideEffects", "", ""}, {"i:35", 
  "NestListEffects", "", ""}, {"i:35", "ReturnValues", "", ""}, {"i:35", 
  "SideEffects", "", ""}, {"i:35", "NestListEffects", "", ""}, {"i:35", 
  "ReturnValues", "", ""}, {"i:35", "SideEffects", "", ""}, {"i:36", 
  "printCounter", "", ""}, {"i:37", "printMemory", "", ""}}},
StyleDefinitions -> "BookStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@@UW:0000000000064<01T1T00000000000
00000000003oo`@^9M3oo`000iL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "C.0"->{
    Cell[1731, 51, 52, 1, 92, "ChapterLine",
      CellTags->"C.0"],
    Cell[1786, 54, 59, 1, 153, "Title",
      CellTags->"C.0"],
    Cell[1848, 57, 668, 13, 110, "Text",
      CellTags->"C.0"]},
  "C.1"->{
    Cell[2541, 74, 51, 1, 40, "Section",
      CellTags->"C.1"],
    Cell[2595, 77, 282, 8, 54, "Text",
      CellTags->"C.1"],
    Cell[2902, 89, 59, 1, 40, "Subsection",
      CellTags->"C.1"],
    Cell[2964, 92, 481, 8, 94, "Text",
      CellTags->{"i:1", "C.1"}],
    Cell[3448, 102, 383, 7, 80, "Text",
      CellTags->{"i:2", "C.1"}],
    Cell[3856, 113, 294, 6, 89, "Input",
      CellTags->"C.1"],
    Cell[4153, 121, 459, 10, 78, "Output",
      CellTags->"C.1"],
    Cell[4627, 134, 386, 7, 80, "Text",
      CellTags->"C.1"],
    Cell[5038, 145, 131, 5, 63, "Input",
      CellTags->"C.1"],
    Cell[5172, 152, 554, 13, 98, "Output",
      CellTags->"C.1"],
    Cell[5741, 168, 191, 5, 38, "Text",
      CellTags->"C.1"],
    Cell[5957, 177, 212, 4, 76, "Input",
      CellTags->"C.1"],
    Cell[6172, 183, 12013, 200, 159, 11869, 195, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[18200, 386, 415, 10, 68, "Text",
      CellTags->"C.1"],
    Cell[18640, 400, 221, 4, 76, "Input",
      CellTags->"C.1"],
    Cell[18864, 406, 11997, 200, 159, 11853, 195, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[30910, 612, 92, 1, 40, "Subsection",
      CellTags->"C.1"],
    Cell[31005, 615, 701, 17, 112, "Text",
      CellTags->{"i:3", "C.1"}],
    Cell[31709, 634, 410, 8, 82, "Text",
      CellTags->"C.1"],
    Cell[32144, 646, 131, 4, 50, "Input",
      CellTags->"C.1"],
    Cell[32278, 652, 1936, 35, 83, 1792, 30, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[34229, 690, 629, 13, 98, "Text",
      CellTags->{"i:4", "C.1"}],
    Cell[34861, 705, 508, 24, 50, "Input",
      CellTags->"C.1"],
    Cell[35372, 731, 430, 8, 80, "Text",
      CellTags->{"i:5", "C.1"}],
    Cell[35827, 743, 221, 4, 89, "Input",
      CellTags->"C.1"],
    Cell[36051, 749, 7878, 132, 75, 7733, 127, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[43944, 884, 240, 5, 52, "Text",
      CellTags->{"i:6", "C.1"}],
    Cell[44187, 891, 720, 15, 116, "Text",
      CellTags->{"i:7", "C.1"}],
    Cell[44910, 908, 143, 4, 38, "Text",
      CellTags->"C.1"],
    Cell[45090, 917, 56, 1, 40, "Subsection",
      CellTags->"C.1"],
    Cell[45149, 920, 597, 14, 100, "Text",
      CellTags->{"i:8", "C.1"}],
    Cell[45749, 936, 466, 13, 70, "Text",
      CellTags->"C.1"],
    Cell[46240, 953, 203, 4, 89, "Input",
      CellTags->"C.1"],
    Cell[46446, 959, 7889, 133, 132, 7742, 128, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[54350, 1095, 408, 9, 68, "Text",
      CellTags->{"i:9", "C.1"}],
    Cell[54783, 1108, 228, 4, 89, "Input",
      CellTags->"C.1"],
    Cell[55014, 1114, 66660, 1096, 132, 66513, 1091, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[121689, 2213, 309, 12, 40, "Text",
      CellTags->"C.1"],
    Cell[122035, 2230, 65, 1, 40, "Subsection",
      CellTags->"C.1"],
    Cell[122103, 2233, 416, 11, 72, "Text",
      CellTags->{"i:10", "C.1"}],
    Cell[122522, 2246, 47, 1, 37, "Input",
      CellTags->"C.1"],
    Cell[122572, 2249, 276, 6, 52, "Text",
      CellTags->"C.1"],
    Cell[122873, 2259, 60, 1, 30, "Subsubsection",
      CellTags->"C.1"],
    Cell[122936, 2262, 692, 14, 126, "Text",
      CellTags->{"i:11", "C.1"}],
    Cell[123631, 2278, 134, 4, 50, "Input",
      CellTags->"C.1"],
    Cell[123768, 2284, 233, 5, 52, "Text",
      CellTags->"C.1"],
    Cell[124026, 2293, 139, 3, 50, "Input",
      CellTags->"C.1"],
    Cell[124168, 2298, 36831, 608, 181, 36660, 602, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[161014, 2909, 232, 5, 52, "Text",
      CellTags->{"i:12", "C.1"}],
    Cell[161271, 2918, 199, 4, 76, "Input",
      CellTags->"C.1"],
    Cell[161473, 2924, 41949, 692, 181, 41776, 686, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[203437, 3619, 227, 5, 52, "Text",
      CellTags->"C.1"],
    Cell[203701, 3629, 54, 1, 30, "Subsubsection",
      CellTags->"C.1"],
    Cell[203758, 3632, 598, 13, 98, "Text",
      CellTags->{"i:13", "C.1"}],
    Cell[204381, 3649, 246, 4, 89, "Input",
      CellTags->"C.1"],
    Cell[204630, 3655, 34309, 566, 163, 34138, 560, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[238954, 4224, 269, 6, 52, "Text",
      CellTags->{"i:14", "C.1"}],
    Cell[239226, 4232, 198, 5, 38, "Text",
      CellTags->"C.1"],
    Cell[239449, 4241, 401, 6, 141, "Input",
      CellTags->"C.1"],
    Cell[239853, 4249, 33634, 555, 163, 33463, 549, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[273536, 4810, 53, 1, 30, "Subsubsection",
      CellTags->"C.1"],
    Cell[273592, 4813, 252, 5, 52, "Text",
      CellTags->{"i:15", "C.1"}],
    Cell[273847, 4820, 440, 10, 82, "Text",
      CellTags->"C.1"],
    Cell[274290, 4832, 212, 5, 63, "Input",
      CellTags->"C.1"],
    Cell[274505, 4839, 89, 1, 24, "Text",
      CellTags->"C.1"],
    Cell[274619, 4844, 168, 3, 50, "Input",
      CellTags->"C.1"],
    Cell[274790, 4849, 99867, 1641, 170, 99726, 1636, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[374672, 6493, 427, 8, 80, "Text",
      CellTags->{"i:16", "C.1"}],
    Cell[375124, 6505, 184, 3, 63, "Input",
      CellTags->"C.1"],
    Cell[375311, 6510, 101272, 1664, 186, 101104, 1658, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[476644, 8181, 61, 1, 40, "Subsection",
      CellTags->"C.1"],
    Cell[476708, 8184, 428, 8, 82, "Text",
      CellTags->{"i:17", "C.1"}],
    Cell[477161, 8196, 731, 11, 245, "Input",
      CellTags->"C.1"],
    Cell[477895, 8209, 86616, 1424, 151, 86456, 1418, "GraphicsData", 
    "Bitmap", "Graphics",
      Evaluatable->False,
      CellTags->"C.1"],
    Cell[564560, 9639, 57, 1, 40, "Subsection",
      CellTags->"C.1"],
    Cell[564620, 9642, 627, 13, 112, "Text",
      CellTags->{"i:18", "C.1"}],
    Cell[565250, 9657, 500, 10, 82, "Text",
      CellTags->{"i:19", "C.1"}]},
  "i:1"->{
    Cell[2964, 92, 481, 8, 94, "Text",
      CellTags->{"i:1", "C.1"}]},
  "i:2"->{
    Cell[3448, 102, 383, 7, 80, "Text",
      CellTags->{"i:2", "C.1"}]},
  "i:3"->{
    Cell[31005, 615, 701, 17, 112, "Text",
      CellTags->{"i:3", "C.1"}]},
  "i:4"->{
    Cell[34229, 690, 629, 13, 98, "Text",
      CellTags->{"i:4", "C.1"}]},
  "i:5"->{
    Cell[35372, 731, 430, 8, 80, "Text",
      CellTags->{"i:5", "C.1"}]},
  "i:6"->{
    Cell[43944, 884, 240, 5, 52, "Text",
      CellTags->{"i:6", "C.1"}]},
  "i:7"->{
    Cell[44187, 891, 720, 15, 116, "Text",
      CellTags->{"i:7", "C.1"}]},
  "i:8"->{
    Cell[45149, 920, 597, 14, 100, "Text",
      CellTags->{"i:8", "C.1"}]},
  "i:9"->{
    Cell[54350, 1095, 408, 9, 68, "Text",
      CellTags->{"i:9", "C.1"}]},
  "i:10"->{
    Cell[122103, 2233, 416, 11, 72, "Text",
      CellTags->{"i:10", "C.1"}]},
  "i:11"->{
    Cell[122936, 2262, 692, 14, 126, "Text",
      CellTags->{"i:11", "C.1"}]},
  "i:12"->{
    Cell[161014, 2909, 232, 5, 52, "Text",
      CellTags->{"i:12", "C.1"}]},
  "i:13"->{
    Cell[203758, 3632, 598, 13, 98, "Text",
      CellTags->{"i:13", "C.1"}]},
  "i:14"->{
    Cell[238954, 4224, 269, 6, 52, "Text",
      CellTags->{"i:14", "C.1"}]},
  "i:15"->{
    Cell[273592, 4813, 252, 5, 52, "Text",
      CellTags->{"i:15", "C.1"}]},
  "i:16"->{
    Cell[374672, 6493, 427, 8, 80, "Text",
      CellTags->{"i:16", "C.1"}]},
  "i:17"->{
    Cell[476708, 8184, 428, 8, 82, "Text",
      CellTags->{"i:17", "C.1"}]},
  "i:18"->{
    Cell[564620, 9642, 627, 13, 112, "Text",
      CellTags->{"i:18", "C.1"}]},
  "i:19"->{
    Cell[565250, 9657, 500, 10, 82, "Text",
      CellTags->{"i:19", "C.1"}]},
  "C.2"->{
    Cell[565799, 9673, 79, 1, 40, "Section",
      CellTags->"C.2"],
    Cell[565881, 9676, 613, 14, 98, "Text",
      CellTags->{"i:20", "C.2"}],
    Cell[566497, 9692, 552, 11, 96, "Text",
      CellTags->"C.2"],
    Cell[567074, 9707, 67, 1, 30, "Subsubsection",
      CellTags->"C.2"],
    Cell[567144, 9710, 434, 8, 82, "Text",
      CellTags->{"i:21", "C.2"}],
    Cell[567581, 9720, 58, 1, 37, "Input",
      CellTags->"C.2"],
    Cell[567676, 9726, 77, 1, 30, "Subsubsection",
      CellTags->"C.2"],
    Cell[567756, 9729, 695, 13, 126, "Text",
      CellTags->{"i:22", "C.2"}],
    Cell[568454, 9744, 133, 3, 50, "Input",
      CellTags->"C.2"],
    Cell[568590, 9749, 305, 6, 54, "Text",
      CellTags->{"i:23", "C.2"}],
    Cell[568898, 9757, 68, 1, 37, "Input",
      CellTags->"C.2"],
    Cell[568969, 9760, 127, 4, 24, "Text",
      CellTags->"C.2"],
    Cell[569099, 9766, 121, 4, 50, "Input",
      CellTags->"C.2"],
    Cell[569223, 9772, 286, 6, 52, "Text",
      CellTags->"C.2"],
    Cell[569512, 9780, 160, 5, 63, "Input",
      CellTags->"C.2"],
    Cell[569709, 9790, 58, 1, 30, "Subsubsection",
      CellTags->"C.2"],
    Cell[569770, 9793, 338, 8, 54, "Text",
      CellTags->{"i:24", "C.2"}],
    Cell[570111, 9803, 163, 6, 37, "Input",
      CellTags->"C.2"],
    Cell[570277, 9811, 546, 10, 96, "Text",
      CellTags->{"i:25", "C.2"}],
    Cell[570826, 9823, 495, 8, 154, "Input",
      CellTags->"C.2"],
    Cell[571324, 9833, 223, 5, 52, "Text",
      CellTags->"C.2"],
    Cell[571550, 9840, 180, 6, 76, "Input",
      CellTags->"C.2"],
    Cell[571767, 9851, 53, 1, 30, "Subsubsection",
      CellTags->"C.2"],
    Cell[571823, 9854, 381, 7, 80, "Text",
      CellTags->"C.2"]},
  "i:20"->{
    Cell[565881, 9676, 613, 14, 98, "Text",
      CellTags->{"i:20", "C.2"}]},
  "i:21"->{
    Cell[567144, 9710, 434, 8, 82, "Text",
      CellTags->{"i:21", "C.2"}]},
  "i:22"->{
    Cell[567756, 9729, 695, 13, 126, "Text",
      CellTags->{"i:22", "C.2"}]},
  "i:23"->{
    Cell[568590, 9749, 305, 6, 54, "Text",
      CellTags->{"i:23", "C.2"}]},
  "i:24"->{
    Cell[569770, 9793, 338, 8, 54, "Text",
      CellTags->{"i:24", "C.2"}]},
  "i:25"->{
    Cell[570277, 9811, 546, 10, 96, "Text",
      CellTags->{"i:25", "C.2"}]},
  "C.3"->{
    Cell[572253, 9867, 72, 1, 40, "Section",
      CellTags->"C.3"],
    Cell[572328, 9870, 509, 9, 94, "Text",
      CellTags->{"i:38", "C.3"}],
    Cell[572862, 9883, 63, 1, 40, "Subsection",
      CellTags->"C.3"],
    Cell[572928, 9886, 373, 7, 66, "Text",
      CellTags->"C.3"],
    Cell[573304, 9895, 357, 10, 74, "Text",
      CellTags->"C.3"],
    Cell[573664, 9907, 170, 5, 63, "Input",
      CellTags->"C.3"],
    Cell[573837, 9914, 165, 5, 63, "Input",
      CellTags->"C.3"],
    Cell[574005, 9921, 178, 4, 38, "Text",
      CellTags->{"i:26", "C.3"}],
    Cell[574208, 9929, 197, 6, 76, "Input",
      CellTags->"C.3"],
    Cell[574408, 9937, 78, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[574501, 9942, 324, 8, 68, "Text",
      CellTags->"C.3"],
    Cell[574850, 9954, 196, 6, 76, "Input",
      CellTags->"C.3"],
    Cell[575049, 9962, 73, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[575137, 9967, 147, 4, 38, "Text",
      CellTags->"C.3"],
    Cell[575287, 9973, 676, 11, 122, "Text",
      CellTags->{"i:27", "C.3"}],
    Cell[575966, 9986, 732, 20, 102, "Text",
      CellTags->{"i:28", "C.3"}],
    Cell[576723, 10010, 60, 1, 37, "Input",
      CellTags->"C.3"],
    Cell[576786, 10013, 92, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[576893, 10018, 185, 5, 38, "Text",
      CellTags->"C.3"],
    Cell[577103, 10027, 118, 3, 50, "Input",
      CellTags->"C.3"],
    Cell[577224, 10032, 67, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[577306, 10037, 638, 14, 98, "Text",
      CellTags->{"i:29", "C.3"}],
    Cell[577969, 10055, 201, 4, 76, "Input",
      CellTags->"C.3"],
    Cell[578173, 10061, 53, 2, 38, "Print",
      CellTags->"C.3"],
    Cell[578229, 10065, 53, 2, 38, "Print",
      CellTags->"C.3"],
    Cell[578285, 10069, 53, 2, 38, "Print",
      CellTags->"C.3"],
    Cell[578341, 10073, 53, 2, 38, "Print",
      CellTags->"C.3"],
    Cell[578397, 10077, 53, 2, 38, "Print",
      CellTags->"C.3"],
    Cell[578453, 10081, 67, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[578535, 10086, 392, 7, 80, "Text",
      CellTags->"C.3"],
    Cell[578952, 10097, 74, 1, 30, "Subsubsection",
      CellTags->"C.3"],
    Cell[579029, 10100, 695, 15, 130, "Text",
      CellTags->{"i:30", "C.3"}],
    Cell[579727, 10117, 80, 1, 37, "Input",
      CellTags->"C.3"],
    Cell[579810, 10120, 162, 6, 42, "Text",
      CellTags->"C.3"],
    Cell[579975, 10128, 117, 4, 50, "Input",
      CellTags->"C.3"],
    Cell[580095, 10134, 175, 5, 40, "Text",
      CellTags->"C.3"],
    Cell[580273, 10141, 201, 6, 76, "Input",
      CellTags->"C.3"],
    Cell[580511, 10152, 65, 1, 30, "Subsubsection",
      CellTags->"C.3"],
    Cell[580579, 10155, 153, 4, 38, "Text",
      CellTags->"C.3"],
    Cell[580757, 10163, 275, 5, 89, "Input",
      CellTags->"C.3"],
    Cell[581035, 10170, 75, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[581125, 10175, 233, 5, 52, "Text",
      CellTags->"C.3"],
    Cell[581361, 10182, 562, 11, 110, "Text",
      CellTags->"C.3"],
    Cell[581948, 10197, 180, 3, 63, "Input",
      CellTags->"C.3"],
    Cell[582131, 10202, 65, 1, 38, "Print",
      CellTags->"C.3"],
    Cell[582199, 10205, 78, 2, 38, "Output",
      CellTags->"C.3"],
    Cell[582326, 10213, 68, 1, 30, "Subsubsection",
      CellTags->"C.3"],
    Cell[582397, 10216, 421, 8, 80, "Text",
      CellTags->{"i:31", "C.3"}],
    Cell[582821, 10226, 596, 9, 193, "Input",
      CellTags->"C.3"],
    Cell[583420, 10237, 170, 3, 63, "Input",
      CellTags->"C.3"],
    Cell[583593, 10242, 276, 6, 52, "Text",
      CellTags->"C.3"],
    Cell[583918, 10254, 78, 1, 40, "Subsection",
      CellTags->"C.3"],
    Cell[583999, 10257, 445, 8, 80, "Text",
      CellTags->{"i:32", "C.3"}],
    Cell[584447, 10267, 538, 9, 108, "Text",
      CellTags->{"i:33", "C.3"}],
    Cell[584988, 10278, 269, 6, 54, "Text",
      CellTags->"C.3"],
    Cell[585260, 10286, 141, 3, 50, "Input",
      CellTags->"C.3"],
    Cell[585404, 10291, 495, 9, 96, "Text",
      CellTags->"C.3"],
    Cell[585902, 10302, 546, 8, 193, "Input",
      CellTags->"C.3"],
    Cell[586451, 10312, 770, 13, 122, "Text",
      CellTags->{"i:34", "C.3"}],
    Cell[587246, 10329, 285, 5, 128, "Input",
      CellTags->"C.3"],
    Cell[587534, 10336, 57, 2, 38, "Output",
      CellTags->"C.3"]},
  "i:38"->{
    Cell[572328, 9870, 509, 9, 94, "Text",
      CellTags->{"i:38", "C.3"}]},
  "i:26"->{
    Cell[574005, 9921, 178, 4, 38, "Text",
      CellTags->{"i:26", "C.3"}]},
  "i:27"->{
    Cell[575287, 9973, 676, 11, 122, "Text",
      CellTags->{"i:27", "C.3"}]},
  "i:28"->{
    Cell[575966, 9986, 732, 20, 102, "Text",
      CellTags->{"i:28", "C.3"}]},
  "i:29"->{
    Cell[577306, 10037, 638, 14, 98, "Text",
      CellTags->{"i:29", "C.3"}]},
  "i:30"->{
    Cell[579029, 10100, 695, 15, 130, "Text",
      CellTags->{"i:30", "C.3"}]},
  "i:31"->{
    Cell[582397, 10216, 421, 8, 80, "Text",
      CellTags->{"i:31", "C.3"}]},
  "i:32"->{
    Cell[583999, 10257, 445, 8, 80, "Text",
      CellTags->{"i:32", "C.3"}]},
  "i:33"->{
    Cell[584447, 10267, 538, 9, 108, "Text",
      CellTags->{"i:33", "C.3"}]},
  "i:34"->{
    Cell[586451, 10312, 770, 13, 122, "Text",
      CellTags->{"i:34", "C.3"}]},
  "C.4"->{
    Cell[587652, 10345, 67, 1, 40, "Section",
      CellTags->"C.4"],
    Cell[587744, 10350, 94, 1, 40, "Subsection",
      CellTags->"C.4"],
    Cell[587841, 10353, 538, 9, 102, "Input",
      CellTags->{"i:35", "C.4"}],
    Cell[588382, 10364, 325, 8, 63, "Input",
      CellTags->"C.4"],
    Cell[588710, 10374, 328, 7, 63, "Input",
      CellTags->"C.4"],
    Cell[589041, 10383, 304, 6, 50, "Input",
      CellTags->"C.4"],
    Cell[589348, 10391, 819, 23, 258, "Input",
      CellTags->"C.4"],
    Cell[590204, 10419, 62, 1, 40, "Subsection",
      CellTags->"C.4"],
    Cell[590269, 10422, 2490, 41, 635, "Input",
      CellTags->"C.4"],
    Cell[592796, 10468, 61, 1, 40, "Subsection",
      CellTags->"C.4"],
    Cell[592860, 10471, 2500, 43, 635, "Input",
      CellTags->"C.4"],
    Cell[595397, 10519, 63, 1, 40, "Subsection",
      CellTags->"C.4"],
    Cell[595463, 10522, 2538, 43, 648, "Input",
      CellTags->"C.4"],
    Cell[598038, 10570, 64, 1, 40, "Subsection",
      CellTags->"C.4"],
    Cell[598105, 10573, 2707, 44, 700, "Input",
      CellTags->"C.4"],
    Cell[600849, 10622, 76, 1, 40, "Subsection",
      CellTags->"C.4"],
    Cell[600928, 10625, 226, 6, 50, "Input",
      CellTags->{"i:36", "C.4"}],
    Cell[601157, 10633, 378, 11, 115, "Input",
      CellTags->{"i:37", "C.4"}]},
  "i:35"->{
    Cell[587841, 10353, 538, 9, 102, "Input",
      CellTags->{"i:35", "C.4"}]},
  "i:36"->{
    Cell[600928, 10625, 226, 6, 50, "Input",
      CellTags->{"i:36", "C.4"}]},
  "i:37"->{
    Cell[601157, 10633, 378, 11, 115, "Input",
      CellTags->{"i:37", "C.4"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"C.0", 603448, 10689},
  {"C.1", 603658, 10696},
  {"i:1", 610037, 10877},
  {"i:2", 610121, 10880},
  {"i:3", 610206, 10883},
  {"i:4", 610294, 10886},
  {"i:5", 610381, 10889},
  {"i:6", 610467, 10892},
  {"i:7", 610553, 10895},
  {"i:8", 610641, 10898},
  {"i:9", 610729, 10901},
  {"i:10", 610817, 10904},
  {"i:11", 610908, 10907},
  {"i:12", 611000, 10910},
  {"i:13", 611090, 10913},
  {"i:14", 611181, 10916},
  {"i:15", 611271, 10919},
  {"i:16", 611361, 10922},
  {"i:17", 611451, 10925},
  {"i:18", 611541, 10928},
  {"i:19", 611633, 10931},
  {"C.2", 611723, 10934},
  {"i:20", 613450, 10983},
  {"i:21", 613541, 10986},
  {"i:22", 613631, 10989},
  {"i:23", 613723, 10992},
  {"i:24", 613813, 10995},
  {"i:25", 613903, 10998},
  {"C.3", 613993, 11001},
  {"i:38", 618313, 11124},
  {"i:26", 618403, 11127},
  {"i:27", 618493, 11130},
  {"i:28", 618585, 11133},
  {"i:29", 618677, 11136},
  {"i:30", 618769, 11139},
  {"i:31", 618862, 11142},
  {"i:32", 618953, 11145},
  {"i:33", 619044, 11148},
  {"i:34", 619136, 11151},
  {"C.4", 619228, 11154},
  {"i:35", 620555, 11191},
  {"i:36", 620648, 11194},
  {"i:37", 620740, 11197}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 52, 1, 92, "ChapterLine",
  CellTags->"C.0"],
Cell[1786, 54, 59, 1, 153, "Title",
  CellTags->"C.0"],
Cell[1848, 57, 668, 13, 110, "Text",
  CellTags->"C.0"],

Cell[CellGroupData[{
Cell[2541, 74, 51, 1, 40, "Section",
  CellTags->"C.1"],
Cell[2595, 77, 282, 8, 54, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[2902, 89, 59, 1, 40, "Subsection",
  CellTags->"C.1"],
Cell[2964, 92, 481, 8, 94, "Text",
  CellTags->{"i:1", "C.1"}],
Cell[3448, 102, 383, 7, 80, "Text",
  CellTags->{"i:2", "C.1"}],

Cell[CellGroupData[{
Cell[3856, 113, 294, 6, 89, "Input",
  CellTags->"C.1"],
Cell[4153, 121, 459, 10, 78, "Output",
  CellTags->"C.1"]
}, Open  ]],
Cell[4627, 134, 386, 7, 80, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[5038, 145, 131, 5, 63, "Input",
  CellTags->"C.1"],
Cell[5172, 152, 554, 13, 98, "Output",
  CellTags->"C.1"]
}, Open  ]],
Cell[5741, 168, 191, 5, 38, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[5957, 177, 212, 4, 76, "Input",
  CellTags->"C.1"],
Cell[6172, 183, 12013, 200, 159, 11869, 195, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[18200, 386, 415, 10, 68, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[18640, 400, 221, 4, 76, "Input",
  CellTags->"C.1"],
Cell[18864, 406, 11997, 200, 159, 11853, 195, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[30910, 612, 92, 1, 40, "Subsection",
  CellTags->"C.1"],
Cell[31005, 615, 701, 17, 112, "Text",
  CellTags->{"i:3", "C.1"}],
Cell[31709, 634, 410, 8, 82, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[32144, 646, 131, 4, 50, "Input",
  CellTags->"C.1"],
Cell[32278, 652, 1936, 35, 83, 1792, 30, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[34229, 690, 629, 13, 98, "Text",
  CellTags->{"i:4", "C.1"}],
Cell[34861, 705, 508, 24, 50, "Input",
  CellTags->"C.1"],
Cell[35372, 731, 430, 8, 80, "Text",
  CellTags->{"i:5", "C.1"}],

Cell[CellGroupData[{
Cell[35827, 743, 221, 4, 89, "Input",
  CellTags->"C.1"],
Cell[36051, 749, 7878, 132, 75, 7733, 127, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[43944, 884, 240, 5, 52, "Text",
  CellTags->{"i:6", "C.1"}],
Cell[44187, 891, 720, 15, 116, "Text",
  CellTags->{"i:7", "C.1"}],
Cell[44910, 908, 143, 4, 38, "Text",
  CellTags->"C.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45090, 917, 56, 1, 40, "Subsection",
  CellTags->"C.1"],
Cell[45149, 920, 597, 14, 100, "Text",
  CellTags->{"i:8", "C.1"}],
Cell[45749, 936, 466, 13, 70, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[46240, 953, 203, 4, 89, "Input",
  CellTags->"C.1"],
Cell[46446, 959, 7889, 133, 132, 7742, 128, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[54350, 1095, 408, 9, 68, "Text",
  CellTags->{"i:9", "C.1"}],

Cell[CellGroupData[{
Cell[54783, 1108, 228, 4, 89, "Input",
  CellTags->"C.1"],
Cell[55014, 1114, 66660, 1096, 132, 66513, 1091, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[121689, 2213, 309, 12, 40, "Text",
  CellTags->"C.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122035, 2230, 65, 1, 40, "Subsection",
  CellTags->"C.1"],
Cell[122103, 2233, 416, 11, 72, "Text",
  CellTags->{"i:10", "C.1"}],
Cell[122522, 2246, 47, 1, 37, "Input",
  CellTags->"C.1"],
Cell[122572, 2249, 276, 6, 52, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[122873, 2259, 60, 1, 30, "Subsubsection",
  CellTags->"C.1"],
Cell[122936, 2262, 692, 14, 126, "Text",
  CellTags->{"i:11", "C.1"}],
Cell[123631, 2278, 134, 4, 50, "Input",
  CellTags->"C.1"],
Cell[123768, 2284, 233, 5, 52, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[124026, 2293, 139, 3, 50, "Input",
  CellTags->"C.1"],
Cell[124168, 2298, 36831, 608, 181, 36660, 602, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[161014, 2909, 232, 5, 52, "Text",
  CellTags->{"i:12", "C.1"}],

Cell[CellGroupData[{
Cell[161271, 2918, 199, 4, 76, "Input",
  CellTags->"C.1"],
Cell[161473, 2924, 41949, 692, 181, 41776, 686, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[203437, 3619, 227, 5, 52, "Text",
  CellTags->"C.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203701, 3629, 54, 1, 30, "Subsubsection",
  CellTags->"C.1"],
Cell[203758, 3632, 598, 13, 98, "Text",
  CellTags->{"i:13", "C.1"}],

Cell[CellGroupData[{
Cell[204381, 3649, 246, 4, 89, "Input",
  CellTags->"C.1"],
Cell[204630, 3655, 34309, 566, 163, 34138, 560, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[238954, 4224, 269, 6, 52, "Text",
  CellTags->{"i:14", "C.1"}],
Cell[239226, 4232, 198, 5, 38, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[239449, 4241, 401, 6, 141, "Input",
  CellTags->"C.1"],
Cell[239853, 4249, 33634, 555, 163, 33463, 549, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[273536, 4810, 53, 1, 30, "Subsubsection",
  CellTags->"C.1"],
Cell[273592, 4813, 252, 5, 52, "Text",
  CellTags->{"i:15", "C.1"}],
Cell[273847, 4820, 440, 10, 82, "Text",
  CellTags->"C.1"],
Cell[274290, 4832, 212, 5, 63, "Input",
  CellTags->"C.1"],
Cell[274505, 4839, 89, 1, 24, "Text",
  CellTags->"C.1"],

Cell[CellGroupData[{
Cell[274619, 4844, 168, 3, 50, "Input",
  CellTags->"C.1"],
Cell[274790, 4849, 99867, 1641, 170, 99726, 1636, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]],
Cell[374672, 6493, 427, 8, 80, "Text",
  CellTags->{"i:16", "C.1"}],

Cell[CellGroupData[{
Cell[375124, 6505, 184, 3, 63, "Input",
  CellTags->"C.1"],
Cell[375311, 6510, 101272, 1664, 186, 101104, 1658, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[476644, 8181, 61, 1, 40, "Subsection",
  CellTags->"C.1"],
Cell[476708, 8184, 428, 8, 82, "Text",
  CellTags->{"i:17", "C.1"}],

Cell[CellGroupData[{
Cell[477161, 8196, 731, 11, 245, "Input",
  CellTags->"C.1"],
Cell[477895, 8209, 86616, 1424, 151, 86456, 1418, "GraphicsData", 
"Bitmap", "Graphics",
  Evaluatable->False,
  CellTags->"C.1"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[564560, 9639, 57, 1, 40, "Subsection",
  CellTags->"C.1"],
Cell[564620, 9642, 627, 13, 112, "Text",
  CellTags->{"i:18", "C.1"}],
Cell[565250, 9657, 500, 10, 82, "Text",
  CellTags->{"i:19", "C.1"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[565799, 9673, 79, 1, 40, "Section",
  CellTags->"C.2"],
Cell[565881, 9676, 613, 14, 98, "Text",
  CellTags->{"i:20", "C.2"}],
Cell[566497, 9692, 552, 11, 96, "Text",
  CellTags->"C.2"],

Cell[CellGroupData[{
Cell[567074, 9707, 67, 1, 30, "Subsubsection",
  CellTags->"C.2"],
Cell[567144, 9710, 434, 8, 82, "Text",
  CellTags->{"i:21", "C.2"}],
Cell[567581, 9720, 58, 1, 37, "Input",
  CellTags->"C.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[567676, 9726, 77, 1, 30, "Subsubsection",
  CellTags->"C.2"],
Cell[567756, 9729, 695, 13, 126, "Text",
  CellTags->{"i:22", "C.2"}],
Cell[568454, 9744, 133, 3, 50, "Input",
  CellTags->"C.2"],
Cell[568590, 9749, 305, 6, 54, "Text",
  CellTags->{"i:23", "C.2"}],
Cell[568898, 9757, 68, 1, 37, "Input",
  CellTags->"C.2"],
Cell[568969, 9760, 127, 4, 24, "Text",
  CellTags->"C.2"],
Cell[569099, 9766, 121, 4, 50, "Input",
  CellTags->"C.2"],
Cell[569223, 9772, 286, 6, 52, "Text",
  CellTags->"C.2"],
Cell[569512, 9780, 160, 5, 63, "Input",
  CellTags->"C.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569709, 9790, 58, 1, 30, "Subsubsection",
  CellTags->"C.2"],
Cell[569770, 9793, 338, 8, 54, "Text",
  CellTags->{"i:24", "C.2"}],
Cell[570111, 9803, 163, 6, 37, "Input",
  CellTags->"C.2"],
Cell[570277, 9811, 546, 10, 96, "Text",
  CellTags->{"i:25", "C.2"}],
Cell[570826, 9823, 495, 8, 154, "Input",
  CellTags->"C.2"],
Cell[571324, 9833, 223, 5, 52, "Text",
  CellTags->"C.2"],
Cell[571550, 9840, 180, 6, 76, "Input",
  CellTags->"C.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[571767, 9851, 53, 1, 30, "Subsubsection",
  CellTags->"C.2"],
Cell[571823, 9854, 381, 7, 80, "Text",
  CellTags->"C.2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[572253, 9867, 72, 1, 40, "Section",
  CellTags->"C.3"],
Cell[572328, 9870, 509, 9, 94, "Text",
  CellTags->{"i:38", "C.3"}],

Cell[CellGroupData[{
Cell[572862, 9883, 63, 1, 40, "Subsection",
  CellTags->"C.3"],
Cell[572928, 9886, 373, 7, 66, "Text",
  CellTags->"C.3"],
Cell[573304, 9895, 357, 10, 74, "Text",
  CellTags->"C.3"],
Cell[573664, 9907, 170, 5, 63, "Input",
  CellTags->"C.3"],
Cell[573837, 9914, 165, 5, 63, "Input",
  CellTags->"C.3"],
Cell[574005, 9921, 178, 4, 38, "Text",
  CellTags->{"i:26", "C.3"}],

Cell[CellGroupData[{
Cell[574208, 9929, 197, 6, 76, "Input",
  CellTags->"C.3"],
Cell[574408, 9937, 78, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]],
Cell[574501, 9942, 324, 8, 68, "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{
Cell[574850, 9954, 196, 6, 76, "Input",
  CellTags->"C.3"],
Cell[575049, 9962, 73, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]],
Cell[575137, 9967, 147, 4, 38, "Text",
  CellTags->"C.3"],
Cell[575287, 9973, 676, 11, 122, "Text",
  CellTags->{"i:27", "C.3"}],
Cell[575966, 9986, 732, 20, 102, "Text",
  CellTags->{"i:28", "C.3"}],

Cell[CellGroupData[{
Cell[576723, 10010, 60, 1, 37, "Input",
  CellTags->"C.3"],
Cell[576786, 10013, 92, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]],
Cell[576893, 10018, 185, 5, 38, "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{
Cell[577103, 10027, 118, 3, 50, "Input",
  CellTags->"C.3"],
Cell[577224, 10032, 67, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]],
Cell[577306, 10037, 638, 14, 98, "Text",
  CellTags->{"i:29", "C.3"}],

Cell[CellGroupData[{
Cell[577969, 10055, 201, 4, 76, "Input",
  CellTags->"C.3"],
Cell[578173, 10061, 53, 2, 38, "Print",
  CellTags->"C.3"],
Cell[578229, 10065, 53, 2, 38, "Print",
  CellTags->"C.3"],
Cell[578285, 10069, 53, 2, 38, "Print",
  CellTags->"C.3"],
Cell[578341, 10073, 53, 2, 38, "Print",
  CellTags->"C.3"],
Cell[578397, 10077, 53, 2, 38, "Print",
  CellTags->"C.3"],
Cell[578453, 10081, 67, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]],
Cell[578535, 10086, 392, 7, 80, "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{
Cell[578952, 10097, 74, 1, 30, "Subsubsection",
  CellTags->"C.3"],
Cell[579029, 10100, 695, 15, 130, "Text",
  CellTags->{"i:30", "C.3"}],
Cell[579727, 10117, 80, 1, 37, "Input",
  CellTags->"C.3"],
Cell[579810, 10120, 162, 6, 42, "Text",
  CellTags->"C.3"],
Cell[579975, 10128, 117, 4, 50, "Input",
  CellTags->"C.3"],
Cell[580095, 10134, 175, 5, 40, "Text",
  CellTags->"C.3"],
Cell[580273, 10141, 201, 6, 76, "Input",
  CellTags->"C.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[580511, 10152, 65, 1, 30, "Subsubsection",
  CellTags->"C.3"],
Cell[580579, 10155, 153, 4, 38, "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{
Cell[580757, 10163, 275, 5, 89, "Input",
  CellTags->"C.3"],
Cell[581035, 10170, 75, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]],
Cell[581125, 10175, 233, 5, 52, "Text",
  CellTags->"C.3"],
Cell[581361, 10182, 562, 11, 110, "Text",
  CellTags->"C.3"],

Cell[CellGroupData[{
Cell[581948, 10197, 180, 3, 63, "Input",
  CellTags->"C.3"],
Cell[582131, 10202, 65, 1, 38, "Print",
  CellTags->"C.3"],
Cell[582199, 10205, 78, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[582326, 10213, 68, 1, 30, "Subsubsection",
  CellTags->"C.3"],
Cell[582397, 10216, 421, 8, 80, "Text",
  CellTags->{"i:31", "C.3"}],
Cell[582821, 10226, 596, 9, 193, "Input",
  CellTags->"C.3"],
Cell[583420, 10237, 170, 3, 63, "Input",
  CellTags->"C.3"],
Cell[583593, 10242, 276, 6, 52, "Text",
  CellTags->"C.3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[583918, 10254, 78, 1, 40, "Subsection",
  CellTags->"C.3"],
Cell[583999, 10257, 445, 8, 80, "Text",
  CellTags->{"i:32", "C.3"}],
Cell[584447, 10267, 538, 9, 108, "Text",
  CellTags->{"i:33", "C.3"}],
Cell[584988, 10278, 269, 6, 54, "Text",
  CellTags->"C.3"],
Cell[585260, 10286, 141, 3, 50, "Input",
  CellTags->"C.3"],
Cell[585404, 10291, 495, 9, 96, "Text",
  CellTags->"C.3"],
Cell[585902, 10302, 546, 8, 193, "Input",
  CellTags->"C.3"],
Cell[586451, 10312, 770, 13, 122, "Text",
  CellTags->{"i:34", "C.3"}],

Cell[CellGroupData[{
Cell[587246, 10329, 285, 5, 128, "Input",
  CellTags->"C.3"],
Cell[587534, 10336, 57, 2, 38, "Output",
  CellTags->"C.3"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[587652, 10345, 67, 1, 40, "Section",
  CellTags->"C.4"],

Cell[CellGroupData[{
Cell[587744, 10350, 94, 1, 40, "Subsection",
  CellTags->"C.4"],
Cell[587841, 10353, 538, 9, 102, "Input",
  CellTags->{"i:35", "C.4"}],
Cell[588382, 10364, 325, 8, 63, "Input",
  CellTags->"C.4"],
Cell[588710, 10374, 328, 7, 63, "Input",
  CellTags->"C.4"],
Cell[589041, 10383, 304, 6, 50, "Input",
  CellTags->"C.4"],
Cell[589348, 10391, 819, 23, 258, "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[590204, 10419, 62, 1, 40, "Subsection",
  CellTags->"C.4"],
Cell[590269, 10422, 2490, 41, 635, "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[592796, 10468, 61, 1, 40, "Subsection",
  CellTags->"C.4"],
Cell[592860, 10471, 2500, 43, 635, "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[595397, 10519, 63, 1, 40, "Subsection",
  CellTags->"C.4"],
Cell[595463, 10522, 2538, 43, 648, "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[598038, 10570, 64, 1, 40, "Subsection",
  CellTags->"C.4"],
Cell[598105, 10573, 2707, 44, 700, "Input",
  CellTags->"C.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[600849, 10622, 76, 1, 40, "Subsection",
  CellTags->"C.4"],
Cell[600928, 10625, 226, 6, 50, "Input",
  CellTags->{"i:36", "C.4"}],
Cell[601157, 10633, 378, 11, 115, "Input",
  CellTags->{"i:37", "C.4"}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

